# Automatically generated by ./create_defs.grib2.mtg2.pl, do not edit
#Total precipitation of at least 1 mm
'Total precipitation of at least 1 mm' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 60 ;
	}
#Total precipitation of at least 5 mm
'Total precipitation of at least 5 mm' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 61 ;
	}
#Total precipitation of at least 40 mm
'Total precipitation of at least 40 mm' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 82 ;
	}
#Total precipitation of at least 60 mm
'Total precipitation of at least 60 mm' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 83 ;
	}
#Total precipitation of at least 80 mm
'Total precipitation of at least 80 mm' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 84 ;
	}
#Total precipitation of at least 100 mm
'Total precipitation of at least 100 mm' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 85 ;
	}
#Total precipitation of at least 150 mm
'Total precipitation of at least 150 mm' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 86 ;
	}
#Total precipitation of at least 200 mm
'Total precipitation of at least 200 mm' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 87 ;
	}
#Total precipitation of at least 300 mm
'Total precipitation of at least 300 mm' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 88 ;
	}
#Surface runoff
'Surface runoff' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 8 ;
	}
#Sub-surface runoff
'Sub-surface runoff' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 9 ;
	}
#UV visible albedo for direct radiation (climatological)
'UV visible albedo for direct radiation (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 15 ;
	}
#UV visible albedo for diffuse radiation (climatological)
'UV visible albedo for diffuse radiation (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 16 ;
	}
#Near IR albedo for direct radiation (climatological)
'Near IR albedo for direct radiation (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 17 ;
	}
#Near IR albedo for diffuse radiation (climatological)
'Near IR albedo for diffuse radiation (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 18 ;
	}
#Surface photosynthetically active radiation, clear sky
'Surface photosynthetically active radiation, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 20 ;
	}
#Unbalanced component of temperature
'Unbalanced component of temperature' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 21 ;
	}
#Unbalanced component of logarithm of surface pressure
'Unbalanced component of logarithm of surface pressure' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 22 ;
	}
#Unbalanced component of divergence
'Unbalanced component of divergence' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 23 ;
	}
#Lake cover
'Lake cover' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 26 ;
	}
#Low vegetation cover
'Low vegetation cover' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 27 ;
	}
#High vegetation cover
'High vegetation cover' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 28 ;
	}
#Type of low vegetation
'Type of low vegetation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 29 ;
	}
#Type of high vegetation
'Type of high vegetation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 30 ;
	}
#Sea ice area fraction
'Sea ice area fraction' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 31 ;
	}
#Snow albedo
'Snow albedo' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 32 ;
	}
#Snow density
'Snow density' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 33 ;
	}
#Sea surface temperature
'Sea surface temperature' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 34 ;
	}
#Snow evaporation
'Snow evaporation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 44 ;
	}
#Snowmelt
'Snowmelt' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 45 ;
	}
#Surface direct normal short-wave (solar) radiation
'Surface direct normal short-wave (solar) radiation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 47 ;
	}
#Time-integrated magnitude of turbulent surface stress
'Time-integrated magnitude of turbulent surface stress' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 48 ;
	}
#Large-scale precipitation fraction
'Large-scale precipitation fraction' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 50 ;
	}
#Montgomery potential
'Montgomery potential' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 53 ;
	}
#Mean temperature at 2 metres in the last 24 hours
'Mean temperature at 2 metres in the last 24 hours' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 55 ;
	}
#Mean 2 metre dewpoint temperature in the last 24 hours
'Mean 2 metre dewpoint temperature in the last 24 hours' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 56 ;
	}
#Surface downward UV radiation
'Surface downward UV radiation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 57 ;
	}
#Photosynthetically active radiation at the surface
'Photosynthetically active radiation at the surface' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 58 ;
	}
#Leaf area index, low vegetation
'Leaf area index, low vegetation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 66 ;
	}
#Leaf area index, high vegetation
'Leaf area index, high vegetation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 67 ;
	}
#Standard deviation of filtered subgrid orography (climatological)
'Standard deviation of filtered subgrid orography (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 74 ;
	}
#Total column cloud liquid water
'Total column cloud liquid water' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 78 ;
	}
#Total column cloud ice water
'Total column cloud ice water' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 79 ;
	}
#Surface emissivity
'Surface emissivity' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 124 ;
	}
#Total column vertically-integrated water vapour
'Total column vertically-integrated water vapour' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 137 ;
	}
#Large-scale precipitation
'Large-scale precipitation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 142 ;
	}
#Snowfall
'Snowfall' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 144 ;
	}
#Charnock
'Charnock' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 148 ;
	}
#Surface net radiation (SW and LW)
'Surface net radiation (SW and LW)' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 149 ;
	}
#Top net radiation (SW and LW)
'Top net radiation (SW and LW)' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 150 ;
	}
#Boundary layer height
'Boundary layer height' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 159 ;
	}
#Standard deviation of sub-gridscale orography
'Standard deviation of sub-gridscale orography' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 160 ;
	}
#Anisotropy of sub-gridscale orography
'Anisotropy of sub-gridscale orography' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 161 ;
	}
#Angle of sub-gridscale orography
'Angle of sub-gridscale orography' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 162 ;
	}
#Slope of sub-gridscale orography
'Slope of sub-gridscale orography' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 163 ;
	}
#Total cloud cover
'Total cloud cover' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 164 ;
	}
#Surface short-wave (solar) radiation downwards
'Surface short-wave (solar) radiation downwards' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 169 ;
	}
#Albedo (climatological)
'Albedo (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 174 ;
	}
#Surface long-wave (thermal) radiation downwards
'Surface long-wave (thermal) radiation downwards' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 175 ;
	}
#Top net short-wave (solar) radiation
'Top net short-wave (solar) radiation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 178 ;
	}
#Time-integrated eastward turbulent surface stress
'Time-integrated eastward turbulent surface stress' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 180 ;
	}
#Time-integrated northward turbulent surface stress
'Time-integrated northward turbulent surface stress' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 181 ;
	}
#Evaporation
'Evaporation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 182 ;
	}
#Low cloud cover
'Low cloud cover' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 186 ;
	}
#Medium cloud cover
'Medium cloud cover' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 187 ;
	}
#High cloud cover
'High cloud cover' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 188 ;
	}
#Eastward gravity wave surface stress
'Eastward gravity wave surface stress' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 195 ;
	}
#Northward gravity wave surface stress
'Northward gravity wave surface stress' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 196 ;
	}
#Gravity wave dissipation
'Gravity wave dissipation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 197 ;
	}
#Skin reservoir content
'Skin reservoir content' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 198 ;
	}
#Runoff
'Runoff' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 205 ;
	}
#Total column ozone
'Total column ozone' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 206 ;
	}
#Top net short-wave (solar) radiation, clear sky
'Top net short-wave (solar) radiation, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 208 ;
	}
#Top net long-wave (thermal) radiation, clear sky
'Top net long-wave (thermal) radiation, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 209 ;
	}
#Surface net short-wave (solar) radiation, clear sky
'Surface net short-wave (solar) radiation, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 210 ;
	}
#Surface net long-wave (thermal) radiation, clear sky
'Surface net long-wave (thermal) radiation, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 211 ;
	}
#TOA incident short-wave (solar) radiation
'TOA incident short-wave (solar) radiation' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 212 ;
	}
#Vertically integrated moisture divergence
'Vertically integrated moisture divergence' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 213 ;
	}
#Instantaneous eastward turbulent surface stress
'Instantaneous eastward turbulent surface stress' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 229 ;
	}
#Instantaneous northward turbulent surface stress
'Instantaneous northward turbulent surface stress' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 230 ;
	}
#Instantaneous surface sensible heat net flux
'Instantaneous surface sensible heat net flux' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 231 ;
	}
#Instantaneous moisture flux
'Instantaneous moisture flux' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 232 ;
	}
#Logarithm of surface roughness length for heat (climatological)
'Logarithm of surface roughness length for heat (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 234 ;
	}
#Temperature of snow layer
'Temperature of snow layer' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 238 ;
	}
#Convective snowfall
'Convective snowfall' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 239 ;
	}
#Large-scale snowfall
'Large-scale snowfall' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 240 ;
	}
#Forecast albedo
'Forecast albedo' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 243 ;
	}
#Forecast surface roughness
'Forecast surface roughness' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 244 ;
	}
#Forecast logarithm of surface roughness for heat
'Forecast logarithm of surface roughness for heat' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 245 ;
	}
#Mean surface net radiation flux
'Mean surface net radiation flux' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 149 ;
	}
#Injection height (from IS4FIRES)
'Injection height (from IS4FIRES)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 60 ;
	}
#Particulate matter d <= 1 um
'Particulate matter d <= 1 um' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 72 ;
	}
#Particulate matter d <= 2.5 um
'Particulate matter d <= 2.5 um' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 73 ;
	}
#Particulate matter d <= 10 um
'Particulate matter d <= 10 um' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 74 ;
	}
#Mean height of maximum injection
'Mean height of maximum injection' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 119 ;
	}
#Plume top height above surface
'Plume top height above surface' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 120 ;
	}
#UV visible albedo for direct radiation, isotropic component (climatological)
'UV visible albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 186 ;
	}
#UV visible albedo for direct radiation, volumetric component (climatological)
'UV visible albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 187 ;
	}
#UV visible albedo for direct radiation, geometric component (climatological)
'UV visible albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 188 ;
	}
#Near IR albedo for direct radiation, isotropic component (climatological)
'Near IR albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 189 ;
	}
#Near IR albedo for direct radiation, volumetric component (climatological)
'Near IR albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 190 ;
	}
#Near IR albedo for direct radiation, geometric component (climatological)
'Near IR albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 191 ;
	}
#UV visible albedo for diffuse radiation, isotropic component (climatological)
'UV visible albedo for diffuse radiation, isotropic component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 192 ;
	}
#UV visible albedo for diffuse radiation, volumetric component (climatological)
'UV visible albedo for diffuse radiation, volumetric component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 193 ;
	}
#UV visible albedo for diffuse radiation, geometric component (climatological)
'UV visible albedo for diffuse radiation, geometric component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 194 ;
	}
#Near IR albedo for diffuse radiation, isotropic component (climatological)
'Near IR albedo for diffuse radiation, isotropic component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 195 ;
	}
#Near IR albedo for diffuse radiation, volumetric component (climatological)
'Near IR albedo for diffuse radiation, volumetric component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 196 ;
	}
#Near IR albedo for diffuse radiation, geometric component (climatological)
'Near IR albedo for diffuse radiation, geometric component (climatological)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 197 ;
	}
#Plume bottom height above surface
'Plume bottom height above surface' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 242 ;
	}
#Random pattern 1 for SPP scheme
'Random pattern 1 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 101 ;
	}
#Random pattern 2 for SPP scheme
'Random pattern 2 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 102 ;
	}
#Random pattern 3 for SPP scheme
'Random pattern 3 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 103 ;
	}
#Random pattern 4 for SPP scheme
'Random pattern 4 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 104 ;
	}
#Random pattern 5 for SPP scheme
'Random pattern 5 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 105 ;
	}
#Random pattern 6 for SPP scheme
'Random pattern 6 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 106 ;
	}
#Random pattern 7 for SPP scheme
'Random pattern 7 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 107 ;
	}
#Random pattern 8 for SPP scheme
'Random pattern 8 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 108 ;
	}
#Random pattern 9 for SPP scheme
'Random pattern 9 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 109 ;
	}
#Random pattern 10 for SPP scheme
'Random pattern 10 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 110 ;
	}
#Random pattern 11 for SPP scheme
'Random pattern 11 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 111 ;
	}
#Random pattern 12 for SPP scheme
'Random pattern 12 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 112 ;
	}
#Random pattern 13 for SPP scheme
'Random pattern 13 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 113 ;
	}
#Random pattern 14 for SPP scheme
'Random pattern 14 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 114 ;
	}
#Random pattern 15 for SPP scheme
'Random pattern 15 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 115 ;
	}
#Random pattern 16 for SPP scheme
'Random pattern 16 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 116 ;
	}
#Random pattern 17 for SPP scheme
'Random pattern 17 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 117 ;
	}
#Random pattern 18 for SPP scheme
'Random pattern 18 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 118 ;
	}
#Random pattern 19 for SPP scheme
'Random pattern 19 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 119 ;
	}
#Random pattern 20 for SPP scheme
'Random pattern 20 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 120 ;
	}
#Random pattern 21 for SPP scheme
'Random pattern 21 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 121 ;
	}
#Random pattern 22 for SPP scheme
'Random pattern 22 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 122 ;
	}
#Random pattern 23 for SPP scheme
'Random pattern 23 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 123 ;
	}
#Random pattern 24 for SPP scheme
'Random pattern 24 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 124 ;
	}
#Random pattern 25 for SPP scheme
'Random pattern 25 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 125 ;
	}
#Random pattern 26 for SPP scheme
'Random pattern 26 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 126 ;
	}
#Random pattern 27 for SPP scheme
'Random pattern 27 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 127 ;
	}
#Random pattern 28 for SPP scheme
'Random pattern 28 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 128 ;
	}
#Random pattern 29 for SPP scheme
'Random pattern 29 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 129 ;
	}
#Random pattern 30 for SPP scheme
'Random pattern 30 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 130 ;
	}
#Random pattern 31 for SPP scheme
'Random pattern 31 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 131 ;
	}
#Random pattern 32 for SPP scheme
'Random pattern 32 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 132 ;
	}
#Random pattern 33 for SPP scheme
'Random pattern 33 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 133 ;
	}
#Random pattern 34 for SPP scheme
'Random pattern 34 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 134 ;
	}
#Random pattern 35 for SPP scheme
'Random pattern 35 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 135 ;
	}
#Random pattern 36 for SPP scheme
'Random pattern 36 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 136 ;
	}
#Random pattern 37 for SPP scheme
'Random pattern 37 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 137 ;
	}
#Random pattern 38 for SPP scheme
'Random pattern 38 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 138 ;
	}
#Random pattern 39 for SPP scheme
'Random pattern 39 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 139 ;
	}
#Random pattern 40 for SPP scheme
'Random pattern 40 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 140 ;
	}
#Random pattern 41 for SPP scheme
'Random pattern 41 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 141 ;
	}
#Random pattern 42 for SPP scheme
'Random pattern 42 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 142 ;
	}
#Random pattern 43 for SPP scheme
'Random pattern 43 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 143 ;
	}
#Random pattern 44 for SPP scheme
'Random pattern 44 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 144 ;
	}
#Random pattern 45 for SPP scheme
'Random pattern 45 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 145 ;
	}
#Random pattern 46 for SPP scheme
'Random pattern 46 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 146 ;
	}
#Random pattern 47 for SPP scheme
'Random pattern 47 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 147 ;
	}
#Random pattern 48 for SPP scheme
'Random pattern 48 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 148 ;
	}
#Random pattern 49 for SPP scheme
'Random pattern 49 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 149 ;
	}
#Random pattern 50 for SPP scheme
'Random pattern 50 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 150 ;
	}
#Random pattern 51 for SPP scheme
'Random pattern 51 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 151 ;
	}
#Random pattern 52 for SPP scheme
'Random pattern 52 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 152 ;
	}
#Random pattern 53 for SPP scheme
'Random pattern 53 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 153 ;
	}
#Random pattern 54 for SPP scheme
'Random pattern 54 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 154 ;
	}
#Random pattern 55 for SPP scheme
'Random pattern 55 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 155 ;
	}
#Random pattern 56 for SPP scheme
'Random pattern 56 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 156 ;
	}
#Random pattern 57 for SPP scheme
'Random pattern 57 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 157 ;
	}
#Random pattern 58 for SPP scheme
'Random pattern 58 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 158 ;
	}
#Random pattern 59 for SPP scheme
'Random pattern 59 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 159 ;
	}
#Random pattern 60 for SPP scheme
'Random pattern 60 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 160 ;
	}
#Random pattern 61 for SPP scheme
'Random pattern 61 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 161 ;
	}
#Random pattern 62 for SPP scheme
'Random pattern 62 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 162 ;
	}
#Random pattern 63 for SPP scheme
'Random pattern 63 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 163 ;
	}
#Random pattern 64 for SPP scheme
'Random pattern 64 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 164 ;
	}
#Random pattern 65 for SPP scheme
'Random pattern 65 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 165 ;
	}
#Random pattern 66 for SPP scheme
'Random pattern 66 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 166 ;
	}
#Random pattern 67 for SPP scheme
'Random pattern 67 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 167 ;
	}
#Random pattern 68 for SPP scheme
'Random pattern 68 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 168 ;
	}
#Random pattern 69 for SPP scheme
'Random pattern 69 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 169 ;
	}
#Random pattern 70 for SPP scheme
'Random pattern 70 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 170 ;
	}
#Random pattern 71 for SPP scheme
'Random pattern 71 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 171 ;
	}
#Random pattern 72 for SPP scheme
'Random pattern 72 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 172 ;
	}
#Random pattern 73 for SPP scheme
'Random pattern 73 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 173 ;
	}
#Random pattern 74 for SPP scheme
'Random pattern 74 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 174 ;
	}
#Random pattern 75 for SPP scheme
'Random pattern 75 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 175 ;
	}
#Random pattern 76 for SPP scheme
'Random pattern 76 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 176 ;
	}
#Random pattern 77 for SPP scheme
'Random pattern 77 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 177 ;
	}
#Random pattern 78 for SPP scheme
'Random pattern 78 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 178 ;
	}
#Random pattern 79 for SPP scheme
'Random pattern 79 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 179 ;
	}
#Random pattern 80 for SPP scheme
'Random pattern 80 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 180 ;
	}
#Random pattern 81 for SPP scheme
'Random pattern 81 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 181 ;
	}
#Random pattern 82 for SPP scheme
'Random pattern 82 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 182 ;
	}
#Random pattern 83 for SPP scheme
'Random pattern 83 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 183 ;
	}
#Random pattern 84 for SPP scheme
'Random pattern 84 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 184 ;
	}
#Random pattern 85 for SPP scheme
'Random pattern 85 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 185 ;
	}
#Random pattern 86 for SPP scheme
'Random pattern 86 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 186 ;
	}
#Random pattern 87 for SPP scheme
'Random pattern 87 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 187 ;
	}
#Random pattern 88 for SPP scheme
'Random pattern 88 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 188 ;
	}
#Random pattern 89 for SPP scheme
'Random pattern 89 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 189 ;
	}
#Random pattern 90 for SPP scheme
'Random pattern 90 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 190 ;
	}
#Random pattern 91 for SPP scheme
'Random pattern 91 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 191 ;
	}
#Random pattern 92 for SPP scheme
'Random pattern 92 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 192 ;
	}
#Random pattern 93 for SPP scheme
'Random pattern 93 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 193 ;
	}
#Random pattern 94 for SPP scheme
'Random pattern 94 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 194 ;
	}
#Random pattern 95 for SPP scheme
'Random pattern 95 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 195 ;
	}
#Random pattern 96 for SPP scheme
'Random pattern 96 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 196 ;
	}
#Random pattern 97 for SPP scheme
'Random pattern 97 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 197 ;
	}
#Random pattern 98 for SPP scheme
'Random pattern 98 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 198 ;
	}
#Random pattern 99 for SPP scheme
'Random pattern 99 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 199 ;
	}
#Random pattern 100 for SPP scheme
'Random pattern 100 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 200 ;
	}
#Random pattern 101 for SPP scheme
'Random pattern 101 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 201 ;
	}
#Random pattern 102 for SPP scheme
'Random pattern 102 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 202 ;
	}
#Random pattern 103 for SPP scheme
'Random pattern 103 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 203 ;
	}
#Random pattern 104 for SPP scheme
'Random pattern 104 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 204 ;
	}
#Random pattern 105 for SPP scheme
'Random pattern 105 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 205 ;
	}
#Random pattern 106 for SPP scheme
'Random pattern 106 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 206 ;
	}
#Random pattern 107 for SPP scheme
'Random pattern 107 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 207 ;
	}
#Random pattern 108 for SPP scheme
'Random pattern 108 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 208 ;
	}
#Random pattern 109 for SPP scheme
'Random pattern 109 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 209 ;
	}
#Random pattern 110 for SPP scheme
'Random pattern 110 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 210 ;
	}
#Random pattern 111 for SPP scheme
'Random pattern 111 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 211 ;
	}
#Random pattern 112 for SPP scheme
'Random pattern 112 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 212 ;
	}
#Random pattern 113 for SPP scheme
'Random pattern 113 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 213 ;
	}
#Random pattern 114 for SPP scheme
'Random pattern 114 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 214 ;
	}
#Random pattern 115 for SPP scheme
'Random pattern 115 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 215 ;
	}
#Random pattern 116 for SPP scheme
'Random pattern 116 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 216 ;
	}
#Random pattern 117 for SPP scheme
'Random pattern 117 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 217 ;
	}
#Random pattern 118 for SPP scheme
'Random pattern 118 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 218 ;
	}
#Random pattern 119 for SPP scheme
'Random pattern 119 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 219 ;
	}
#Random pattern 120 for SPP scheme
'Random pattern 120 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 220 ;
	}
#Random pattern 121 for SPP scheme
'Random pattern 121 for SPP scheme' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 221 ;
	}
#Cosine of solar zenith angle
'Cosine of solar zenith angle' = {
	 discipline = 192 ;
	 parameterCategory = 214 ;
	 parameterNumber = 1 ;
	}
#UV biologically effective dose
'UV biologically effective dose' = {
	 discipline = 192 ;
	 parameterCategory = 214 ;
	 parameterNumber = 2 ;
	}
#UV biologically effective dose clear-sky
'UV biologically effective dose clear-sky' = {
	 discipline = 192 ;
	 parameterCategory = 214 ;
	 parameterNumber = 3 ;
	}
#Ammonia mass mixing ratio
'Ammonia mass mixing ratio' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 19 ;
	}
#Nitrogen monoxide mass mixing ratio
'Nitrogen monoxide mass mixing ratio' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 27 ;
	}
#Surface direct short-wave (solar) radiation
'Surface direct short-wave (solar) radiation' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 21 ;
	}
#Surface direct short-wave radiation, clear sky
'Surface direct short-wave radiation, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 22 ;
	}
#Cloud base height
'Cloud base height' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 23 ;
	}
#Geometric height of 0 degrees C atmospheric isothermal level above ground
'Geometric height of 0 degrees C atmospheric isothermal level above ground' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 24 ;
	}
#Maximum 10 metre wind gust in the last 3 hours
'Maximum 10 metre wind gust in the last 3 hours' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 28 ;
	}
#Height of zero-degree wet-bulb temperature
'Height of zero-degree wet-bulb temperature' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 47 ;
	}
#Height of one-degree wet-bulb temperature
'Height of one-degree wet-bulb temperature' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 48 ;
	}
#Instantaneous total lightning flash density
'Instantaneous total lightning flash density' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 50 ;
	}
#Averaged total lightning flash density in the last hour
'Averaged total lightning flash density in the last hour' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 51 ;
	}
#Instantaneous cloud-to-ground lightning flash density
'Instantaneous cloud-to-ground lightning flash density' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 52 ;
	}
#Averaged cloud-to-ground lightning flash density in the last hour
'Averaged cloud-to-ground lightning flash density in the last hour' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 53 ;
	}
#Averaged total lightning flash density in the last 3 hours
'Averaged total lightning flash density in the last 3 hours' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 57 ;
	}
#Averaged total lightning flash density in the last 6 hours
'Averaged total lightning flash density in the last 6 hours' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 58 ;
	}
#Averaged cloud-to-ground lightning flash density in the last 3 hours
'Averaged cloud-to-ground lightning flash density in the last 3 hours' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 59 ;
	}
#Averaged cloud-to-ground lightning flash density in the last 6 hours
'Averaged cloud-to-ground lightning flash density in the last 6 hours' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 60 ;
	}
#Accumulated Carbon Dioxide Net Ecosystem Exchange
'Accumulated Carbon Dioxide Net Ecosystem Exchange' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Gross Primary Production
'Accumulated Carbon Dioxide Gross Primary Production' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Ecosystem Respiration
'Accumulated Carbon Dioxide Ecosystem Respiration' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Carbon dioxide net ecosystem exchange flux
'Carbon dioxide net ecosystem exchange flux' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}
#Carbon dioxide gross primary production flux
'Carbon dioxide gross primary production flux' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}
#Carbon dioxide ecosystem respiration flux
'Carbon dioxide ecosystem respiration flux' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}
#Total column rain water
'Total column rain water' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 89 ;
	}
#Total column snow water
'Total column snow water' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 90 ;
	}
#Ice temperature
'Ice temperature' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 94 ;
	}
#Surface short-wave (solar) radiation downward clear-sky
'Surface short-wave (solar) radiation downward clear-sky' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 129 ;
	}
#Surface long-wave (thermal) radiation downward clear-sky
'Surface long-wave (thermal) radiation downward clear-sky' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 130 ;
	}
#100 metre wind speed
'100 metre wind speed' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 249 ;
	}
#Potential evaporation
'Potential evaporation' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 251 ;
	}
#Volume-mean total column mixing ratio
'Volume-mean total column mixing ratio' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	}
#Emission mass flux from vegetation
'Emission mass flux from vegetation' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 192 ;
	}
#Emission mass flux from biomass burning
'Emission mass flux from biomass burning' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 193 ;
	}
#Emission mass flux from settlements
'Emission mass flux from settlements' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 194 ;
	}
#Emission mass flux from soil
'Emission mass flux from soil' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 195 ;
	}
#Emission mass flux from wild animals
'Emission mass flux from wild animals' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 196 ;
	}
#Emission mass flux from commercial buildings heating
'Emission mass flux from commercial buildings heating' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 197 ;
	}
#Emission mass flux from residential heating
'Emission mass flux from residential heating' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 198 ;
	}
#Emission mass flux from oil refineries and transformation industry
'Emission mass flux from oil refineries and transformation industry' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 199 ;
	}
#Emission mass flux from gas production
'Emission mass flux from gas production' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 200 ;
	}
#Mean 2 metre temperature in the last 24 hours gradient
'Mean 2 metre temperature in the last 24 hours gradient' = {
	 discipline = 192 ;
	 parameterCategory = 129 ;
	 parameterNumber = 55 ;
	}
#Mean 2 metre dewpoint temperature in the last 24 hours gradient
'Mean 2 metre dewpoint temperature in the last 24 hours gradient' = {
	 discipline = 192 ;
	 parameterCategory = 129 ;
	 parameterNumber = 56 ;
	}
#Mean vertical velocity
'Mean vertical velocity' = {
	 discipline = 192 ;
	 parameterCategory = 130 ;
	 parameterNumber = 232 ;
	}
#Total precipitation less than 0.1 mm
'Total precipitation less than 0.1 mm' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 64 ;
	}
#Total precipitation rate less than 1 mm/day
'Total precipitation rate less than 1 mm/day' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 65 ;
	}
#Total precipitation rate of at least 3 mm/day
'Total precipitation rate of at least 3 mm/day' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 66 ;
	}
#Total precipitation rate of at least 5 mm/day
'Total precipitation rate of at least 5 mm/day' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 67 ;
	}
#10 metre Wind speed of at least 10 m/s
'10 metre Wind speed of at least 10 m/s' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 68 ;
	}
#10 metre Wind speed of at least 15 m/s
'10 metre Wind speed of at least 15 m/s' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 69 ;
	}
#2 metre temperature less than 273.15 K
'2 metre temperature less than 273.15 K' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 73 ;
	}
#Period corresponding to maximum individual wave height
'Period corresponding to maximum individual wave height' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 217 ;
	}
#Envelop-maximum individual wave height
'Envelop-maximum individual wave height' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 218 ;
	}
#Model bathymetry
'Model bathymetry' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 219 ;
	}
#Mean wave period based on first moment
'Mean wave period based on first moment' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 220 ;
	}
#Mean zero-crossing wave period
'Mean zero-crossing wave period' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 221 ;
	}
#Wave spectral directional width
'Wave spectral directional width' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 222 ;
	}
#Mean wave period based on first moment for wind waves
'Mean wave period based on first moment for wind waves' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 223 ;
	}
#Mean wave period based on second moment for wind waves
'Mean wave period based on second moment for wind waves' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 224 ;
	}
#Wave spectral directional width for wind waves
'Wave spectral directional width for wind waves' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 225 ;
	}
#Mean wave period based on first moment for swell
'Mean wave period based on first moment for swell' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 226 ;
	}
#Mean wave period based on second moment for swell
'Mean wave period based on second moment for swell' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 227 ;
	}
#Wave spectral directional width for swell
'Wave spectral directional width for swell' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 228 ;
	}
#Peak wave period
'Peak wave period' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 231 ;
	}
#Coefficient of drag with waves
'Coefficient of drag with waves' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 233 ;
	}
#Mean direction of wind waves
'Mean direction of wind waves' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 235 ;
	}
#Significant height of total swell
'Significant height of total swell' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 237 ;
	}
#Mean direction of total swell
'Mean direction of total swell' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 238 ;
	}
#Mean period of total swell
'Mean period of total swell' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 239 ;
	}
#Standard deviation wave height
'Standard deviation wave height' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 240 ;
	}
#Mean of 10 metre wind speed
'Mean of 10 metre wind speed' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 241 ;
	}
#Mean wind direction
'Mean wind direction' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 242 ;
	}
#Standard deviation of 10 metre wind speed
'Standard deviation of 10 metre wind speed' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 243 ;
	}
#Mean square slope of waves
'Mean square slope of waves' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 244 ;
	}
#10 metre wind speed
'10 metre wind speed' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 245 ;
	}
#Altimeter wave height
'Altimeter wave height' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 246 ;
	}
#Altimeter corrected wave height
'Altimeter corrected wave height' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 247 ;
	}
#Altimeter range relative correction
'Altimeter range relative correction' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 248 ;
	}
#10 metre wind direction
'10 metre wind direction' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 249 ;
	}
#2D wave spectra (single)
'2D wave spectra (single)' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 251 ;
	}
#Wave spectral kurtosis
'Wave spectral kurtosis' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 252 ;
	}
#Benjamin-Feir index
'Benjamin-Feir index' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 253 ;
	}
#Wave spectral peakedness
'Wave spectral peakedness' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 254 ;
	}
#Sea water potential temperature
'Sea water potential temperature' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 129 ;
	}
#Sea water practical salinity
'Sea water practical salinity' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 130 ;
	}
#Eastward surface sea water velocity
'Eastward surface sea water velocity' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 131 ;
	}
#Northward surface sea water velocity
'Northward surface sea water velocity' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 132 ;
	}
#Upward sea water velocity
'Upward sea water velocity' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 133 ;
	}
#Sea water sigma theta
'Sea water sigma theta' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 138 ;
	}
#Sea surface height
'Sea surface height' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 145 ;
	}
#Surface downward eastward stress
'Surface downward eastward stress' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 153 ;
	}
#Surface downward northward stress
'Surface downward northward stress' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 154 ;
	}
#Depth of 20C isotherm
'Depth of 20C isotherm' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 163 ;
	}
#Average sea water practical salinity in the upper 300m
'Average sea water practical salinity in the upper 300m' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 175 ;
	}
#Skin reservoir content
'Skin reservoir content' = {
	 discipline = 192 ;
	 parameterCategory = 160 ;
	 parameterNumber = 198 ;
	}
#Surface geopotential
'Surface geopotential' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 51 ;
	}
#Total column vertically-integrated mass of atmosphere
'Total column vertically-integrated mass of atmosphere' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 53 ;
	}
#Total column vertically-integrated temperature
'Total column vertically-integrated temperature' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 54 ;
	}
#Total column vertically-integrated water vapour
'Total column vertically-integrated water vapour' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 55 ;
	}
#Total column vertically-integrated cloud liquid water
'Total column vertically-integrated cloud liquid water' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 56 ;
	}
#Total column vertically-integrated cloud frozen water
'Total column vertically-integrated cloud frozen water' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 57 ;
	}
#Total column vertically-integrated ozone
'Total column vertically-integrated ozone' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 58 ;
	}
#Total column vertically-integrated kinetic energy
'Total column vertically-integrated kinetic energy' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 59 ;
	}
#Total column vertically-integrated enthalpy
'Total column vertically-integrated enthalpy' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 60 ;
	}
#Total column vertically-integrated potential + internal energy
'Total column vertically-integrated potential + internal energy' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 61 ;
	}
#Total column vertically-integrated potential+internal+latent energy
'Total column vertically-integrated potential+internal+latent energy' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 62 ;
	}
#Total column vertically-integrated total energy
'Total column vertically-integrated total energy' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 63 ;
	}
#Total column vertically-integrated energy conversion
'Total column vertically-integrated energy conversion' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 64 ;
	}
#Total column vertically-integrated eastward mass flux
'Total column vertically-integrated eastward mass flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 65 ;
	}
#Total column vertically-integrated northward mass flux
'Total column vertically-integrated northward mass flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 66 ;
	}
#Total column vertically-integrated eastward kinetic energy flux
'Total column vertically-integrated eastward kinetic energy flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 67 ;
	}
#Total column vertically-integrated northward kinetic energy flux
'Total column vertically-integrated northward kinetic energy flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 68 ;
	}
#Total column vertically-integrated eastward heat flux
'Total column vertically-integrated eastward heat flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 69 ;
	}
#Total column vertically-integrated northward heat flux
'Total column vertically-integrated northward heat flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 70 ;
	}
#Total column vertically-integrated eastward water vapour flux
'Total column vertically-integrated eastward water vapour flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 71 ;
	}
#Total column vertically-integrated northward water vapour flux
'Total column vertically-integrated northward water vapour flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 72 ;
	}
#Total column vertically-integrated eastward geopotential flux
'Total column vertically-integrated eastward geopotential flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 73 ;
	}
#Total column vertically-integrated northward geopotential flux
'Total column vertically-integrated northward geopotential flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 74 ;
	}
#Total column vertically-integrated eastward total energy flux
'Total column vertically-integrated eastward total energy flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 75 ;
	}
#Total column vertically-integrated northward total energy flux
'Total column vertically-integrated northward total energy flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 76 ;
	}
#Total column vertically-integrated eastward ozone flux
'Total column vertically-integrated eastward ozone flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 77 ;
	}
#Total column vertically-integrated northward ozone flux
'Total column vertically-integrated northward ozone flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 78 ;
	}
#Total column vertically-integrated divergence of mass flux
'Total column vertically-integrated divergence of mass flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 81 ;
	}
#Total column vertically-integrated divergence of kinetic energy flux
'Total column vertically-integrated divergence of kinetic energy flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 82 ;
	}
#Total column vertically-integrated divergence of thermal energy flux
'Total column vertically-integrated divergence of thermal energy flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 83 ;
	}
#Total column vertically-integrated moisture divergence flux
'Total column vertically-integrated moisture divergence flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 84 ;
	}
#Total column vertically-integrated divergence of geopotential flux
'Total column vertically-integrated divergence of geopotential flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 85 ;
	}
#Total column vertically-integrated divergence of total energy flux
'Total column vertically-integrated divergence of total energy flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 86 ;
	}
#Total column vertically-integrated divergence of ozone flux
'Total column vertically-integrated divergence of ozone flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 87 ;
	}
#Time-integrated temperature tendency due to short-wave radiation
'Time-integrated temperature tendency due to short-wave radiation' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 100 ;
	}
#Time-integrated temperature tendency due to long-wave radiation
'Time-integrated temperature tendency due to long-wave radiation' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 101 ;
	}
#Time-integrated temperature tendency due to short wave radiation, clear sky
'Time-integrated temperature tendency due to short wave radiation, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 102 ;
	}
#Time-integrated temperature tendency due to long-wave radiation, clear sky
'Time-integrated temperature tendency due to long-wave radiation, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 103 ;
	}
#Time-integrated updraught mass flux
'Time-integrated updraught mass flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 104 ;
	}
#Time-integrated downdraught mass flux
'Time-integrated downdraught mass flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 105 ;
	}
#Time-integrated updraught detrainment rate
'Time-integrated updraught detrainment rate' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 106 ;
	}
#Time-integrated downdraught detrainment rate
'Time-integrated downdraught detrainment rate' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 107 ;
	}
#Time-integrated total precipitation flux
'Time-integrated total precipitation flux' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 108 ;
	}
#Time-integrated turbulent diffusion coefficient for heat
'Time-integrated turbulent diffusion coefficient for heat' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 109 ;
	}
#Time-integrated temperature tendency due to parametrisations
'Time-integrated temperature tendency due to parametrisations' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 110 ;
	}
#Time-integrated specific humidity tendency due to parametrisations
'Time-integrated specific humidity tendency due to parametrisations' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 111 ;
	}
#Time-integrated eastward wind tendency due to parametrisations
'Time-integrated eastward wind tendency due to parametrisations' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 112 ;
	}
#Time-integrated northward wind tendency due to parametrisations
'Time-integrated northward wind tendency due to parametrisations' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 113 ;
	}
#Variance of geopotential
'Variance of geopotential' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 206 ;
	}
#Covariance of geopotential/temperature
'Covariance of geopotential/temperature' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 207 ;
	}
#Variance of temperature
'Variance of temperature' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 208 ;
	}
#Covariance of geopotential/specific humidity
'Covariance of geopotential/specific humidity' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 209 ;
	}
#Covariance of temperature/specific humidity
'Covariance of temperature/specific humidity' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 210 ;
	}
#Variance of specific humidity
'Variance of specific humidity' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 211 ;
	}
#Covariance of u component/geopotential
'Covariance of u component/geopotential' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 212 ;
	}
#Covariance of u component/temperature
'Covariance of u component/temperature' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 213 ;
	}
#Covariance of u component/specific humidity
'Covariance of u component/specific humidity' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 214 ;
	}
#Variance of u component
'Variance of u component' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 215 ;
	}
#Time-mean large-scale precipitation rate
'Time-mean large-scale precipitation rate' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 142 ;
	}
#Time-mean convective precipitation rate
'Time-mean convective precipitation rate' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 143 ;
	}
#Time-mean total snowfall rate
'Time-mean total snowfall rate' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 144 ;
	}
#Time-mean surface sensible heat flux
'Time-mean surface sensible heat flux' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 146 ;
	}
#Time-mean surface latent heat flux
'Time-mean surface latent heat flux' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 147 ;
	}
#Time-mean surface downward short-wave (solar) radiation flux
'Time-mean surface downward short-wave (solar) radiation flux' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 169 ;
	}
#Time-mean surface downward long-wave (thermal) radiation flux
'Time-mean surface downward long-wave (thermal) radiation flux' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 175 ;
	}
#Time-mean surface net short-wave (solar) radiation flux
'Time-mean surface net short-wave (solar) radiation flux' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 176 ;
	}
#Time-mean surface net long-wave (thermal) radiation flux
'Time-mean surface net long-wave (thermal) radiation flux' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 177 ;
	}
#Time-mean top net short-wave (solar) radiation flux
'Time-mean top net short-wave (solar) radiation flux' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 178 ;
	}
#Time-mean top net long-wave (thermal) radiation flux
'Time-mean top net long-wave (thermal) radiation flux' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 179 ;
	}
#Time-mean eastward turbulent surface stress
'Time-mean eastward turbulent surface stress' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 180 ;
	}
#Time-mean northward turbulent surface stress
'Time-mean northward turbulent surface stress' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 181 ;
	}
#Time-mean evaporation rate
'Time-mean evaporation rate' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 182 ;
	}
#Time-mean runoff rate
'Time-mean runoff rate' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 205 ;
	}
#Time-mean top net short-wave (solar) radiation flux, clear sky
'Time-mean top net short-wave (solar) radiation flux, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 208 ;
	}
#Time-mean top net long-wave (thermal) radiation flux, clear sky
'Time-mean top net long-wave (thermal) radiation flux, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 209 ;
	}
#Time-mean surface net short-wave (solar) radiation flux, clear sky
'Time-mean surface net short-wave (solar) radiation flux, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 210 ;
	}
#Time-mean surface net long-wave (thermal) radiation flux, clear sky
'Time-mean surface net long-wave (thermal) radiation flux, clear sky' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 211 ;
	}
#Time-mean short-wave (solar) insolation rate
'Time-mean short-wave (solar) insolation rate' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 212 ;
	}
#Time-mean total precipitation rate
'Time-mean total precipitation rate' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 228 ;
	}
#Surface runoff
'Surface runoff' = {
	 discipline = 192 ;
	 parameterCategory = 174 ;
	 parameterNumber = 8 ;
	}
#Sea-ice thickness
'Sea-ice thickness' = {
	 discipline = 192 ;
	 parameterCategory = 174 ;
	 parameterNumber = 98 ;
	}
#Snow depth
'Snow depth' = {
	 discipline = 192 ;
	 parameterCategory = 190 ;
	 parameterNumber = 141 ;
	}
#Nitrogen dioxide mass mixing ratio
'Nitrogen dioxide mass mixing ratio' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 121 ;
	}
#Sulphur dioxide mass mixing ratio
'Sulphur dioxide mass mixing ratio' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 122 ;
	}
#Carbon monoxide mass mixing ratio
'Carbon monoxide mass mixing ratio' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 123 ;
	}
#Ozone mass mixing ratio (full chemistry scheme)
'Ozone mass mixing ratio (full chemistry scheme)' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 203 ;
	}
#Nitrogen dioxide mass mixing ratio difference
'Nitrogen dioxide mass mixing ratio difference' = {
	 discipline = 192 ;
	 parameterCategory = 211 ;
	 parameterNumber = 121 ;
	}
#Sulphur dioxide mass mixing ratio difference
'Sulphur dioxide mass mixing ratio difference' = {
	 discipline = 192 ;
	 parameterCategory = 211 ;
	 parameterNumber = 122 ;
	}
#Carbon monoxide mass mixing ratio difference
'Carbon monoxide mass mixing ratio difference' = {
	 discipline = 192 ;
	 parameterCategory = 211 ;
	 parameterNumber = 123 ;
	}
#Ozone mass mixing ratio difference (full chemistry scheme)
'Ozone mass mixing ratio difference (full chemistry scheme)' = {
	 discipline = 192 ;
	 parameterCategory = 211 ;
	 parameterNumber = 203 ;
	}
#Friction velocity
'Friction velocity' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 3 ;
	}
#Time-mean 2 metre temperature
'Time-mean 2 metre temperature' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 4 ;
	}
#Time-mean 10 metre wind speed
'Time-mean 10 metre wind speed' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 5 ;
	}
#Mean total cloud cover
'Mean total cloud cover' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 6 ;
	}
#Lake total depth
'Lake total depth' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 7 ;
	}
#Lake mix-layer temperature
'Lake mix-layer temperature' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 8 ;
	}
#Lake mix-layer depth
'Lake mix-layer depth' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 9 ;
	}
#Lake bottom temperature
'Lake bottom temperature' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 10 ;
	}
#Lake total layer temperature
'Lake total layer temperature' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 11 ;
	}
#Lake shape factor
'Lake shape factor' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 12 ;
	}
#Lake ice surface temperature
'Lake ice surface temperature' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 13 ;
	}
#Lake ice total depth
'Lake ice total depth' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 14 ;
	}
#Minimum vertical gradient of refractivity inside trapping layer
'Minimum vertical gradient of refractivity inside trapping layer' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 15 ;
	}
#Mean vertical gradient of refractivity inside trapping layer
'Mean vertical gradient of refractivity inside trapping layer' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 16 ;
	}
#Duct base height
'Duct base height' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 17 ;
	}
#Trapping layer base height
'Trapping layer base height' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 18 ;
	}
#Trapping layer top height
'Trapping layer top height' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 19 ;
	}
#10 metre u-component of neutral wind
'10 metre u-component of neutral wind' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 131 ;
	}
#10 metre v-component of neutral wind
'10 metre v-component of neutral wind' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 132 ;
	}
#U-component surface stokes drift
'U-component surface stokes drift' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 215 ;
	}
#V-component surface stokes drift
'V-component surface stokes drift' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 216 ;
	}
#100 metre U wind component
'100 metre U wind component' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 246 ;
	}
#100 metre V wind component
'100 metre V wind component' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 247 ;
}
