# file generated by get_86_paramdef_for_grib_api.pl at 2014-11-14 10:59:45 EET host gogol.fmi.fi
'Pressure in hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 1 ;
}
'Geopotential' = {
	table2Version = 203 ;
	indicatorOfParameter = 2 ;
}
'Height of level in meters' = {
	table2Version = 203 ;
	indicatorOfParameter = 3 ;
}
'Temperature in Celsius' = {
	table2Version = 203 ;
	indicatorOfParameter = 4 ;
}
'Potential temperature' = {
	table2Version = 203 ;
	indicatorOfParameter = 8 ;
}
'Pseudoadiabatic potential temperature in K' = {
	table2Version = 203 ;
	indicatorOfParameter = 9 ;
}
'Dew point Temperature in C' = {
	table2Version = 203 ;
	indicatorOfParameter = 10 ;
}
'Specific Humidity in kg/kg' = {
	table2Version = 203 ;
	indicatorOfParameter = 12 ;
}
'Relative Humidity in percents' = {
	table2Version = 203 ;
	indicatorOfParameter = 13 ;
}
'Cloud Symbol' = {
	table2Version = 203 ;
	indicatorOfParameter = 15 ;
}
'Front Symbol' = {
	table2Version = 203 ;
	indicatorOfParameter = 18 ;
}
'Fog symbol' = {
	table2Version = 203 ;
	indicatorOfParameter = 19 ;
}
'Wind Direction in Degrees' = {
	table2Version = 203 ;
	indicatorOfParameter = 20 ;
}
'Wind speed in m/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 21 ;
}
'Wind Vector in m/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 22 ;
}
'U wind in m/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 23 ;
}
'V wind in m/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 24 ;
}
'Instantaneous Wind Speed in m/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 27 ;
}
'Height of -20 C level in meters' = {
	table2Version = 203 ;
	indicatorOfParameter = 28 ;
}
'Absolute Vorticity in HZ/10000' = {
	table2Version = 203 ;
	indicatorOfParameter = 31 ;
}
'FMI Air Quality Index' = {
	table2Version = 203 ;
	indicatorOfParameter = 38 ;
}
'WindSpeed at 10 m in m/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 39 ;
}
'Vertical Velocity in pa/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 40 ;
}
'Vertical Velocity in mm/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 43 ;
}
'Vertical Velocity in m/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 44 ;
}
'Precipitable water in mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 47 ;
}
'Total precipitation' = {
	table2Version = 203 ;
	indicatorOfParameter = 50 ;
}
'Snow Depth in Meters' = {
	table2Version = 203 ;
	indicatorOfParameter = 51 ;
}
'Precalculated weather symbol' = {
	table2Version = 203 ;
	indicatorOfParameter = 52 ;
}
'Precalculated weather symbol' = {
	table2Version = 203 ;
	indicatorOfParameter = 53 ;
}
'Rain over the last 6 hours in mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 54 ;
}
'Rain over the last 12 hours in mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 55 ;
}
'Rain over the last 1 hour in mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 56 ;
}
'Rain over the last 2 hours in mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 57 ;
}
'Rain over the last 3 hours in mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 58 ;
}
'Precipitation form' = {
	table2Version = 203 ;
	indicatorOfParameter = 59 ;
}
'Calculated smog appearance' = {
	table2Version = 203 ;
	indicatorOfParameter = 60 ;
}
'Large Scale precipitation in 10ths of mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 62 ;
}
'Convective precipitation in 10ths of mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 63 ;
}
'Snowfall accumulation  in mm' = {
	table2Version = 203 ;
	indicatorOfParameter = 68 ;
}
'Net long wave radiation' = {
	table2Version = 203 ;
	indicatorOfParameter = 69 ;
}
'Height of 0 C level in meters' = {
	table2Version = 203 ;
	indicatorOfParameter = 70 ;
}
'Total Precipitation rate in kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 71 ;
}
'Convective Precipitation rate in kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 72 ;
}
'Large Scale Precipitation rate in kg m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 73 ;
}
'Log Surface Pressure' = {
	table2Version = 203 ;
	indicatorOfParameter = 74 ;
}
'Ground Temperature in Kelvins' = {
	table2Version = 203 ;
	indicatorOfParameter = 75 ;
}
'Loose snow depth in cm' = {
	table2Version = 203 ;
	indicatorOfParameter = 77 ;
}
'Cloud water' = {
	table2Version = 203 ;
	indicatorOfParameter = 78 ;
}
'Total Cloud Cover in %' = {
	table2Version = 203 ;
	indicatorOfParameter = 79 ;
}
'Stability index (-50 -> 50)' = {
	table2Version = 203 ;
	indicatorOfParameter = 80 ;
}
'ALBEDO 0 to 1' = {
	table2Version = 203 ;
	indicatorOfParameter = 89 ;
}
'Simple weather symbol fo HS and others' = {
	table2Version = 203 ;
	indicatorOfParameter = 91 ;
}
'Long wave radiation' = {
	table2Version = 203 ;
	indicatorOfParameter = 95 ;
}
'Global radiation' = {
	table2Version = 203 ;
	indicatorOfParameter = 96 ;
}
'Land Cover, 1=land, 0=sea' = {
	table2Version = 203 ;
	indicatorOfParameter = 99 ;
}
'Ice Cover, 1=ice, 0=no ice' = {
	table2Version = 203 ;
	indicatorOfParameter = 100 ;
}
'Density of dry air in Kg m-3' = {
	table2Version = 203 ;
	indicatorOfParameter = 101 ;
}
'Sea spray icing for major oceans' = {
	table2Version = 203 ;
	indicatorOfParameter = 102 ;
}
'Icing, code 20041 in BUFR' = {
	table2Version = 203 ;
	indicatorOfParameter = 103 ;
}
'Cloud ice' = {
	table2Version = 203 ;
	indicatorOfParameter = 104 ;
}
'Cloud condensate' = {
	table2Version = 203 ;
	indicatorOfParameter = 105 ;
}
'Large scale snow accumulation in kg/m2' = {
	table2Version = 203 ;
	indicatorOfParameter = 106 ;
}
'Convective snow accumulation in kg/m2' = {
	table2Version = 203 ;
	indicatorOfParameter = 107 ;
}
'Large scale snowfall rate in mm/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 108 ;
}
'Convective snowfall rate in mm/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 109 ;
}
'Snowfall rate in mm/s or mm/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 110 ;
}
'Temperature in cluster 1 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 111 ;
}
'Temperature in cluster 2 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 112 ;
}
'Temperature in cluster 3 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 113 ;
}
'Temperature in cluster 4 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 114 ;
}
'Temperature in cluster 5 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 115 ;
}
'Temperature in cluster 6 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 116 ;
}
'Geopotential in cluster 1 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 117 ;
}
'Geopotential in cluster 2 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 118 ;
}
'Geopotential in cluster 3 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 119 ;
}
'Geopotential in cluster 4 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 120 ;
}
'Geopotential in cluster 5 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 121 ;
}
'Geopotential in cluster 6 of EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 122 ;
}
'Net long wave radiation, top of athmosphere' = {
	table2Version = 203 ;
	indicatorOfParameter = 126 ;
}
'Net short wave radiation' = {
	table2Version = 203 ;
	indicatorOfParameter = 128 ;
}
'Equivalent potential temperature in K' = {
	table2Version = 203 ;
	indicatorOfParameter = 129 ;
}
'Absolute humidity, kg/m^3' = {
	table2Version = 203 ;
	indicatorOfParameter = 130 ;
}
'Probability of big negative temperature anomaly (-8 K) in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 131 ;
}
'Probability of moderate negative temperature anomaly (-4 K) in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 132 ;
}
'Probability of moderate positive temperature anomaly (+4 K) in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 133 ;
}
'Probability of big positive temperature anomaly (+8 K) in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 134 ;
}
'Probability of reaching precipitation of 1 mm in 24 hours in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 141 ;
}
'Probability of reaching precipitation of 5 mm in 24 hours in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 142 ;
}
'Probability of reaching precipitation of 10 mm in 24 hours in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 143 ;
}
'Probability of reaching precipitation of 20 mm in 24 hours in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 144 ;
}
'Wind shear in knots' = {
	table2Version = 203 ;
	indicatorOfParameter = 145 ;
}
'Wind shear at 1km in knots' = {
	table2Version = 203 ;
	indicatorOfParameter = 146 ;
}
'Storm relative helicity' = {
	table2Version = 203 ;
	indicatorOfParameter = 147 ;
}
'Storm relative helicity, 0 .. 1 km' = {
	table2Version = 203 ;
	indicatorOfParameter = 148 ;
}
'Wind speed at 1500 meters in m/s' = {
	table2Version = 203 ;
	indicatorOfParameter = 149 ;
}
'Equivalent potential temperature from range 0 ..3km in C' = {
	table2Version = 203 ;
	indicatorOfParameter = 150 ;
}
'Probability of reaching wind speed of 10 m/s in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 151 ;
}
'Probability of reaching wind speed of 15 m/s in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 152 ;
}
'Probability of reaching wind gust speed of 15 m/s in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 153 ;
}
'Probability of reaching wind gust speed of 20 m/s in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 154 ;
}
'Probability of reaching wind gust speed of 25 m/s in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 155 ;
}
'Extreme forecast index for wind speed' = {
	table2Version = 203 ;
	indicatorOfParameter = 156 ;
}
'Extreme forecast index for temperature' = {
	table2Version = 203 ;
	indicatorOfParameter = 157 ;
}
'Extreme forecast index for wind gusts' = {
	table2Version = 203 ;
	indicatorOfParameter = 158 ;
}
'Extreme forecast index for precipitation' = {
	table2Version = 203 ;
	indicatorOfParameter = 159 ;
}
'Probability of snow' = {
	table2Version = 203 ;
	indicatorOfParameter = 161 ;
}
'Inverse of Monin-Obukhov length, i.e. 1/L in m-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 163 ;
}
'Surface Roughness (momentum) in meters' = {
	table2Version = 203 ;
	indicatorOfParameter = 164 ;
}
'Instant rain in kg/m2' = {
	table2Version = 203 ;
	indicatorOfParameter = 165 ;
}
'Instant solid precipitation (snow+graupel) in kg/m2' = {
	table2Version = 203 ;
	indicatorOfParameter = 166 ;
}
'Mixed layer height in m' = {
	table2Version = 203 ;
	indicatorOfParameter = 167 ;
}
'Showalter index' = {
	table2Version = 203 ;
	indicatorOfParameter = 168 ;
}
'Lifted index' = {
	table2Version = 203 ;
	indicatorOfParameter = 169 ;
}
'Cross totals index' = {
	table2Version = 203 ;
	indicatorOfParameter = 170 ;
}
'Vertical totals index' = {
	table2Version = 203 ;
	indicatorOfParameter = 171 ;
}
'Total totals index' = {
	table2Version = 203 ;
	indicatorOfParameter = 172 ;
}
'0th fractal (ie. minimum) temperature in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 173 ;
}
'10th fractal temperature in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 174 ;
}
'25th fractal temperature in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 175 ;
}
'50th fractal temperature in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 176 ;
}
'75th fractal temperature in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 177 ;
}
'90th fractal temperature in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 178 ;
}
'100th fractal (ie. maximum) temperature in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 179 ;
}
'Height of LCL in hPa, source data is found from most unstable level' = {
	table2Version = 203 ;
	indicatorOfParameter = 180 ;
}
'Height of LFC in hPa, source data is found from most unstable level' = {
	table2Version = 203 ;
	indicatorOfParameter = 181 ;
}
'Height of EL in hPa, source data is found from most unstable level' = {
	table2Version = 203 ;
	indicatorOfParameter = 182 ;
}
'Surface Roughness in Meters' = {
	table2Version = 203 ;
	indicatorOfParameter = 183 ;
}
'Height of LCL in meters, source data is found from most unstable level' = {
	table2Version = 203 ;
	indicatorOfParameter = 184 ;
}
'Height of LFC in meters, source data is found from most unstable level' = {
	table2Version = 203 ;
	indicatorOfParameter = 185 ;
}
'Soil Moisture Content in Kg per square meter' = {
	table2Version = 203 ;
	indicatorOfParameter = 186 ;
}
'0th fractal precipitation in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 187 ;
}
'10th fractal precipitation in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 188 ;
}
'25th fractal precipitation in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 189 ;
}
'50th fractal precipitation in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 190 ;
}
'75th fractal precipitation in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 191 ;
}
'90th fractal precipitation in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 192 ;
}
'100th fractal precipitation in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 193 ;
}
'Height of EL in meters, source data is found from most unstable level' = {
	table2Version = 203 ;
	indicatorOfParameter = 194 ;
}
'Convective available potential energy, source data is most unstable' = {
	table2Version = 203 ;
	indicatorOfParameter = 195 ;
}
'UV index maximum' = {
	table2Version = 203 ;
	indicatorOfParameter = 196 ;
}
'UV index' = {
	table2Version = 203 ;
	indicatorOfParameter = 197 ;
}
'Ozone anomaly' = {
	table2Version = 203 ;
	indicatorOfParameter = 198 ;
}
'Convective inhibition, source data is most unstable' = {
	table2Version = 203 ;
	indicatorOfParameter = 199 ;
}
'Canopy water' = {
	table2Version = 203 ;
	indicatorOfParameter = 200 ;
}
'Latent heat flux' = {
	table2Version = 203 ;
	indicatorOfParameter = 201 ;
}
'Sensible heat flux' = {
	table2Version = 203 ;
	indicatorOfParameter = 202 ;
}
'Scalar momentum flux in Pa' = {
	table2Version = 203 ;
	indicatorOfParameter = 203 ;
}
'CAPE, source data is most unstable, value of CAPE between 0 .. 3km' = {
	table2Version = 203 ;
	indicatorOfParameter = 204 ;
}
'CAPE, source data is most unstable, value of parameter when -40C < T < -10C' = {
	table2Version = 203 ;
	indicatorOfParameter = 205 ;
}
'FMIWEATHERSYMBOL1' = {
	table2Version = 203 ;
	indicatorOfParameter = 206 ;
}
'Soil type' = {
	table2Version = 203 ;
	indicatorOfParameter = 207 ;
}
'Kinetic energy of turbulence in J kg-1' = {
	table2Version = 203 ;
	indicatorOfParameter = 208 ;
}
'U-component of momentum flux in N m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 209 ;
}
'V-component of momentum flux in N m-2' = {
	table2Version = 203 ;
	indicatorOfParameter = 210 ;
}
'Vegetation type' = {
	table2Version = 203 ;
	indicatorOfParameter = 211 ;
}
'Graupel rate in mm/h' = {
	table2Version = 203 ;
	indicatorOfParameter = 212 ;
}
'Solid precipitation rate (f.ex. snow+graupel)' = {
	table2Version = 203 ;
	indicatorOfParameter = 213 ;
}
'0th fractal cloudiness in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 214 ;
}
'10th fractal cloudiness in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 215 ;
}
'25th fractal cloudiness in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 216 ;
}
'50th fractal cloudiness in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 217 ;
}
'75th fractal cloudiness in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 218 ;
}
'90th fractal cloudiness in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 219 ;
}
'100th fractal cloudiness in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 220 ;
}
'0th fractal wind gust speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 221 ;
}
'10th fractal wind gust speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 222 ;
}
'25th fractal wind gust speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 223 ;
}
'50th fractal wind gust speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 224 ;
}
'75th fractal wind gust speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 225 ;
}
'90th fractal wind gust speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 226 ;
}
'100th fractal wind gust speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 227 ;
}
'0th fractal wind speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 228 ;
}
'10th fractal wind speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 229 ;
}
'25th fractal wind speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 230 ;
}
'50th fractal wind speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 231 ;
}
'75th fractal wind speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 232 ;
}
'90th fractal wind speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 233 ;
}
'100th fractal wind speed in EPS' = {
	table2Version = 203 ;
	indicatorOfParameter = 234 ;
}
'Height of LCL in hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 235 ;
}
'Height of LFC in hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 236 ;
}
'Height of EL in hPa' = {
	table2Version = 203 ;
	indicatorOfParameter = 237 ;
}
'Height of LCL in meters' = {
	table2Version = 203 ;
	indicatorOfParameter = 238 ;
}
'Height of LFC in meters' = {
	table2Version = 203 ;
	indicatorOfParameter = 239 ;
}
'Height of EL in meters' = {
	table2Version = 203 ;
	indicatorOfParameter = 240 ;
}
'Convective available potential energy' = {
	table2Version = 203 ;
	indicatorOfParameter = 241 ;
}
'Convective available potential energy, source data is LCL-500 and EL-500' = {
	table2Version = 203 ;
	indicatorOfParameter = 242 ;
}
'Convective available potential energy, value of parameter when -40C < T < -10C' = {
	table2Version = 203 ;
	indicatorOfParameter = 243 ;
}
'Convective inhibition (cin)' = {
	table2Version = 203 ;
	indicatorOfParameter = 244 ;
}
'Height of LCL in hPa, source data is averaged between 0 .. 500m' = {
	table2Version = 203 ;
	indicatorOfParameter = 245 ;
}
'Height of LFC in hPa, source data is averaged between 0 .. 500m' = {
	table2Version = 203 ;
	indicatorOfParameter = 246 ;
}
'Height of EL in hPa, source data is averaged between 0 .. 500m' = {
	table2Version = 203 ;
	indicatorOfParameter = 247 ;
}
'Height of LCL in meters, source data is averaged between 0 .. 500m' = {
	table2Version = 203 ;
	indicatorOfParameter = 248 ;
}
'Height of LFC in meters, source data is averaged between 0 .. 500m' = {
	table2Version = 203 ;
	indicatorOfParameter = 249 ;
}
'Height of EL in meters, source data is averaged between 0 .. 500m' = {
	table2Version = 203 ;
	indicatorOfParameter = 250 ;
}
'Convective available potential energy, value of CAPE between 0 .. 3km' = {
	table2Version = 203 ;
	indicatorOfParameter = 251 ;
}
'CAPE, source data is LFC-500 and EL-500, value of CAPE between 0 .. 3km' = {
	table2Version = 203 ;
	indicatorOfParameter = 252 ;
}
'CAPE, source data is LFC-500 and EL-500, value of CAPE when -40C < T < -10C' = {
	table2Version = 203 ;
	indicatorOfParameter = 253 ;
}
'Convective inhibition, source data is LFC-500 and EL-500' = {
	table2Version = 203 ;
	indicatorOfParameter = 254 ;
}
'Precipitation form, duplicate parameter for HIMAN purposes' = {
	table2Version = 203 ;
	indicatorOfParameter = 255 ;
}
'Sea Temperature in Celsius' = {
	table2Version = 205 ;
	indicatorOfParameter = 1 ;
}
'Ice concentration' = {
	table2Version = 205 ;
	indicatorOfParameter = 2 ;
}
'Ice thickness' = {
	table2Version = 205 ;
	indicatorOfParameter = 3 ;
}
'Ice minimum thickness' = {
	table2Version = 205 ;
	indicatorOfParameter = 4 ;
}
'Ice maximum thickness' = {
	table2Version = 205 ;
	indicatorOfParameter = 5 ;
}
'Ice degree of ridging' = {
	table2Version = 205 ;
	indicatorOfParameter = 6 ;
}
'Sea ice velocity (U) in m/s' = {
	table2Version = 205 ;
	indicatorOfParameter = 7 ;
}
'Sea ice velocity (V) in m/s' = {
	table2Version = 205 ;
	indicatorOfParameter = 8 ;
}
'Ice mean thickness' = {
	table2Version = 205 ;
	indicatorOfParameter = 9 ;
}
'Ice concentration of ridging' = {
	table2Version = 205 ;
	indicatorOfParameter = 10 ;
}
'Rafted sea ice mean thickness' = {
	table2Version = 205 ;
	indicatorOfParameter = 11 ;
}
'Rafted sea ice concentration' = {
	table2Version = 205 ;
	indicatorOfParameter = 12 ;
}
'Ice Direction in Degrees' = {
	table2Version = 205 ;
	indicatorOfParameter = 13 ;
}
'Ice speed in m/s' = {
	table2Version = 205 ;
	indicatorOfParameter = 14 ;
}
'Pressure in Pascals' = {
	table2Version = 253 ;
	indicatorOfParameter = 1 ;
}
'Pressure in Pascals' = {
	table2Version = 253 ;
	indicatorOfParameter = 2 ;
}
'Geopotential' = {
	table2Version = 253 ;
	indicatorOfParameter = 6 ;
}
'Height of level in meters' = {
	table2Version = 253 ;
	indicatorOfParameter = 8 ;
}
'Temperature in Kelvins' = {
	table2Version = 253 ;
	indicatorOfParameter = 11 ;
}
'Potential temperature' = {
	table2Version = 253 ;
	indicatorOfParameter = 13 ;
}
'Maximum Temperature in Celsius' = {
	table2Version = 253 ;
	indicatorOfParameter = 15 ;
}
'Minimum Temperature in Celsius' = {
	table2Version = 253 ;
	indicatorOfParameter = 16 ;
}
'Dew point Temperature in K' = {
	table2Version = 253 ;
	indicatorOfParameter = 17 ;
}
'Visibility in Meters' = {
	table2Version = 253 ;
	indicatorOfParameter = 20 ;
}
'U wind in m/s' = {
	table2Version = 253 ;
	indicatorOfParameter = 33 ;
}
'V wind in m/s' = {
	table2Version = 253 ;
	indicatorOfParameter = 34 ;
}
'Vertical Velocity in pa/s' = {
	table2Version = 253 ;
	indicatorOfParameter = 39 ;
}
'Vertical Velocity in m/s' = {
	table2Version = 253 ;
	indicatorOfParameter = 40 ;
}
'Absolute Vorticity in HZ' = {
	table2Version = 253 ;
	indicatorOfParameter = 41 ;
}
'Specific Humidity in kg/kg' = {
	table2Version = 253 ;
	indicatorOfParameter = 51 ;
}
'Relative Humidity in percents' = {
	table2Version = 253 ;
	indicatorOfParameter = 52 ;
}
'Precipitable water in mm' = {
	table2Version = 253 ;
	indicatorOfParameter = 54 ;
}
'Evaporation in mm' = {
	table2Version = 253 ;
	indicatorOfParameter = 57 ;
}
'Cloud ice' = {
	table2Version = 253 ;
	indicatorOfParameter = 58 ;
}
'Total precipitation in kg/m2' = {
	table2Version = 253 ;
	indicatorOfParameter = 61 ;
}
'Snow Depth in Meters' = {
	table2Version = 253 ;
	indicatorOfParameter = 66 ;
}
'Mixed layer height in m' = {
	table2Version = 253 ;
	indicatorOfParameter = 67 ;
}
'Cloudiness 0...1' = {
	table2Version = 253 ;
	indicatorOfParameter = 71 ;
}
'Low Cloud Amount' = {
	table2Version = 253 ;
	indicatorOfParameter = 73 ;
}
'Medium Cloud Amount' = {
	table2Version = 253 ;
	indicatorOfParameter = 74 ;
}
'High Cloud Amount' = {
	table2Version = 253 ;
	indicatorOfParameter = 75 ;
}
'Cloud water' = {
	table2Version = 253 ;
	indicatorOfParameter = 76 ;
}
'Land Cover, 1=land, 0=sea' = {
	table2Version = 253 ;
	indicatorOfParameter = 81 ;
}
'Surface Roughness in Meters' = {
	table2Version = 253 ;
	indicatorOfParameter = 83 ;
}
'ALBEDO 0 to 1' = {
	table2Version = 253 ;
	indicatorOfParameter = 84 ;
}
'Soil Moisture Content in Kg per square meter' = {
	table2Version = 253 ;
	indicatorOfParameter = 86 ;
}
'Ice Cover, 1=ice, 0=no ice' = {
	table2Version = 253 ;
	indicatorOfParameter = 91 ;
}
'Mean wave direction at spectral peak in degrees' = {
	table2Version = 253 ;
	indicatorOfParameter = 101 ;
}
'Significant wave height in m' = {
	table2Version = 253 ;
	indicatorOfParameter = 102 ;
}
'Peak wave period in s' = {
	table2Version = 253 ;
	indicatorOfParameter = 103 ;
}
'Net short wave radiation accumulation' = {
	table2Version = 253 ;
	indicatorOfParameter = 111 ;
}
'Net long wave radiation accumulation' = {
	table2Version = 253 ;
	indicatorOfParameter = 112 ;
}
'Net short wave radiation, top of athmosphere' = {
	table2Version = 253 ;
	indicatorOfParameter = 113 ;
}
'Net short wave radiation accumulation, top of atmosphere' = {
	table2Version = 253 ;
	indicatorOfParameter = 113 ;
}
'Net long wave radiation, top of athmosphere' = {
	table2Version = 253 ;
	indicatorOfParameter = 114 ;
}
'Net long wave radiation accumulation, top of atmosphere' = {
	table2Version = 253 ;
	indicatorOfParameter = 114 ;
}
'Long wave radiation accumulation' = {
	table2Version = 253 ;
	indicatorOfParameter = 115 ;
}
'Global radiation accumulation' = {
	table2Version = 253 ;
	indicatorOfParameter = 117 ;
}
'Latent heat flux' = {
	table2Version = 253 ;
	indicatorOfParameter = 121 ;
}
'Sensible heat flux' = {
	table2Version = 253 ;
	indicatorOfParameter = 122 ;
}
'U-component of momentum flux in N m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 124 ;
}
'V-component of momentum flux in N m-2' = {
	table2Version = 253 ;
	indicatorOfParameter = 125 ;
}
'Icing warning index, values between 0 ... 4' = {
	table2Version = 253 ;
	indicatorOfParameter = 135 ;
}
'Precipitation type' = {
	table2Version = 253 ;
	indicatorOfParameter = 144 ;
}
'Convective available potential energy' = {
	table2Version = 253 ;
	indicatorOfParameter = 160 ;
}
'U-component of wind gust' = {
	table2Version = 253 ;
	indicatorOfParameter = 162 ;
}
'V-component of wind gust' = {
	table2Version = 253 ;
	indicatorOfParameter = 163 ;
}
'Instant rain in kg/m2' = {
	table2Version = 253 ;
	indicatorOfParameter = 181 ;
}
'Snowfall accumulation  in mm' = {
	table2Version = 253 ;
	indicatorOfParameter = 184 ;
}
'Instant snowfall rate in mm/s or mm/h' = {
	table2Version = 253 ;
	indicatorOfParameter = 184 ;
}
'Solid precipitation (f.ex. snow+graupel)' = {
	table2Version = 253 ;
	indicatorOfParameter = 185 ;
}
'Cloud base height' = {
	table2Version = 253 ;
	indicatorOfParameter = 186 ;
}
'Height of cloud top' = {
	table2Version = 253 ;
	indicatorOfParameter = 187 ;
}
'Kinetic energy of turbulence in J kg-1' = {
	table2Version = 253 ;
	indicatorOfParameter = 200 ;
}
'Graupel precipitation in kg/m2' = {
	table2Version = 253 ;
	indicatorOfParameter = 201 ;
}
'Instant graupel in kg/m2' = {
	table2Version = 253 ;
	indicatorOfParameter = 201 ;
}
'Total hail precipitation in kg/m2' = {
	table2Version = 253 ;
	indicatorOfParameter = 204 ;
}
'Multiplicity Of The Flash, Number' = {
	table2Version = 253 ;
	indicatorOfParameter = 209 ;
}
'Clutter corrected ceflectivity' = {
	table2Version = 253 ;
	indicatorOfParameter = 210 ;
}
'Instantaneous Wind Speed in m/s' = {
	table2Version = 253 ;
	indicatorOfParameter = 228 ;
}
