# Automatically generated by ./create_defs.grib1.pl, do not edit
#Stream function
'm**2 s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 35 ;
	}
#Velocity potential
'm**2 s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 36 ;
	}
#Potential temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 13 ;
	}
#Wind speed
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 32 ;
	}
#Sea ice area fraction
'(0 - 1)' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 91 ;
	}
#Montgomery potential
'm**2 s**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 37 ;
	}
#Pressure
'Pa' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 1 ;
	}
#Potential vorticity
'K m**2 kg**-1 s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 4 ;
	}
#Total column cloud liquid water
'kg m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 227 ;
	}
#Total column cloud ice water
'kg m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 58 ;
	}
#Geopotential
'm**2 s**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 6 ;
	}
#Temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 11 ;
	}
#U component of wind
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 33 ;
	}
#V component of wind
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 34 ;
	}
#Specific humidity
'kg kg**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 51 ;
	}
#Surface pressure
'Pa' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Vertical velocity
'Pa s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 39 ;
	}
#Total column vertically-integrated water vapour
'kg m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 54 ;
	}
#Vorticity (relative)
's**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 43 ;
	}
#Mean sea level pressure
'Pa' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 2 ;
	}
#Divergence
's**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 44 ;
	}
#Geopotential height
'gpm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 7 ;
	}
#Relative humidity
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 52 ;
	}
#10 metre U wind component
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 33 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 10 ;
	}
#10 metre V wind component
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 34 ;
	 indicatorOfTypeOfLevel = 105 ;
	 topLevel = 10 ;
	}
#2 metre temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 11 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Land-sea mask
'(0 - 1)' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 81 ;
	}
#Surface roughness (climatological)
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 83 ;
	}
#Brightness temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 118 ;
	}
#Specific cloud ice water content
'kg kg**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 229 ;
	}
#Snow depth
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 66 ;
	}
#Convective cloud cover
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 72 ;
	}
#Low cloud cover
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 73 ;
	}
#Medium cloud cover
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 74 ;
	}
#High cloud cover
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 75 ;
	}
#Large scale snow
'kg m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 79 ;
	}
#Latent heat flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 121 ;
	}
#Sensible heat flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 122 ;
	}
#Boundary layer dissipation
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 123 ;
	}
#2 metre specific humidity
'kg kg**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 51 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Convective snow
'kg m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 78 ;
	}
#Surface downward short-wave radiation flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 204 ;
	}
#Surface upward short-wave radiation flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 211 ;
	}
#Surface downward long-wave radiation flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 205 ;
	}
#Surface upward long-wave radiation flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 212 ;
	}
#Cloud water
'kg m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 76 ;
	}
#Cloud work function
'J kg**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 146 ;
	}
#Total column integrated ozone
'DU' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 10 ;
	}
#Ground heat flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 155 ;
	}
#2 metre relative humidity
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 52 ;
	 indicatorOfTypeOfLevel = 105 ;
	 level = 2 ;
	}
#Clear Sky Downward Solar Flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 161 ;
	}
#Clear Sky Upward Solar Flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 160 ;
	}
#Clear Sky Upward Long Wave Flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 162 ;
	}
#Clear Sky Downward Long Wave Flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 163 ;
	}
#Forecast albedo
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 84 ;
	}
#Mean evaporation
'mm per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 57 ;
	}
#Mean total precipitation
'mm per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 61 ;
	}
#Mean large scale precipitation
'mm per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 62 ;
	}
#Mean convective precipitation
'mm per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 63 ;
	}
#Mean snowfall rate water equivalent
'mm per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 64 ;
	}
#Mean surface water runoff
'mm per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 90 ;
	}
#Square of Brunt-Vaisala frequency
's**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 132 ;
	}
#Adiabatic zonal acceleration
'm s**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 151 ;
	}
#Adiabatic meridional acceleration
'm s**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 165 ;
	}
#Mean frequency of deep convection
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 170 ;
	}
#Mean frequency of shallow convection
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 171 ;
	}
#Mean frequency of stratocumulus parameterisation
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 172 ;
	}
#Gravity wave zonal acceleration
'm s**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 173 ;
	}
#Gravity wave meridional acceleration
'm s**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 174 ;
	}
#Mean evapotranspiration
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 202 ;
	}
#Adiabatic heating rate
'K per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 222 ;
	}
#Moisture storage on canopy
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 223 ;
	}
#Moisture storage on ground or cover
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 224 ;
	}
#Mass concentration of condensed water in soil
'kg m**-3' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 226 ;
	}
#Upward mass flux at cloud base
'kg m**-2 s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 230 ;
	}
#Upward mass flux
'kg m**-2 s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 231 ;
	}
#Adiabatic moistening rate
'kg kg**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 236 ;
	}
#Ozone mixing ratio
'mg kg**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 237 ;
	}
#Convective zonal acceleration
'm s**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 239 ;
	}
#Mean zonal momentum flux by long gravity wave
'N m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 147 ;
	}
#Mean meridional momentum flux by long gravity wave
'N m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 148 ;
	}
#Mean meridional momentum flux by short gravity wave
'N m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 154 ;
	}
#Mean zonal momentum flux by short gravity wave
'N m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 159 ;
	}
#Convective meridional acceleration
'm s**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 240 ;
	}
#Large scale condensation heating rate
'K per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 241 ;
	}
#Convective heating rate
'K per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 242 ;
	}
#Convective moistening rate
'kg kg**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 243 ;
	}
#Vertical diffusion heating rate
'K per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 246 ;
	}
#Vertical diffusion zonal acceleration
'm s**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 247 ;
	}
#Vertical diffusion meridional acceleration
'm s**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 248 ;
	}
#Vertical diffusion moistening rate
'kg kg**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 249 ;
	}
#Solar radiative heating rate
'K per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 250 ;
	}
#Long wave radiative heating rate
'K per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 251 ;
	}
#Large scale moistening rate
'kg kg**-1 per day' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 253 ;
	}
#Type of vegetation
'(Code table JMA-252)' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 252 ;
	}
#Virtual temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 12 ;
	}
#Vertical velocity
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 40 ;
	}
#Interception loss
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 203 ;
	}
#Soil wetness of surface
'(0 - 1)' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 225 ;
	}
#Temperature at canopy
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 144 ;
	}
#Ground/surface cover temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 145 ;
	}
#Pressure tendency
'Pa s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 3 ;
	}
#ICAO Standard Atmosphere reference height
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 5 ;
	}
#Geometrical height above ground
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 8 ;
	}
#Standard deviation of height
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 9 ;
	}
#Pseudo-adiabatic potential temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 14 ;
	}
#Maximum temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 15 ;
	}
#Minimum temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 16 ;
	}
#Dew point temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 17 ;
	}
#Dew point depression (or deficit)
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 18 ;
	}
#Lapse rate
'K m**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 19 ;
	}
#Visibility
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 20 ;
	}
#Radar spectra (1)
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 21 ;
	}
#Radar spectra (2)
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 22 ;
	}
#Radar spectra (3)
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 23 ;
	}
#Parcel lifted index (to 500 hPa)
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 24 ;
	}
#Temperature anomaly
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 25 ;
	}
#Pressure anomaly
'Pa' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 26 ;
	}
#Geopotential height anomaly
'gpm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 27 ;
	}
#Wave spectra (1)
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 28 ;
	}
#Wave spectra (2)
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 29 ;
	}
#Wave spectra (3)
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 30 ;
	}
#Wind direction
'Degree true' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 31 ;
	}
#Sigma coordinate vertical velocity
's**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 38 ;
	}
#Absolute vorticity
's**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 41 ;
	}
#Absolute divergence
's**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 42 ;
	}
#Vertical u-component shear
's**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 45 ;
	}
#Vertical v-component shear
's**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 46 ;
	}
#Direction of current
'Degree true' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 47 ;
	}
#Speed of current
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 48 ;
	}
#Humidity mixing ratio
'kg kg**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 53 ;
	}
#Vapour pressure
'Pa' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 55 ;
	}
#Saturation deficit
'Pa' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 56 ;
	}
#Precipitation rate
'kg m**-2 s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 59 ;
	}
#Thunderstorm probability
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 60 ;
	}
#Mixed layer depth
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 67 ;
	}
#Transient thermocline depth
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 68 ;
	}
#Main thermocline depth
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 69 ;
	}
#Main thermocline anomaly
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 70 ;
	}
#Best lifted index (to 500 hPa)
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 77 ;
	}
#Water temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 80 ;
	}
#Deviation of sea-level from mean
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 82 ;
	}
#Soil moisture content
'kg m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 86 ;
	}
#Salinity
'kg kg**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 88 ;
	}
#Density
'kg m**-3' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 89 ;
	}
#Ice thickness
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 92 ;
	}
#Direction of ice drift
'Degree true' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 93 ;
	}
#Speed of ice drift
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 94 ;
	}
#U-component of ice drift
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 95 ;
	}
#V-component of ice drift
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 96 ;
	}
#Ice growth rate
'm s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 97 ;
	}
#Ice divergence
's**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 98 ;
	}
#Snowmelt
'kg m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 99 ;
	}
#Significant height of combined wind waves and swell
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 100 ;
	}
#Mean direction of wind waves
'Degree true' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 101 ;
	}
#Significant height of wind waves
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 102 ;
	}
#Mean period of wind waves
's' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 103 ;
	}
#Direction of swell waves
'Degree true' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 104 ;
	}
#Significant height of swell waves
'm' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 105 ;
	}
#Mean period of swell waves
's' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 106 ;
	}
#Primary wave direction
'Degree true' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 107 ;
	}
#Primary wave mean period
's' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 108 ;
	}
#Secondary wave direction
'Degree true' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 109 ;
	}
#Secondary wave mean period
's' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 110 ;
	}
#Net short-wave radiation flux (surface)
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 111 ;
	}
#Net long-wave radiation flux (surface)
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 112 ;
	}
#Net short-wave radiation flux(atmosph.top)
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 113 ;
	}
#Net long-wave radiation flux(atmosph.top)
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 114 ;
	}
#Long wave radiation flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 115 ;
	}
#Short wave radiation flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 116 ;
	}
#Global radiation flux
'W m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 117 ;
	}
#Radiance (with respect to wave number)
'W m**-1 sr**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 119 ;
	}
#Radiance (with respect to wave length)
'W m**-3 sr**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 120 ;
	}
#Momentum flux, u-component
'N m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 124 ;
	}
#Momentum flux, v-component
'N m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 125 ;
	}
#Wind mixing energy
'J' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 126 ;
	}
#Image data
'~' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 127 ;
	}
#Cloud liquid water
'kg kg**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 228 ;
	}
#Percentage of vegetation
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 87 ;
	}
#Total column vertically-integrated eastward heat flux
'W m**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 190 ;
	}
#Total column vertically-integrated northward heat flux
'W m**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 191 ;
	}
#Total column vertically-integrated eastward water vapour flux
'kg m**-1 s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 157 ;
	}
#Total column vertically-integrated northward water vapour flux
'kg m**-1 s**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 152 ;
	}
#specific cloud water content
'kg kg**-1' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 221 ;
	}
#Soil temperature
'K' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 85 ;
	}
#Snow depth water equivalent
'kg m**-2' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 65 ;
	}
#Total Cloud Cover
'%' = {
	 table2Version = 200 ;
	 indicatorOfParameter = 71 ;
}
