"sdlsynop" = { unexpandedDescriptors = 307192; }
"sdlnat" = { unexpandedDescriptors = 307207; }
"radio" = { unexpandedDescriptors = 318202 ; }
"sdlclimat" = { unexpandedDescriptors = 307219 ; }
"sdspaob" = { unexpandedDescriptors = 308192 ; }
"forecast" = { unexpandedDescriptors = 353212 ; }
