# Automatically generated by ./create_defs.grib2.mtg2.pl, do not edit
#5-wave geopotential height
'wavh5' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#5-wave geopotential height anomaly
'wava5' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	}
#Best (4-layer) lifted index
'lftx4' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 193 ;
}
