# Automatically generated by ./create_defs.grib2.lte33.pl, do not edit
#Sea ice area fraction
'Sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Sea ice area fraction
'Sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Snow density
'Snow density' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Sea surface temperature
'Sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Convective available potential energy
'Convective available potential energy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Maximum temperature at 2 metres in the last 6 hours
'Maximum temperature at 2 metres in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 lengthOfTimeRange = 6 ;
	}
#Minimum temperature at 2 metres in the last 6 hours
'Minimum temperature at 2 metres in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	 lengthOfTimeRange = 6 ;
	}
#Total column water
'Total column water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#2 metre temperature
'2 metre temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#2 metre temperature
'2 metre temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#2 metre dewpoint temperature
'2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#2 metre dewpoint temperature
'2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	}
#2 metre dewpoint temperature
'2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-integrated eastward turbulent surface stress
'Time-integrated eastward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 38 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated northward turbulent surface stress
'Time-integrated northward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Skin temperature
'Skin temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean sea water potential temperature in the upper 300 m
'Mean sea water potential temperature in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Sea surface practical salinity
'Sea surface practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Ocean mixed layer thickness defined by sigma theta 0.01 kg/m3
'Ocean mixed layer thickness defined by sigma theta 0.01 kg/m3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Snow albedo
'Snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Soil moisture top 20 cm
'Soil moisture top 20 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Soil moisture top 100 cm
'Soil moisture top 100 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 10 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Soil temperature top 20 cm
'Soil temperature top 20 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Soil temperature top 100 cm
'Soil temperature top 100 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 10 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Eastward surface sea water velocity
'Eastward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Northward surface sea water velocity
'Northward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Sea surface height
'Sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Depth of 20C isotherm
'Depth of 20C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Average sea water practical salinity in the upper 300m
'Average sea water practical salinity in the upper 300m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Sea-ice thickness
'Sea-ice thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Snow depth water equivalent
'Snow depth water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Total Cloud Cover
'Total Cloud Cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
}
