# Automatically generated by ./create_def.pl, do not edit
#Convective available potential energy
'59' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	}
#Snow phase change heat flux
'260007' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Condensate
'260017' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 195 ;
	}
#Horizontal moisture convergence
'260022' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 197 ;
	}
#Categorical rain
'260029' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Categorical freezing rain
'260030' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Categorical ice pellets
'260031' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}
#Categorical snow
'260032' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}
#Convective precipitation rate
'260033' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	}
#Percent frozen precipitation
'260035' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Potential evaporation
'260036' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	}
#Snow cover
'260038' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 201 ;
	}
#Rain fraction of total cloud water
'260039' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 202 ;
	}
#Rime factor
'260040' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 203 ;
	}
#Total column integrated rain
'260041' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 204 ;
	}
#Total column integrated snow
'260042' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 205 ;
	}
#Water equivalent of accumulated snow depth (deprecated)
'260056' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Vertical speed shear
'260068' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	}
#Horizontal momentum flux
'260069' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	}
#U-component storm motion
'260070' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 194 ;
	}
#V-component storm motion
'260071' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 195 ;
	}
#Drag coefficient
'260072' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	}
#Frictional velocity
'260073' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 197 ;
	}
#5-wave geopotential height
'260080' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#Instantaneous eastward gravity wave surface stress
'260081' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}
#Instantaneous northward gravity wave surface stress
'260082' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}
#5-wave geopotential height anomaly
'260084' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	}
#Surface downward short-wave radiation flux
'260087' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}
#Surface upward short-wave radiation flux
'260088' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	}
#UV index
'260094' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 196 ;
	}
#Surface downward long-wave radiation flux
'260097' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 192 ;
	}
#Surface upward long-wave radiation flux
'260098' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 193 ;
	}
#Non-convective cloud cover
'260110' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	}
#Cloud work function
'260111' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 193 ;
	}
#Convective cloud efficiency
'260112' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 194 ;
	}
#Total column-integrated cloud water
'260114' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 196 ;
	}
#Total column-integrated cloud ice
'260115' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 197 ;
	}
#Total column-integrated condensate
'260116' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 198 ;
	}
#Ice fraction of total condensate
'260117' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 199 ;
	}
#Surface lifted index
'260127' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 192 ;
	}
#Best (4-layer) lifted index
'260128' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 193 ;
	}
#Ozone mixing ratio
'260131' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	}
#Maximum snow albedo
'260161' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	}
#Snow free albedo
'260162' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	}
#Seconds prior to initial reference time (defined in Section 1)
'260168' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 194 ;
	}
#Baseflow-groundwater runoff
'260174' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Storm surface runoff
'260175' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}
#Volumetric soil moisture content
'260185' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Ground heat flux
'260186' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}
#Moisture availability
'260187' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	}
#Exchange coefficient
'260188' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}
#Plant canopy surface water
'260189' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}
#Blackadar mixing length scale
'260190' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}
#Canopy conductance
'260191' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 199 ;
	}
#Minimal stomatal resistance
'260192' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 200 ;
	}
#Solar parameter in canopy conductance
'260193' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 202 ;
	}
#Temperature parameter in canopy conductance
'260194' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 203 ;
	}
#Soil moisture parameter in canopy conductance
'260195' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 205 ;
	}
#Humidity parameter in canopy conductance
'260196' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 204 ;
	}
#Liquid volumetric soil moisture (non-frozen)
'260205' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}
#Number of soil layers in root zone
'260206' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#Transpiration stress-onset (soil moisture)
'260207' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}
#Direct evaporation cease (soil moisture)
'260208' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}
#Soil porosity
'260209' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	}
#Temperature tendency by all radiation
'260243' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}
#Relative Error Variance
'260244' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	}
#Large Scale Condensate Heating rate
'260245' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}
#Deep Convective Heating rate
'260246' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}
#Total Downward Heat Flux at Surface
'260247' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}
#Temperature Tendency By All Physics
'260248' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 198 ;
	}
#Temperature Tendency By Non-radiation Physics
'260249' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 199 ;
	}
#Standard Dev. of IR Temp. over 1x1 deg. area
'260250' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 200 ;
	}
#Shallow Convective Heating rate
'260251' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	}
#Vertical Diffusion Heating rate
'260252' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 202 ;
	}
#Potential temperature at top of viscous sublayer
'260253' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 203 ;
	}
#Tropical Cyclone Heat Potential
'260254' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 204 ;
	}
#Minimum Relative Humidity
'260261' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	}
#Total Icing Potential Diagnostic
'260269' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 206 ;
	}
#Number concentration for ice particles
'260270' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 207 ;
	}
#Snow temperature
'260271' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 208 ;
	}
#Total column-integrated supercooled liquid water
'260272' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 209 ;
	}
#Total column-integrated melting ice
'260273' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 210 ;
	}
#Evaporation - Precipitation
'260274' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 211 ;
	}
#Sublimation (evaporation from snow)
'260275' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 212 ;
	}
#Deep Convective Moistening Rate
'260276' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 213 ;
	}
#Shallow Convective Moistening Rate
'260277' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 214 ;
	}
#Vertical Diffusion Moistening Rate
'260278' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 215 ;
	}
#Condensation Pressure of Parcali Lifted From Indicate Surface
'260279' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 216 ;
	}
#Large scale moistening rate
'260280' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 217 ;
	}
#Specific humidity at top of viscous sublayer
'260281' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 218 ;
	}
#Maximum specific humidity at 2m
'260282' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 219 ;
	}
#Minimum specific humidity at 2m
'260283' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 220 ;
	}
#Liquid precipitation (rainfall)
'260284' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 221 ;
	}
#Snow temperature, depth-avg
'260285' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 222 ;
	}
#Total precipitation (nearest grid point)
'260286' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 223 ;
	}
#Convective precipitation (nearest grid point)
'260287' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 224 ;
	}
#Freezing Rain
'260288' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 225 ;
	}
#Latitude of U Wind Component of Velocity
'260295' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 198 ;
	}
#Longitude of U Wind Component of Velocity
'260296' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 199 ;
	}
#Latitude of V Wind Component of Velocity
'260297' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 200 ;
	}
#Longitude of V Wind Component of Velocity
'260298' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 201 ;
	}
#Latitude of Pressure Point
'260299' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 202 ;
	}
#Longitude of Pressure Point
'260300' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 203 ;
	}
#Vertical Eddy Diffusivity Heat exchange
'260301' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 204 ;
	}
#Covariance between Meridional and Zonal Components of the wind.
'260302' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 205 ;
	}
#Covariance between Temperature and Zonal Components of the wind.
'260303' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 206 ;
	}
#Covariance between Temperature and Meridional Components of the wind.
'260304' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 207 ;
	}
#Vertical Diffusion Zonal Acceleration
'260305' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 208 ;
	}
#Vertical Diffusion Meridional Acceleration
'260306' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 209 ;
	}
#Gravity wave drag zonal acceleration
'260307' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 210 ;
	}
#Gravity wave drag meridional acceleration
'260308' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 211 ;
	}
#Convective zonal momentum mixing acceleration
'260309' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 212 ;
	}
#Convective meridional momentum mixing acceleration
'260310' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 213 ;
	}
#Tendency of vertical velocity
'260311' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 214 ;
	}
#Omega (Dp/Dt) divide by density
'260312' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 215 ;
	}
#Convective Gravity wave drag zonal acceleration
'260313' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 216 ;
	}
#Convective Gravity wave drag meridional acceleration
'260314' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 217 ;
	}
#Velocity Point Model Surface
'260315' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 218 ;
	}
#Potential Vorticity (Mass-Weighted)
'260316' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 219 ;
	}
#MSLP (Eta model reduction)
'260317' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}
#MSLP (MAPS System Reduction)
'260323' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}
#3-hr pressure tendency (Std. Atmos. Reduction)
'260324' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}
#Pressure of level from which parcel was lifted
'260325' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	}
#X-gradient of Log Pressure
'260326' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	}
#Y-gradient of Log Pressure
'260327' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 202 ;
	}
#X-gradient of Height
'260328' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 203 ;
	}
#Y-gradient of Height
'260329' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 204 ;
	}
#Layer Thickness
'260330' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 205 ;
	}
#Natural Log of Surface Pressure
'260331' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 206 ;
	}
#Convective updraft mass flux
'260332' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 207 ;
	}
#Convective downdraft mass flux
'260333' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 208 ;
	}
#Convective detrainment mass flux
'260334' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 209 ;
	}
#Mass Point Model Surface
'260335' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 210 ;
	}
#Geopotential Height (nearest grid point)
'260336' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 211 ;
	}
#Pressure (nearest grid point)
'260337' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 212 ;
	}
#UV-B downward solar flux
'260340' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	}
#Clear sky UV-B downward solar flux
'260341' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	}
#Clear Sky Downward Solar Flux
'260342' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	}
#Solar Radiative Heating Rate
'260343' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 197 ;
	}
#Clear Sky Upward Solar Flux
'260344' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	}
#Cloud Forcing Net Solar Flux
'260345' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 199 ;
	}
#Visible Beam Downward Solar Flux
'260346' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 200 ;
	}
#Visible Diffuse Downward Solar Flux
'260347' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 201 ;
	}
#Near IR Beam Downward Solar Flux
'260348' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 202 ;
	}
#Near IR Diffuse Downward Solar Flux
'260349' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 203 ;
	}
#Downward Total radiation Flux
'260350' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 204 ;
	}
#Upward Total radiation Flux
'260351' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 205 ;
	}
#Long-Wave Radiative Heating Rate
'260354' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 194 ;
	}
#Clear Sky Upward Long Wave Flux
'260355' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 195 ;
	}
#Clear Sky Downward Long Wave Flux
'260356' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 196 ;
	}
#Cloud Forcing Net Long Wave Flux
'260357' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 197 ;
	}
#Convective Cloud Mass Flux
'260366' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 200 ;
	}
#Richardson Number
'260369' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 194 ;
	}
#Convective Weather Detection Index
'260370' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 195 ;
	}
#Updraft Helicity
'260372' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 197 ;
	}
#Leaf Area Index
'260373' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 198 ;
	}
#Particulate matter (coarse)
'260374' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 192 ;
	}
#Particulate matter (fine)
'260375' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 193 ;
	}
#Particulate matter (fine)
'260376' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 194 ;
	}
#Integrated column particulate matter (fine)
'260377' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 195 ;
	}
#Ozone Concentration (PPB)
'260379' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 193 ;
	}
#Categorical Ozone Concentration
'260380' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 194 ;
	}
#Ozone vertical diffusion
'260381' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 195 ;
	}
#Ozone production
'260382' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 196 ;
	}
#Ozone tendency
'260383' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 197 ;
	}
#Ozone production from temperature term
'260384' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 198 ;
	}
#Ozone production from col ozone term
'260385' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 199 ;
	}
#Derived radar reflectivity backscatter from rain
'260386' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 192 ;
	}
#Derived radar reflectivity backscatter from ice
'260387' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 193 ;
	}
#Derived radar reflectivity backscatter from parameterized convection
'260388' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 194 ;
	}
#Derived radar reflectivity
'260389' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 195 ;
	}
#Maximum/Composite radar reflectivity
'260390' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 196 ;
	}
#Lightning
'260391' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 192 ;
	}
#Slight risk convective outlook
'260394' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 194 ;
	}
#Moderate risk convective outlook
'260395' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 195 ;
	}
#High risk convective outlook
'260396' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 196 ;
	}
#Tornado probability
'260397' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 197 ;
	}
#Hail probability
'260398' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 198 ;
	}
#Wind probability
'260399' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 199 ;
	}
#Significant Tornado probability
'260400' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 200 ;
	}
#Significant Hail probability
'260401' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 201 ;
	}
#Significant Wind probability
'260402' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 202 ;
	}
#Categorical Thunderstorm (1-yes, 0-no)
'260403' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 203 ;
	}
#Number of mixed layers next to surface
'260404' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 204 ;
	}
#Flight Category
'260405' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 205 ;
	}
#Confidence - Ceiling
'260406' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 206 ;
	}
#Confidence - Visibility
'260407' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 207 ;
	}
#Confidence - Flight Category
'260408' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 208 ;
	}
#Low-Level aviation interest
'260409' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 209 ;
	}
#High-Level aviation interest
'260410' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 210 ;
	}
#Visible, Black Sky Albedo
'260411' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 211 ;
	}
#Visible, White Sky Albedo
'260412' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 212 ;
	}
#Near IR, Black Sky Albedo
'260413' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 213 ;
	}
#Near IR, White Sky Albedo
'260414' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 214 ;
	}
#Total Probability of Severe Thunderstorms (Days 2,3)
'260415' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 215 ;
	}
#Total Probability of Extreme Severe Thunderstorms (Days 2,3)
'260416' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 216 ;
	}
#Supercooled Large Droplet (SLD) Potential
'260417' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 217 ;
	}
#Radiative emissivity
'260418' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 218 ;
	}
#Turbulence Potential Forecast Index
'260419' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 219 ;
	}
#Volcanic Ash Forecast Transport and Dispersion
'260420' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 232 ;
	}
#Latitude (-90 to +90)
'260421' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 192 ;
	}
#East Longitude (0 - 360)
'260422' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 193 ;
	}
#Model Layer number (From bottom up)
'260424' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 195 ;
	}
#Latitude (nearest neighbor) (-90 to +90)
'260425' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 196 ;
	}
#East Longitude (nearest neighbor) (0 - 360)
'260426' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 197 ;
	}
#Probability of Freezing Precipitation
'260429' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Probability of precipitation exceeding flash flood guidance values
'260431' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}
#Probability of Wetting Rain, exceeding in 0.10 in a given time period
'260432' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}
#Vegetation Type
'260439' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 198 ;
	}
#Wilting Point
'260442' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	}
#Rate of water dropping from canopy to ground
'260447' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 206 ;
	}
#Ice-free water surface
'260448' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 207 ;
	}
#Surface exchange coefficients for T and Q divided by delta z
'260449' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 208 ;
	}
#Surface exchange coefficients for U and V divided by delta z
'260450' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 209 ;
	}
#Vegetation canopy temperature
'260451' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 210 ;
	}
#Surface water storage
'260452' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 211 ;
	}
#Liquid soil moisture content (non-frozen)
'260453' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 212 ;
	}
#Open water evaporation (standing water)
'260454' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 213 ;
	}
#Groundwater recharge
'260455' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 214 ;
	}
#Flood plain recharge
'260456' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 215 ;
	}
#Roughness length for heat
'260457' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 216 ;
	}
#Normalized Difference Vegetation Index
'260458' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 217 ;
	}
#Land-sea coverage (nearest neighbor) [land=1,sea=0]
'260459' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 218 ;
	}
#Asymptotic mixing length scale
'260460' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 219 ;
	}
#Water vapor added by precip assimilation
'260461' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 220 ;
	}
#Water condensate added by precip assimilation
'260462' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 221 ;
	}
#Water Vapor Flux Convergence (Vertical Int)
'260463' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 222 ;
	}
#Water Condensate Flux Convergence (Vertical Int)
'260464' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 223 ;
	}
#Water Vapor Zonal Flux (Vertical Int)
'260465' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 224 ;
	}
#Water Vapor Meridional Flux (Vertical Int)
'260466' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 225 ;
	}
#Water Condensate Zonal Flux (Vertical Int)
'260467' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 226 ;
	}
#Water Condensate Meridional Flux (Vertical Int)
'260468' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 227 ;
	}
#Aerodynamic conductance
'260469' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 228 ;
	}
#Canopy water evaporation
'260470' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 229 ;
	}
#Transpiration
'260471' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 230 ;
	}
#Surface Slope Type
'260474' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}
#Direct evaporation from bare soil
'260478' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}
#Land Surface Precipitation Accumulation
'260479' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}
#Bare soil surface skin temperature
'260480' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	}
#Average surface skin temperature
'260481' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	}
#Effective radiative skin temperature
'260482' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 202 ;
	}
#Field Capacity
'260483' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 203 ;
	}
#Scatterometer Estimated U Wind Component
'260484' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Scatterometer Estimated V Wind Component
'260485' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Wave Steepness
'260486' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Ocean Mixed Layer U Velocity
'260487' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Ocean Mixed Layer V Velocity
'260488' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Barotropic U velocity
'260489' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}
#Barotropic V velocity
'260490' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}
#Storm Surge
'260491' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}
#Extra Tropical Storm Surge
'260492' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#Ocean Surface Elevation Relative to Geoid
'260493' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}
#Sea Surface Height Relative to Geoid
'260494' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}
#Ocean Mixed Layer Potential Density (Reference 2000m)<br
'260495' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}
#Net Air-Ocean Heat Flux
'260496' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	}
#Assimilative Heat Flux
'260497' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}
#Surface Temperature Trend
'260498' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}
#Surface Salinity Trend
'260499' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	}
#Kinetic Energy
'260500' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	}
#Salt Flux
'260501' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 202 ;
	}
#3-D Temperature
'260502' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}
#3-D Salinity
'260503' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	}
#Barotropic Kinetic Energy
'260504' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	}
#Geometric Depth Below Sea Surface
'260505' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	}
#Interface Depths
'260506' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	}
#Ocean Heat Content
'260507' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 197 ;
	}
#Image data
'260508' = {
	 discipline = 255 ;
	 parameterCategory = 255 ;
	 parameterNumber = 255 ;
	}
#Sunshine Duration
'7001292' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 201 ;
	}
#Icing severity
'7001293' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 234 ;
	}
#Simulated Brightness Temperature for AMSRE on Aqua, Channel 10
'7001294' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 11 ;
	}
#Simulated Brightness Temperature for AMSRE on Aqua, Channel 11
'7001295' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 12 ;
	}
#Simulated Brightness Temperature for AMSRE on Aqua, Channel 12
'7001296' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 13 ;
	}
#Simulated Brightness Temperature for AMSRE on Aqua, Channel 9
'7001297' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 10 ;
	}
#Simulated Brightness Counts for GOES 12, Channel 3
'7001298' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 4 ;
	}
#Simulated Brightness Counts for GOES 12, Channel 4
'7001299' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 5 ;
	}
#Simulated Brightness Temperature for GOES 11, Channel 2
'7001300' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 6 ;
	}
#Simulated Brightness Temperature for GOES 11, Channel 3
'7001301' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 7 ;
	}
#Simulated Brightness Temperature for GOES 11, Channel 4
'7001302' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 8 ;
	}
#Simulated Brightness Temperature for GOES 11, Channel 5
'7001303' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 9 ;
	}
#Simulated Brightness Temperature for GOES 12, Channel 2
'7001304' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 0 ;
	}
#Simulated Brightness Temperature for GOES 12, Channel 3
'7001305' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 1 ;
	}
#Simulated Brightness Temperature for GOES 12, Channel 4
'7001306' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 2 ;
	}
#Simulated Brightness Temperature for GOES 12, Channel 6
'7001307' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 3 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-10
'7001308' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 23 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-11
'7001309' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 24 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-12
'7001310' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 25 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-13
'7001311' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 26 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-14
'7001312' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 27 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-15
'7001313' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 28 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-16
'7001314' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 29 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-7
'7001315' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 20 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-8
'7001316' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 21 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-9
'7001317' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 22 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-10
'7001318' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 39 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-11
'7001319' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 40 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-12
'7001320' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 41 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-13
'7001321' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 42 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-14
'7001322' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 43 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-15
'7001323' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 44 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-16
'7001324' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 45 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-7
'7001325' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 36 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-8
'7001326' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 37 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-9
'7001327' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 38 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-1
'7001328' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 14 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-2
'7001329' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 15 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-3
'7001330' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 16 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-4
'7001331' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 17 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-5
'7001332' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 18 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-6
'7001333' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 19 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-1
'7001334' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 30 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-2
'7001335' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 31 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-3
'7001336' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 32 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-4
'7001337' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 33 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-5
'7001338' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 34 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-6
'7001339' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 35 ;
	}
#Ventilation Rate
'7001353' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 224 ;
	}
#Convective inhibition
'228001' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	}
#Total Cloud Cover
'228164' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	}
#Total Precipitation
'228228' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 8 ;
}
