# (C) Copyright 2005- ECMWF.

# Local definition 60 - Ocean data analysis date and analysis time

unsigned[2] yearOfAnalysis = 0 : dump;
unsigned[1] monthOfAnalysis = 0 : dump;
unsigned[1] dayOfAnalysis = 0 : dump;
unsigned[1] hourOfAnalysis = 0 : dump;
unsigned[1] minuteOfAnalysis = 0 : dump;

constant secondsOfAnalysis = 0;

meta dateOfAnalysis  g2date(yearOfAnalysis,monthOfAnalysis,dayOfAnalysis) : dump;
meta timeOfAnalysis  time(hourOfAnalysis,minuteOfAnalysis,secondsOfAnalysis) : dump;

#alias mars.refdate = dateOfAnalysis;
#alias mars.reftime = timeOfAnalysis;
#alias mars.date = dateOfAnalysis;
#alias mars.time = timeOfAnalysis;
#alias mars.offdate = dataDate;
#alias mars.offtime = dataTime;
