# Concept combinationOfAttributesOfTile

'undef' = {attributeOfTile = [0];}
'unmod' = {attributeOfTile = [1];}
'snow' = {attributeOfTile = [2];}
'flood' = {attributeOfTile = [3];}
'ice' = {attributeOfTile = [4];}
'itcw' = {attributeOfTile = [5];}
'itcs' = {attributeOfTile = [6];}
'agg' = {attributeOfTile = [7];}

'snow_flood' = {attributeOfTile = [2,3];}
'snow_ice' = {attributeOfTile = [2,4];}
'snow_itcw' = {attributeOfTile = [2,5];}
'snow_itcs' = {attributeOfTile = [2,6];}
'flood_ice' = {attributeOfTile = [3,4];}
'flood_itcw' = {attributeOfTile = [3,5];}
'flood_itcs' = {attributeOfTile = [3,6];}
'ice_itcw' = {attributeOfTile = [4,5];}
'ice_itcs' = {attributeOfTile = [4,6];}
'itcw_itcs' = {attributeOfTile = [5,6];}

'snow_flood_ice' = {attributeOfTile = [2,3,4];}
'snow_flood_itcw' = {attributeOfTile = [2,3,5];}
'snow_flood_itcs' = {attributeOfTile = [2,3,6];}
'snow_ice_itcw' = {attributeOfTile = [2,4,5];}
'snow_ice_itcs' = {attributeOfTile = [2,4,6];}
'snow_itcw_itcs' = {attributeOfTile = [2,5,6];}
'flood_ice_itcw' = {attributeOfTile = [3,4,5];}
'flood_ice_itcs' = {attributeOfTile = [3,4,6];}
'flood_itcw_itcs' = {attributeOfTile = [3,5,6];}
'ice_itcw_itcs' = {attributeOfTile = [4,5,6];}

'snow_flood_ice_itcw' = {attributeOfTile = [2,3,4,5];}
'snow_flood_ice_itcs' = {attributeOfTile = [2,3,4,6];}
'snow_flood_itcw_itcs' = {attributeOfTile = [2,3,5,6];}
'snow_ice_itcw_itcs' = {attributeOfTile = [2,4,5,6];}
'flood_ice_itcw_itcs' = {attributeOfTile = [3,4,5,6];}

'snow_flood_ice_itcw_itcs' = {attributeOfTile = [2,3,4,5,6];}

