# author: Sebastien Villaume
# created: 14 Feb 2014
#
#
# This piece of definition is common to all SMHI definitions
# It is only accessed through "include" statement inside local.82.x.def
#

codetable[1]    marsClass   "mars/eswi/class.table"     : dump,lowercase;
codetable[1]    marsType    "mars/eswi/type.table"      : dump,lowercase,string_type;
codetable[2]    marsStream  "mars/eswi/stream.table"    : dump,lowercase,string_type;
ksec1expver[4]  experimentVersionNumber = "0000"        : dump;
# For now, Ensemble stuff is desactivated because it is not used yet
# instead we use a padding of 2
#unsigned[1]    perturbationNumber : dump;
#unsigned[1]    numberOfForecastsInEnsemble : dump;
pad reservedNeedNotBePresent(2);
codetable[1]    marsModel   "mars/eswi/model.table"     : dump,lowercase,string_type;

