# Automatically generated by ./create_defs.grib1.pl, do not edit
#Pressure
'300001' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 1 ;
	}
#Pressure reduced to msl
'300002' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 2 ;
	}
#Pressure tendency
'300003' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 3 ;
	}
#Geopotential
'300006' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 6 ;
	}
#Geopotential height
'300007' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 7 ;
	}
#Geometric height
'300008' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 8 ;
	}
#Absolute temperature
'300011' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 11 ;
	}
#Virtual temperature
'300012' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 12 ;
	}
#Potential temperature
'300013' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 13 ;
	}
#Pseudo-adiabatic potential temperature
'300014' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 14 ;
	}
#Maximum temperature
'300015' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 15 ;
	}
#Minimum temperature
'300016' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 16 ;
	}
#Dew point temperature
'300017' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 17 ;
	}
#Dew point depression
'300018' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 18 ;
	}
#Lapse rate
'300019' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 19 ;
	}
#Radar spectra(1)
'300021' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 21 ;
	}
#Radar spectra(2)
'300022' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 22 ;
	}
#Radar spectra(3)
'300023' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 23 ;
	}
#Temperature anomaly
'300025' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 25 ;
	}
#Pressure anomaly
'300026' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 26 ;
	}
#Geopot height anomaly
'300027' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 27 ;
	}
#Wave spectra(1)
'300028' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 28 ;
	}
#Wave spectra(2)
'300029' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 29 ;
	}
#Wave spectra(3)
'300030' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 30 ;
	}
#Wind direction
'300031' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 31 ;
	}
#Wind speed
'300032' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 32 ;
	}
#Zonal wind (u)
'300033' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 33 ;
	}
#Meridional wind (v)
'300034' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 34 ;
	}
#Stream function
'300035' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 35 ;
	}
#Velocity potential
'300036' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 36 ;
	}
#Sigma coord vert vel
'300038' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 38 ;
	}
#Omega
'300039' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 39 ;
	}
#Vertical velocity
'300040' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 40 ;
	}
#Absolute vorticity
'300041' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 41 ;
	}
#Absolute divergence
'300042' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 42 ;
	}
#Vorticity
'300043' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 43 ;
	}
#Divergence
'300044' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 44 ;
	}
#Vertical u-comp shear
'300045' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 45 ;
	}
#Vert v-comp shear
'300046' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 46 ;
	}
#Direction of current
'300047' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 47 ;
	}
#Speed of current
'300048' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 48 ;
	}
#U-component of current
'300049' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 49 ;
	}
#V-component of current
'300050' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 50 ;
	}
#Specific humidity
'300051' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 51 ;
	}
#Relative humidity
'300052' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 52 ;
	}
#Humidity mixing ratio
'300053' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 53 ;
	}
#Inst. precipitable water
'300054' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 54 ;
	}
#Vapour pressure
'300055' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 55 ;
	}
#Saturation deficit
'300056' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 56 ;
	}
#Evaporation
'300057' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 57 ;
	}
#Precipitation rate
'300059' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 59 ;
	}
#Thunder probability
'300060' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 60 ;
	}
#Total precipitation
'300061' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 61 ;
	}
#Large scale precipitation
'300062' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 62 ;
	}
#Convective precipitation
'300063' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 63 ;
	}
#Snowfall
'300064' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 64 ;
	}
#Wat equiv acc snow depth
'300065' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 65 ;
	}
#Snow depth
'300066' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 66 ;
	}
#Mixed layer depth
'300067' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 67 ;
	}
#Trans thermocline depth
'300068' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 68 ;
	}
#Main thermocline depth
'300069' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 69 ;
	}
#Main thermocline anom
'300070' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 70 ;
	}
#Cloud cover
'300071' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 71 ;
	}
#Convective cloud cover
'300072' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 72 ;
	}
#Low cloud cover
'300073' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 73 ;
	}
#Medium cloud cover
'300074' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 74 ;
	}
#High cloud cover
'300075' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 75 ;
	}
#Cloud water
'300076' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 76 ;
	}
#Best lifted index (to 500 hpa)
'300077' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 77 ;
	}
#Land sea mask
'300081' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 81 ;
	}
#Dev sea_lev from mean
'300082' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 82 ;
	}
#Roughness length
'300083' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 83 ;
	}
#Albedo
'300084' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 84 ;
	}
#Deep soil temperature
'300085' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 85 ;
	}
#Soil moisture content
'300086' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 86 ;
	}
#Vegetation
'300087' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 87 ;
	}
#Density
'300089' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 89 ;
	}
#Ice concentration
'300091' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 91 ;
	}
#Ice thickness
'300092' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 92 ;
	}
#Direction of ice drift
'300093' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 93 ;
	}
#Speed of ice drift
'300094' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 94 ;
	}
#U-comp of ice drift
'300095' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 95 ;
	}
#V-comp of ice drift
'300096' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 96 ;
	}
#Ice growth
'300097' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 97 ;
	}
#Ice divergence
'300098' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 98 ;
	}
#Sig hgt com wave/swell
'300100' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 100 ;
	}
#Direction of wind wave
'300101' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 101 ;
	}
#Sig hght of wind waves
'300102' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 102 ;
	}
#Mean period wind waves
'300103' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 103 ;
	}
#Direction of swell wave
'300104' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 104 ;
	}
#Sig height swell waves
'300105' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 105 ;
	}
#Mean period swell waves
'300106' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 106 ;
	}
#Primary wave direction
'300107' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 107 ;
	}
#Prim wave mean period
'300108' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 108 ;
	}
#Second wave direction
'300109' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 109 ;
	}
#Second wave mean period
'300110' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 110 ;
	}
#Short wave absorbed at ground
'300111' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 111 ;
	}
#Net long wave at bottom
'300112' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 112 ;
	}
#Net short-wav rad(top)
'300113' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 113 ;
	}
#Outgoing long wave at top
'300114' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 114 ;
	}
#Long-wav rad
'300115' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 115 ;
	}
#Short wave absorbed by earth/atmosphere
'300116' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 116 ;
	}
#Global radiation
'300117' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 117 ;
	}
#Latent heat flux from surface
'300121' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 121 ;
	}
#Sensible heat flux from surface
'300122' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 122 ;
	}
#Bound layer dissipation
'300123' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 123 ;
	}
#Image
'300127' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 127 ;
	}
#2 metre temperature
'300128' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 128 ;
	}
#2 metre dewpoint temperature
'300129' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 129 ;
	}
#10 metre u-wind component
'300130' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 130 ;
	}
#10 metre v-wind component
'300131' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 131 ;
	}
#Topography
'300132' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 132 ;
	}
#Geometric mean surface pressure
'300133' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 133 ;
	}
#Ln surface pressure
'300134' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 134 ;
	}
#Surface pressure
'300135' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 135 ;
	}
#M s l pressure (mesinger method)
'300136' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 136 ;
	}
#Mask
'300137' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 137 ;
	}
#Maximum u-wind
'300138' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 138 ;
	}
#Maximum v-wind
'300139' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 139 ;
	}
#Convective avail. pot.energy
'300140' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 140 ;
	}
#Convective inhib. energy
'300141' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 141 ;
	}
#Convective latent heating
'300142' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 142 ;
	}
#Convective moisture source
'300143' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 143 ;
	}
#Shallow conv. moisture source
'300144' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 144 ;
	}
#Shallow convective heating
'300145' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 145 ;
	}
#Maximum wind press. lvl
'300146' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 146 ;
	}
#Storm motion u-component
'300147' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 147 ;
	}
#Storm motion v-component
'300148' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 148 ;
	}
#Mean cloud cover
'300149' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 149 ;
	}
#Pressure at cloud base
'300150' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 150 ;
	}
#Pressure at cloud top
'300151' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 151 ;
	}
#Freezing level height
'300152' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 152 ;
	}
#Freezing level relative humidity
'300153' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 153 ;
	}
#Flight levels temperature
'300154' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 154 ;
	}
#Flight levels u-wind
'300155' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 155 ;
	}
#Flight levels v-wind
'300156' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 156 ;
	}
#Tropopause pressure
'300157' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 157 ;
	}
#Tropopause temperature
'300158' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 158 ;
	}
#Tropopause u-wind component
'300159' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 159 ;
	}
#Tropopause v-wind component
'300160' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 160 ;
	}
#Gravity wave drag du/dt
'300162' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 162 ;
	}
#Gravity wave drag dv/dt
'300163' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 163 ;
	}
#Gravity wave drag sfc zonal stress
'300164' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 164 ;
	}
#Gravity wave drag sfc meridional stress
'300165' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 165 ;
	}
#Divergence of specific humidity
'300167' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 167 ;
	}
#Horiz. moisture flux conv.
'300168' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 168 ;
	}
#Vert. integrated moisture flux conv.
'300169' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 169 ;
	}
#Vertical moisture advection
'300170' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 170 ;
	}
#Neg. hum. corr. moisture source
'300171' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 171 ;
	}
#Large scale latent heating
'300172' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 172 ;
	}
#Large scale moisture source
'300173' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 173 ;
	}
#Soil moisture availability
'300174' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 174 ;
	}
#Soil temperature of root zone
'300175' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 175 ;
	}
#Bare soil latent heat
'300176' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 176 ;
	}
#Potential sfc evaporation
'300177' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 177 ;
	}
#Runoff
'300178' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 178 ;
	}
#Interception loss
'300179' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 179 ;
	}
#Vapor pressure of canopy air space
'300180' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 180 ;
	}
#Surface spec humidity
'300181' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 181 ;
	}
#Soil wetness of surface
'300182' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 182 ;
	}
#Soil wetness of root zone
'300183' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 183 ;
	}
#Soil wetness of drainage zone
'300184' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 184 ;
	}
#Storage on canopy
'300185' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 185 ;
	}
#Storage on ground
'300186' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 186 ;
	}
#Surface temperature
'300187' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 187 ;
	}
#Surface absolute temperature
'300188' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 188 ;
	}
#Temperature of canopy air space
'300189' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 189 ;
	}
#Temperature at canopy
'300190' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 190 ;
	}
#Ground/surface cover temperature
'300191' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 191 ;
	}
#Surface zonal wind (u)
'300192' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 192 ;
	}
#Surface zonal wind stress
'300193' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 193 ;
	}
#Surface meridional wind (v)
'300194' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 194 ;
	}
#Surface meridional wind stress
'300195' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 195 ;
	}
#Surface momentum flux
'300196' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 196 ;
	}
#Incident short wave flux
'300197' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 197 ;
	}
#Time ave ground ht flx
'300198' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 198 ;
	}
#Net long wave at bottom (clear)
'300200' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 200 ;
	}
#Outgoing long wave at top (clear)
'300201' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 201 ;
	}
#Short wv absrbd by earth/atmos (clear)
'300202' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 202 ;
	}
#Short wave absorbed at ground (clear)
'300203' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 203 ;
	}
#Long wave radiative heating
'300205' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 205 ;
	}
#Short wave radiative heating
'300206' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 206 ;
	}
#Downward long wave at bottom
'300207' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 207 ;
	}
#Downward long wave at bottom (clear)
'300208' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 208 ;
	}
#Downward short wave at ground
'300209' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 209 ;
	}
#Downward short wave at ground (clear)
'300210' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 210 ;
	}
#Upward long wave at bottom
'300211' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 211 ;
	}
#Upward short wave at ground
'300212' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 212 ;
	}
#Upward short wave at ground (clear)
'300213' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 213 ;
	}
#Upward short wave at top
'300214' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 214 ;
	}
#Upward short wave at top (clear)
'300215' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 215 ;
	}
#Horizontal heating diffusion
'300218' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 218 ;
	}
#Horizontal moisture diffusion
'300219' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 219 ;
	}
#Horizontal divergence diffusion
'300220' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 220 ;
	}
#Horizontal vorticity diffusion
'300221' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 221 ;
	}
#Vertical diff. moisture source
'300222' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 222 ;
	}
#Vertical diffusion du/dt
'300223' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 223 ;
	}
#Vertical diffusion dv/dt
'300224' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 224 ;
	}
#Vertical diffusion heating
'300225' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 225 ;
	}
#Surface relative humidity
'300226' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 226 ;
	}
#Vertical dist total cloud cover
'300227' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 227 ;
	}
#Time mean surface zonal wind (u)
'300230' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 230 ;
	}
#Time mean surface meridional wind (v)
'300231' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 231 ;
	}
#Time mean surface absolute temperature
'300232' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 232 ;
	}
#Time mean surface relative humidity
'300233' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 233 ;
	}
#Time mean absolute temperature
'300234' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 234 ;
	}
#Time mean deep soil temperature
'300235' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 235 ;
	}
#Time mean derived omega
'300236' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 236 ;
	}
#Time mean divergence
'300237' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 237 ;
	}
#Time mean geopotential height
'300238' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 238 ;
	}
#Time mean log surface pressure
'300239' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 239 ;
	}
#Time mean mask
'300240' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 240 ;
	}
#Time mean meridional wind (v)
'300241' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 241 ;
	}
#Time mean omega
'300242' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 242 ;
	}
#Time mean potential temperature
'300243' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 243 ;
	}
#Time mean precip. water
'300244' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 244 ;
	}
#Time mean relative humidity
'300245' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 245 ;
	}
#Time mean sea level pressure
'300246' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 246 ;
	}
#Time mean sigmadot
'300247' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 247 ;
	}
#Time mean specific humidity
'300248' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 248 ;
	}
#Time mean stream function
'300249' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 249 ;
	}
#Time mean surface pressure
'300250' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 250 ;
	}
#Time mean surface temperature
'300251' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 251 ;
	}
#Time mean velocity potential
'300252' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 252 ;
	}
#Time mean virtual temperature
'300253' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 253 ;
	}
#Time mean vorticity
'300254' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 254 ;
	}
#Time mean zonal wind (u)
'300255' = {
	 table2Version = 254 ;
	 indicatorOfParameter = 255 ;
}
