# (C) Copyright 2005- ECMWF.

# Uncertainties in ensembles of regional re-analysis project (UERRA)
if(localUsePresent == 0){
constant marsExpver = 'prod';
} else {
constant marsExpver = experimentVersionNumber;
}
include "grib2/products_uerra.def"
