# Local definition 20: 4D variational increments

unsigned[1] iterationNumber  : dump;
alias number=iterationNumber;

unsigned[1] totalNumberOfIterations  : dump;
alias totalNumber=totalNumberOfIterations;

alias iteration = iterationNumber;

alias local.iterationNumber =iterationNumber;
alias local.totalNumberOfIterations=totalNumberOfIterations;
