'aifs-single-mse-v0.2.0' = { generatingProcessIdentifier = 1; }
'aifs-single-mse-v0.2.1' = { generatingProcessIdentifier = 2; }
'aifs-single-mse-v1.0' = { generatingProcessIdentifier = 3; }
'aifs-single-mse-v1.1' = { generatingProcessIdentifier = 4; }
'aifs-single-mse-v2.0' = { generatingProcessIdentifier = 5; }
