'v0.2.0' = { generatingProcessIdentifier = 1; }
'v0.2.1' = { generatingProcessIdentifier = 2; }
'v1.0' = { generatingProcessIdentifier = 3; }
'v1.1' = { generatingProcessIdentifier = 4; }
'v2.0' = { generatingProcessIdentifier = 5; }
