#1-39 keep the numbers for Efas
'v2' = { generatingProcessIdentifier = 1; }
'v3' = { generatingProcessIdentifier = 2; }
'v3.5' = { generatingProcessIdentifier = 3 ; }
'v4' = { generatingProcessIdentifier = 4; }
'v5' = { generatingProcessIdentifier = 5; }

#40-79 keep the numbers for Glofas
'v3.1' = { generatingProcessIdentifier = 40; }
'v4.0' = { generatingProcessIdentifier = 41; }

#80-119 keep the numbers for c3s europe
'v1' = { generatingProcessIdentifier = 80; }

#120-159 keep the numbers for c3s global
'v1' = { generatingProcessIdentifier = 120; }
