# (C) Copyright 2005- ECMWF.

# GRID DEFINITION stretched latitude/longitude grid
# grib 1 -> 2
constant gridDefinitionTemplateNumber     = 2;

template commonBlock "grib1/grid_definition_latlon.def";

ascii[4] zeros : read_only;

# Stretching parameters
include "grib1/grid_stretching.def"
