# Concept paramtype
#
# parameters in the wave part of table 4.2
'wave' = {discipline=10; parameterCategory=0;}
# some specific wave parameters outside the wave table
# to be replaced if entries in wave part of 4.2 available
'wave' = {
          true = is_one_of(paramId,140101,141101,143101,144101,145101,140102,141102,143102,144102,145102);
          true = is_one_of(MTG2Switch,1,2);
         }
'base' = {productDefinitionTemplateNumber=0;}
'base' = {productDefinitionTemplateNumber=1;}
'base' = {productDefinitionTemplateNumber=2;}
'base' = {productDefinitionTemplateNumber=3;}
'base' = {productDefinitionTemplateNumber=4;}
'base' = {productDefinitionTemplateNumber=5;}
'base' = {productDefinitionTemplateNumber=6;}
'base' = {productDefinitionTemplateNumber=7;}
'base' = {productDefinitionTemplateNumber=8;}
'base' = {productDefinitionTemplateNumber=9;}
'base' = {productDefinitionTemplateNumber=10;}
'base' = {productDefinitionTemplateNumber=11;}
'base' = {productDefinitionTemplateNumber=12;}
'base' = {productDefinitionTemplateNumber=13;}
'base' = {productDefinitionTemplateNumber=14;}
'base' = {productDefinitionTemplateNumber=15;}
'base' = {productDefinitionTemplateNumber=20;}
'satellite' = {productDefinitionTemplateNumber=30;}
'satellite' = {productDefinitionTemplateNumber=31;}
'satellite' = {productDefinitionTemplateNumber=32;}
'satellite' = {productDefinitionTemplateNumber=33;}
'satellite' = {productDefinitionTemplateNumber=34;}
'satellite' = {productDefinitionTemplateNumber=35;}
# chemical templates should appear in gribMix as paramtype base
# gribMix data won't have the chem mars key !
'base' = {productDefinitionTemplateNumber=40; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=41; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=42; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=43; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=44; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=45; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=46; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=47; MTG2Switch=1;}
'chemical' = {productDefinitionTemplateNumber=40; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=41; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=42; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=43; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=44; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=45; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=46; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=47; MTG2Switch=2;}
# chemical optical parameters in gribMix have no chem 
# therefore they have paramtype optical
'optical' = {productDefinitionTemplateNumber=48; MTG2Switch=1;}
'optical' = {productDefinitionTemplateNumber=49; MTG2Switch=1;}
'chemical_optical' = {productDefinitionTemplateNumber=48; MTG2Switch=2;}
'chemical_optical' = {productDefinitionTemplateNumber=49; MTG2Switch=2;}
# chemical templates should appear in gribMix as paramtype base
# gribMix data won't have the chem mars key !
'base' = {productDefinitionTemplateNumber=50; MTG2Switch=1;}
'chemical' = {productDefinitionTemplateNumber=50; MTG2Switch=2;}
'base' = {productDefinitionTemplateNumber=51;}
'base' = {productDefinitionTemplateNumber=53;}
'base' = {productDefinitionTemplateNumber=54;}
'tile' = {productDefinitionTemplateNumber=55;}
'base' = {productDefinitionTemplateNumber=56;}
# chemical templates should appear in gribMix as paramtype base
# gribMix data won't have the chem mars key !
'base' = {productDefinitionTemplateNumber=57; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=58; MTG2Switch=1;}
'chemical' = {productDefinitionTemplateNumber=57; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=58; MTG2Switch=2;}
'tile' = {productDefinitionTemplateNumber=59;}
'base' = {productDefinitionTemplateNumber=60;}
'base' = {productDefinitionTemplateNumber=61;}
'tile' = {productDefinitionTemplateNumber=62;}
'tile' = {productDefinitionTemplateNumber=63;}
# chemical templates should appear in gribMix as paramtype base
# gribMix data won't have the chem mars key !
'base' = {productDefinitionTemplateNumber=67; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=68; MTG2Switch=1;}
'chemical' = {productDefinitionTemplateNumber=67; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=68; MTG2Switch=2;}
'base' = {productDefinitionTemplateNumber=70;}
'base' = {productDefinitionTemplateNumber=71;}
'base' = {productDefinitionTemplateNumber=72;}
'base' = {productDefinitionTemplateNumber=73;}
# chemical templates should appear in gribMix as paramtype base
# gribMix data won't have the chem mars key !
'base' = {productDefinitionTemplateNumber=76; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=77; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=78; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=79; MTG2Switch=1;}
'chemical' = {productDefinitionTemplateNumber=76; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=77; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=78; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=79; MTG2Switch=2;}
# chemical optical parameters in gribMix have no chem
# therefore they have paramtype optical
'optical' = {productDefinitionTemplateNumber=80; MTG2Switch=1;}
'optical' = {productDefinitionTemplateNumber=81; MTG2Switch=1;}
'chemical_optical' = {productDefinitionTemplateNumber=80; MTG2Switch=2;}
'chemical_optical' = {productDefinitionTemplateNumber=81; MTG2Switch=2;}
# chemical templates should appear in gribMix as paramtype base
# gribMix data won't have the chem mars key !
'base' = {productDefinitionTemplateNumber=82; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=83; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=84; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=85; MTG2Switch=1;}
'chemical' = {productDefinitionTemplateNumber=82; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=83; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=84; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=85; MTG2Switch=2;}
'base' = {productDefinitionTemplateNumber=86;}
'base' = {productDefinitionTemplateNumber=87;}
'base' = {productDefinitionTemplateNumber=88;}
'base' = {productDefinitionTemplateNumber=89;}
'base' = {productDefinitionTemplateNumber=90;}
'base' = {productDefinitionTemplateNumber=91;}
'base' = {productDefinitionTemplateNumber=92;}
'base' = {productDefinitionTemplateNumber=93;}
'base' = {productDefinitionTemplateNumber=94;}
'base' = {productDefinitionTemplateNumber=95;}
'base' = {productDefinitionTemplateNumber=96;}
'base' = {productDefinitionTemplateNumber=97;}
'base' = {productDefinitionTemplateNumber=98;}
'wave_spectra' = {productDefinitionTemplateNumber=99; MTG2Switch=1;}
'wave_spectra' = {productDefinitionTemplateNumber=100; MTG2Switch=1;}
'wave_spectra' = {productDefinitionTemplateNumber=101; MTG2Switch=1;}
'wave_spectra' = {productDefinitionTemplateNumber=102; MTG2Switch=1;}
'wave_spectra' = {productDefinitionTemplateNumber=99; MTG2Switch=2;}
'wave_spectra' = {productDefinitionTemplateNumber=100; MTG2Switch=2;}
'wave_spectra' = {productDefinitionTemplateNumber=101; MTG2Switch=2;}
'wave_spectra' = {productDefinitionTemplateNumber=102; MTG2Switch=2;}
'wave' = {productDefinitionTemplateNumber=103; MTG2Switch=1;}
'wave' = {productDefinitionTemplateNumber=104; MTG2Switch=1;}
'wave' = {productDefinitionTemplateNumber=103; MTG2Switch=2;}
'wave' = {productDefinitionTemplateNumber=104; MTG2Switch=2;}
'base' = {productDefinitionTemplateNumber=105;}
'base' = {productDefinitionTemplateNumber=106;}
'base' = {productDefinitionTemplateNumber=107;}
'optical' = {productDefinitionTemplateNumber=108;}
'optical' = {productDefinitionTemplateNumber=109;}
'optical' = {productDefinitionTemplateNumber=110;}
'optical' = {productDefinitionTemplateNumber=111;}
'base' = {productDefinitionTemplateNumber=112;}
'tile' = {productDefinitionTemplateNumber=113;}
'tile' = {productDefinitionTemplateNumber=114;}
'tile' = {productDefinitionTemplateNumber=115;}
'tile' = {productDefinitionTemplateNumber=116;}
'base' = {productDefinitionTemplateNumber=117;}
'base' = {productDefinitionTemplateNumber=118;}
'base' = {productDefinitionTemplateNumber=119;}
'base' = {productDefinitionTemplateNumber=120;}
'base' = {productDefinitionTemplateNumber=121;}
'base' = {productDefinitionTemplateNumber=122;}
'base' = {productDefinitionTemplateNumber=123;}
# chemical templates should appear in gribMix as paramtype base
# gribMix data won't have the chem mars key !
'base' = {productDefinitionTemplateNumber=124; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=125; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=126; MTG2Switch=1;}
'base' = {productDefinitionTemplateNumber=127; MTG2Switch=1;}
'chemical' = {productDefinitionTemplateNumber=124; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=125; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=126; MTG2Switch=2;}
'chemical' = {productDefinitionTemplateNumber=127; MTG2Switch=2;}
'base' = {productDefinitionTemplateNumber=128;}
'base' = {productDefinitionTemplateNumber=129;}
'base' = {productDefinitionTemplateNumber=130;}
'base' = {productDefinitionTemplateNumber=131;}
'base' = {productDefinitionTemplateNumber=132;}
'base' = {productDefinitionTemplateNumber=133;}
'base' = {productDefinitionTemplateNumber=134;}
'base' = {productDefinitionTemplateNumber=135;}
'base' = {productDefinitionTemplateNumber=136;}
'base' = {productDefinitionTemplateNumber=137;}
'base' = {productDefinitionTemplateNumber=138;}
'wave' = {productDefinitionTemplateNumber=139;}
'wave' = {productDefinitionTemplateNumber=140;}
'wave_spectra' = {productDefinitionTemplateNumber=141;}
'wave_spectra' = {productDefinitionTemplateNumber=142;}
'base' = {productDefinitionTemplateNumber=143;}
'wave' = {productDefinitionTemplateNumber=144;}
'wave' = {productDefinitionTemplateNumber=145;}
'base' = {productDefinitionTemplateNumber=146;}
'base' = {productDefinitionTemplateNumber=147;}
'base' = {productDefinitionTemplateNumber=148;}
'base' = {productDefinitionTemplateNumber=149;}
'base' = {productDefinitionTemplateNumber=150;}
'base' = {productDefinitionTemplateNumber=151;}
'chemical' = {productDefinitionTemplateNumber=152;}
'chemical' = {productDefinitionTemplateNumber=153;}
'base' = {productDefinitionTemplateNumber=154;}
'base' = {productDefinitionTemplateNumber=155;}
'base' = {productDefinitionTemplateNumber=254;}
'base' = {productDefinitionTemplateNumber=311;}
'base' = {productDefinitionTemplateNumber=1000;}
'base' = {productDefinitionTemplateNumber=1001;}
'base' = {productDefinitionTemplateNumber=1002;}
'base' = {productDefinitionTemplateNumber=1100;}
'base' = {productDefinitionTemplateNumber=1101;}
'base' = {productDefinitionTemplateNumber=2000;}
