# Automatically generated by ./create_def.pl, do not edit
#Total convective Precipitation
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	 stepType = "accum" ;
	}
#Total large scale precipitation
'kg m**-2' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	 stepType = "accum" ;
	}
#Convective Available Potential Energy instantaneous
'm**2 s**-2' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
}
