# Automatically generated by ./create_defs.grib1.pl, do not edit
#Geopotential
'geopotential' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 6 ;
	}
#Geopotential
'geopotential' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 6 ;
	}
#Geopotential
'geopotential' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 6 ;
	}
#Temperature
'air_temperature' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 11 ;
	}
#Temperature
'air_temperature' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 11 ;
	}
#Temperature
'air_temperature' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 11 ;
	}
#U component of wind
'eastward_wind' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 33 ;
	}
#U component of wind
'eastward_wind' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 33 ;
	}
#U component of wind
'eastward_wind' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 33 ;
	}
#V component of wind
'northward_wind' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 34 ;
	}
#V component of wind
'northward_wind' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 34 ;
	}
#V component of wind
'northward_wind' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 34 ;
	}
#Specific humidity
'specific_humidity' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 51 ;
	}
#Specific humidity
'specific_humidity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 51 ;
	}
#Specific humidity
'specific_humidity' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 51 ;
	}
#Surface pressure
'surface_air_pressure' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Surface pressure
'surface_air_pressure' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Surface pressure
'surface_air_pressure' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 1 ;
	 indicatorOfTypeOfLevel = 1 ;
	}
#Vertical velocity
'lagrangian_tendency_of_air_pressure' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 39 ;
	}
#Vertical velocity
'lagrangian_tendency_of_air_pressure' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 39 ;
	}
#Vertical velocity
'lagrangian_tendency_of_air_pressure' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 39 ;
	}
#Vorticity (relative)
'atmosphere_relative_vorticity' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 43 ;
	}
#Vorticity (relative)
'atmosphere_relative_vorticity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 43 ;
	}
#Vorticity (relative)
'atmosphere_relative_vorticity' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 43 ;
	}
#Mean sea level pressure
'air_pressure_at_mean_sea_level' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 2 ;
	}
#Mean sea level pressure
'air_pressure_at_mean_sea_level' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 2 ;
	}
#Mean sea level pressure
'air_pressure_at_mean_sea_level' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 2 ;
	}
#Divergence
'divergence_of_wind' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 44 ;
	}
#Divergence
'divergence_of_wind' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 44 ;
	}
#Divergence
'divergence_of_wind' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 44 ;
	}
#Geopotential height
'geopotential_height' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 7 ;
	}
#Geopotential height
'geopotential_height' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 7 ;
	}
#Geopotential height
'geopotential_height' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 7 ;
	}
#Relative humidity
'relative_humidity' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 52 ;
	}
#Relative humidity
'relative_humidity' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 52 ;
	}
#Relative humidity
'relative_humidity' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 52 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 81 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 81 ;
	}
#Land-sea mask
'land_binary_mask' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 81 ;
	}
#Surface roughness (climatological)
'surface_roughness_length' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 83 ;
	}
#Surface roughness (climatological)
'surface_roughness_length' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 83 ;
	}
#Surface roughness (climatological)
'surface_roughness_length' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 83 ;
	}
#Evaporation
'lwe_thickness_of_water_evaporation_amount' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 57 ;
	}
#Evaporation
'lwe_thickness_of_water_evaporation_amount' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 57 ;
	}
#Evaporation
'lwe_thickness_of_water_evaporation_amount' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 57 ;
	}
#Total column ozone
'atmosphere_mass_content_of_ozone' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 10 ;
	}
#Total column ozone
'atmosphere_mass_content_of_ozone' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 10 ;
	}
#Total column ozone
'atmosphere_mass_content_of_ozone' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 10 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 66 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 66 ;
	}
#Snow depth
'lwe_thickness_of_surface_snow_amount' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 66 ;
	}
#Convective cloud cover
'convective_cloud_area_fraction' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 72 ;
	}
#Convective cloud cover
'convective_cloud_area_fraction' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 72 ;
	}
#Convective cloud cover
'convective_cloud_area_fraction' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 72 ;
	}
#Latent heat flux
'surface_upward_latent_heat_flux' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 121 ;
	}
#Latent heat flux
'surface_upward_latent_heat_flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 121 ;
	}
#Latent heat flux
'surface_upward_latent_heat_flux' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 121 ;
	}
#Sensible heat flux
'surface_upward_sensible_heat_flux' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 122 ;
	}
#Sensible heat flux
'surface_upward_sensible_heat_flux' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 122 ;
	}
#Sensible heat flux
'surface_upward_sensible_heat_flux' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 122 ;
	}
#Boundary layer dissipation
'kinetic_energy_dissipation_in_atmosphere_boundary_layer' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 123 ;
	}
#Boundary layer dissipation
'kinetic_energy_dissipation_in_atmosphere_boundary_layer' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 123 ;
	}
#Boundary layer dissipation
'kinetic_energy_dissipation_in_atmosphere_boundary_layer' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 123 ;
	}
#Forecast albedo
'surface_albedo' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 84 ;
	}
#Forecast albedo
'surface_albedo' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 84 ;
	}
#Forecast albedo
'surface_albedo' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 84 ;
	}
#Convective precipitation (water)
'lwe_thickness_of_convective_precipitation_amount' = {
	 table2Version = 3 ;
	 indicatorOfParameter = 63 ;
	}
#Convective precipitation (water)
'lwe_thickness_of_convective_precipitation_amount' = {
	 table2Version = 2 ;
	 indicatorOfParameter = 63 ;
	}
#Convective precipitation (water)
'lwe_thickness_of_convective_precipitation_amount' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 63 ;
}
