# Local definition 52: LDAS

codetable[2] targetFcstSystem "mars/stream.table" = "oper" : dump,string_type,lowercase;

# Hours
unsigned[2] offsetToEndOf4DvarWindow : dump;
unsigned[2] lengthOf4DvarWindow : dump;

alias anoffset=offsetToEndOf4DvarWindow;
