# Automatically generated by ./create_def.pl, do not edit
#Convective available potential energy
'Convective available potential energy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	}
#Snow phase change heat flux
'Snow phase change heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Condensate
'Condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 195 ;
	}
#Horizontal moisture convergence
'Horizontal moisture convergence' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 197 ;
	}
#Categorical rain
'Categorical rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Categorical freezing rain
'Categorical freezing rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Categorical ice pellets
'Categorical ice pellets' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}
#Categorical snow
'Categorical snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}
#Convective precipitation rate
'Convective precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	}
#Percent frozen precipitation
'Percent frozen precipitation' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Potential evaporation
'Potential evaporation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	}
#Snow cover
'Snow cover' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 201 ;
	}
#Rain fraction of total cloud water
'Rain fraction of total cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 202 ;
	}
#Rime factor
'Rime factor' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 203 ;
	}
#Total column integrated rain
'Total column integrated rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 204 ;
	}
#Total column integrated snow
'Total column integrated snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 205 ;
	}
#Water equivalent of accumulated snow depth (deprecated)
'Water equivalent of accumulated snow depth (deprecated)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Vertical speed shear
'Vertical speed shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	}
#Horizontal momentum flux
'Horizontal momentum flux' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	}
#U-component storm motion
'U-component storm motion' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 194 ;
	}
#V-component storm motion
'V-component storm motion' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 195 ;
	}
#Drag coefficient
'Drag coefficient' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	}
#Frictional velocity
'Frictional velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 197 ;
	}
#5-wave geopotential height
'5-wave geopotential height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#Instantaneous eastward gravity wave surface stress
'Instantaneous eastward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}
#Instantaneous northward gravity wave surface stress
'Instantaneous northward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}
#5-wave geopotential height anomaly
'5-wave geopotential height anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	}
#Surface downward short-wave radiation flux
'Surface downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}
#Surface upward short-wave radiation flux
'Surface upward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	}
#UV index
'UV index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 196 ;
	}
#Surface downward long-wave radiation flux
'Surface downward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 192 ;
	}
#Surface upward long-wave radiation flux
'Surface upward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 193 ;
	}
#Non-convective cloud cover
'Non-convective cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	}
#Cloud work function
'Cloud work function' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 193 ;
	}
#Convective cloud efficiency
'Convective cloud efficiency' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 194 ;
	}
#Total column-integrated cloud water
'Total column-integrated cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 196 ;
	}
#Total column-integrated cloud ice
'Total column-integrated cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 197 ;
	}
#Total column-integrated condensate
'Total column-integrated condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 198 ;
	}
#Ice fraction of total condensate
'Ice fraction of total condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 199 ;
	}
#Surface lifted index
'Surface lifted index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 192 ;
	}
#Best (4-layer) lifted index
'Best (4-layer) lifted index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 193 ;
	}
#Ozone mixing ratio
'Ozone mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	}
#Maximum snow albedo
'Maximum snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	}
#Snow free albedo
'Snow free albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	}
#Seconds prior to initial reference time (defined in Section 1)
'Seconds prior to initial reference time (defined in Section 1)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 194 ;
	}
#Baseflow-groundwater runoff
'Baseflow-groundwater runoff' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Storm surface runoff
'Storm surface runoff' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}
#Volumetric soil moisture content
'Volumetric soil moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Ground heat flux
'Ground heat flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}
#Moisture availability
'Moisture availability' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	}
#Exchange coefficient
'Exchange coefficient' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}
#Plant canopy surface water
'Plant canopy surface water' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}
#Blackadar mixing length scale
'Blackadar mixing length scale' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}
#Canopy conductance
'Canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 199 ;
	}
#Minimal stomatal resistance
'Minimal stomatal resistance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 200 ;
	}
#Solar parameter in canopy conductance
'Solar parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 202 ;
	}
#Temperature parameter in canopy conductance
'Temperature parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 203 ;
	}
#Soil moisture parameter in canopy conductance
'Soil moisture parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 205 ;
	}
#Humidity parameter in canopy conductance
'Humidity parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 204 ;
	}
#Liquid volumetric soil moisture (non-frozen)
'Liquid volumetric soil moisture (non-frozen)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}
#Number of soil layers in root zone
'Number of soil layers in root zone' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#Transpiration stress-onset (soil moisture)
'Transpiration stress-onset (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}
#Direct evaporation cease (soil moisture)
'Direct evaporation cease (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}
#Soil porosity
'Soil porosity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	}
#Temperature tendency by all radiation
'Temperature tendency by all radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}
#Relative Error Variance
'Relative Error Variance' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	}
#Large Scale Condensate Heating rate
'Large Scale Condensate Heating rate' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}
#Deep Convective Heating rate
'Deep Convective Heating rate' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}
#Total Downward Heat Flux at Surface
'Total Downward Heat Flux at Surface' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}
#Temperature Tendency By All Physics
'Temperature Tendency By All Physics' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 198 ;
	}
#Temperature Tendency By Non-radiation Physics
'Temperature Tendency By Non-radiation Physics' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 199 ;
	}
#Standard Dev. of IR Temp. over 1x1 deg. area
'Standard Dev. of IR Temp. over 1x1 deg. area' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 200 ;
	}
#Shallow Convective Heating rate
'Shallow Convective Heating rate' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	}
#Vertical Diffusion Heating rate
'Vertical Diffusion Heating rate' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 202 ;
	}
#Potential temperature at top of viscous sublayer
'Potential temperature at top of viscous sublayer' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 203 ;
	}
#Tropical Cyclone Heat Potential
'Tropical Cyclone Heat Potential' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 204 ;
	}
#Minimum Relative Humidity
'Minimum Relative Humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	}
#Total Icing Potential Diagnostic
'Total Icing Potential Diagnostic' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 206 ;
	}
#Number concentration for ice particles
'Number concentration for ice particles' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 207 ;
	}
#Snow temperature
'Snow temperature' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 208 ;
	}
#Total column-integrated supercooled liquid water
'Total column-integrated supercooled liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 209 ;
	}
#Total column-integrated melting ice
'Total column-integrated melting ice' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 210 ;
	}
#Evaporation - Precipitation
'Evaporation - Precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 211 ;
	}
#Sublimation (evaporation from snow)
'Sublimation (evaporation from snow)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 212 ;
	}
#Deep Convective Moistening Rate
'Deep Convective Moistening Rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 213 ;
	}
#Shallow Convective Moistening Rate
'Shallow Convective Moistening Rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 214 ;
	}
#Vertical Diffusion Moistening Rate
'Vertical Diffusion Moistening Rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 215 ;
	}
#Condensation Pressure of Parcali Lifted From Indicate Surface
'Condensation Pressure of Parcali Lifted From Indicate Surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 216 ;
	}
#Large scale moistening rate
'Large scale moistening rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 217 ;
	}
#Specific humidity at top of viscous sublayer
'Specific humidity at top of viscous sublayer' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 218 ;
	}
#Maximum specific humidity at 2m
'Maximum specific humidity at 2m' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 219 ;
	}
#Minimum specific humidity at 2m
'Minimum specific humidity at 2m' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 220 ;
	}
#Liquid precipitation (rainfall)
'Liquid precipitation (rainfall)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 221 ;
	}
#Snow temperature, depth-avg
'Snow temperature, depth-avg' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 222 ;
	}
#Total precipitation (nearest grid point)
'Total precipitation (nearest grid point)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 223 ;
	}
#Convective precipitation (nearest grid point)
'Convective precipitation (nearest grid point)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 224 ;
	}
#Freezing Rain
'Freezing Rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 225 ;
	}
#Latitude of U Wind Component of Velocity
'Latitude of U Wind Component of Velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 198 ;
	}
#Longitude of U Wind Component of Velocity
'Longitude of U Wind Component of Velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 199 ;
	}
#Latitude of V Wind Component of Velocity
'Latitude of V Wind Component of Velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 200 ;
	}
#Longitude of V Wind Component of Velocity
'Longitude of V Wind Component of Velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 201 ;
	}
#Latitude of Pressure Point
'Latitude of Pressure Point' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 202 ;
	}
#Longitude of Pressure Point
'Longitude of Pressure Point' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 203 ;
	}
#Vertical Eddy Diffusivity Heat exchange
'Vertical Eddy Diffusivity Heat exchange' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 204 ;
	}
#Covariance between Meridional and Zonal Components of the wind.
'Covariance between Meridional and Zonal Components of the wind.' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 205 ;
	}
#Covariance between Temperature and Zonal Components of the wind.
'Covariance between Temperature and Zonal Components of the wind.' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 206 ;
	}
#Covariance between Temperature and Meridional Components of the wind.
'Covariance between Temperature and Meridional Components of the wind.' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 207 ;
	}
#Vertical Diffusion Zonal Acceleration
'Vertical Diffusion Zonal Acceleration' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 208 ;
	}
#Vertical Diffusion Meridional Acceleration
'Vertical Diffusion Meridional Acceleration' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 209 ;
	}
#Gravity wave drag zonal acceleration
'Gravity wave drag zonal acceleration' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 210 ;
	}
#Gravity wave drag meridional acceleration
'Gravity wave drag meridional acceleration' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 211 ;
	}
#Convective zonal momentum mixing acceleration
'Convective zonal momentum mixing acceleration' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 212 ;
	}
#Convective meridional momentum mixing acceleration
'Convective meridional momentum mixing acceleration' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 213 ;
	}
#Tendency of vertical velocity
'Tendency of vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 214 ;
	}
#Omega (Dp/Dt) divide by density
'Omega (Dp/Dt) divide by density' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 215 ;
	}
#Convective Gravity wave drag zonal acceleration
'Convective Gravity wave drag zonal acceleration' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 216 ;
	}
#Convective Gravity wave drag meridional acceleration
'Convective Gravity wave drag meridional acceleration' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 217 ;
	}
#Velocity Point Model Surface
'Velocity Point Model Surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 218 ;
	}
#Potential Vorticity (Mass-Weighted)
'Potential Vorticity (Mass-Weighted)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 219 ;
	}
#MSLP (Eta model reduction)
'MSLP (Eta model reduction)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}
#MSLP (MAPS System Reduction)
'MSLP (MAPS System Reduction)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}
#3-hr pressure tendency (Std. Atmos. Reduction)
'3-hr pressure tendency (Std. Atmos. Reduction)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}
#Pressure of level from which parcel was lifted
'Pressure of level from which parcel was lifted' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	}
#X-gradient of Log Pressure
'X-gradient of Log Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	}
#Y-gradient of Log Pressure
'Y-gradient of Log Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 202 ;
	}
#X-gradient of Height
'X-gradient of Height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 203 ;
	}
#Y-gradient of Height
'Y-gradient of Height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 204 ;
	}
#Layer Thickness
'Layer Thickness' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 205 ;
	}
#Natural Log of Surface Pressure
'Natural Log of Surface Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 206 ;
	}
#Convective updraft mass flux
'Convective updraft mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 207 ;
	}
#Convective downdraft mass flux
'Convective downdraft mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 208 ;
	}
#Convective detrainment mass flux
'Convective detrainment mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 209 ;
	}
#Mass Point Model Surface
'Mass Point Model Surface' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 210 ;
	}
#Geopotential Height (nearest grid point)
'Geopotential Height (nearest grid point)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 211 ;
	}
#Pressure (nearest grid point)
'Pressure (nearest grid point)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 212 ;
	}
#UV-B downward solar flux
'UV-B downward solar flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	}
#Clear sky UV-B downward solar flux
'Clear sky UV-B downward solar flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	}
#Clear Sky Downward Solar Flux
'Clear Sky Downward Solar Flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	}
#Solar Radiative Heating Rate
'Solar Radiative Heating Rate' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 197 ;
	}
#Clear Sky Upward Solar Flux
'Clear Sky Upward Solar Flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	}
#Cloud Forcing Net Solar Flux
'Cloud Forcing Net Solar Flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 199 ;
	}
#Visible Beam Downward Solar Flux
'Visible Beam Downward Solar Flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 200 ;
	}
#Visible Diffuse Downward Solar Flux
'Visible Diffuse Downward Solar Flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 201 ;
	}
#Near IR Beam Downward Solar Flux
'Near IR Beam Downward Solar Flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 202 ;
	}
#Near IR Diffuse Downward Solar Flux
'Near IR Diffuse Downward Solar Flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 203 ;
	}
#Downward Total radiation Flux
'Downward Total radiation Flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 204 ;
	}
#Upward Total radiation Flux
'Upward Total radiation Flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 205 ;
	}
#Long-Wave Radiative Heating Rate
'Long-Wave Radiative Heating Rate' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 194 ;
	}
#Clear Sky Upward Long Wave Flux
'Clear Sky Upward Long Wave Flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 195 ;
	}
#Clear Sky Downward Long Wave Flux
'Clear Sky Downward Long Wave Flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 196 ;
	}
#Cloud Forcing Net Long Wave Flux
'Cloud Forcing Net Long Wave Flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 197 ;
	}
#Convective Cloud Mass Flux
'Convective Cloud Mass Flux' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 200 ;
	}
#Richardson Number
'Richardson Number' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 194 ;
	}
#Convective Weather Detection Index
'Convective Weather Detection Index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 195 ;
	}
#Updraft Helicity
'Updraft Helicity' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 197 ;
	}
#Leaf Area Index
'Leaf Area Index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 198 ;
	}
#Particulate matter (coarse)
'Particulate matter (coarse)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 192 ;
	}
#Particulate matter (fine)
'Particulate matter (fine)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 193 ;
	}
#Particulate matter (fine)
'Particulate matter (fine)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 194 ;
	}
#Integrated column particulate matter (fine)
'Integrated column particulate matter (fine)' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 195 ;
	}
#Ozone Concentration (PPB)
'Ozone Concentration (PPB)' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 193 ;
	}
#Categorical Ozone Concentration
'Categorical Ozone Concentration' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 194 ;
	}
#Ozone vertical diffusion
'Ozone vertical diffusion' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 195 ;
	}
#Ozone production
'Ozone production' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 196 ;
	}
#Ozone tendency
'Ozone tendency' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 197 ;
	}
#Ozone production from temperature term
'Ozone production from temperature term' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 198 ;
	}
#Ozone production from col ozone term
'Ozone production from col ozone term' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 199 ;
	}
#Derived radar reflectivity backscatter from rain
'Derived radar reflectivity backscatter from rain' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 192 ;
	}
#Derived radar reflectivity backscatter from ice
'Derived radar reflectivity backscatter from ice' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 193 ;
	}
#Derived radar reflectivity backscatter from parameterized convection
'Derived radar reflectivity backscatter from parameterized convection' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 194 ;
	}
#Derived radar reflectivity
'Derived radar reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 195 ;
	}
#Maximum/Composite radar reflectivity
'Maximum/Composite radar reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 196 ;
	}
#Lightning
'Lightning' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 192 ;
	}
#Slight risk convective outlook
'Slight risk convective outlook' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 194 ;
	}
#Moderate risk convective outlook
'Moderate risk convective outlook' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 195 ;
	}
#High risk convective outlook
'High risk convective outlook' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 196 ;
	}
#Tornado probability
'Tornado probability' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 197 ;
	}
#Hail probability
'Hail probability' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 198 ;
	}
#Wind probability
'Wind probability' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 199 ;
	}
#Significant Tornado probability
'Significant Tornado probability' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 200 ;
	}
#Significant Hail probability
'Significant Hail probability' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 201 ;
	}
#Significant Wind probability
'Significant Wind probability' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 202 ;
	}
#Categorical Thunderstorm (1-yes, 0-no)
'Categorical Thunderstorm (1-yes, 0-no)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 203 ;
	}
#Number of mixed layers next to surface
'Number of mixed layers next to surface' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 204 ;
	}
#Flight Category
'Flight Category' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 205 ;
	}
#Confidence - Ceiling
'Confidence - Ceiling' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 206 ;
	}
#Confidence - Visibility
'Confidence - Visibility' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 207 ;
	}
#Confidence - Flight Category
'Confidence - Flight Category' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 208 ;
	}
#Low-Level aviation interest
'Low-Level aviation interest' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 209 ;
	}
#High-Level aviation interest
'High-Level aviation interest' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 210 ;
	}
#Visible, Black Sky Albedo
'Visible, Black Sky Albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 211 ;
	}
#Visible, White Sky Albedo
'Visible, White Sky Albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 212 ;
	}
#Near IR, Black Sky Albedo
'Near IR, Black Sky Albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 213 ;
	}
#Near IR, White Sky Albedo
'Near IR, White Sky Albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 214 ;
	}
#Total Probability of Severe Thunderstorms (Days 2,3)
'Total Probability of Severe Thunderstorms (Days 2,3)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 215 ;
	}
#Total Probability of Extreme Severe Thunderstorms (Days 2,3)
'Total Probability of Extreme Severe Thunderstorms (Days 2,3)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 216 ;
	}
#Supercooled Large Droplet (SLD) Potential
'Supercooled Large Droplet (SLD) Potential' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 217 ;
	}
#Radiative emissivity
'Radiative emissivity' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 218 ;
	}
#Turbulence Potential Forecast Index
'Turbulence Potential Forecast Index' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 219 ;
	}
#Volcanic Ash Forecast Transport and Dispersion
'Volcanic Ash Forecast Transport and Dispersion' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 232 ;
	}
#Latitude (-90 to +90)
'Latitude (-90 to +90)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 192 ;
	}
#East Longitude (0 - 360)
'East Longitude (0 - 360)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 193 ;
	}
#Model Layer number (From bottom up)
'Model Layer number (From bottom up)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 195 ;
	}
#Latitude (nearest neighbor) (-90 to +90)
'Latitude (nearest neighbor) (-90 to +90)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 196 ;
	}
#East Longitude (nearest neighbor) (0 - 360)
'East Longitude (nearest neighbor) (0 - 360)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 197 ;
	}
#Probability of Freezing Precipitation
'Probability of Freezing Precipitation' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Probability of precipitation exceeding flash flood guidance values
'Probability of precipitation exceeding flash flood guidance values' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}
#Probability of Wetting Rain, exceeding in 0.10 in a given time period
'Probability of Wetting Rain, exceeding in 0.10 in a given time period' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}
#Vegetation Type
'Vegetation Type' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 198 ;
	}
#Wilting Point
'Wilting Point' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	}
#Rate of water dropping from canopy to ground
'Rate of water dropping from canopy to ground' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 206 ;
	}
#Ice-free water surface
'Ice-free water surface' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 207 ;
	}
#Surface exchange coefficients for T and Q divided by delta z
'Surface exchange coefficients for T and Q divided by delta z' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 208 ;
	}
#Surface exchange coefficients for U and V divided by delta z
'Surface exchange coefficients for U and V divided by delta z' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 209 ;
	}
#Vegetation canopy temperature
'Vegetation canopy temperature' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 210 ;
	}
#Surface water storage
'Surface water storage' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 211 ;
	}
#Liquid soil moisture content (non-frozen)
'Liquid soil moisture content (non-frozen)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 212 ;
	}
#Open water evaporation (standing water)
'Open water evaporation (standing water)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 213 ;
	}
#Groundwater recharge
'Groundwater recharge' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 214 ;
	}
#Flood plain recharge
'Flood plain recharge' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 215 ;
	}
#Roughness length for heat
'Roughness length for heat' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 216 ;
	}
#Normalized Difference Vegetation Index
'Normalized Difference Vegetation Index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 217 ;
	}
#Land-sea coverage (nearest neighbor) [land=1,sea=0]
'Land-sea coverage (nearest neighbor) [land=1,sea=0]' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 218 ;
	}
#Asymptotic mixing length scale
'Asymptotic mixing length scale' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 219 ;
	}
#Water vapor added by precip assimilation
'Water vapor added by precip assimilation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 220 ;
	}
#Water condensate added by precip assimilation
'Water condensate added by precip assimilation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 221 ;
	}
#Water Vapor Flux Convergence (Vertical Int)
'Water Vapor Flux Convergence (Vertical Int)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 222 ;
	}
#Water Condensate Flux Convergence (Vertical Int)
'Water Condensate Flux Convergence (Vertical Int)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 223 ;
	}
#Water Vapor Zonal Flux (Vertical Int)
'Water Vapor Zonal Flux (Vertical Int)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 224 ;
	}
#Water Vapor Meridional Flux (Vertical Int)
'Water Vapor Meridional Flux (Vertical Int)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 225 ;
	}
#Water Condensate Zonal Flux (Vertical Int)
'Water Condensate Zonal Flux (Vertical Int)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 226 ;
	}
#Water Condensate Meridional Flux (Vertical Int)
'Water Condensate Meridional Flux (Vertical Int)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 227 ;
	}
#Aerodynamic conductance
'Aerodynamic conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 228 ;
	}
#Canopy water evaporation
'Canopy water evaporation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 229 ;
	}
#Transpiration
'Transpiration' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 230 ;
	}
#Surface Slope Type
'Surface Slope Type' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}
#Direct evaporation from bare soil
'Direct evaporation from bare soil' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}
#Land Surface Precipitation Accumulation
'Land Surface Precipitation Accumulation' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}
#Bare soil surface skin temperature
'Bare soil surface skin temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	}
#Average surface skin temperature
'Average surface skin temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	}
#Effective radiative skin temperature
'Effective radiative skin temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 202 ;
	}
#Field Capacity
'Field Capacity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 203 ;
	}
#Scatterometer Estimated U Wind Component
'Scatterometer Estimated U Wind Component' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Scatterometer Estimated V Wind Component
'Scatterometer Estimated V Wind Component' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Wave Steepness
'Wave Steepness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}
#Ocean Mixed Layer U Velocity
'Ocean Mixed Layer U Velocity' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}
#Ocean Mixed Layer V Velocity
'Ocean Mixed Layer V Velocity' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}
#Barotropic U velocity
'Barotropic U velocity' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}
#Barotropic V velocity
'Barotropic V velocity' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}
#Storm Surge
'Storm Surge' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}
#Extra Tropical Storm Surge
'Extra Tropical Storm Surge' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}
#Ocean Surface Elevation Relative to Geoid
'Ocean Surface Elevation Relative to Geoid' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}
#Sea Surface Height Relative to Geoid
'Sea Surface Height Relative to Geoid' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}
#Ocean Mixed Layer Potential Density (Reference 2000m)<br
'Ocean Mixed Layer Potential Density (Reference 2000m)<br' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}
#Net Air-Ocean Heat Flux
'Net Air-Ocean Heat Flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	}
#Assimilative Heat Flux
'Assimilative Heat Flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}
#Surface Temperature Trend
'Surface Temperature Trend' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}
#Surface Salinity Trend
'Surface Salinity Trend' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	}
#Kinetic Energy
'Kinetic Energy' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	}
#Salt Flux
'Salt Flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 202 ;
	}
#3-D Temperature
'3-D Temperature' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}
#3-D Salinity
'3-D Salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	}
#Barotropic Kinetic Energy
'Barotropic Kinetic Energy' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	}
#Geometric Depth Below Sea Surface
'Geometric Depth Below Sea Surface' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	}
#Interface Depths
'Interface Depths' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	}
#Ocean Heat Content
'Ocean Heat Content' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 197 ;
	}
#Image data
'Image data' = {
	 discipline = 255 ;
	 parameterCategory = 255 ;
	 parameterNumber = 255 ;
	}
#Sunshine Duration
'Sunshine Duration' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 201 ;
	}
#Icing severity
'Icing severity' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 234 ;
	}
#Simulated Brightness Temperature for AMSRE on Aqua, Channel 10
'Simulated Brightness Temperature for AMSRE on Aqua, Channel 10' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 11 ;
	}
#Simulated Brightness Temperature for AMSRE on Aqua, Channel 11
'Simulated Brightness Temperature for AMSRE on Aqua, Channel 11' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 12 ;
	}
#Simulated Brightness Temperature for AMSRE on Aqua, Channel 12
'Simulated Brightness Temperature for AMSRE on Aqua, Channel 12' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 13 ;
	}
#Simulated Brightness Temperature for AMSRE on Aqua, Channel 9
'Simulated Brightness Temperature for AMSRE on Aqua, Channel 9' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 10 ;
	}
#Simulated Brightness Counts for GOES 12, Channel 3
'Simulated Brightness Counts for GOES 12, Channel 3' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 4 ;
	}
#Simulated Brightness Counts for GOES 12, Channel 4
'Simulated Brightness Counts for GOES 12, Channel 4' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 5 ;
	}
#Simulated Brightness Temperature for GOES 11, Channel 2
'Simulated Brightness Temperature for GOES 11, Channel 2' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 6 ;
	}
#Simulated Brightness Temperature for GOES 11, Channel 3
'Simulated Brightness Temperature for GOES 11, Channel 3' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 7 ;
	}
#Simulated Brightness Temperature for GOES 11, Channel 4
'Simulated Brightness Temperature for GOES 11, Channel 4' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 8 ;
	}
#Simulated Brightness Temperature for GOES 11, Channel 5
'Simulated Brightness Temperature for GOES 11, Channel 5' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 9 ;
	}
#Simulated Brightness Temperature for GOES 12, Channel 2
'Simulated Brightness Temperature for GOES 12, Channel 2' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 0 ;
	}
#Simulated Brightness Temperature for GOES 12, Channel 3
'Simulated Brightness Temperature for GOES 12, Channel 3' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 1 ;
	}
#Simulated Brightness Temperature for GOES 12, Channel 4
'Simulated Brightness Temperature for GOES 12, Channel 4' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 2 ;
	}
#Simulated Brightness Temperature for GOES 12, Channel 6
'Simulated Brightness Temperature for GOES 12, Channel 6' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 3 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-10
'Simulated Brightness Temperature for ABI GOES-16, Band-10' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 23 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-11
'Simulated Brightness Temperature for ABI GOES-16, Band-11' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 24 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-12
'Simulated Brightness Temperature for ABI GOES-16, Band-12' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 25 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-13
'Simulated Brightness Temperature for ABI GOES-16, Band-13' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 26 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-14
'Simulated Brightness Temperature for ABI GOES-16, Band-14' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 27 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-15
'Simulated Brightness Temperature for ABI GOES-16, Band-15' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 28 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-16
'Simulated Brightness Temperature for ABI GOES-16, Band-16' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 29 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-7
'Simulated Brightness Temperature for ABI GOES-16, Band-7' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 20 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-8
'Simulated Brightness Temperature for ABI GOES-16, Band-8' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 21 ;
	}
#Simulated Brightness Temperature for ABI GOES-16, Band-9
'Simulated Brightness Temperature for ABI GOES-16, Band-9' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 22 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-10
'Simulated Brightness Temperature for ABI GOES-17, Band-10' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 39 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-11
'Simulated Brightness Temperature for ABI GOES-17, Band-11' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 40 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-12
'Simulated Brightness Temperature for ABI GOES-17, Band-12' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 41 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-13
'Simulated Brightness Temperature for ABI GOES-17, Band-13' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 42 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-14
'Simulated Brightness Temperature for ABI GOES-17, Band-14' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 43 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-15
'Simulated Brightness Temperature for ABI GOES-17, Band-15' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 44 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-16
'Simulated Brightness Temperature for ABI GOES-17, Band-16' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 45 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-7
'Simulated Brightness Temperature for ABI GOES-17, Band-7' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 36 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-8
'Simulated Brightness Temperature for ABI GOES-17, Band-8' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 37 ;
	}
#Simulated Brightness Temperature for ABI GOES-17, Band-9
'Simulated Brightness Temperature for ABI GOES-17, Band-9' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 38 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-1
'Simulated Reflectance Factor for ABI GOES-16, Band-1' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 14 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-2
'Simulated Reflectance Factor for ABI GOES-16, Band-2' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 15 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-3
'Simulated Reflectance Factor for ABI GOES-16, Band-3' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 16 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-4
'Simulated Reflectance Factor for ABI GOES-16, Band-4' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 17 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-5
'Simulated Reflectance Factor for ABI GOES-16, Band-5' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 18 ;
	}
#Simulated Reflectance Factor for ABI GOES-16, Band-6
'Simulated Reflectance Factor for ABI GOES-16, Band-6' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 19 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-1
'Simulated Reflectance Factor for ABI GOES-17, Band-1' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 30 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-2
'Simulated Reflectance Factor for ABI GOES-17, Band-2' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 31 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-3
'Simulated Reflectance Factor for ABI GOES-17, Band-3' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 32 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-4
'Simulated Reflectance Factor for ABI GOES-17, Band-4' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 33 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-5
'Simulated Reflectance Factor for ABI GOES-17, Band-5' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 34 ;
	}
#Simulated Reflectance Factor for ABI GOES-17, Band-6
'Simulated Reflectance Factor for ABI GOES-17, Band-6' = {
	 discipline = 3 ;
	 parameterCategory = 192 ;
	 parameterNumber = 35 ;
	}
#Ventilation Rate
'Ventilation Rate' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 224 ;
	}
#Convective inhibition
'Convective inhibition' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	}
#Total Cloud Cover
'Total Cloud Cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	}
#Total Precipitation
'Total Precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 8 ;
}
