# Automatically generated by ./create_def.pl, do not edit
#Maximum temperature at 2 metres in the last 6 hours
'Maximum temperature at 2 metres in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 lengthOfTimeRange = 6 ;
	}
#Minimum temperature at 2 metres in the last 6 hours
'Minimum temperature at 2 metres in the last 6 hours' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 indicatorOfUnitForTimeRange = 1 ;
	 lengthOfTimeRange = 6 ;
	}
#2 metre temperature
'2 metre temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	}
#2 metre dewpoint temperature
'2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	}
#Surface air relative humidity
'Surface air relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	}
#2 metre specific humidity
'2 metre specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 15 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	}
