#Methane (chemistry)
'CH4_c' = {
	localTablesVersion = 1 ;
	constituentType = 2 ;
	}
#Volcanic sulphur dioxide
'SO2_v' = {
	localTablesVersion = 1 ;
	constituentType = 65507 ;
	}
#Stratospheric ozone
'O3S' = {
	localTablesVersion = 1 ;
	constituentType = 65524 ;
	}
#PAR budget corrector
'rxpar' = {
	localTablesVersion = 1 ;
	constituentType = 65520 ;
	}
#NO to NO2 operator
'xo2' = {
	localTablesVersion = 1 ;
	constituentType = 65521 ;
	}
#NO to alkyl nitrate operator
'xo2n' = {
	localTablesVersion = 1 ;
	constituentType = 65522 ;
	}
#Polar stratospheric cloud
'psc' = {
	localTablesVersion = 1 ;
	constituentType = 65516 ;
	}
#Methacrolein MVK
'ISPD' = {
	localTablesVersion = 1 ;
	constituentType = 65523 ;
	}
#Acetone product
'aco2' = {
	localTablesVersion = 1 ;
	constituentType = 65515 ;
	}
#HYPROPO2
'hypropo2' = {
	localTablesVersion = 1 ;
	constituentType = 65519 ;
	}
#Nitrogen oxides Transp
'noxa' = {
	localTablesVersion = 1 ;
	constituentType = 65514 ;
	}
#Carbon dioxide (chemistry)
'CO2_c' = {
	localTablesVersion = 1 ;
	constituentType = 3 ;
	}
#Nitrous oxide (chemistry)
'N2O_c' = {
	localTablesVersion = 1 ;
	constituentType = 6 ;
	}
#Water vapour (chemistry)
'H2O_c' = {
	localTablesVersion = 1 ;
	constituentType = 1 ;
	}
#Toluene and less reactive aromatics
'tol' = {
	localTablesVersion = 1 ;
	constituentType = 65529 ;
	}
#Xylene and more reactive aromatics
'xyl' = {
	localTablesVersion = 1 ;
	constituentType = 65530 ;
	}
#Lumped alkenes
'BIGENE' = {
	localTablesVersion = 1 ;
	constituentType = 60010 ;
	}
#Lumped alkanes
'BIGALK' = {
	localTablesVersion = 1 ;
	constituentType = 60009 ;
	}
#Hydrogen atom
'h_c' = {
	localTablesVersion = 1 ;
	constituentType = 65513 ;
	}
#Condensable gas type 1
'sog1' = {
	localTablesVersion = 1 ;
	constituentType = 65526 ;
	}
#Condensable gas type 2a
'sog2a' = {
	localTablesVersion = 1 ;
	constituentType = 65527 ;
	}
#Condensable gas type 2b
'sog2b' = {
	localTablesVersion = 1 ;
	constituentType = 65528 ;
	}
#Asymmetric chlorine dioxide radical
'cloo' = {
	localTablesVersion = 1 ;
	constituentType = 65518 ;
	}
#GEMS ozone
'gO3' = {
	localTablesVersion = 1 ;
	constituentType = 0 ;
	}
#Stratospheric aerosol
'strataer' = {
	localTablesVersion = 1 ;
	constituentType = 65517 ;
	}
#Biogenic secondary organic aerosol precursor
'aer_biosecorg_pre' = {
	localTablesVersion = 1 ;
	constituentType = 65511 ;
	}
#Anthropogenic secondary organic aerosol precursor
'aer_antsecorg_pre' = {
	localTablesVersion = 1 ;
	constituentType = 65512 ;
	}
#SO2 precursor
'aer_so2_pre' = {
	localTablesVersion = 1 ;
	constituentType = 65510 ;
	}
#Aerosol small mode
'aer_sm' = {
	localTablesVersion = 1 ;
	constituentType = 65508 ;
	}
#Aerosol large mode
'aer_lm' = {
	localTablesVersion = 1 ;
	constituentType = 65509 ;
	}
#Volcanic Sulphate
'SO4_v' = {
	localTablesVersion = 1 ;
	constituentType = 65506 ;
	}
