# Automatically generated by ./create_defs.grib2.mtg2.pl, do not edit
#Total precipitation of at least 1 mm
'tpg1' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 60 ;
	}
#Total precipitation of at least 5 mm
'tpg5' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 61 ;
	}
#Total precipitation of at least 40 mm
'tpg40' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 82 ;
	}
#Total precipitation of at least 60 mm
'tpg60' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 83 ;
	}
#Total precipitation of at least 80 mm
'tpg80' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 84 ;
	}
#Total precipitation of at least 100 mm
'tpg100' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 85 ;
	}
#Total precipitation of at least 150 mm
'tpg150' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 86 ;
	}
#Total precipitation of at least 200 mm
'tpg200' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 87 ;
	}
#Total precipitation of at least 300 mm
'tpg300' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 88 ;
	}
#Surface runoff
'sro' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 8 ;
	}
#Sub-surface runoff
'ssro' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 9 ;
	}
#UV visible albedo for direct radiation (climatological)
'aluvp' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 15 ;
	}
#UV visible albedo for diffuse radiation (climatological)
'aluvd' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 16 ;
	}
#Near IR albedo for direct radiation (climatological)
'alnip' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 17 ;
	}
#Near IR albedo for diffuse radiation (climatological)
'alnid' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 18 ;
	}
#Surface photosynthetically active radiation, clear sky
'parcs' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 20 ;
	}
#Unbalanced component of temperature
'uctp' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 21 ;
	}
#Unbalanced component of logarithm of surface pressure
'ucln' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 22 ;
	}
#Unbalanced component of divergence
'ucdv' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 23 ;
	}
#Lake cover
'cl' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 26 ;
	}
#Low vegetation cover
'cvl' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 27 ;
	}
#High vegetation cover
'cvh' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 28 ;
	}
#Type of low vegetation
'tvl' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 29 ;
	}
#Type of high vegetation
'tvh' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 30 ;
	}
#Sea ice area fraction
'ci' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 31 ;
	}
#Snow albedo
'asn' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 32 ;
	}
#Snow density
'rsn' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 33 ;
	}
#Sea surface temperature
'sst' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 34 ;
	}
#Snow evaporation
'es' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 44 ;
	}
#Snowmelt
'smlt' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 45 ;
	}
#Surface direct normal short-wave (solar) radiation
'dsrp' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 47 ;
	}
#Time-integrated magnitude of turbulent surface stress
'magss' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 48 ;
	}
#Large-scale precipitation fraction
'lspf' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 50 ;
	}
#Montgomery potential
'mont' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 53 ;
	}
#Mean temperature at 2 metres in the last 24 hours
'mean2t24' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 55 ;
	}
#Mean 2 metre dewpoint temperature in the last 24 hours
'mn2d24' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 56 ;
	}
#Surface downward UV radiation
'uvb' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 57 ;
	}
#Photosynthetically active radiation at the surface
'par' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 58 ;
	}
#Leaf area index, low vegetation
'lai_lv' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 66 ;
	}
#Leaf area index, high vegetation
'lai_hv' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 67 ;
	}
#Standard deviation of filtered subgrid orography (climatological)
'sdfor' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 74 ;
	}
#Total column cloud liquid water
'tclw' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 78 ;
	}
#Total column cloud ice water
'tciw' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 79 ;
	}
#Surface emissivity
'emis' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 124 ;
	}
#Total column vertically-integrated water vapour
'tcwv' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 137 ;
	}
#Large-scale precipitation
'lsp' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 142 ;
	}
#Snowfall
'sf' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 144 ;
	}
#Charnock
'chnk' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 148 ;
	}
#Surface net radiation (SW and LW)
'snr' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 149 ;
	}
#Top net radiation (SW and LW)
'tnr' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 150 ;
	}
#Boundary layer height
'blh' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 159 ;
	}
#Standard deviation of sub-gridscale orography
'sdor' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 160 ;
	}
#Anisotropy of sub-gridscale orography
'isor' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 161 ;
	}
#Angle of sub-gridscale orography
'anor' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 162 ;
	}
#Slope of sub-gridscale orography
'slor' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 163 ;
	}
#Total cloud cover
'tcc' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 164 ;
	}
#Surface short-wave (solar) radiation downwards
'ssrd' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 169 ;
	}
#Albedo (climatological)
'al' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 174 ;
	}
#Surface long-wave (thermal) radiation downwards
'strd' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 175 ;
	}
#Top net short-wave (solar) radiation
'tsr' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 178 ;
	}
#Time-integrated eastward turbulent surface stress
'ewss' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 180 ;
	}
#Time-integrated northward turbulent surface stress
'nsss' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 181 ;
	}
#Evaporation
'e' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 182 ;
	}
#Low cloud cover
'lcc' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 186 ;
	}
#Medium cloud cover
'mcc' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 187 ;
	}
#High cloud cover
'hcc' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 188 ;
	}
#Eastward gravity wave surface stress
'lgws' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 195 ;
	}
#Northward gravity wave surface stress
'mgws' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 196 ;
	}
#Gravity wave dissipation
'gwd' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 197 ;
	}
#Skin reservoir content
'src' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 198 ;
	}
#Runoff
'ro' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 205 ;
	}
#Total column ozone
'tco3' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 206 ;
	}
#Top net short-wave (solar) radiation, clear sky
'tsrc' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 208 ;
	}
#Top net long-wave (thermal) radiation, clear sky
'ttrc' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 209 ;
	}
#Surface net short-wave (solar) radiation, clear sky
'ssrc' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 210 ;
	}
#Surface net long-wave (thermal) radiation, clear sky
'strc' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 211 ;
	}
#TOA incident short-wave (solar) radiation
'tisr' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 212 ;
	}
#Vertically integrated moisture divergence
'vimd' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 213 ;
	}
#Instantaneous eastward turbulent surface stress
'iews' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 229 ;
	}
#Instantaneous northward turbulent surface stress
'inss' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 230 ;
	}
#Instantaneous surface sensible heat net flux
'ishf' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 231 ;
	}
#Instantaneous moisture flux
'ie' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 232 ;
	}
#Logarithm of surface roughness length for heat (climatological)
'lsrh' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 234 ;
	}
#Temperature of snow layer
'tsn' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 238 ;
	}
#Convective snowfall
'csf' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 239 ;
	}
#Large-scale snowfall
'lsf' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 240 ;
	}
#Forecast albedo
'fal' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 243 ;
	}
#Forecast surface roughness
'fsr' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 244 ;
	}
#Forecast logarithm of surface roughness for heat
'flsr' = {
	 discipline = 192 ;
	 parameterCategory = 128 ;
	 parameterNumber = 245 ;
	}
#Mean surface net radiation flux
'msnrf' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 149 ;
	}
#Injection height (from IS4FIRES)
'injh' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 60 ;
	}
#Particulate matter d <= 1 um
'pm1' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 72 ;
	}
#Particulate matter d <= 2.5 um
'pm2p5' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 73 ;
	}
#Particulate matter d <= 10 um
'pm10' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 74 ;
	}
#Mean height of maximum injection
'mami' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 119 ;
	}
#Plume top height above surface
'apt' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 120 ;
	}
#UV visible albedo for direct radiation, isotropic component (climatological)
'aluvpi' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 186 ;
	}
#UV visible albedo for direct radiation, volumetric component (climatological)
'aluvpv' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 187 ;
	}
#UV visible albedo for direct radiation, geometric component (climatological)
'aluvpg' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 188 ;
	}
#Near IR albedo for direct radiation, isotropic component (climatological)
'alnipi' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 189 ;
	}
#Near IR albedo for direct radiation, volumetric component (climatological)
'alnipv' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 190 ;
	}
#Near IR albedo for direct radiation, geometric component (climatological)
'alnipg' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 191 ;
	}
#UV visible albedo for diffuse radiation, isotropic component (climatological)
'aluvdi' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 192 ;
	}
#UV visible albedo for diffuse radiation, volumetric component (climatological)
'aluvdv' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 193 ;
	}
#UV visible albedo for diffuse radiation, geometric component (climatological)
'aluvdg' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 194 ;
	}
#Near IR albedo for diffuse radiation, isotropic component (climatological)
'alnidi' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 195 ;
	}
#Near IR albedo for diffuse radiation, volumetric component (climatological)
'alnidv' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 196 ;
	}
#Near IR albedo for diffuse radiation, geometric component (climatological)
'alnidg' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 197 ;
	}
#Plume bottom height above surface
'apb' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 242 ;
	}
#Random pattern 1 for SPP scheme
'spp1' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 101 ;
	}
#Random pattern 2 for SPP scheme
'spp2' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 102 ;
	}
#Random pattern 3 for SPP scheme
'spp3' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 103 ;
	}
#Random pattern 4 for SPP scheme
'spp4' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 104 ;
	}
#Random pattern 5 for SPP scheme
'spp5' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 105 ;
	}
#Random pattern 6 for SPP scheme
'spp6' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 106 ;
	}
#Random pattern 7 for SPP scheme
'spp7' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 107 ;
	}
#Random pattern 8 for SPP scheme
'spp8' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 108 ;
	}
#Random pattern 9 for SPP scheme
'spp9' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 109 ;
	}
#Random pattern 10 for SPP scheme
'spp10' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 110 ;
	}
#Random pattern 11 for SPP scheme
'spp11' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 111 ;
	}
#Random pattern 12 for SPP scheme
'spp12' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 112 ;
	}
#Random pattern 13 for SPP scheme
'spp13' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 113 ;
	}
#Random pattern 14 for SPP scheme
'spp14' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 114 ;
	}
#Random pattern 15 for SPP scheme
'spp15' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 115 ;
	}
#Random pattern 16 for SPP scheme
'spp16' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 116 ;
	}
#Random pattern 17 for SPP scheme
'spp17' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 117 ;
	}
#Random pattern 18 for SPP scheme
'spp18' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 118 ;
	}
#Random pattern 19 for SPP scheme
'spp19' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 119 ;
	}
#Random pattern 20 for SPP scheme
'spp20' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 120 ;
	}
#Random pattern 21 for SPP scheme
'spp21' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 121 ;
	}
#Random pattern 22 for SPP scheme
'spp22' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 122 ;
	}
#Random pattern 23 for SPP scheme
'spp23' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 123 ;
	}
#Random pattern 24 for SPP scheme
'spp24' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 124 ;
	}
#Random pattern 25 for SPP scheme
'spp25' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 125 ;
	}
#Random pattern 26 for SPP scheme
'spp26' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 126 ;
	}
#Random pattern 27 for SPP scheme
'spp27' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 127 ;
	}
#Random pattern 28 for SPP scheme
'spp28' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 128 ;
	}
#Random pattern 29 for SPP scheme
'spp29' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 129 ;
	}
#Random pattern 30 for SPP scheme
'spp30' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 130 ;
	}
#Random pattern 31 for SPP scheme
'spp31' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 131 ;
	}
#Random pattern 32 for SPP scheme
'spp32' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 132 ;
	}
#Random pattern 33 for SPP scheme
'spp33' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 133 ;
	}
#Random pattern 34 for SPP scheme
'spp34' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 134 ;
	}
#Random pattern 35 for SPP scheme
'spp35' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 135 ;
	}
#Random pattern 36 for SPP scheme
'spp36' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 136 ;
	}
#Random pattern 37 for SPP scheme
'spp37' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 137 ;
	}
#Random pattern 38 for SPP scheme
'spp38' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 138 ;
	}
#Random pattern 39 for SPP scheme
'spp39' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 139 ;
	}
#Random pattern 40 for SPP scheme
'spp40' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 140 ;
	}
#Random pattern 41 for SPP scheme
'spp41' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 141 ;
	}
#Random pattern 42 for SPP scheme
'spp42' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 142 ;
	}
#Random pattern 43 for SPP scheme
'spp43' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 143 ;
	}
#Random pattern 44 for SPP scheme
'spp44' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 144 ;
	}
#Random pattern 45 for SPP scheme
'spp45' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 145 ;
	}
#Random pattern 46 for SPP scheme
'spp46' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 146 ;
	}
#Random pattern 47 for SPP scheme
'spp47' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 147 ;
	}
#Random pattern 48 for SPP scheme
'spp48' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 148 ;
	}
#Random pattern 49 for SPP scheme
'spp49' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 149 ;
	}
#Random pattern 50 for SPP scheme
'spp50' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 150 ;
	}
#Random pattern 51 for SPP scheme
'spp51' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 151 ;
	}
#Random pattern 52 for SPP scheme
'spp52' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 152 ;
	}
#Random pattern 53 for SPP scheme
'spp53' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 153 ;
	}
#Random pattern 54 for SPP scheme
'spp54' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 154 ;
	}
#Random pattern 55 for SPP scheme
'spp55' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 155 ;
	}
#Random pattern 56 for SPP scheme
'spp56' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 156 ;
	}
#Random pattern 57 for SPP scheme
'spp57' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 157 ;
	}
#Random pattern 58 for SPP scheme
'spp58' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 158 ;
	}
#Random pattern 59 for SPP scheme
'spp59' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 159 ;
	}
#Random pattern 60 for SPP scheme
'spp60' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 160 ;
	}
#Random pattern 61 for SPP scheme
'spp61' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 161 ;
	}
#Random pattern 62 for SPP scheme
'spp62' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 162 ;
	}
#Random pattern 63 for SPP scheme
'spp63' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 163 ;
	}
#Random pattern 64 for SPP scheme
'spp64' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 164 ;
	}
#Random pattern 65 for SPP scheme
'spp65' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 165 ;
	}
#Random pattern 66 for SPP scheme
'spp66' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 166 ;
	}
#Random pattern 67 for SPP scheme
'spp67' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 167 ;
	}
#Random pattern 68 for SPP scheme
'spp68' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 168 ;
	}
#Random pattern 69 for SPP scheme
'spp69' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 169 ;
	}
#Random pattern 70 for SPP scheme
'spp70' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 170 ;
	}
#Random pattern 71 for SPP scheme
'spp71' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 171 ;
	}
#Random pattern 72 for SPP scheme
'spp72' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 172 ;
	}
#Random pattern 73 for SPP scheme
'spp73' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 173 ;
	}
#Random pattern 74 for SPP scheme
'spp74' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 174 ;
	}
#Random pattern 75 for SPP scheme
'spp75' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 175 ;
	}
#Random pattern 76 for SPP scheme
'spp76' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 176 ;
	}
#Random pattern 77 for SPP scheme
'spp77' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 177 ;
	}
#Random pattern 78 for SPP scheme
'spp78' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 178 ;
	}
#Random pattern 79 for SPP scheme
'spp79' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 179 ;
	}
#Random pattern 80 for SPP scheme
'spp80' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 180 ;
	}
#Random pattern 81 for SPP scheme
'spp81' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 181 ;
	}
#Random pattern 82 for SPP scheme
'spp82' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 182 ;
	}
#Random pattern 83 for SPP scheme
'spp83' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 183 ;
	}
#Random pattern 84 for SPP scheme
'spp84' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 184 ;
	}
#Random pattern 85 for SPP scheme
'spp85' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 185 ;
	}
#Random pattern 86 for SPP scheme
'spp86' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 186 ;
	}
#Random pattern 87 for SPP scheme
'spp87' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 187 ;
	}
#Random pattern 88 for SPP scheme
'spp88' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 188 ;
	}
#Random pattern 89 for SPP scheme
'spp89' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 189 ;
	}
#Random pattern 90 for SPP scheme
'spp90' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 190 ;
	}
#Random pattern 91 for SPP scheme
'spp91' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 191 ;
	}
#Random pattern 92 for SPP scheme
'spp92' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 192 ;
	}
#Random pattern 93 for SPP scheme
'spp93' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 193 ;
	}
#Random pattern 94 for SPP scheme
'spp94' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 194 ;
	}
#Random pattern 95 for SPP scheme
'spp95' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 195 ;
	}
#Random pattern 96 for SPP scheme
'spp96' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 196 ;
	}
#Random pattern 97 for SPP scheme
'spp97' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 197 ;
	}
#Random pattern 98 for SPP scheme
'spp98' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 198 ;
	}
#Random pattern 99 for SPP scheme
'spp99' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 199 ;
	}
#Random pattern 100 for SPP scheme
'spp100' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 200 ;
	}
#Random pattern 101 for SPP scheme
'spp101' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 201 ;
	}
#Random pattern 102 for SPP scheme
'spp102' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 202 ;
	}
#Random pattern 103 for SPP scheme
'spp103' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 203 ;
	}
#Random pattern 104 for SPP scheme
'spp104' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 204 ;
	}
#Random pattern 105 for SPP scheme
'spp105' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 205 ;
	}
#Random pattern 106 for SPP scheme
'spp106' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 206 ;
	}
#Random pattern 107 for SPP scheme
'spp107' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 207 ;
	}
#Random pattern 108 for SPP scheme
'spp108' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 208 ;
	}
#Random pattern 109 for SPP scheme
'spp109' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 209 ;
	}
#Random pattern 110 for SPP scheme
'spp110' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 210 ;
	}
#Random pattern 111 for SPP scheme
'spp111' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 211 ;
	}
#Random pattern 112 for SPP scheme
'spp112' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 212 ;
	}
#Random pattern 113 for SPP scheme
'spp113' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 213 ;
	}
#Random pattern 114 for SPP scheme
'spp114' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 214 ;
	}
#Random pattern 115 for SPP scheme
'spp115' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 215 ;
	}
#Random pattern 116 for SPP scheme
'spp116' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 216 ;
	}
#Random pattern 117 for SPP scheme
'spp117' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 217 ;
	}
#Random pattern 118 for SPP scheme
'spp118' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 218 ;
	}
#Random pattern 119 for SPP scheme
'spp119' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 219 ;
	}
#Random pattern 120 for SPP scheme
'spp120' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 220 ;
	}
#Random pattern 121 for SPP scheme
'spp121' = {
	 discipline = 192 ;
	 parameterCategory = 213 ;
	 parameterNumber = 221 ;
	}
#Cosine of solar zenith angle
'cossza' = {
	 discipline = 192 ;
	 parameterCategory = 214 ;
	 parameterNumber = 1 ;
	}
#UV biologically effective dose
'uvbed' = {
	 discipline = 192 ;
	 parameterCategory = 214 ;
	 parameterNumber = 2 ;
	}
#UV biologically effective dose clear-sky
'uvbedcs' = {
	 discipline = 192 ;
	 parameterCategory = 214 ;
	 parameterNumber = 3 ;
	}
#Ammonia mass mixing ratio
'nh3' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 19 ;
	}
#Nitrogen monoxide mass mixing ratio
'no' = {
	 discipline = 192 ;
	 parameterCategory = 217 ;
	 parameterNumber = 27 ;
	}
#Surface direct short-wave (solar) radiation
'fdir' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 21 ;
	}
#Surface direct short-wave radiation, clear sky
'cdir' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 22 ;
	}
#Cloud base height
'cbh' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 23 ;
	}
#Geometric height of 0 degrees C atmospheric isothermal level above ground
'deg0l' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 24 ;
	}
#Maximum 10 metre wind gust in the last 3 hours
'10fg3' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 28 ;
	}
#Height of zero-degree wet-bulb temperature
'hwbt0' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 47 ;
	}
#Height of one-degree wet-bulb temperature
'hwbt1' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 48 ;
	}
#Instantaneous total lightning flash density
'litoti' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 50 ;
	}
#Averaged total lightning flash density in the last hour
'litota1' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 51 ;
	}
#Instantaneous cloud-to-ground lightning flash density
'licgi' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 52 ;
	}
#Averaged cloud-to-ground lightning flash density in the last hour
'licga1' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 53 ;
	}
#Averaged total lightning flash density in the last 3 hours
'litota3' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 57 ;
	}
#Averaged total lightning flash density in the last 6 hours
'litota6' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 58 ;
	}
#Averaged cloud-to-ground lightning flash density in the last 3 hours
'licga3' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 59 ;
	}
#Averaged cloud-to-ground lightning flash density in the last 6 hours
'licga6' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 60 ;
	}
#Accumulated Carbon Dioxide Net Ecosystem Exchange
'aco2nee' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Gross Primary Production
'aco2gpp' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Ecosystem Respiration
'aco2rec' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Carbon dioxide net ecosystem exchange flux
'fco2nee' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}
#Carbon dioxide gross primary production flux
'fco2gpp' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}
#Carbon dioxide ecosystem respiration flux
'fco2rec' = {
	 localTablesVersion = 1 ;
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}
#Total column rain water
'tcrw' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 89 ;
	}
#Total column snow water
'tcsw' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 90 ;
	}
#Ice temperature
'ist' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 94 ;
	}
#Surface short-wave (solar) radiation downward clear-sky
'ssrdc' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 129 ;
	}
#Surface long-wave (thermal) radiation downward clear-sky
'strdc' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 130 ;
	}
#100 metre wind speed
'100si' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 249 ;
	}
#Potential evaporation
'pev' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 251 ;
	}
#Volume-mean total column mixing ratio
'vm_tc_vol_mixrat' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	}
#Emission mass flux from vegetation
'emi_mflx_veg' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 192 ;
	}
#Emission mass flux from biomass burning
'emi_mflx_biomburn' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 193 ;
	}
#Emission mass flux from settlements
'emi_mflx_settl' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 194 ;
	}
#Emission mass flux from soil
'emi_mflx_soil' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 195 ;
	}
#Emission mass flux from wild animals
'emi_mflx_wildanim' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 196 ;
	}
#Emission mass flux from commercial buildings heating
'emi_mflx_cbh' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 197 ;
	}
#Emission mass flux from residential heating
'emi_mflx_rh' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 198 ;
	}
#Emission mass flux from oil refineries and transformation industry
'emi_mflx_oti' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 199 ;
	}
#Emission mass flux from gas production
'emi_mflx_gp' = {
	 localTablesVersion = 1 ;
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 200 ;
	}
#Mean 2 metre temperature in the last 24 hours gradient
'mean2t24grd' = {
	 discipline = 192 ;
	 parameterCategory = 129 ;
	 parameterNumber = 55 ;
	}
#Mean 2 metre dewpoint temperature in the last 24 hours gradient
'mn2d24grd' = {
	 discipline = 192 ;
	 parameterCategory = 129 ;
	 parameterNumber = 56 ;
	}
#Mean vertical velocity
'mvv' = {
	 discipline = 192 ;
	 parameterCategory = 130 ;
	 parameterNumber = 232 ;
	}
#Total precipitation less than 0.1 mm
'tpl01' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 64 ;
	}
#Total precipitation rate less than 1 mm/day
'tprl1' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 65 ;
	}
#Total precipitation rate of at least 3 mm/day
'tprg3' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 66 ;
	}
#Total precipitation rate of at least 5 mm/day
'tprg5' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 67 ;
	}
#10 metre Wind speed of at least 10 m/s
'10spg10' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 68 ;
	}
#10 metre Wind speed of at least 15 m/s
'10spg15' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 69 ;
	}
#2 metre temperature less than 273.15 K
'2tl273' = {
	 discipline = 192 ;
	 parameterCategory = 131 ;
	 parameterNumber = 73 ;
	}
#Period corresponding to maximum individual wave height
'tmax' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 217 ;
	}
#Envelop-maximum individual wave height
'hmax' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 218 ;
	}
#Model bathymetry
'wmb' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 219 ;
	}
#Mean wave period based on first moment
'mp1' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 220 ;
	}
#Mean zero-crossing wave period
'mp2' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 221 ;
	}
#Wave spectral directional width
'wdw' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 222 ;
	}
#Mean wave period based on first moment for wind waves
'p1ww' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 223 ;
	}
#Mean wave period based on second moment for wind waves
'p2ww' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 224 ;
	}
#Wave spectral directional width for wind waves
'dwww' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 225 ;
	}
#Mean wave period based on first moment for swell
'p1ps' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 226 ;
	}
#Mean wave period based on second moment for swell
'p2ps' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 227 ;
	}
#Wave spectral directional width for swell
'dwps' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 228 ;
	}
#Peak wave period
'pp1d' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 231 ;
	}
#Coefficient of drag with waves
'cdww' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 233 ;
	}
#Mean direction of wind waves
'mdww' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 235 ;
	}
#Significant height of total swell
'shts' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 237 ;
	}
#Mean direction of total swell
'mdts' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 238 ;
	}
#Mean period of total swell
'mpts' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 239 ;
	}
#Standard deviation wave height
'sdhs' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 240 ;
	}
#Mean of 10 metre wind speed
'mu10' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 241 ;
	}
#Mean wind direction
'mdwi' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 242 ;
	}
#Standard deviation of 10 metre wind speed
'sdu' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 243 ;
	}
#Mean square slope of waves
'msqs' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 244 ;
	}
#10 metre wind speed
'wind' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 245 ;
	}
#Altimeter wave height
'awh' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 246 ;
	}
#Altimeter corrected wave height
'acwh' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 247 ;
	}
#Altimeter range relative correction
'arrc' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 248 ;
	}
#10 metre wind direction
'dwi' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 249 ;
	}
#2D wave spectra (single)
'2dfd' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 251 ;
	}
#Wave spectral kurtosis
'wsk' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 252 ;
	}
#Benjamin-Feir index
'bfi' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 253 ;
	}
#Wave spectral peakedness
'wsp' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 254 ;
	}
#Sea water potential temperature
'thetao' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 129 ;
	}
#Sea water practical salinity
'so' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 130 ;
	}
#Eastward surface sea water velocity
'ocu' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 131 ;
	}
#Northward surface sea water velocity
'ocv' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 132 ;
	}
#Upward sea water velocity
'wo' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 133 ;
	}
#Sea water sigma theta
'sigmat' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 138 ;
	}
#Sea surface height
'zos' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 145 ;
	}
#Surface downward eastward stress
'taueo' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 153 ;
	}
#Surface downward northward stress
'tauno' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 154 ;
	}
#Depth of 20C isotherm
't20d' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 163 ;
	}
#Average sea water practical salinity in the upper 300m
'sav300' = {
	 discipline = 192 ;
	 parameterCategory = 151 ;
	 parameterNumber = 175 ;
	}
#Skin reservoir content
'srcon' = {
	 discipline = 192 ;
	 parameterCategory = 160 ;
	 parameterNumber = 198 ;
	}
#Surface geopotential
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 51 ;
	}
#Total column vertically-integrated mass of atmosphere
'vima' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 53 ;
	}
#Total column vertically-integrated temperature
'vit' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 54 ;
	}
#Total column vertically-integrated water vapour
'viwv' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 55 ;
	}
#Total column vertically-integrated cloud liquid water
'vilw' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 56 ;
	}
#Total column vertically-integrated cloud frozen water
'viiw' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 57 ;
	}
#Total column vertically-integrated ozone
'vioz' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 58 ;
	}
#Total column vertically-integrated kinetic energy
'vike' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 59 ;
	}
#Total column vertically-integrated enthalpy
'vithe' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 60 ;
	}
#Total column vertically-integrated potential + internal energy
'vipie' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 61 ;
	}
#Total column vertically-integrated potential+internal+latent energy
'vipile' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 62 ;
	}
#Total column vertically-integrated total energy
'vitoe' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 63 ;
	}
#Total column vertically-integrated energy conversion
'viec' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 64 ;
	}
#Total column vertically-integrated eastward mass flux
'vimae' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 65 ;
	}
#Total column vertically-integrated northward mass flux
'viman' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 66 ;
	}
#Total column vertically-integrated eastward kinetic energy flux
'vikee' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 67 ;
	}
#Total column vertically-integrated northward kinetic energy flux
'viken' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 68 ;
	}
#Total column vertically-integrated eastward heat flux
'vithee' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 69 ;
	}
#Total column vertically-integrated northward heat flux
'vithen' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 70 ;
	}
#Total column vertically-integrated eastward water vapour flux
'viwve' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 71 ;
	}
#Total column vertically-integrated northward water vapour flux
'viwvn' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 72 ;
	}
#Total column vertically-integrated eastward geopotential flux
'vige' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 73 ;
	}
#Total column vertically-integrated northward geopotential flux
'vign' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 74 ;
	}
#Total column vertically-integrated eastward total energy flux
'vitee' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 75 ;
	}
#Total column vertically-integrated northward total energy flux
'viten' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 76 ;
	}
#Total column vertically-integrated eastward ozone flux
'vioze' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 77 ;
	}
#Total column vertically-integrated northward ozone flux
'viozn' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 78 ;
	}
#Total column vertically-integrated divergence of mass flux
'vimad' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 81 ;
	}
#Total column vertically-integrated divergence of kinetic energy flux
'viked' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 82 ;
	}
#Total column vertically-integrated divergence of thermal energy flux
'vithed' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 83 ;
	}
#Total column vertically-integrated moisture divergence flux
'vimdf' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 84 ;
	}
#Total column vertically-integrated divergence of geopotential flux
'vigd' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 85 ;
	}
#Total column vertically-integrated divergence of total energy flux
'vited' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 86 ;
	}
#Total column vertically-integrated divergence of ozone flux
'viozd' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 87 ;
	}
#Time-integrated temperature tendency due to short-wave radiation
'srta' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 100 ;
	}
#Time-integrated temperature tendency due to long-wave radiation
'trta' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 101 ;
	}
#Time-integrated temperature tendency due to short wave radiation, clear sky
'srtca' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 102 ;
	}
#Time-integrated temperature tendency due to long-wave radiation, clear sky
'trtca' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 103 ;
	}
#Time-integrated updraught mass flux
'umfa' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 104 ;
	}
#Time-integrated downdraught mass flux
'dmfa' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 105 ;
	}
#Time-integrated updraught detrainment rate
'udra' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 106 ;
	}
#Time-integrated downdraught detrainment rate
'ddra' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 107 ;
	}
#Time-integrated total precipitation flux
'tpfa' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 108 ;
	}
#Time-integrated turbulent diffusion coefficient for heat
'tdcha' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 109 ;
	}
#Time-integrated temperature tendency due to parametrisations
'ttpha' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 110 ;
	}
#Time-integrated specific humidity tendency due to parametrisations
'qtpha' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 111 ;
	}
#Time-integrated eastward wind tendency due to parametrisations
'utpha' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 112 ;
	}
#Time-integrated northward wind tendency due to parametrisations
'vtpha' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 113 ;
	}
#Variance of geopotential
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 206 ;
	}
#Covariance of geopotential/temperature
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 207 ;
	}
#Variance of temperature
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 208 ;
	}
#Covariance of geopotential/specific humidity
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 209 ;
	}
#Covariance of temperature/specific humidity
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 210 ;
	}
#Variance of specific humidity
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 211 ;
	}
#Covariance of u component/geopotential
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 212 ;
	}
#Covariance of u component/temperature
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 213 ;
	}
#Covariance of u component/specific humidity
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 214 ;
	}
#Variance of u component
'~' = {
	 discipline = 192 ;
	 parameterCategory = 162 ;
	 parameterNumber = 215 ;
	}
#Time-mean large-scale precipitation rate
'mlsprt' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 142 ;
	}
#Time-mean convective precipitation rate
'cprate' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 143 ;
	}
#Time-mean total snowfall rate
'mtsfr' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 144 ;
	}
#Time-mean surface sensible heat flux
'msshfl' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 146 ;
	}
#Time-mean surface latent heat flux
'mslhfl' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 147 ;
	}
#Time-mean surface downward short-wave (solar) radiation flux
'msdsrf' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 169 ;
	}
#Time-mean surface downward long-wave (thermal) radiation flux
'msdtrf' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 175 ;
	}
#Time-mean surface net short-wave (solar) radiation flux
'msnsrf' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 176 ;
	}
#Time-mean surface net long-wave (thermal) radiation flux
'msntrf' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 177 ;
	}
#Time-mean top net short-wave (solar) radiation flux
'mtnsrf' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 178 ;
	}
#Time-mean top net long-wave (thermal) radiation flux
'mtntrf' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 179 ;
	}
#Time-mean eastward turbulent surface stress
'ewssra' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 180 ;
	}
#Time-mean northward turbulent surface stress
'nsssra' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 181 ;
	}
#Time-mean evaporation rate
'erate' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 182 ;
	}
#Time-mean runoff rate
'mrort' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 205 ;
	}
#Time-mean top net short-wave (solar) radiation flux, clear sky
'~' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 208 ;
	}
#Time-mean top net long-wave (thermal) radiation flux, clear sky
'~' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 209 ;
	}
#Time-mean surface net short-wave (solar) radiation flux, clear sky
'~' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 210 ;
	}
#Time-mean surface net long-wave (thermal) radiation flux, clear sky
'~' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 211 ;
	}
#Time-mean short-wave (solar) insolation rate
'soira' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 212 ;
	}
#Time-mean total precipitation rate
'tprate' = {
	 discipline = 192 ;
	 parameterCategory = 172 ;
	 parameterNumber = 228 ;
	}
#Surface runoff
'sro' = {
	 discipline = 192 ;
	 parameterCategory = 174 ;
	 parameterNumber = 8 ;
	}
#Sea-ice thickness
'sithick' = {
	 discipline = 192 ;
	 parameterCategory = 174 ;
	 parameterNumber = 98 ;
	}
#Snow depth
'sdsien' = {
	 discipline = 192 ;
	 parameterCategory = 190 ;
	 parameterNumber = 141 ;
	}
#Nitrogen dioxide mass mixing ratio
'no2' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 121 ;
	}
#Sulphur dioxide mass mixing ratio
'so2' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 122 ;
	}
#Carbon monoxide mass mixing ratio
'co' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 123 ;
	}
#Ozone mass mixing ratio (full chemistry scheme)
'go3' = {
	 discipline = 192 ;
	 parameterCategory = 210 ;
	 parameterNumber = 203 ;
	}
#Nitrogen dioxide mass mixing ratio difference
'no2diff' = {
	 discipline = 192 ;
	 parameterCategory = 211 ;
	 parameterNumber = 121 ;
	}
#Sulphur dioxide mass mixing ratio difference
'so2diff' = {
	 discipline = 192 ;
	 parameterCategory = 211 ;
	 parameterNumber = 122 ;
	}
#Carbon monoxide mass mixing ratio difference
'codiff' = {
	 discipline = 192 ;
	 parameterCategory = 211 ;
	 parameterNumber = 123 ;
	}
#Ozone mass mixing ratio difference (full chemistry scheme)
'go3diff' = {
	 discipline = 192 ;
	 parameterCategory = 211 ;
	 parameterNumber = 203 ;
	}
#Friction velocity
'zust' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 3 ;
	}
#Time-mean 2 metre temperature
'avg_2t' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 4 ;
	}
#Time-mean 10 metre wind speed
'avg_10ws' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 5 ;
	}
#Mean total cloud cover
'meantcc' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 6 ;
	}
#Lake total depth
'dl' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 7 ;
	}
#Lake mix-layer temperature
'lmlt' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 8 ;
	}
#Lake mix-layer depth
'lmld' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 9 ;
	}
#Lake bottom temperature
'lblt' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 10 ;
	}
#Lake total layer temperature
'ltlt' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 11 ;
	}
#Lake shape factor
'lshf' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 12 ;
	}
#Lake ice surface temperature
'lict' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 13 ;
	}
#Lake ice total depth
'licd' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 14 ;
	}
#Minimum vertical gradient of refractivity inside trapping layer
'dndzn' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 15 ;
	}
#Mean vertical gradient of refractivity inside trapping layer
'dndza' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 16 ;
	}
#Duct base height
'dctb' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 17 ;
	}
#Trapping layer base height
'tplb' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 18 ;
	}
#Trapping layer top height
'tplt' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 19 ;
	}
#10 metre u-component of neutral wind
'u10n' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 131 ;
	}
#10 metre v-component of neutral wind
'v10n' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 132 ;
	}
#U-component surface stokes drift
'ust' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 215 ;
	}
#V-component surface stokes drift
'vst' = {
	 discipline = 192 ;
	 parameterCategory = 140 ;
	 parameterNumber = 216 ;
	}
#100 metre U wind component
'100u' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 246 ;
	}
#100 metre V wind component
'100v' = {
	 discipline = 192 ;
	 parameterCategory = 228 ;
	 parameterNumber = 247 ;
}
