# (C) Copyright 2005- ECMWF.

# See ECC-1846
# This is ecmf local so we shouldn't use MasterDir. Instead we look for pseudocentre (conceptsDir2) then centre (conceptsLocalDirAll)

concept modelName(unknown, "modelNameConcept.def", conceptsDir2, conceptsLocalDirAll): no_copy, dump;

if (modelName isnot "unknown") {
   concept modelVersion(unknown, "modelVersionConcept.[modelName].def", conceptsDir2, conceptsLocalDirAll): no_copy, dump, read_only;
   if ( grib2LocalSectionPresent or localUsePresent ) { # See ECC-2039
      if ( defined(marsClass) && marsClass == 51 ) { # See ECC-2032: 51=Operational AIFS (ai)
         alias ls.model = modelName;
         alias mars.model = modelName;
      }
   }
}
