# Automatically generated by get_definitionsALL.sql from database PRJ_TDCFDOKU.GRIB_PARAMETER@OFC1MIR.DWD.DE, do not edit! 2025-10-01 06:15
#paramId: 500000
#Pressure (S) (not reduced)
'Pressure (S) (not reduced)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500001
#Pressure
'Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}

#paramId: 500002
#Pressure Reduced to MSL
'Pressure Reduced to MSL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}

#paramId: 500003
#Pressure Tendency (S)
'Pressure Tendency (S)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500004
#Geopotential (S)
'Geopotential (S)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500005
#Geopotential (full lev)
'Geopotential (full lev)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 105 ;
	 typeOfFirstFixedSurface = 105 ;
	}

#paramId: 500006
#Geopotential
'Geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}

#paramId: 500007
#Geometric Height of the earths surface above sea level
'Geometric Height of the earths surface above sea level' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500008
#Geometric Height of the layer limits above sea level(NN)
'Geometric Height of the layer limits above sea level(NN)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 101 ;
	}

#paramId: 500009
#Total Column Integrated Ozone
'Total Column Integrated Ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	}

#paramId: 500010
#Temperature (G)
'Temperature (G)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500011
#2m Temperature
'2m Temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500012
#2m Temperature (AV)
'2m Temperature (AV)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500013
#Climat. temperature, 2m Temperature
'Climat. temperature, 2m Temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}

#paramId: 500014
#Temperature
'Temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 500015
#Max 2m Temperature (i)
'Max 2m Temperature (i)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500016
#Min 2m Temperature (i)
'Min 2m Temperature (i)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500017
#2m Dew Point Temperature
'2m Dew Point Temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500018
#2m Dew Point Temperature (AV)
'2m Dew Point Temperature (AV)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500019
#Radar spectra (1)
'Radar spectra (1)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500020
#Wave spectra (1)
'Wave spectra (1)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 500021
#Wave spectra (2)
'Wave spectra (2)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 500022
#Wave spectra (3)
'Wave spectra (3)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 500023
#Wind Direction (DD_10M)
'Wind Direction (DD_10M)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500024
#Wind Direction (DD)
'Wind Direction (DD)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}

#paramId: 500025
#Wind speed (SP_10M)
'Wind speed (SP_10M)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500026
#Wind speed (SP)
'Wind speed (SP)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}

#paramId: 500027
#U-Component of Wind
'U-Component of Wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500028
#U-Component of Wind
'U-Component of Wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 500029
#V-Component of Wind
'V-Component of Wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500030
#V-Component of Wind
'V-Component of Wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}

#paramId: 500031
#Vertical Velocity (Pressure) ( omega=dp/dt )
'Vertical Velocity (Pressure) ( omega=dp/dt )' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}

#paramId: 500032
#Vertical Velocity (Geometric) (w)
'Vertical Velocity (Geometric) (w)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 9 ;
	}

#paramId: 500034
#Specific Humidity (2m)
'Specific Humidity (2m)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500035
#Specific Humidity
'Specific Humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 500036
#2m Relative Humidity
'2m Relative Humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500037
#Relative Humidity
'Relative Humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 500038
#Total column integrated water vapour
'Total column integrated water vapour' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	}

#paramId: 500039
#Evaporation (s)
'Evaporation (s)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500040
#Total Column-Integrated Cloud Ice
'Total Column-Integrated Cloud Ice' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	}

#paramId: 500041
#Total Precipitation (Accumulation)
'Total Precipitation (Accumulation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500042
#Large-Scale Precipitation (Accumulation)
'Large-Scale Precipitation (Accumulation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500043
#Convective Precipitation (Accumulation)
'Convective Precipitation (Accumulation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500044
#Snow depth water equivalent
'Snow depth water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	}

#paramId: 500045
#Snow Depth
'Snow Depth' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}

#paramId: 500046
#Total Cloud Cover
'Total Cloud Cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	}

#paramId: 500047
#Convective Cloud Cover
'Convective Cloud Cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 2 ;
	}

#paramId: 500048
#Cloud Cover (800 hPa - Soil)
'Cloud Cover (800 hPa - Soil)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 800 ;
	}

#paramId: 500049
#Cloud Cover (400 - 800 hPa)
'Cloud Cover (400 - 800 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 800 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 400 ;
	}

#paramId: 500050
#Cloud Cover (0 - 400 hPa)
'Cloud Cover (0 - 400 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 400 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500051
#Total Column-Integrated Cloud Water
'Total Column-Integrated Cloud Water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	}

#paramId: 500052
#Convective Snowfall water equivalent (s)
'Convective Snowfall water equivalent (s)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500053
#Large-Scale snowfall - water equivalent (Accumulation)
'Large-Scale snowfall - water equivalent (Accumulation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500054
#Land Cover (1=land, 0=sea)
'Land Cover (1=land, 0=sea)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 500055
#Surface Roughness length Surface Roughness
'Surface Roughness length Surface Roughness' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 500056
#Albedo (in short-wave)
'Albedo (in short-wave)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	}

#paramId: 500057
#Albedo (in short-wave, average)
'Albedo (in short-wave, average)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500058
#Soil Temperature  ( 36 cm depth, vv=0h)
'Soil Temperature  ( 36 cm depth, vv=0h)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 36 ;
	}

#paramId: 500059
#Soil Temperature (41 cm depth)
'Soil Temperature (41 cm depth)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 41 ;
	}

#paramId: 500060
#Soil Temperature
'Soil Temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 9 ;
	}

#paramId: 500061
#Soil Temperature
'Soil Temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500062
#Column-integrated Soil Moisture
'Column-integrated Soil Moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 190 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	}

#paramId: 500063
#Column-integrated Soil Moisture (1) 0 -10 cm
'Column-integrated Soil Moisture (1) 0 -10 cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 10 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500064
#Column-integrated Soil Moisture (2) 10-100cm
'Column-integrated Soil Moisture (2) 10-100cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 100 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500065
#Plant cover
'Plant cover' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 500066
#Water Runoff
'Water Runoff' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500068
#Water Runoff (s)
'Water Runoff (s)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500069
#Sea Ice Cover ( 0= free, 1=cover)
'Sea Ice Cover ( 0= free, 1=cover)' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}

#paramId: 500070
#Sea Ice Thickness
'Sea Ice Thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}

#paramId: 500071
#Significant height of combined wind waves and swell
'Significant height of combined wind waves and swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 500072
#Direction of wind waves
'Direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 500073
#Significant height of wind waves
'Significant height of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}

#paramId: 500074
#Mean period of wind waves
'Mean period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 500075
#Direction of swell waves
'Direction of swell waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}

#paramId: 500076
#Significant height of swell waves
'Significant height of swell waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}

#paramId: 500077
#Mean period of swell waves
'Mean period of swell waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}

#paramId: 500078
#Net short wave radiation flux (at the surface)
'Net short wave radiation flux (at the surface)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500079
#Net short wave radiation flux (at the surface)
'Net short wave radiation flux (at the surface)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500080
#Net long wave radiation flux (m) (at the surface)
'Net long wave radiation flux (m) (at the surface)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500081
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500082
#Net short wave radiation flux (on the model top)
'Net short wave radiation flux (on the model top)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500083
#Net short wave radiation flux
'Net short wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500084
#Net long wave radiation flux (m) (on the model top)
'Net long wave radiation flux (m) (on the model top)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500085
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500086
#Latent Heat Net Flux (m)
'Latent Heat Net Flux (m)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500087
#Sensible Heat Net Flux (m)
'Sensible Heat Net Flux (m)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500088
#Momentum Flux, U-Component (m)
'Momentum Flux, U-Component (m)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500089
#Momentum Flux, V-Component (m)
'Momentum Flux, V-Component (m)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500090
#Photosynthetically active radiation (m) (at the surface)
'Photosynthetically active radiation (m) (at the surface)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500091
#Photosynthetically active radiation
'Photosynthetically active radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500098
#Cloud cover
'Cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	}

#paramId: 500099
#Non-Convective Cloud Cover, grid scale
'Non-Convective Cloud Cover, grid scale' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 14 ;
	}

#paramId: 500100
#Cloud Mixing Ratio
'Cloud Mixing Ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 22 ;
	}

#paramId: 500101
#Cloud Ice Mixing Ratio
'Cloud Ice Mixing Ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 82 ;
	}

#paramId: 500102
#Rain mixing ratio
'Rain mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	}

#paramId: 500103
#Snow mixing ratio
'Snow mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 25 ;
	}

#paramId: 500104
#Total column integrated rain
'Total column integrated rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	}

#paramId: 500105
#Total column integrated snow
'Total column integrated snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	}

#paramId: 500106
#Grauple
'Grauple' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 32 ;
	}

#paramId: 500107
#Total column integrated grauple
'Total column integrated grauple' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	}

#paramId: 500108
#Total Column integrated water (all components incl. precipitation)
'Total Column integrated water (all components incl. precipitation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 78 ;
	}

#paramId: 500118
#Height of Convective Cloud Base above msl
'Height of Convective Cloud Base above msl' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 26 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500119
#Height of Convective Cloud Top above msl
'Height of Convective Cloud Top above msl' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 500127
#Height of 0 degree Celsius isotherm above msl
'Height of 0 degree Celsius isotherm above msl' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 4 ;
	}

#paramId: 500132
#Large scale rain rate
'Large scale rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	}

#paramId: 500133
#Large scale snowfall rate water equivalent
'Large scale snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	}

#paramId: 500134
#Large scale rain (Accumulation)
'Large scale rain (Accumulation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500135
#Convective rain rate
'Convective rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	}

#paramId: 500136
#Convective snowfall rate water equivalent
'Convective snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	}

#paramId: 500137
#Convective rain
'Convective rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500138
#rain amount, grid-scale plus convective
'rain amount, grid-scale plus convective' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500139
#snow amount, grid-scale plus convective
'snow amount, grid-scale plus convective' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500145
#Graupel (snow pellets) precipitation rate
'Graupel (snow pellets) precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	}

#paramId: 500146
#Graupel (snow pellets) precipitation (Accumulation)
'Graupel (snow pellets) precipitation (Accumulation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500147
#Snow density
'Snow density' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	}

#paramId: 500155
#Convective turbulent kinetic enery
'Convective turbulent kinetic enery' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 24 ;
	}

#paramId: 500158
#Turbulent Kinetic Energy
'Turbulent Kinetic Energy' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 11 ;
	}

#paramId: 500159
#Turbulent diffusioncoefficient for momentum
'Turbulent diffusioncoefficient for momentum' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 31 ;
	}

#paramId: 500160
#Turbulent diffusion coefficient for heat (and moisture)
'Turbulent diffusion coefficient for heat (and moisture)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}

#paramId: 500161
#Turbulent transfer coefficient for impulse
'Turbulent transfer coefficient for impulse' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	}

#paramId: 500162
#Turbulent transfer coefficient for heat (and Moisture)
'Turbulent transfer coefficient for heat (and Moisture)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}

#paramId: 500163
#mixed layer depth
'mixed layer depth' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	}

#paramId: 500164
#maximum Wind 10m
'maximum Wind 10m' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500166
#Soil Temperature (multilayer model)
'Soil Temperature (multilayer model)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500167
#Column-integrated Soil Moisture (multilayers)
'Column-integrated Soil Moisture (multilayers)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500168
#soil ice content (multilayers)
'soil ice content (multilayers)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500169
#Plant Canopy Surface Water
'Plant Canopy Surface Water' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}

#paramId: 500170
#Snow temperature (top of snow)
'Snow temperature (top of snow)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}

#paramId: 500171
#Minimal Stomatal Resistance
'Minimal Stomatal Resistance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}

#paramId: 500172
#Sea Ice Temperature
'Sea Ice Temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}

#paramId: 500173
#Base reflectivity
'Base reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500174
#Base reflectivity
'Base reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	}

#paramId: 500175
#Base reflectivity (cmax)
'Base reflectivity (cmax)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500183
#Convective Available Potential Energy
'Convective Available Potential Energy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	}

#paramId: 500185
#Direction of combined wind waves and swell
'Direction of combined wind waves and swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}

#paramId: 500187
#Peak period of total swell
'Peak period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	}

#paramId: 500189
#Peak period of wind waves
'Peak period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	}

#paramId: 500190
#Peak wave period
'Peak wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	}

#paramId: 500191
#Mean period of combined wind waves and swell
'Mean period of combined wind waves and swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}

#paramId: 500192
#Inverse mean wave frequency
'Inverse mean wave frequency' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}

#paramId: 500193
#Mean zero-crossing wave period
'Mean zero-crossing wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}

#paramId: 500194
#Wave directional width
'Wave directional width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	}

#paramId: 500200
#Standard deviation of sub-grid scale orography
'Standard deviation of sub-grid scale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	}

#paramId: 500201
#Anisotropy of sub-gridscale orography
'Anisotropy of sub-gridscale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 24 ;
	}

#paramId: 500202
#Angle of sub-gridscale orography
'Angle of sub-gridscale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	}

#paramId: 500203
#Slope of sub-gridscale orography
'Slope of sub-gridscale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	}

#paramId: 500206
#Leaf area index
'Leaf area index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}

#paramId: 500207
#root depth of vegetation
'root depth of vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	}

#paramId: 500210
#Plant covering degree in the vegetation phase
'Plant covering degree in the vegetation phase' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500211
#Plant covering degree in the quiescent phas
'Plant covering degree in the quiescent phas' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}

#paramId: 500212
#Max Leaf area index
'Max Leaf area index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500213
#Min Leaf area index
'Min Leaf area index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 3 ;
	}

#paramId: 500214
#Orographie + Land-Meer-Verteilung
'Orographie + Land-Meer-Verteilung' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}

#paramId: 500217
#evergreen forest
'evergreen forest' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	}

#paramId: 500218
#deciduous forest
'deciduous forest' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	}

#paramId: 500219
#normalized differential vegetation index
'normalized differential vegetation index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500220
#normalized differential vegetation index (NDVI)
'normalized differential vegetation index (NDVI)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500223
#Total sulfate aerosol
'Total sulfate aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62006 ;
	}

#paramId: 500224
#Total sulfate aerosol (12M)
'Total sulfate aerosol (12M)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62006 ;
	}

#paramId: 500225
#Total soil dust aerosol (climatology)
'Total soil dust aerosol (climatology)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62001 ;
	}

#paramId: 500226
#Total soil dust aerosol (climatology,12M)
'Total soil dust aerosol (climatology,12M)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62001 ;
	}

#paramId: 500227
#Organic aerosol
'Organic aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62010 ;
	}

#paramId: 500228
#Organic aerosol (12M)
'Organic aerosol (12M)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62010 ;
	}

#paramId: 500229
#Black carbon aerosol
'Black carbon aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62009 ;
	}

#paramId: 500230
#Black carbon aerosol (12M)
'Black carbon aerosol (12M)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62009 ;
	}

#paramId: 500231
#Sea salt aerosol
'Sea salt aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62008 ;
	}

#paramId: 500232
#Sea salt aerosol (12M)
'Sea salt aerosol (12M)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62008 ;
	}

#paramId: 500236
#geographical latitude
'geographical latitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	}

#paramId: 500237
#geographical longitude
'geographical longitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	}

#paramId: 500238
#Friction velocity
'Friction velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	}

#paramId: 500242
#Ozone Mixing Ratio
'Ozone Mixing Ratio' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	}

#paramId: 500243
#Air concentration of Ruthenium 103
'Air concentration of Ruthenium 103' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30102 ;
	}

#paramId: 500244
#Ru103 - dry deposition
'Ru103 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30102 ;
	}

#paramId: 500245
#Ru103 - wet deposition
'Ru103 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30102 ;
	}

#paramId: 500246
#Air concentration of Strontium 90
'Air concentration of Strontium 90' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30067 ;
	}

#paramId: 500247
#Sr90 - dry deposition
'Sr90 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30067 ;
	}

#paramId: 500248
#Sr90 - wet deposition
'Sr90 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30067 ;
	}

#paramId: 500249
#Air concentration of Iodine 131 aerosol
'Air concentration of Iodine 131 aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30141 ;
	}

#paramId: 500250
#I131a - dry deposition
'I131a - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30141 ;
	}

#paramId: 500251
#I131a - wet deposition
'I131a - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30141 ;
	}

#paramId: 500252
#Air concentration of Caesium 137
'Air concentration of Caesium 137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30172 ;
	}

#paramId: 500253
#Cs137 - dry deposition
'Cs137 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30172 ;
	}

#paramId: 500255
#Air concentration of Tellurium 132
'Air concentration of Tellurium 132' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30129 ;
	}

#paramId: 500256
#Te132 - dry deposition
'Te132 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30129 ;
	}

#paramId: 500257
#Te132 - wet deposition
'Te132 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30129 ;
	}

#paramId: 500258
#Air concentration of Zirconium 95
'Air concentration of Zirconium 95' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30079 ;
	}

#paramId: 500259
#Zr95 - dry deposition
'Zr95 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30079 ;
	}

#paramId: 500260
#Zr95 - wet deposition
'Zr95 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30079 ;
	}

#paramId: 500261
#Air concentration of Krypton 85
'Air concentration of Krypton 85' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30059 ;
	}

#paramId: 500262
#Kr85 - dry deposition
'Kr85 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30059 ;
	}

#paramId: 500263
#Kr85 - wet deposition
'Kr85 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30059 ;
	}

#paramId: 500264
#TRACER - concentration
'TRACER - concentration' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30000 ;
	}

#paramId: 500265
#TRACER - dry deposition
'TRACER - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30000 ;
	}

#paramId: 500266
#TRACER - wet deposition
'TRACER - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30000 ;
	}

#paramId: 500267
#Air concentration of Xenon 133
'Air concentration of Xenon 133' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30161 ;
	}

#paramId: 500268
#Xe133 - dry deposition
'Xe133 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30161 ;
	}

#paramId: 500269
#Xe133 - wet deposition
'Xe133 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30161 ;
	}

#paramId: 500270
#Air concentration of Iodine 131 elementary gaseous
'Air concentration of Iodine 131 elementary gaseous' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30138 ;
	}

#paramId: 500271
#I131g - dry deposition
'I131g - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30138 ;
	}

#paramId: 500272
#I131g - wet deposition
'I131g - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30138 ;
	}

#paramId: 500273
#Air concentration of Iodine 131 organic bounded
'Air concentration of Iodine 131 organic bounded' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30139 ;
	}

#paramId: 500274
#I131o - dry deposition
'I131o - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30139 ;
	}

#paramId: 500275
#I131o - wet deposition
'I131o - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30139 ;
	}

#paramId: 500276
#Air concentration of Barium 140
'Air concentration of Barium 140' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30175 ;
	}

#paramId: 500277
#Ba140 - dry deposition
'Ba140 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30175 ;
	}

#paramId: 500278
#Ba140 - wet deposition
'Ba140 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30175 ;
	}

#paramId: 500284
#Gravity wave dissipation (vertical integral)
'Gravity wave dissipation (vertical integral)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	}

#paramId: 500285
#UV Index, clouded sky, maximum
'UV Index, clouded sky, maximum' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500286
#Vertical speed shear
'Vertical speed shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	}

#paramId: 500287
#storm relative helicity
'storm relative helicity' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 8 ;
	}

#paramId: 500290
#Hoehe der Konvektionsuntergrenze ueber Grund
'Hoehe der Konvektionsuntergrenze ueber Grund' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 26 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500292
#weather interpretation (WMO)
'weather interpretation (WMO)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 25 ;
	}

#paramId: 500301
#Druck einer isentropen Flaeche
'Druck einer isentropen Flaeche' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 107 ;
	}

#paramId: 500302
#KO index
'KO index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 3 ;
	}

#paramId: 500303
#Aequivalentpotentielle Temperatur
'Aequivalentpotentielle Temperatur' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 500304
#Ceiling
'Ceiling' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	}

#paramId: 500305
#Icing Grade (1=LGT,2=MOD,3=SEV)
'Icing Grade (1=LGT,2=MOD,3=SEV)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 7 ;
	}

#paramId: 500308
#Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL
'Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500309
#Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL
'Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500310
#Monthly Mean of RMS of difference FG-AN of u-component of wind
'Monthly Mean of RMS of difference FG-AN of u-component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500311
#Monthly Mean of RMS of difference IA-AN of u-component of wind
'Monthly Mean of RMS of difference IA-AN of u-component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500312
#Monthly Mean of RMS of difference FG-AN of v-component of wind
'Monthly Mean of RMS of difference FG-AN of v-component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500313
#Monthly Mean of RMS of difference IA-AN of v-component of wind
'Monthly Mean of RMS of difference IA-AN of v-component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500314
#Monthly Mean of RMS of difference FG-AN of geopotential
'Monthly Mean of RMS of difference FG-AN of geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500315
#Monthly Mean of RMS of difference IA-AN of geopotential
'Monthly Mean of RMS of difference IA-AN of geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500316
#Monthly Mean of RMS of difference FG-AN of relative humidity
'Monthly Mean of RMS of difference FG-AN of relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500317
#Monthly Mean of RMS of difference IA-AN of relative humidity
'Monthly Mean of RMS of difference IA-AN of relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500318
#Monthly Mean of RMS of difference FG-AN of temperature
'Monthly Mean of RMS of difference FG-AN of temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500319
#Monthly Mean of RMS of difference IA-AN of temperature
'Monthly Mean of RMS of difference IA-AN of temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500320
#Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)
'Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500321
#Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)
'Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500324
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500325
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500326
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500327
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500328
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500329
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500330
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500331
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500332
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500333
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500334
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500335
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500336
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500337
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500338
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500339
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500340
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500341
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500342
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500343
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500344
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500345
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500346
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500347
#Synth. Sat. brightness temperature cloudy
'Synth. Sat. brightness temperature cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500348
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500349
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500350
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500351
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500352
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500353
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500354
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500355
#Synth. Sat. brightness temperature clear sky
'Synth. Sat. brightness temperature clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500356
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500357
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500358
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500359
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500360
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500361
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500362
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500363
#Synth. Sat. radiance cloudy
'Synth. Sat. radiance cloudy' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500364
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500365
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500366
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500367
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500368
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500369
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500370
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500371
#Synth. Sat. radiance clear sky
'Synth. Sat. radiance clear sky' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500372
#smoothed forecast, temperature
'smoothed forecast, temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500373
#smoothed forecast, maximum temp.
'smoothed forecast, maximum temp.' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500374
#smoothed forecast, minimum temp.
'smoothed forecast, minimum temp.' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500375
#smoothed forecast, dew point temp.
'smoothed forecast, dew point temp.' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500376
#smoothed forecast, u comp. of wind
'smoothed forecast, u comp. of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500377
#smoothed forecast, v comp. of wind
'smoothed forecast, v comp. of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500378
#smoothed forecast, total precipitation (Accumulation)
'smoothed forecast, total precipitation (Accumulation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500379
#smoothed forecast, total cloud cover
'smoothed forecast, total cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500380
#smoothed forecast, cloud cover low
'smoothed forecast, cloud cover low' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 800 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500381
#smoothed forecast, cloud cover medium
'smoothed forecast, cloud cover medium' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 800 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 400 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500382
#smoothed forecast, cloud cover high
'smoothed forecast, cloud cover high' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 400 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500383
#smoothed forecast, large-scale snowfall
'smoothed forecast, large-scale snowfall' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500384
#smoothed forecast, soil temperature
'smoothed forecast, soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500385
#smoothed forecast, wind speed (gust)
'smoothed forecast, wind speed (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500386
#calibrated forecast, total precipitation  (Accumulation)
'calibrated forecast, total precipitation  (Accumulation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 198 ;
	}

#paramId: 500387
#calibrated forecast, large-scale snowfall
'calibrated forecast, large-scale snowfall' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 198 ;
	}

#paramId: 500388
#calibrated forecast, wind speed (gust)
'calibrated forecast, wind speed (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 198 ;
	}

#paramId: 500389
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'Obser. Sat. Meteosat sec. generation Albedo (scaled)' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 2000000 ;
	}

#paramId: 500390
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'Obser. Sat. Meteosat sec. generation Albedo (scaled)' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 625000 ;
	}

#paramId: 500391
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'Obser. Sat. Meteosat sec. generation Albedo (scaled)' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 1666666 ;
	}

#paramId: 500392
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'Obser. Sat. Meteosat sec. generation Albedo (scaled)' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 1250000 ;
	}

#paramId: 500393
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500394
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 83333 ;
	}

#paramId: 500395
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500396
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500397
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500398
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500399
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500400
#Obser. Sat. Meteosat sec. generation brightness temperature
'Obser. Sat. Meteosat sec. generation brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500401
#Total Precipitation Difference
'Total Precipitation Difference' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 500419
#Net short wave radiation flux
'Net short wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500420
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500421
#Net short wave radiation flux (at the surface)
'Net short wave radiation flux (at the surface)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500422
#Net long wave radiation flux
'Net long wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500468
#UV Index, clear sky, maximum
'UV Index, clear sky, maximum' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500469
#Total ozone
'Total ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500474
#wind chill factor
'wind chill factor' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}

#paramId: 500475
#Water temperature
'Water temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}

#paramId: 500477
#Absolute Vorticity
'Absolute Vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}

#paramId: 500482
#Upward diffusive short wave radiation flux at surface ( mean over forecast time)
'Upward diffusive short wave radiation flux at surface ( mean over forecast time)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500490
#Water Fraction
'Water Fraction' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 500491
#Lake depth
'Lake depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500492
#Wind fetch
'Wind fetch' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 33 ;
	}

#paramId: 500493
#Attenuation coefficient of water with respect to solar radiation
'Attenuation coefficient of water with respect to solar radiation' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500494
#Depth of thermally active layer of bottom sediment
'Depth of thermally active layer of bottom sediment' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfSecondFixedSurface = 164 ;
	 typeOfFirstFixedSurface = 162 ;
	}

#paramId: 500495
#Temperature at the lower boundary of the thermally active layer of bottom sediment
'Temperature at the lower boundary of the thermally active layer of bottom sediment' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 164 ;
	}

#paramId: 500496
#Mean temperature of the water column
'Mean temperature of the water column' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500497
#Mixed-layer temperature
'Mixed-layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 166 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500498
#Bottom temperature (temperature at the water-bottom sediment interface)
'Bottom temperature (temperature at the water-bottom sediment interface)' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	}

#paramId: 500499
#Mixed-layer depth
'Mixed-layer depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 166 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500500
#Shape factor with respect to the temperature profile in the thermocline
'Shape factor with respect to the temperature profile in the thermocline' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 166 ;
	}

#paramId: 500501
#Temperature at the lower boundary of the upper layer of bottom sediment (penetrated by thermal wave)
'Temperature at the lower boundary of the upper layer of bottom sediment (penetrated by thermal wave)' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 165 ;
	}

#paramId: 500502
#Sediment thickness of the upper layer of bottom sediments
'Sediment thickness of the upper layer of bottom sediments' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfSecondFixedSurface = 165 ;
	 typeOfFirstFixedSurface = 162 ;
	}

#paramId: 500539
#cloud top height
'cloud top height' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 500543
#vertical vorticity
'vertical vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 500544
#Potential vorticity
'Potential vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	}

#paramId: 500545
#Density
'Density' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}

#paramId: 500546
#Altimeter Settings
'Altimeter Settings' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}

#paramId: 500547
#Convective Precipitation (difference)
'Convective Precipitation (difference)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 500548
#Soil moisture
'Soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}

#paramId: 500549
#Soil moisture
'Soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}

#paramId: 500568
#Geopotential height
'Geopotential height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}

#paramId: 500569
#Relative Divergenz
'Relative Divergenz' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	}

#paramId: 500574
#Logarithm of Pressure
'Logarithm of Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	}

#paramId: 500579
#Soil Temperature (layer)
'Soil Temperature (layer)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500580
#Soil Moisture Content (0-7 cm)
'Soil Moisture Content (0-7 cm)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 7 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500581
#Soil Moisture Content (7-50 cm)
'Soil Moisture Content (7-50 cm)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 50 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 7 ;
	}

#paramId: 500584
#Sunshine duration
'Sunshine duration' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500588
#Snow melt
'Snow melt' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500590
#ICAO Standard Atmosphere reference height
'ICAO Standard Atmosphere reference height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}

#paramId: 500593
#Global radiation flux
'Global radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}

#paramId: 500594
#exner pressure
'exner pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 26 ;
	}

#paramId: 500595
#normal wind component
'normal wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 34 ;
	}

#paramId: 500596
#tangential wind component
'tangential wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 35 ;
	}

#paramId: 500597
#virtual potential temperature
'virtual potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}

#paramId: 500598
#Current Direction
'Current Direction' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 500599
#Current Speed
'Current Speed' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 500642
#Lapse rate
'Lapse rate' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}

#paramId: 500905
#Specific Humidity (S)
'Specific Humidity (S)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502307
#Albedo - diffusive solar - time average (0.3 - 5.0 m-6)
'Albedo - diffusive solar - time average (0.3 - 5.0 m-6)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 502308
#Albedo - diffusive solar (0.3 - 5.0 m-6)
'Albedo - diffusive solar (0.3 - 5.0 m-6)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 18 ;
	}

#paramId: 502309
#center latitude
'center latitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 numberOfGridInReference = 1 ;
	}

#paramId: 502310
#center longitude
'center longitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 numberOfGridInReference = 1 ;
	}

#paramId: 502311
#edge midpoint latitude
'edge midpoint latitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 numberOfGridInReference = 3 ;
	}

#paramId: 502312
#edge midpoint longitude
'edge midpoint longitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 numberOfGridInReference = 3 ;
	}

#paramId: 502313
#vertex latitude
'vertex latitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 numberOfGridInReference = 2 ;
	}

#paramId: 502314
#vertex longitude
'vertex longitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 numberOfGridInReference = 2 ;
	}

#paramId: 502315
#Number of cloud droplets per unit mass of air
'Number of cloud droplets per unit mass of air' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 28 ;
	}

#paramId: 502316
#Number of cloud ice particles per unit mass of air
'Number of cloud ice particles per unit mass of air' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 29 ;
	}

#paramId: 502317
#Latent Heat Net Flux - instant - at surface
'Latent Heat Net Flux - instant - at surface' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502318
#Sensible Heat Net Flux - instant - at surface
'Sensible Heat Net Flux - instant - at surface' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502319
#Latent Heat Net Flux - accumulated _ surface
'Latent Heat Net Flux - accumulated _ surface' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502320
#Sensible Heat Net Flux - accumulated _ surface
'Sensible Heat Net Flux - accumulated _ surface' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502321
#Net short wave radiation flux - accumulated _ surface
'Net short wave radiation flux - accumulated _ surface' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502322
#Net long wave radiation flux - accumulated _  surface
'Net long wave radiation flux - accumulated _  surface' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502323
#Net long wave radiation flux  - accumulated _ model top
'Net long wave radiation flux  - accumulated _ model top' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 502327
#Net short wave radiation flux - accumulated _ model top
'Net short wave radiation flux - accumulated _ model top' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 502328
#Snow temperature  - multi level
'Snow temperature  - multi level ' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502329
#Snow depth  - multi level
'Snow depth  - multi level ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502330
#Snow density in  - multi level
'Snow density in  - multi level ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502331
#Water equivalent  of accumulated snoe depth in - multi level
'Water equivalent  of accumulated snoe depth in - multi level ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502333
#salinity
'salinity' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 502334
#Stream function
'Stream function' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}

#paramId: 502335
#Velocity potential
'Velocity potential' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}

#paramId: 502336
#Skin temperature
'Skin temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502340
#Snow cover
'Snow cover ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 42 ;
	}

#paramId: 502341
#Cloud Cover (0 - 400 hPa)
'Cloud Cover (0 - 400 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 40000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 502342
#Cloud Cover (400 - 800 hPa)
'Cloud Cover (400 - 800 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaledValueOfSecondFixedSurface = 80000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaledValueOfFirstFixedSurface = 40000 ;
	}

#paramId: 502343
#Cloud Cover (800 hPa - Soil)
'Cloud Cover (800 hPa - Soil)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaledValueOfFirstFixedSurface = 80000 ;
	}

#paramId: 502348
#Water Runoff (s)
'Water Runoff (s)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 502349
#Water Runoff
'Water Runoff' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	}

#paramId: 502397
#Virtual Temperature
'Virtual Temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 502424
#Vertical u-component shear
'Vertical u-component shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	}

#paramId: 502425
#Vertical v-component shear
'Vertical v-component shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	}

#paramId: 502693
#Potential temperature
'Potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 502700
#Boundary layer dissipation
'Boundary layer dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	}

#paramId: 502701
#Sunshine duration
'Sunshine duration' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502702
#Brightness temperature
'Brightness temperature' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 4 ;
	}

#paramId: 502703
#Heat index
'Heat index' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}

#paramId: 502705
#Total column water
'Total column water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	}

#paramId: 502706
#Large scale precipitation (non-convective)
'Large scale precipitation (non-convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}

#paramId: 502707
#Snowfall rate water equivalent
'Snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}

#paramId: 502708
#Convective snow
'Convective snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	}

#paramId: 502709
#Large scale snow
'Large scale snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	}

#paramId: 502710
#Snow age
'Snow age' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	}

#paramId: 502711
#Absolute humidity
'Absolute humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 18 ;
	}

#paramId: 502712
#Precipitation type
'Precipitation type' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	}

#paramId: 502713
#Integrated liquid water
'Integrated liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 20 ;
	}

#paramId: 502714
#Condensate
'Condensate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 21 ;
	}

#paramId: 502715
#Ice water mixing ratio
'Ice water mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 23 ;
	}

#paramId: 502717
#Maximum relative humidity
'Maximum relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 27 ;
	}

#paramId: 502718
#Maximum absolute humidity
'Maximum absolute humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 28 ;
	}

#paramId: 502719
#Total snowfall
'Total snowfall' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 29 ;
	}

#paramId: 502720
#Precipitable water category
'Precipitable water category' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 30 ;
	}

#paramId: 502721
#Hail
'Hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 31 ;
	}

#paramId: 502722
#Categorical rain
'Categorical rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 33 ;
	}

#paramId: 502723
#Categorical freezing rain
'Categorical freezing rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 34 ;
	}

#paramId: 502724
#Categorical ice pellets
'Categorical ice pellets' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 35 ;
	}

#paramId: 502725
#Categorical snow
'Categorical snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 36 ;
	}

#paramId: 502727
#Percent frozen precipitation
'Percent frozen precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 39 ;
	}

#paramId: 502728
#Potential evaporation
'Potential evaporation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 40 ;
	}

#paramId: 502729
#Potential evaporation rate
'Potential evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 41 ;
	}

#paramId: 502730
#Rain fraction of total cloud water
'Rain fraction of total cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 43 ;
	}

#paramId: 502731
#Rime factor
'Rime factor' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 44 ;
	}

#paramId: 502732
#Large scale water precipitation (non-convective)
'Large scale water precipitation (non-convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 47 ;
	}

#paramId: 502733
#Convective water precipitation
'Convective water precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 48 ;
	}

#paramId: 502734
#Total water precipitation
'Total water precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 49 ;
	}

#paramId: 502735
#Total snow precipitation
'Total snow precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 50 ;
	}

#paramId: 502737
#Snow Fall water equivalent
'Snow Fall water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	}

#paramId: 502738
#Convective snowfall rate
'Convective snowfall rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 58 ;
	}

#paramId: 502739
#Large scale snowfall rate
'Large scale snowfall rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 59 ;
	}

#paramId: 502740
#Water equivalent of accumulated snow depth
'Water equivalent of accumulated snow depth' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}

#paramId: 502741
#Freezing rain precipitation rate
'Freezing rain precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	}

#paramId: 502742
#Ice pellets precipitation rate
'Ice pellets precipitation rate ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 68 ;
	}

#paramId: 502743
#Maximum wind speed
'Maximum wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	}

#paramId: 502744
#u-component of wind (gust)
'u-component of wind (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	}

#paramId: 502745
#v-component of wind (gust)
'v-component of wind (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	}

#paramId: 502746
#Horizontal momentum flux
'Horizontal momentum flux' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 26 ;
	}

#paramId: 502747
#U-component storm motion
'U-component storm motion' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 27 ;
	}

#paramId: 502748
#V-component storm motion
'V-component storm motion' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 28 ;
	}

#paramId: 502749
#Thickness
'Thickness' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}

#paramId: 502751
#Minimum dew point depression
'Minimum dew point depression' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}

#paramId: 502752
#Pressure altitude
'Pressure altitude' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}

#paramId: 502753
#Density altitude
'Density altitude' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}

#paramId: 502754
#5-wave geopotential height
'5-wave geopotential height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}

#paramId: 502755
#Zonal flux of gravity wave stress
'Zonal flux of gravity wave stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	}

#paramId: 502756
#Meridional flux of gravity wave stress
'Meridional flux of gravity wave stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	}

#paramId: 502757
#Planetary boundary layer height
'Planetary boundary layer height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	}

#paramId: 502758
#5-wave geopotential height anomaly
'5-wave geopotential height anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}

#paramId: 502759
#Net short-wave radiation flux (top of atmosphere)
'Net short-wave radiation flux (top of atmosphere)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}

#paramId: 502760
#Downward short-wave radiation flux
'Downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	}

#paramId: 502761
#Net short-wave radiation flux, clear sky
'Net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	}

#paramId: 502762
#Downward UV radiation
'Downward UV radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	}

#paramId: 502763
#Net long wave radiation flux (surface)
'Net long wave radiation flux (surface)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 0 ;
	}

#paramId: 502764
#Net long wave radiation flux (top of atmosphere)
'Net long wave radiation flux (top of atmosphere)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 1 ;
	}

#paramId: 502765
#Downward long-wave radiation flux
'Downward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	}

#paramId: 502766
#Upward long-wave radiation flux
'Upward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	}

#paramId: 502767
#Net long-wave radiation flux, clear sky
'Net long-wave radiation flux, clear sky ' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	}

#paramId: 502768
#Cloud Ice
'Cloud Ice' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	}

#paramId: 502769
#Cloud water
'Cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 6 ;
	}

#paramId: 502770
#Cloud amount
'Cloud amount' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 7 ;
	}

#paramId: 502771
#Cloud type
'Cloud type' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 8 ;
	}

#paramId: 502772
#Thunderstorm maximum tops
'Thunderstorm maximum tops' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 9 ;
	}

#paramId: 502773
#Thunderstorm coverage
'Thunderstorm coverage' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 10 ;
	}

#paramId: 502774
#Cloud base
'Cloud base' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	}

#paramId: 502775
#Cloud top
'Cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 12 ;
	}

#paramId: 502776
#Cloud work function
'Cloud work function' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 15 ;
	}

#paramId: 502777
#Convective cloud efficiency
'Convective cloud efficiency' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 16 ;
	}

#paramId: 502778
#Total condensate
'Total condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 17 ;
	}

#paramId: 502779
#Total column-integrated cloud water
'Total column-integrated cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 18 ;
	}

#paramId: 502780
#Total column-integrated cloud ice
'Total column-integrated cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 19 ;
	}

#paramId: 502781
#Total column-integrated condensate
'Total column-integrated condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 20 ;
	}

#paramId: 502782
#Ice fraction of total condensate
'Ice fraction of total condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 21 ;
	}

#paramId: 502783
#Cloud ice mixing ratio
'Cloud ice mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 23 ;
	}

#paramId: 502785
#K index
'K index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	}

#paramId: 502786
#Total totals index
'Total totals index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	}

#paramId: 502787
#Sweat index
'Sweat index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 5 ;
	}

#paramId: 502788
#Energy helicity index
'Energy helicity index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 9 ;
	}

#paramId: 502789
#Surface lifted index
'Surface lifted index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 10 ;
	}

#paramId: 502790
#Best (4-layer) lifted index
'Best (4-layer) lifted index ' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 11 ;
	}

#paramId: 502791
#Aerosol type
'Aerosol type' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 0 ;
	}

#paramId: 502792
#Base spectrum width
'Base spectrum width' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 0 ;
	}

#paramId: 502793
#Base radial velocity
'Base radial velocity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 2 ;
	}

#paramId: 502794
#Vertically-integrated liquid
'Vertically-integrated liquid' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 3 ;
	}

#paramId: 502795
#Layer-maximum base reflectivity
'Layer-maximum base reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 4 ;
	}

#paramId: 502796
#Precipitation
'Precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 502797
#Air concentration of Caesium 137
'Air concentration of Caesium 137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 0 ;
	}

#paramId: 502798
#Air concentration of Iodine 131
'Air concentration of Iodine 131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 1 ;
	}

#paramId: 502799
#Air concentration of radioactive pollutant
'Air concentration of radioactive pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 2 ;
	}

#paramId: 502800
#Ground deposition of Caesium 137
'Ground deposition of Caesium 137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 3 ;
	}

#paramId: 502801
#Ground deposition of Iodine 131
'Ground deposition of Iodine 131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 4 ;
	}

#paramId: 502802
#Ground deposition of radioactive pollutant
'Ground deposition of radioactive pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 5 ;
	}

#paramId: 502843
#Time-integrated air concentration of caesium pollutant
'Time-integrated air concentration of caesium pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 6 ;
	}

#paramId: 502844
#Time-integrated air concentration of iodine pollutant
'Time-integrated air concentration of iodine pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 7 ;
	}

#paramId: 502845
#Time-integrated air concentration of radioactive pollutant
'Time-integrated air concentration of radioactive pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 8 ;
	}

#paramId: 502846
#Volcanic ash
'Volcanic ash' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 4 ;
	}

#paramId: 502847
#Icing top
'Icing top' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 5 ;
	}

#paramId: 502848
#Icing base
'Icing base' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 6 ;
	}

#paramId: 502849
#Turbulence top
'Turbulence top' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 8 ;
	}

#paramId: 502850
#Turbulence base
'Turbulence base' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 9 ;
	}

#paramId: 502851
#Turbulence
'Turbulence' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 10 ;
	}

#paramId: 502852
#Planetary boundary layer regime
'Planetary boundary layer regime' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 12 ;
	}

#paramId: 502853
#Contrail intensity
'Contrail intensity' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 13 ;
	}

#paramId: 502854
#Contrail engine type
'Contrail engine type' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 14 ;
	}

#paramId: 502855
#Contrail top
'Contrail top' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 15 ;
	}

#paramId: 502856
#Contrail base
'Contrail base' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 16 ;
	}

#paramId: 502857
#Maximum snow albedo
'Maximum snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 17 ;
	}

#paramId: 502858
#Icing
'Icing' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 20 ;
	}

#paramId: 502859
#Horizontal extent of cumulonimbus (CB)
'Horizontal extent of cumulonimbus (CB)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 25 ;
	}

#paramId: 502860
#In-cloud turbulence
'In-cloud turbulence ' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 21 ;
	}

#paramId: 502861
#Clear air turbulence (CAT)
'Clear air turbulence (CAT)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 22 ;
	}

#paramId: 502862
#Supercooled large droplet probability (see Note 4)
'Supercooled large droplet probability (see Note 4)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 23 ;
	}

#paramId: 502864
#Seconds prior to initial reference time (defined in Section 1)
'Seconds prior to initial reference time (defined in Section 1)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}

#paramId: 502865
#Flash flood guidance (Encoded as an accumulation over a floating subinterval of time between the ref
'Flash flood guidance (Encoded as an accumulation over a floating subinterval of time between the ref' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 502866
#Flash flood runoff (Encoded as an accumulation over a floating subinterval of time)
'Flash flood runoff (Encoded as an accumulation over a floating subinterval of time)' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 502867
#Remotely sensed snow cover
'Remotely sensed snow cover' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 502868
#Elevation of snow covered terrain
'Elevation of snow covered terrain' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 502869
#Snow water equivalent percent of normal
'Snow water equivalent percent of normal' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 502870
#Baseflow-groundwater runoff
'Baseflow-groundwater runoff' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}

#paramId: 502871
#Storm surface runoff
'Storm surface runoff' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 502872
#Conditional percent precipitation amount fractile for an overall period (Encoded as an accumulation)
'Conditional percent precipitation amount fractile for an overall period (Encoded as an accumulation)' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 502873
#Percent precipitation in a sub-period of an overall period (Encoded as per cent accumulation over th
'Percent precipitation in a sub-period of an overall period (Encoded as per cent accumulation over th' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 502874
#Probability of 0.01 inch of precipitation (POP)
'Probability of 0.01 inch of precipitation (POP)' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 502875
#Evapotranspiration
'Evapotranspiration' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 502876
#Land use
'Land use' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}

#paramId: 502877
#Volumetric soil moisture content
'Volumetric soil moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}

#paramId: 502878
#Ground heat flux
'Ground heat flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}

#paramId: 502879
#Moisture availability
'Moisture availability' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}

#paramId: 502880
#Exchange coefficient
'Exchange coefficient' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}

#paramId: 502881
#Blackadar mixing length scale
'Blackadar mixing length scale' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}

#paramId: 502882
#Canopy conductance
'Canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}

#paramId: 502883
#Solar parameter in canopy conductance
'Solar parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}

#paramId: 502885
#Soil moisture parameter in canopy conductance
'Soil moisture parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}

#paramId: 502886
#Humidity parameter in canopy conductance
'Humidity parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}

#paramId: 502887
#Column-integrated soil water
'Column-integrated soil water' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}

#paramId: 502888
#Heat flux
'Heat flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}

#paramId: 502889
#Volumetric soil moisture
'Volumetric soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}

#paramId: 502890
#Volumetric wilting point
'Volumetric wilting point' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}

#paramId: 502891
#Upper layer soil temperature
'Upper layer soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}

#paramId: 502892
#Upper layer soil moisture
'Upper layer soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	}

#paramId: 502893
#Lower layer soil moisture
'Lower layer soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}

#paramId: 502894
#Bottom layer soil temperature
'Bottom layer soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}

#paramId: 502895
#Liquid volumetric soil moisture (non-frozen)
'Liquid volumetric soil moisture (non-frozen)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}

#paramId: 502896
#Number of soil layers in root zone
'Number of soil layers in root zone' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	}

#paramId: 502897
#Transpiration stress-onset (soil moisture)
'Transpiration stress-onset (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}

#paramId: 502898
#Direct evaporation cease (soil moisture)
'Direct evaporation cease (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}

#paramId: 502899
#Soil porosity
'Soil porosity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}

#paramId: 502900
#Liquid volumetric soil moisture (non-frozen)
'Liquid volumetric soil moisture (non-frozen)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}

#paramId: 502919
#Volumetric transpiration stress-onset (soil moisture)
'Volumetric transpiration stress-onset (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}

#paramId: 502920
#Transpiration stress-onset (soil moisture)
'Transpiration stress-onset (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}

#paramId: 502921
#Volumetric direct evaporation cease (soil moisture)
'Volumetric direct evaporation cease (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}

#paramId: 502922
#Direct evaporation cease (soil moisture)
'Direct evaporation cease (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}

#paramId: 502923
#Soil porosity
'Soil porosity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}

#paramId: 502924
#Volumetric saturation of soil moisture
'Volumetric saturation of soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	}

#paramId: 502926
#Estimated precipitation
'Estimated precipitation' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 502927
#Instantaneous rain rate
'Instantaneous rain rate' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 502928
#Cloud top height quality indicator
'Cloud top height quality indicator' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}

#paramId: 502929
#Estimated u component of wind
'Estimated u component of wind' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}

#paramId: 502930
#Estimated v component of wind
'Estimated v component of wind' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}

#paramId: 502931
#Number of pixels used
'Number of pixels used' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 6 ;
	}

#paramId: 502932
#Solar zenith angle
'Solar zenith angle' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}

#paramId: 502933
#Reflectance in 0.6 micron channel
'Reflectance in 0.6 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}

#paramId: 502934
#Reflectance in 0.8 micron channel
'Reflectance in 0.8 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}

#paramId: 502935
#Reflectance in 1.6 micron channel
'Reflectance in 1.6 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}

#paramId: 502936
#Reflectance in 3.9 micron channel
'Reflectance in 3.9 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}

#paramId: 502937
#Atmospheric divergence
'Atmospheric divergence' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}

#paramId: 502938
#Primary wave direction
'Primary wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}

#paramId: 502939
#Primary wave mean period
'Primary wave mean period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}

#paramId: 502940
#Secondary wave mean period
'Secondary wave mean period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}

#paramId: 502941
#Deviation of sea level from mea
'Deviation of sea level from mea' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}

#paramId: 502942
#Seconds prior to initial reference time (defined in Section 1)
'Seconds prior to initial reference time (defined in Section 1)' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}

#paramId: 502943
#Standard deviation of height
'Standard deviation of height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}

#paramId: 502944
#Maximum temperature
'Maximum temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 502945
#Minimum temperature
'Minimum temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}

#paramId: 502946
#Visibility
'Visibility' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	}

#paramId: 502947
#Radar spectra (2)
'Radar spectra (2)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 7 ;
	}

#paramId: 502948
#Radar spectra (3)
'Radar spectra (3)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 8 ;
	}

#paramId: 502949
#Parcel lifted index (to 500 hPa)
'Parcel lifted index (to 500 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	}

#paramId: 502950
#Temperature anomaly
'Temperature anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}

#paramId: 502951
#Pressure anomaly
'Pressure anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}

#paramId: 502952
#Geopotential height anomaly
'Geopotential height anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}

#paramId: 502953
#Montgomery stream Function
'Montgomery stream Function' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}

#paramId: 502954
#Sigma coordinate vertical velocity
'Sigma coordinate vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}

#paramId: 502955
#Absolute divergence
'Absolute divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	}

#paramId: 502958
#U-component of current
'U-component of current' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 502959
#V-component of current
'V-component of current' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}

#paramId: 502960
#Precipitable water
'Precipitable water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}

#paramId: 502961
#Saturation deficit
'Saturation deficit' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}

#paramId: 502962
#Precipitation rate
'Precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}

#paramId: 502963
#Thunderstorm probability
'Thunderstorm probability' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 2 ;
	}

#paramId: 502964
#Convective precipitation (water)
'Convective precipitation (water)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}

#paramId: 502965
#Transient thermocline depth
'Transient thermocline depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 2 ;
	}

#paramId: 502966
#Main thermocline depth
'Main thermocline depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	}

#paramId: 502967
#Main thermocline anomaly
'Main thermocline anomaly' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}

#paramId: 502968
#Best lifted index (to 500 hPa)
'Best lifted index (to 500 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 1 ;
	}

#paramId: 502969
#Soil moisture content
'Soil moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 503011
#Salinity
'Salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}

#paramId: 503012
#Direction of ice drift
'Direction of ice drift' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 503013
#Speed of ice drift
'Speed of ice drift' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}

#paramId: 503014
#U-component of ice drift
'U-component of ice drift' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}

#paramId: 503015
#V-component of ice drift
'V-component of ice drift' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}

#paramId: 503016
#Ice growth rate
'Ice growth rate' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}

#paramId: 503017
#Ice divergence
'Ice divergence' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}

#paramId: 503019
#Secondary wave direction
'Secondary wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}

#paramId: 503020
#Net short-wave radiation flux (surface)
'Net short-wave radiation flux (surface)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	}

#paramId: 503021
#Radiance (with respect to wave number)
'Radiance (with respect to wave number)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 5 ;
	}

#paramId: 503022
#Radiance (with respect to wave length)
'Radiance (with respect to wave length)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 6 ;
	}

#paramId: 503023
#Convective inhibition
'Convective inhibition' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	}

#paramId: 503024
#Wind mixing energy
'Wind mixing energy' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	}

#paramId: 503025
#Soil Temperature
'Soil Temperature' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 503028
#Wilting point
'Wilting point' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 503038
#Snow phase change heat flux
'Snow phase change heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}

#paramId: 503039
#Vapor pressure
'Vapor pressure' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}

#paramId: 503047
#Land use class fraction
'Land use class fraction' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	}

#paramId: 503048
#Saturation of soil moisture
'Saturation of soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	}

#paramId: 503062
#Upward diffusive short wave radiation flux at surface ( mean over forecast time)
'Upward diffusive short wave radiation flux at surface ( mean over forecast time)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503063
#Momentum Flux, U-Component (m)
'Momentum Flux, U-Component (m)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503064
#Momentum Flux, V-Component (m)
'Momentum Flux, V-Component (m)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503075
#Geometric height of the earths surface above mean sea level at vertex point (ICON)
'Geometric height of the earths surface above mean sea level at vertex point (ICON) ' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 numberOfGridInReference = 2 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503076
#Gravity wave dissipation
'Gravity wave dissipation ' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503080
#Land use class
'Land use class' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	}

#paramId: 503081
#Water depth
'Water depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	}

#paramId: 503082
#Friction velocity
'Friction velocity' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	}

#paramId: 503083
#Coefficient of drag with waves
'Coefficient of drag with waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}

#paramId: 503084
#Normalized wave stress
'Normalized wave stress' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}

#paramId: 503085
#Inverse mean frequency of wind waves
'Inverse mean frequency of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	}

#paramId: 503086
#Mean zero-crossing period of wind waves
'Mean zero-crossing period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	}

#paramId: 503087
#Directional width of wind waves
'Directional width of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	}

#paramId: 503088
#Inverse mean frequency of total swell
'Inverse mean frequency of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}

#paramId: 503089
#Inverse mean zero crossing period of total swell
'Inverse mean zero crossing period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	}

#paramId: 503090
#Directional width of total swell
'Directional width of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	}

#paramId: 503091
#Goda peakedness parameter
'Goda peakedness parameter' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 45 ;
	}

#paramId: 503092
#Spectral kurtosis
'Spectral kurtosis' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	}

#paramId: 503093
#Benjamin-Feir index
'Benjamin-Feir index' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	}

#paramId: 503094
#Maximum individual wave height
'Maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}

#paramId: 503095
#Maximum wave period
'Maximum wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}

#paramId: 503097
#Meansquare slope
'Meansquare slope' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}

#paramId: 503106
#Hail  mixing ratio
'Hail  mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 71 ;
	}

#paramId: 503107
#Hail
'Hail  ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 72 ;
	}

#paramId: 503108
#Hail  precipitation rate
'Hail  precipitation rate ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 73 ;
	}

#paramId: 503109
#Reflectivity of cloud droplets
'Reflectivity of cloud droplets' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 9 ;
	}

#paramId: 503110
#Reflectivity of  cloud ice
'Reflectivity of  cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 10 ;
	}

#paramId: 503111
#Reflectivity of snow
'Reflectivity of snow' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 11 ;
	}

#paramId: 503112
#Reflectivity of rain
'Reflectivity of rain' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 12 ;
	}

#paramId: 503113
#Reflectivity of graupel
'Reflectivity of graupel' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 13 ;
	}

#paramId: 503114
#Reflectivity of hail
'Reflectivity of hail' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 14 ;
	}

#paramId: 503130
#Hail  precipitation rate, accumulation
'Hail  precipitation rate, accumulation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503132
#Number density of cloud droplets
'Number density of cloud droplets' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 30 ;
	}

#paramId: 503133
#Number density of cloud ice particles
'Number density of cloud ice particles' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 31 ;
	}

#paramId: 503134
#Downward long-wave radiation flux
'Downward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503135
#Downward long-wave radiation flux avg
'Downward long-wave radiation flux avg' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503136
#Downward long-wave radiation flux accum
'Downward long-wave radiation flux accum' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503145
#2m absolute humidity
'2m absolute humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503154
#Bulk Richardson number
'Bulk Richardson number' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 16 ;
	}

#paramId: 503155
#Cape of mixed (mean) layer parcel, ascent up to 3 km
'Cape of mixed (mean) layer parcel, ascent up to 3 km' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 192 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 3000 ;
	}

#paramId: 503166
#Geostrophic wind direction
'Geostrophic wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 43 ;
	}

#paramId: 503169
#Dewpoint depression
'Dewpoint depression' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}

#paramId: 503170
#2m dewpoint depression
'2m dewpoint depression' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503173
#Geostrophic wind speed
'Geostrophic wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 44 ;
	}

#paramId: 503174
#Downward short wave radiation flux at surface (time average)
'Downward short wave radiation flux at surface (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503186
#Height of lifting condensation level of mixed (mean) layer parcel
'Height of lifting condensation level of mixed (mean) layer parcel' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 192 ;
	 typeOfFirstFixedSurface = 5 ;
	}

#paramId: 503192
#Humidity mixing ratio
'Humidity mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 503193
#2m Humidity mixing ratio
'2m Humidity mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503195
#relative humidity over ice
'relative humidity over ice' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 94 ;
	}

#paramId: 503196
#Gradient Richardson number
'Gradient Richardson number' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 17 ;
	}

#paramId: 503197
#Showalter index
'Showalter index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 13 ;
	}

#paramId: 503204
#Surface lifted index
'Surface lifted index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503210
#2m potential temperature
'2m potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503211
#Dew point temperature
'Dew point temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 503212
#2m equivalentTemperature
'2m equivalentTemperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503213
#2m virtual potential temperature
'2m virtual potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503214
#Temperature at cloud top
'Temperature at cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 503215
#Wet bulb temperature
'Wet bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}

#paramId: 503216
#2m wet bulb temperature
'2m wet bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503219
#Universal thermal climate index with direct incident short wave radiation
'Universal thermal climate index with direct incident short wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}

#paramId: 503220
#u-component of geostrophic wind
'u-component of geostrophic wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 41 ;
	}

#paramId: 503221
#v-component of geostrophic wind
'v-component of geostrophic wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 42 ;
	}

#paramId: 503229
#Prognostic mass mixing ratio of volcanic ash particles for bin number 1
'Prognostic mass mixing ratio of volcanic ash particles for bin number 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503230
#Prognostic mass mixing ratio of volcanic ash particles for bin number 2
'Prognostic mass mixing ratio of volcanic ash particles for bin number 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503231
#Prognostic mass mixing ratio of volcanic ash particles for bin number 3
'Prognostic mass mixing ratio of volcanic ash particles for bin number 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503232
#Prognostic mass mixing ratio of volcanic ash particles for bin number 4
'Prognostic mass mixing ratio of volcanic ash particles for bin number 4' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 4 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503233
#Prognostic mass mixing ratio of volcanic ash particles for bin number 5
'Prognostic mass mixing ratio of volcanic ash particles for bin number 5' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 5 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503234
#Prognostic mass mixing ratio of volcanic ash particles for bin number 6
'Prognostic mass mixing ratio of volcanic ash particles for bin number 6' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 6 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503235
#Modal prognostic mass mixing ratio of volcanic ash particles (fine mode)
'Modal prognostic mass mixing ratio of volcanic ash particles (fine mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503236
#Modal prognostic mass mixing ratio of volcanic ash particles (medium mode)
'Modal prognostic mass mixing ratio of volcanic ash particles (medium mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503237
#Modal prognostic mass mixing ratio of volcanic ash particles (coarse mode)
'Modal prognostic mass mixing ratio of volcanic ash particles (coarse mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503238
#Modal prognostic specific number concentration of volcanic ash particles (fine mode)
'Modal prognostic specific number concentration of volcanic ash particles (fine mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62025 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503239
#Modal prognostic specific number concentration of volcanic ash particles (medium mode)
'Modal prognostic specific number concentration of volcanic ash particles (medium mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62025 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503240
#Modal prognostic specific number concentration of volcanic ash particles (coarse mode)
'Modal prognostic specific number concentration of volcanic ash particles (coarse mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62025 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503241
#Modal prognostic mass mixing ratio of mineral dust particles (fine mode)
'Modal prognostic mass mixing ratio of mineral dust particles (fine mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503242
#Modal prognostic mass mixing ratio of mineral dust particles (medium mode)
'Modal prognostic mass mixing ratio of mineral dust particles (medium mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503243
#Modal prognostic mass mixing ratio of mineral dust particles (coarse mode)
'Modal prognostic mass mixing ratio of mineral dust particles (coarse mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503244
#Modal prognostic specific number concentration  of mineral dust particles (fine mode)
'Modal prognostic specific number concentration  of mineral dust particles (fine mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503245
#Modal prognostic specific number concentration  of mineral dust particles (medium mode)
'Modal prognostic specific number concentration  of mineral dust particles (medium mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503246
#Modal prognostic specific number concentration  of mineral dust particles (coarsemode)
'Modal prognostic specific number concentration  of mineral dust particles (coarsemode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503247
#Modal prognostic mass mixing ratio of sea salt particles (fine mode)
'Modal prognostic mass mixing ratio of sea salt particles (fine mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503248
#Modal prognostic mass mixing ratio of sea salt particles (medium mode)
'Modal prognostic mass mixing ratio of sea salt particles (medium mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503249
#Modal prognostic mass mixing ratio of sea salt particles (coarse mode)
'Modal prognostic mass mixing ratio of sea salt particles (coarse mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503250
#Modal prognostic specific number concentration of sea salt particles (fine mode)
'Modal prognostic specific number concentration of sea salt particles (fine mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62008 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503251
#Modal prognostic specific number concentration of sea salt particles (medium mode)
'Modal prognostic specific number concentration of sea salt particles (medium mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62008 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503252
#Modal prognostic specific number concentration of sea salt particles (coarse mode)
'Modal prognostic specific number concentration of sea salt particles (coarse mode)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62008 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503253
#Cs137 - wet deposition
'Cs137 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30172 ;
	}

#paramId: 503254
#Prognostic specific activity concentration of Iodine 131 aerosol
'Prognostic specific activity concentration of Iodine 131 aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30141 ;
	}

#paramId: 503255
#Te132 - total (wet + dry) deposition
'Te132 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30129 ;
	}

#paramId: 503256
#Prognostic specific activity concentration of Zirconium 95
'Prognostic specific activity concentration of Zirconium 95' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30079 ;
	}

#paramId: 503257
#Prognostic specific activity concentration of Xenon 133
'Prognostic specific activity concentration of Xenon 133' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30161 ;
	}

#paramId: 503258
#Prognostic specific activity concentration of Iodine 131 elementary gaseous
'Prognostic specific activity concentration of Iodine 131 elementary gaseous' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30138 ;
	}

#paramId: 503259
#Prognostic specific activity concentration of Iodine 131 organic bounded
'Prognostic specific activity concentration of Iodine 131 organic bounded' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30139 ;
	}

#paramId: 503260
#Prognostic specific activity concentration of Barium 140
'Prognostic specific activity concentration of Barium 140' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30175 ;
	}

#paramId: 503261
#Prognostic specific activity concentration of Ruthenium 103
'Prognostic specific activity concentration of Ruthenium 103' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30102 ;
	}

#paramId: 503262
#Diagnostic total mass concentration of volcanic ash
'Diagnostic total mass concentration of volcanic ash' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62025 ;
	}

#paramId: 503263
#Diagnostic maximum total mass concentration of volcanic ash in layer SFC-FL200
'Diagnostic maximum total mass concentration of volcanic ash in layer SFC-FL200' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 101325 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 46500 ;
	 constituentType = 62025 ;
	}

#paramId: 503265
#Diagnostic total column of mass concentration of volcanic ash
'Diagnostic total column of mass concentration of volcanic ash' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 10 ;
	 constituentType = 62025 ;
	}

#paramId: 503266
#Diagnostic height of model layer with maximal total mass concentration of volcanic ash
'Diagnostic height of model layer with maximal total mass concentration of volcanic ash' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 62 ;
	 constituentType = 62025 ;
	}

#paramId: 503267
#Diagnostic volcanic ash optical depth
'Diagnostic volcanic ash optical depth' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62025 ;
	}

#paramId: 503268
#Diagnostic mineral dust optical depth
'Diagnostic mineral dust optical depth' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62001 ;
	}

#paramId: 503269
#Diagnostic sea salt optical depth
'Diagnostic sea salt optical depth' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62008 ;
	}

#paramId: 503270
#Diagnostic vmaximum activity concentration of radionuclides in a layer
'Diagnostic vmaximum activity concentration of radionuclides in a layer' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 15 ;
	}

#paramId: 503273
#Diagnostic maximum total mass concentration of volcanic ash in layer FL200-FL350
'Diagnostic maximum total mass concentration of volcanic ash in layer FL200-FL350' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 46500 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 24000 ;
	 constituentType = 62025 ;
	}

#paramId: 503274
#Diagnostic maximum total mass concentration of volcanic ash in layer SFC-FL100
'Diagnostic maximum total mass concentration of volcanic ash in layer SFC-FL100' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 101325 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 70000 ;
	 constituentType = 62025 ;
	}

#paramId: 503275
#Diagnostic maximum total mass concentration of volcanic ash in layer FL350-FL550
'Diagnostic maximum total mass concentration of volcanic ash in layer FL350-FL550' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 24000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 9100 ;
	 constituentType = 62025 ;
	}

#paramId: 503276
#Diagnostic maximum total mass concentration of volcanic ash in layer FL100-FL245
'Diagnostic maximum total mass concentration of volcanic ash in layer FL100-FL245' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 70000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 38500 ;
	 constituentType = 62025 ;
	}

#paramId: 503277
#Diagnostic maximum total mass concentration of volcanic ash in layer FL245-FL390
'Diagnostic maximum total mass concentration of volcanic ash in layer FL245-FL390' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 38500 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 20000 ;
	 constituentType = 62025 ;
	}

#paramId: 503278
#Diagnostic maximum total mass concentration of volcanic ash in layer FL390-FL530
'Diagnostic maximum total mass concentration of volcanic ash in layer FL390-FL530' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 20000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 constituentType = 62025 ;
	}

#paramId: 503279
#Diagnostic maximum total mass concentration of volcanic ash in a layer
'Diagnostic maximum total mass concentration of volcanic ash in a layer' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 constituentType = 62025 ;
	}

#paramId: 503280
#Aerosol optical depth
'Aerosol optical depth' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	}

#paramId: 503293
#Large Scale Rain Difference
'Large Scale Rain Difference' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503294
#Large Scale Snowfall water Equivalent Difference
'Large Scale Snowfall water Equivalent Difference' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503295
#Convective Rain Difference
'Convective Rain Difference' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503296
#Convective Snowfall Water Equivalent Difference
'Convective Snowfall Water Equivalent Difference' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503303
#Total precipitation rate
'Total precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	}

#paramId: 503304
#Horizontal moisture convergence
'Horizontal moisture convergence' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 26 ;
	}

#paramId: 503305
#TOA downward solar radiation
'TOA downward solar radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503306
#Surface upward thermal radiation
'Surface upward thermal radiation' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503307
#Surface upward thermal radiation
'Surface upward thermal radiation' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503308
#Specific mass of liquid water coating on hail
'Specific mass of liquid water coating on hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 110 ;
	}

#paramId: 503309
#Specific mass of liquid water coating on graupel
'Specific mass of liquid water coating on graupel' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 113 ;
	}

#paramId: 503310
#Specific mass of liquid water coating on snow
'Specific mass of liquid water coating on snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 116 ;
	}

#paramId: 503311
#Specific number concentration of rain
'Specific number concentration of rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 100 ;
	}

#paramId: 503312
#Number density of rain
'Number density of rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 104 ;
	}

#paramId: 503313
#Specific number concentration of snow
'Specific number concentration of snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 101 ;
	}

#paramId: 503314
#Specific number concentration of graupel
'Specific number concentration of graupel' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 102 ;
	}

#paramId: 503315
#Specific number concentration of hail
'Specific number concentration of hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 103 ;
	}

#paramId: 503316
#Number density of snow
'Number density of snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 105 ;
	}

#paramId: 503317
#Number density of graupel
'Number density of graupel' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 106 ;
	}

#paramId: 503318
#Number density of hail
'Number density of hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 107 ;
	}

#paramId: 503319
#Mass density of rain
'Mass density of rain ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 96 ;
	}

#paramId: 503320
#Mass density of snow
'Mass density of snow ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 97 ;
	}

#paramId: 503321
#Mass density of graupel
'Mass density of graupel' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 98 ;
	}

#paramId: 503322
#Mass density of cloud droplets
'Mass density of cloud droplets' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 38 ;
	}

#paramId: 503323
#Mass density of cloud ice
'Mass density of cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 39 ;
	}

#paramId: 503324
#Mass density of hail
'Mass density of hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 99 ;
	}

#paramId: 503326
#Diagnostic total column of activity concentration of radionuclides
'Diagnostic total column of activity concentration of radionuclides' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503327
#Base for given threshold of mass density for volcanic ash cloud
'Base for given threshold of mass density for volcanic ash cloud' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 21 ;
	 constituentType = 62025 ;
	}

#paramId: 503328
#Base for given threshold of mass density for mineral dust cloud
'Base for given threshold of mass density for mineral dust cloud' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 21 ;
	 constituentType = 62001 ;
	}

#paramId: 503330
#Top for given threshold of mass density for volcanic ash cloud
'Top for given threshold of mass density for volcanic ash cloud' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 22 ;
	 constituentType = 62025 ;
	}

#paramId: 503331
#Top for given threshold of mass density for mineral dust cloud
'Top for given threshold of mass density for mineral dust cloud' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 22 ;
	 constituentType = 62001 ;
	}

#paramId: 503332
#Top for given threshold of air concentration of radionuclides
'Top for given threshold of air concentration of radionuclides' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 24 ;
	}

#paramId: 503333
#Emission rate of dust for mode 2
'Emission rate of dust for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503334
#Emission rate of dust for mode 3
'Emission rate of dust for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503335
#Emission rate of dust for mode 1
'Emission rate of dust for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503336
#Accumulated dust Emission for mode 2
'Accumulated dust Emission for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503337
#Accumulated dust Emission for mode 1
'Accumulated dust Emission for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503338
#Accumulated dust Emission for mode 3
'Accumulated dust Emission for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503340
#Base for given threshold of air concentration of radionuclides
'Base for given threshold of air concentration of radionuclides' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 23 ;
	}

#paramId: 503341
#Maximum amplitude (positive or negative) of updraft helicity  (over given time interval)
'Maximum amplitude (positive or negative) of updraft helicity  (over given time interval)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503344
#Maximum total-column integrated condensed water above -10 C isotherm (over given time interval)
'Maximum total-column integrated condensed water above -10 C isotherm (over given time interval)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	}

#paramId: 503345
#Maximum total-column integrated condensed  water (over given time interval)
'Maximum total-column integrated condensed  water (over given time interval)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503346
#Composite reflectivity - observation
'Composite reflectivity - observation' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 5 ;
	 typeOfGeneratingProcess = 8 ;
	}

#paramId: 503347
#Composite reflectivity - forecast (simulation)
'Composite reflectivity - forecast (simulation)' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 5 ;
	}

#paramId: 503349
#Maximum reflectivity track (over given time interval and entire atmosphere)
'Maximum reflectivity track (over given time interval and entire atmosphere)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503350
#relative vorticity
'relative vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 503352
#2m Temperature, restricted to land
'2m Temperature, restricted to land' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 181 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503353
#2m Dew Point Temperature, restricted to land
'2m Dew Point Temperature, restricted to land' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 181 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503354
#2m Relative Humidity, restricted to land
'2m Relative Humidity, restricted to land' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 181 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503357
#Maximum 10m wind speed without  gust
'Maximum 10m wind speed without  gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503360
#Birch (betula) pollen concentration
'Birch (betula) pollen concentration' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62101 ;
	}

#paramId: 503362
#Fraction of land occupied by birch (betula)
'Fraction of land occupied by birch (betula)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503368
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of birch (betula)
'Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of birch (betula) ' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62101 ;
	}

#paramId: 503375
#Alder (alnus) pollen concentration
'Alder (alnus) pollen concentration' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62100 ;
	}

#paramId: 503376
#Fraction of land occupied by alder (alnus)
'Fraction of land occupied by alder (alnus)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503382
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of alder (alnus)
'Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of alder (alnus) ' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62100 ;
	}

#paramId: 503390
#Grasses (poaceae) pollen concentration
'Grasses (poaceae) pollen concentration' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62300 ;
	}

#paramId: 503391
#Fraction of land occupied by grasses (poaceae)
'Fraction of land occupied by grasses (poaceae)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503397
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of grasses (poaceae)
'Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of grasses (poaceae) ' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62300 ;
	}

#paramId: 503405
#ragweed  (ambrosia) pollen concentration
'ragweed  (ambrosia) pollen concentration' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62200 ;
	}

#paramId: 503406
#Fraction of land occupied by ragweed  (ambrosia)
'Fraction of land occupied by ragweed  (ambrosia)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503412
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of ragweed  (ambrosia)
'Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of ragweed  (ambrosia) ' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62200 ;
	}

#paramId: 503421
#Echotop-pressure: smallest pressure where radar reflectivity above a threshold is present
'Echotop-pressure: smallest pressure where radar reflectivity above a threshold is present' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 25 ;
	}

#paramId: 503422
#Echotop-height: largest height where radar reflectivity above a threshold is present
'Echotop-height: largest height where radar reflectivity above a threshold is present' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 25 ;
	}

#paramId: 503423
#Maximum horizontal moisture convergence track (over given time interval and column)
'Maximum horizontal moisture convergence track (over given time interval and column)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503431
#Accumulated dry deposition (surface) of dust for mode 1
'Accumulated dry deposition (surface) of dust for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503432
#Accumulated dry deposition (surface) of dust for mode 2
'Accumulated dry deposition (surface) of dust for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503433
#Accumulated dry deposition (surface) of dust for mode 3
'Accumulated dry deposition (surface) of dust for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503434
#Accumulated wet deposition by grid scale precipitation of dust for mode 1
'Accumulated wet deposition by grid scale precipitation of dust for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503435
#Accumulated wet deposition by grid scale precipitation of dust for mode 2
'Accumulated wet deposition by grid scale precipitation of dust for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503436
#Accumulated wet deposition by grid scale precipitation of dust for mode 3
'Accumulated wet deposition by grid scale precipitation of dust for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503437
#Accumulated wet deposition by convective precipitation of dust for mode 1
'Accumulated wet deposition by convective precipitation of dust for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503438
#Accumulated wet deposition by convective precipitation of dust for mode 2
'Accumulated wet deposition by convective precipitation of dust for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503439
#Accumulated wet deposition by convective precipitation of dust for mode 3
'Accumulated wet deposition by convective precipitation of dust for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503443
#Accumulated sedimentation of dust for mode 1
'Accumulated sedimentation of dust for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503444
#Accumulated sedimentation of dust for mode 2
'Accumulated sedimentation of dust for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503445
#Accumulated sedimentation of dust for mode 3
'Accumulated sedimentation of dust for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503458
#Attenuated backscatter from satellite for dust (for given wave length)
'Attenuated backscatter from satellite for dust (for given wave length)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	 aerosolType = 62001 ;
	}

#paramId: 503459
#Attenuated backscatter from ground (ceilometer) for dust (for given wave length)
'Attenuated backscatter from ground (ceilometer) for dust (for given wave length)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	 aerosolType = 62001 ;
	}

#paramId: 503461
#Attenuated backscatter from satellite for volcanic ash (for given wave length)
'Attenuated backscatter from satellite for volcanic ash (for given wave length)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	 aerosolType = 62025 ;
	}

#paramId: 503462
#Attenuated backscatter from ground (ceilometer) for volcanic ash (for given wave length)
'Attenuated backscatter from ground (ceilometer) for volcanic ash (for given wave length)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	 aerosolType = 62025 ;
	}

#paramId: 503467
#2m Temperature analysis increment, filtered in time
'2m Temperature analysis increment, filtered in time' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 206 ;
	}

#paramId: 503468
#Cs137 - total (wet + dry) deposition
'Cs137 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30172 ;
	}

#paramId: 503469
#Prognostic specific activity concentration of Caesium 137
'Prognostic specific activity concentration of Caesium 137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30172 ;
	}

#paramId: 503470
#Averaged air concentration of Caesium 137
'Averaged air concentration of Caesium 137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30172 ;
	}

#paramId: 503471
#Accumulated air concentration of Caesium 137
'Accumulated air concentration of Caesium 137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30172 ;
	}

#paramId: 503480
#Prognostic specific activity concentration of Krypton 85
'Prognostic specific activity concentration of Krypton 85' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30059 ;
	}

#paramId: 503481
#Kr85 - total (wet + dry) deposition
'Kr85 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30059 ;
	}

#paramId: 503482
#Averaged air concentration of Krypton 85
'Averaged air concentration of Krypton 85' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30059 ;
	}

#paramId: 503483
#Accumulated air concentration of Krypton 85
'Accumulated air concentration of Krypton 85' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30059 ;
	}

#paramId: 503484
#Prognostic specific activity concentration of Strontium 90
'Prognostic specific activity concentration of Strontium 90' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30067 ;
	}

#paramId: 503485
#Averaged air concentration of Strontium 90
'Averaged air concentration of Strontium 90' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30067 ;
	}

#paramId: 503486
#Accumulated air concentration of Strontium 90
'Accumulated air concentration of Strontium 90' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30067 ;
	}

#paramId: 503487
#Sr90 - total (wet + dry) deposition
'Sr90 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30067 ;
	}

#paramId: 503489
#I131a - total (wet + dry) deposition
'I131a - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30141 ;
	}

#paramId: 503490
#Averaged air concentration of Iodine 131 aerosol
'Averaged air concentration of Iodine 131 aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30141 ;
	}

#paramId: 503491
#Accumulated air concentration of Iodine 131 aerosol
'Accumulated air concentration of Iodine 131 aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30141 ;
	}

#paramId: 503492
#Averaged air concentration of Cobalt 60
'Averaged air concentration of Cobalt 60' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30042 ;
	}

#paramId: 503493
#Accumulated air concentration of Cobalt 60
'Accumulated air concentration of Cobalt 60' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30042 ;
	}

#paramId: 503494
#Prognostic specific activity concentration of Cobalt 60
'Prognostic specific activity concentration of Cobalt 60' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30042 ;
	}

#paramId: 503495
#Co-60 - wet deposition
'Co-60 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30042 ;
	}

#paramId: 503496
#Co60 - total (wet + dry) deposition
'Co60 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30042 ;
	}

#paramId: 503497
#Ru103 - total (wet + dry) deposition
'Ru103 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30102 ;
	}

#paramId: 503499
#Averaged air concentration of Ruthenium 103
'Averaged air concentration of Ruthenium 103' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30102 ;
	}

#paramId: 503500
#Accumulated air concentration of Ruthenium 103
'Accumulated air concentration of Ruthenium 103' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30102 ;
	}

#paramId: 503501
#Prognostic specific activity concentration of Tellurium 132
'Prognostic specific activity concentration of Tellurium 132' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30129 ;
	}

#paramId: 503502
#Averaged air concentration of Tellurium 132
'Averaged air concentration of Tellurium 132' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30129 ;
	}

#paramId: 503503
#Accumulated air concentration of Tellurium 132
'Accumulated air concentration of Tellurium 132' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30129 ;
	}

#paramId: 503504
#Zr95 - total (wet + dry) deposition
'Zr95 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30079 ;
	}

#paramId: 503505
#Averaged air concentration of Zirconium 95
'Averaged air concentration of Zirconium 95' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30079 ;
	}

#paramId: 503506
#Accumulated air concentration of Zirconium 95
'Accumulated air concentration of Zirconium 95' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30079 ;
	}

#paramId: 503507
#TRACER - total (wet + dry) deposition
'TRACER - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30000 ;
	}

#paramId: 503508
#Prognostic specific activity concentration of TRACER
'Prognostic specific activity concentration of TRACER' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30000 ;
	}

#paramId: 503509
#Averaged air concentration of TRACER
'Averaged air concentration of TRACER' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30000 ;
	}

#paramId: 503510
#Accumulated air concentration of TRACER
'Accumulated air concentration of TRACER' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30000 ;
	}

#paramId: 503511
#Averaged air concentration of Xenon 133
'Averaged air concentration of Xenon 133' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30161 ;
	}

#paramId: 503512
#Accumulated air concentration of Xenon 133
'Accumulated air concentration of Xenon 133' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30161 ;
	}

#paramId: 503513
#Xe133 - total (wet + dry) deposition
'Xe133 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30161 ;
	}

#paramId: 503514
#Air concentration of Iodine 131
'Air concentration of Iodine 131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30137 ;
	}

#paramId: 503515
#I131 - dry deposition
'I131 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30137 ;
	}

#paramId: 503516
#Averaged air concentration of Iodine 131
'Averaged air concentration of Iodine 131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30137 ;
	}

#paramId: 503517
#Accumulated air concentration of Iodine 131
'Accumulated air concentration of Iodine 131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30137 ;
	}

#paramId: 503518
#Prognostic specific activity concentration of Iodine 131
'Prognostic specific activity concentration of Iodine 131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30137 ;
	}

#paramId: 503519
#I131 - wet deposition
'I131 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30137 ;
	}

#paramId: 503520
#I131 - total (wet + dry) deposition
'I131 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30137 ;
	}

#paramId: 503522
#Averaged air concentration of Iodine 131 elementary gaseous
'Averaged air concentration of Iodine 131 elementary gaseous' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30138 ;
	}

#paramId: 503523
#Accumulated air concentration of Iodine 131 elementary gaseous
'Accumulated air concentration of Iodine 131 elementary gaseous' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30138 ;
	}

#paramId: 503524
#I131g - total (wet + dry) deposition
'I131g - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30138 ;
	}

#paramId: 503525
#Averaged air concentration of Iodine 131 organic bounded
'Averaged air concentration of Iodine 131 organic bounded' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30139 ;
	}

#paramId: 503526
#Accumulated air concentration of Iodine 131 organic bounded
'Accumulated air concentration of Iodine 131 organic bounded' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30139 ;
	}

#paramId: 503527
#I131o - total (wet + dry) deposition
'I131o - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30139 ;
	}

#paramId: 503528
#Ba140 - total (wet + dry) deposition
'Ba140 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30175 ;
	}

#paramId: 503529
#Averaged air concentration of Barium 140
'Averaged air concentration of Barium 140' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30175 ;
	}

#paramId: 503530
#Accumulated air concentration of Barium 140
'Accumulated air concentration of Barium 140' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30175 ;
	}

#paramId: 503531
#Air concentration of Ruthenium 106
'Air concentration of Ruthenium 106' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30104 ;
	}

#paramId: 503532
#Ru106 - total (wet + dry) deposition
'Ru106 - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30104 ;
	}

#paramId: 503533
#Prognostic specific activity concentration of Ruthenium 106
'Prognostic specific activity concentration of Ruthenium 106' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30104 ;
	}

#paramId: 503534
#Ru106 - dry deposition
'Ru106 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30104 ;
	}

#paramId: 503535
#Ru106 - wet deposition
'Ru106 - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30104 ;
	}

#paramId: 503536
#Averaged air concentration of Ruthenium 106
'Averaged air concentration of Ruthenium 106' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30104 ;
	}

#paramId: 503537
#Accumulated air concentration of Ruthenium 106
'Accumulated air concentration of Ruthenium 106' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30104 ;
	}

#paramId: 503538
#Co-60 - dry deposition
'Co-60 - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30042 ;
	}

#paramId: 503539
#Air concentration of Cobalt 60
'Air concentration of Cobalt 60' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30042 ;
	}

#paramId: 503542
#Kr85m - wet deposition
'Kr85m - wet deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30060 ;
	}

#paramId: 503543
#Kr85m - total (wet + dry) deposition
'Kr85m - total (wet + dry) deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30060 ;
	}

#paramId: 503544
#Prognostic specific activity concentration of Krypton 85m
'Prognostic specific activity concentration of Krypton 85m' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30060 ;
	}

#paramId: 503545
#Kr85m - dry deposition
'Kr85m - dry deposition' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30060 ;
	}

#paramId: 503546
#Averaged air concentration of Krypton 85m
'Averaged air concentration of Krypton 85m' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30060 ;
	}

#paramId: 503547
#Accumulated air concentration of Krypton 85m
'Accumulated air concentration of Krypton 85m' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30060 ;
	}

#paramId: 503548
#Air concentration of Krypton 85m
'Air concentration of Krypton 85m' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30060 ;
	}

#paramId: 503551
#Birch (betula) pollen specific number concentration
'Birch (betula) pollen specific number concentration' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62101 ;
	}

#paramId: 503552
#Alder (alnus) pollen specific number concentration
'Alder (alnus) pollen specific number concentration' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62100 ;
	}

#paramId: 503553
#Grasses (poaceae) pollen specific number concentration
'Grasses (poaceae) pollen specific number concentration' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62300 ;
	}

#paramId: 503554
#Ragweed (ambrosia) pollen specific number concentration
'Ragweed (ambrosia) pollen specific number concentration' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62200 ;
	}

#paramId: 503560
#Total lightning flash density - instantaneous
'Total lightning flash density - instantaneous' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503561
#Total lightning flash density - time average
'Total lightning flash density - time average' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503563
#Temperature tendency perturbation due to stochastic model of model error
'Temperature tendency perturbation due to stochastic model of model error' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfGeneratingProcess = 221 ;
	}

#paramId: 503564
#Zonal wind tendency perturbation due to stochastic model of model error
'Zonal wind tendency perturbation due to stochastic model of model error' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfGeneratingProcess = 221 ;
	}

#paramId: 503565
#Meridional wind tendency perturbation due to stochastic model of model error
'Meridional wind tendency perturbation due to stochastic model of model error' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfGeneratingProcess = 221 ;
	}

#paramId: 503566
#Effective radius of cloud water
'Effective radius of cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 129 ;
	}

#paramId: 503567
#Effective radius of rain
'Effective radius of rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 130 ;
	}

#paramId: 503568
#Effective radius of cloud ice
'Effective radius of cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 131 ;
	}

#paramId: 503569
#Effective radius of snow
'Effective radius of snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 132 ;
	}

#paramId: 503570
#Effective radius of graupel
'Effective radius of graupel' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 133 ;
	}

#paramId: 503571
#Effective radius of hail
'Effective radius of hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 134 ;
	}

#paramId: 503572
#Effective radius of subgrid liquid clouds
'Effective radius of subgrid liquid clouds' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 135 ;
	}

#paramId: 503573
#Effective radius of subgrid ice clouds
'Effective radius of subgrid ice clouds' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 136 ;
	}

#paramId: 503574
#Effective aspect ratio of rain
'Effective aspect ratio of rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 137 ;
	}

#paramId: 503575
#Effective aspect ratio of cloud ice
'Effective aspect ratio of cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 138 ;
	}

#paramId: 503576
#Effective aspect ratio of snow
'Effective aspect ratio of snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 139 ;
	}

#paramId: 503577
#Effective aspect ratio of graupel
'Effective aspect ratio of graupel' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 140 ;
	}

#paramId: 503578
#Effective aspect ratio of hail
'Effective aspect ratio of hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 141 ;
	}

#paramId: 503579
#Effective aspect ratio of subgrid ice clouds
'Effective aspect ratio of subgrid ice clouds' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 142 ;
	}

#paramId: 503580
#Relative Humidity in lowest model layer - time-filtered assimilation increment
'Relative Humidity in lowest model layer - time-filtered assimilation increment' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503581
#Temperature in lowest model layer - time-filtered assimilation increment
'Temperature in lowest model layer - time-filtered assimilation increment' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503583
#Wind speed (time average)
'Wind speed (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503584
#10m wind speed (time average)
'10m wind speed (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503587
#Total cloud cover (time average)
'Total cloud cover (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503593
#Clear-sky net solar radiation flux (at the surface)
'Clear-sky net solar radiation flux (at the surface)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503594
#Clear-sky net thermal radiation flux (at the surface)
'Clear-sky net thermal radiation flux (at the surface)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503595
#Clear-sky net solar radiation flux (on model top)
'Clear-sky net solar radiation flux (on model top)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503596
#Clear-sky net thermal radiation flux (on model top)
'Clear-sky net thermal radiation flux (on model top)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503597
#Clear-sky net solar radiation flux (at the surface) - time average
'Clear-sky net solar radiation flux (at the surface) - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503598
#Clear-sky net thermal radiation flux (at the surface) - time average
'Clear-sky net thermal radiation flux (at the surface) - time average' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503599
#Clear-sky net solar radiation flux (on model top) - time average
'Clear-sky net solar radiation flux (on model top) - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503600
#Clear-sky net thermal radiation flux (on model top) - time average
'Clear-sky net thermal radiation flux (on model top) - time average' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503601
#TOA downward solar radiation (time average)
'TOA downward solar radiation (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503602
#Volumetric saturation of soil moisture
'Volumetric saturation of soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503616
#Pressure in lowest model layer - time-filtered assimilation increment
'Pressure in lowest model layer - time-filtered assimilation increment' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503617
#Maximum amplitude of updraft helicity in tropospheric column of low height
'Maximum amplitude of updraft helicity in tropospheric column of low height' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 102 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 3000 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 503618
#Maximum amplitude of updraft helicity in tropospheric column of medium height
'Maximum amplitude of updraft helicity in tropospheric column of medium height' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 102 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 5000 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2000 ;
	}

#paramId: 503621
#Large-scale precipitation rate
'Large-scale precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	}

#paramId: 503624
#Total lightning flash density - maximum
'Total lightning flash density - maximum' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503628
#Smoke - high absorption (mass mixing ratio)
'Smoke - high absorption (mass mixing ratio)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62020 ;
	}

#paramId: 503629
#Smoke - high absorption (mass density)
'Smoke - high absorption (mass density)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62020 ;
	}

#paramId: 503630
#Smoke - high absorption (specific number concentration)
'Smoke - high absorption (specific number concentration)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62020 ;
	}

#paramId: 503631
#Smoke - low absorption (mass mixing ratio)
'Smoke - low absorption (mass mixing ratio)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62021 ;
	}

#paramId: 503632
#Smoke - low absorption (mass density)
'Smoke - low absorption (mass density)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62021 ;
	}

#paramId: 503633
#Smoke - low absorption (specific number concentration)
'Smoke - low absorption (specific number concentration)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62021 ;
	}

#paramId: 503634
#Sulphur dioxide (SO2) - volume mixing ratio
'Sulphur dioxide (SO2) - volume mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 52 ;
	 constituentType = 8 ;
	}

#paramId: 503635
#Sulphur dioxide (SO2) - mass density
'Sulphur dioxide (SO2) - mass density' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 8 ;
	}

#paramId: 503636
#Hazel (corylus) pollen concentration
'Hazel (corylus) pollen concentration' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62104 ;
	}

#paramId: 503637
#Fraction of land occupied by hazel (corylus)
'Fraction of land occupied by hazel (corylus)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503643
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of hazel (corylus)
'Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of hazel (corylus)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62104 ;
	}

#paramId: 503651
#Hazel (corylus) pollen specific number concentration
'Hazel (corylus) pollen specific number concentration' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62104 ;
	}

#paramId: 503657
#Temperature in lowest model layer - time-filtered assimilation increment, weighted with cos(2pi loc.time/day)
'Temperature in lowest model layer - time-filtered assimilation increment, weighted with cos(2pi loc.time/day)' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 208 ;
	}

#paramId: 503662
#Thickness of snow layer - multi level
'Thickness of snow layer - multi level' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503664
#Snow temperature of layer (defined at layer top) - multi level
'Snow temperature of layer (defined at layer top) - multi level' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503672
#Lightning Potential Index from convection scheme
'Lightning Potential Index from convection scheme' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 5 ;
	}

#paramId: 503673
#Maximum Lightning Potential Index from convection scheme
'Maximum Lightning Potential Index from convection scheme' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503674
#Wind speed in lowest model layer - time-filtered assimilation increment
'Wind speed in lowest model layer - time-filtered assimilation increment' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503675
#Eddy Dissipation Parameter
'Eddy Dissipation Parameter' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 30 ;
	}

#paramId: 503676
#Icing Severity (0=None, 1=Trace, 2=Light, 3=Moderate, 4=Severe)
'Icing Severity (0=None, 1=Trace, 2=Light, 3=Moderate, 4=Severe)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 37 ;
	}

#paramId: 503677
#U-component surface Stokes drift
'U-component surface Stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}

#paramId: 503678
#V-component surface Stokes drift
'V-component surface Stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}

#paramId: 503679
#Peak wave direction
'Peak wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	}

#paramId: 503680
#Significant wave height of first swell partition
'Significant wave height of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	}

#paramId: 503681
#Significant wave height of second swell partition
'Significant wave height of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	}

#paramId: 503682
#Significant wave height of third swell partition
'Significant wave height of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	}

#paramId: 503683
#Mean wave period of first swell partition
'Mean wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	}

#paramId: 503684
#Mean wave period of second swell partition
'Mean wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	}

#paramId: 503685
#Mean wave period of third swell partition
'Mean wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	}

#paramId: 503686
#Mean wave direction of first swell partition
'Mean wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	}

#paramId: 503687
#Mean wave direction of second swell partition
'Mean wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	}

#paramId: 503688
#Mean wave direction of third swell partition
'Mean wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	}

#paramId: 503689
#Diagnostic total mass concentration of mineral dust aerosol
'Diagnostic total mass concentration of mineral dust aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62001 ;
	}

#paramId: 503690
#Diagnostic total mass concentration of sea salt aerosol
'Diagnostic total mass concentration of sea salt aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62008 ;
	}

#paramId: 503691
#Diagnostic total mass concentration of black carbon aerosol (soot)
'Diagnostic total mass concentration of black carbon aerosol (soot)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62009 ;
	}

#paramId: 503692
#Diagnostic black carbon aerosol (soot) optical depth
'Diagnostic black carbon aerosol (soot) optical depth' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62009 ;
	}

#paramId: 503693
#Total atmosphere optical depth due to mineral dust aerosol
'Total atmosphere optical depth due to mineral dust aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62001 ;
	}

#paramId: 503694
#Total atmosphere optical depth due to sea salt aerosol
'Total atmosphere optical depth due to sea salt aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62008 ;
	}

#paramId: 503695
#Total atmosphere optical depth due to volcanic ash aerosol
'Total atmosphere optical depth due to volcanic ash aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62025 ;
	}

#paramId: 503696
#Total atmosphere optical depth due to black carbon aerosol (soot)
'Total atmosphere optical depth due to black carbon aerosol (soot)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62009 ;
	}

#paramId: 503697
#Modal prognostic mass mixing ratio of mineral dust aerosol (all modes)
'Modal prognostic mass mixing ratio of mineral dust aerosol (all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503698
#Modal prognostic mass mixing ratio of sea salt aerosol (all modes)
'Modal prognostic mass mixing ratio of sea salt aerosol (all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503699
#Modal prognostic mass mixing ratio of black carbon aerosol (soot) (all modes)
'Modal prognostic mass mixing ratio of black carbon aerosol (soot) (all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62009 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503700
#Modal prognostic specific number concentration of black carbon aerosol (soot) (all modes)
'Modal prognostic specific number concentration of black carbon aerosol (soot) (all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62009 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503701
#Modal prognostic mass mixing ratio of volcanic ash aerosol (all modes)
'Modal prognostic mass mixing ratio of volcanic ash aerosol (all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503702
#Modal prognostic specific number concentration of total aerosol (all modes)
'Modal prognostic specific number concentration of total aerosol (all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62000 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503703
#Base reflectivity - low layer maximum
'Base reflectivity - low layer maximum' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 103 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 500 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2500 ;
	}

#paramId: 503706
#Sea water density
'Sea water density' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 16 ;
	}

#paramId: 503707
#Sea water potential temperature
'Sea water potential temperature' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	}

#paramId: 503708
#Sea water potential density
'Sea water potential density' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 19 ;
	}

#paramId: 503709
#Sea water practical salinity
'Sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	}

#paramId: 503722
#Diagnostic total column of mass concentration of mineral dust aerosol
'Diagnostic total column of mass concentration of mineral dust aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 10 ;
	 constituentType = 62001 ;
	}

#paramId: 503723
#Diagnostic vertical maximum total mass concentration of mineral dust aerosol in a layer
'Diagnostic vertical maximum total mass concentration of mineral dust aerosol in a layer' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 constituentType = 62001 ;
	}

#paramId: 503724
#Diagnostic temporal maximum activity concentration of Caesium 137 in a time range
'Diagnostic temporal maximum activity concentration of Caesium 137 in a time range' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30172 ;
	}

#paramId: 503725
#Diagnostic temporal maximum activity concentration of Iodine 131 in a time range
'Diagnostic temporal maximum activity concentration of Iodine 131 in a time range' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30137 ;
	}

#paramId: 503726
#Diagnostic temporal maximum activity concentration of Caesium 137 in a time range and vertical maximum in a layer
'Diagnostic temporal maximum activity concentration of Caesium 137 in a time range and vertical maximum in a layer' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30172 ;
	}

#paramId: 503727
#Diagnostic temporal maximum activity concentration of Iodine 131 in a time range and vertical maximum in a layer
'Diagnostic temporal maximum activity concentration of Iodine 131 in a time range and vertical maximum in a layer' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30137 ;
	}

#paramId: 503728
#Total accumulated dry deposition (surface) of dust (sum of all modes)
'Total accumulated dry deposition (surface) of dust (sum of all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503729
#Total accumulated dust emission (sum of all modes)
'Total accumulated dust emission (sum of all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503730
#Total accumulated sedimentation of dust (sum of all modes)
'Total accumulated sedimentation of dust (sum of all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503731
#Total accumulated wet deposition of dust (sum of all modes)
'Total accumulated wet deposition of dust (sum of all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503737
#Maximum total precipitation rate
'Maximum total precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503738
#Top of persistent contrails
'Top of persistent contrails' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 48 ;
	}

#paramId: 503739
#Base of persistent contrails
'Base of persistent contrails' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 49 ;
	}

#paramId: 503743
#U-component of 10m wind - time average
'U-component of 10m wind - time average' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503744
#V-component of 10m wind - time average
'V-component of 10m wind - time average' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503759
#Zonal component of sea water velocity (west-east direction counted positive)
'Zonal component of sea water velocity (west-east direction counted positive)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	}

#paramId: 503760
#Meridional component of sea water velocity (south-north direction counted positive)
'Meridional component of sea water velocity (south-north direction counted positive)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	}

#paramId: 503763
#Mixed layer depth in ocean
'Mixed layer depth in ocean' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	}

#paramId: 503764
#Normal component of sea water velocity (normal in relation to local grid cell edge)
'Normal component of sea water velocity (normal in relation to local grid cell edge)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 53 ;
	}

#paramId: 503781
#Model level - height above mean sea level
'Model level - height above mean sea level' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 33 ;
	 typeOfFirstFixedSurface = 150 ;
	}

#paramId: 503782
#Model level - height above ground level
'Model level - height above ground level' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 150 ;
	}

#paramId: 503784
#Mean mass diameter of hail (mean mass with respect to particle size distribution)
'Mean mass diameter of hail (mean mass with respect to particle size distribution)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 170 ;
	}

#paramId: 503785
#Time maximum of mean mass diameter of hail at surface
'Time maximum of mean mass diameter of hail at surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 170 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503786
#Estimated maximum diameter of hail at surface (maximum estimated with respect to particle size distribution)
'Estimated maximum diameter of hail at surface (maximum estimated with respect to particle size distribution)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 171 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503787
#Time maximum of estimated maximum diameter of hail at surface
'Time maximum of estimated maximum diameter of hail at surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 171 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503788
#Hail kinetic energy flux at surface
'Hail kinetic energy flux at surface' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503789
#Time maximum of hail kinetic energy flux at surface
'Time maximum of hail kinetic energy flux at surface' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503790
#Hail kinetic energy at surface (flux accumulated over time)
'Hail kinetic energy at surface (flux accumulated over time)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503791
#Wave energy spectral density of ocean surface gravity waves
'Wave energy spectral density of ocean surface gravity waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	}

#paramId: 500092
#Solar radiation heating rate
'Solar radiation heating rate' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}

#paramId: 500093
#Thermal radiation heating rate
'Thermal radiation heating rate' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 192 ;
	}

#paramId: 500094
#Latent heat flux from bare soil
'Latent heat flux from bare soil' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500095
#Latent heat flux from plants
'Latent heat flux from plants' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500097
#Stomatal resistance
'Stomatal resistance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}

#paramId: 500109
#Vertical integral of divergence of total water content - accumulation
'Vertical integral of divergence of total water content - accumulation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500110
#Sub-grid scale cloud water
'Sub-grid scale cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}

#paramId: 500111
#Sub-grid scale cloud ice
'Sub-grid scale cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}

#paramId: 500115
#Cloud base above MSL, shallow convection
'Cloud base above MSL, shallow convection' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500116
#Cloud top above MSL, shallow convection
'Cloud top above MSL, shallow convection' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 193 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 500117
#Specific cloud liquid water content, convective cloud
'Specific cloud liquid water content, convective cloud' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}

#paramId: 500120
#Base index (vertical level) of main convective cloud
'Base index (vertical level) of main convective cloud' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500121
#Top index (vertical level) of main convective cloud
'Top index (vertical level) of main convective cloud' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500122
#Temperature tendency due to convection
'Temperature tendency due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500123
#Specific humidity tendency due to convection
'Specific humidity tendency due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 197 ;
	}

#paramId: 500124
#Zonal wind tendency due to convection
'Zonal wind tendency due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	}

#paramId: 500125
#Meridional wind tendency due to convection
'Meridional wind tendency due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	}

#paramId: 500126
#Height of top of dry convection above MSL
'Height of top of dry convection above MSL' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 196 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 500128
#Height of snow fall limit above MSL
'Height of snow fall limit above MSL' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 204 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 4 ;
	}

#paramId: 500129
#Tendency of specific cloud liquid water content due to convection
'Tendency of specific cloud liquid water content due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	}

#paramId: 500130
#Tendency of specific cloud ice content due to convection
'Tendency of specific cloud ice content due to convection' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	}

#paramId: 500131
#Specific content of precipitation particles (needed for water loading)
'Specific content of precipitation particles (needed for water loading)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	}

#paramId: 500140
#Temperature tendency due to grid scale precipitation
'Temperature tendency due to grid scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}

#paramId: 500141
#Specific humidity tendency due to grid scale precipitation
'Specific humidity tendency due to grid scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 200 ;
	}

#paramId: 500142
#Tendency of specific cloud liquid water content due to grid scale precipitation
'Tendency of specific cloud liquid water content due to grid scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 201 ;
	}

#paramId: 500143
#Fresh snow factor (weighting function for albedo indicating freshness of snow)
'Fresh snow factor (weighting function for albedo indicating freshness of snow)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 203 ;
	}

#paramId: 500144
#Tendency of specific cloud ice content due to grid scale precipitation
'Tendency of specific cloud ice content due to grid scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 202 ;
	}

#paramId: 500148
#Pressure perturbation
'Pressure perturbation' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}

#paramId: 500149
#Supercell detection index 1 (rot. up- and downdrafts)
'Supercell detection index 1 (rot. up- and downdrafts)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 192 ;
	}

#paramId: 500150
#Supercell detection index 2 (only rot. updrafts)
'Supercell detection index 2 (only rot. updrafts)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 193 ;
	}

#paramId: 500151
#Convective Available Potential Energy, most unstable
'Convective Available Potential Energy, most unstable' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 193 ;
	}

#paramId: 500152
#Convective Inhibition, most unstable
'Convective Inhibition, most unstable' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 193 ;
	}

#paramId: 500153
#Convective Available Potential Energy, mean layer
'Convective Available Potential Energy, mean layer' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 192 ;
	}

#paramId: 500154
#Convective Inhibition, mean layer
'Convective Inhibition, mean layer' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 192 ;
	}

#paramId: 500156
#Tendency of turbulent kinetic energy
'Tendency of turbulent kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	}

#paramId: 500157
#Kinetic energy
'Kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	}

#paramId: 500176
#Solution of 2-d Helmholtz equations - needed for restart
'Solution of 2-d Helmholtz equations - needed for restart' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 192 ;
	}

#paramId: 500177
#Effective transmissivity of solar radiation
'Effective transmissivity of solar radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	}

#paramId: 500178
#Sum of contributions to evaporation
'Sum of contributions to evaporation' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}

#paramId: 500179
#Total transpiration from all soil layers
'Total transpiration from all soil layers' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}

#paramId: 500180
#Total forcing at soil surface
'Total forcing at soil surface' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}

#paramId: 500181
#Residuum of soil moisture
'Residuum of soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}

#paramId: 500182
#Mass flux at convective cloud base
'Mass flux at convective cloud base' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 205 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500184
#Moisture convergence for Kuo-type closure
'Moisture convergence for Kuo-type closure' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 206 ;
	}

#paramId: 500195
#Analysis error (standard deviation), geopotential (gpm)
'Analysis error (standard deviation), geopotential (gpm)' = {
	 discipline = 0 ;
	 parameterCategory = 194 ;
	 parameterNumber = 5 ;
	 typeOfGeneratingProcess = 7 ;
	}

#paramId: 500196
#Analysis error (standard deviation), u-comp. of wind
'Analysis error (standard deviation), u-comp. of wind' = {
	 discipline = 0 ;
	 parameterCategory = 194 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 7 ;
	}

#paramId: 500197
#Analysis error (standard deviation), v-comp. of wind
'Analysis error (standard deviation), v-comp. of wind' = {
	 discipline = 0 ;
	 parameterCategory = 194 ;
	 parameterNumber = 3 ;
	 typeOfGeneratingProcess = 7 ;
	}

#paramId: 500198
#Zonal wind tendency due to sub-grid scale oro.
'Zonal wind tendency due to sub-grid scale oro.' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 194 ;
	}

#paramId: 500199
#Meridional wind tendency due to sub-grid scale oro.
'Meridional wind tendency due to sub-grid scale oro.' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 195 ;
	}

#paramId: 500204
#Surface emissivity
'Surface emissivity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}

#paramId: 500205
#Soil type (1...9, local soilType.table)
'Soil type (1...9, local soilType.table)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}

#paramId: 500208
#Height of ozone maximum (climatological)
'Height of ozone maximum (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	}

#paramId: 500209
#Vertically integrated ozone content (climatological)
'Vertically integrated ozone content (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 193 ;
	}

#paramId: 500221
#Ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'Ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500222
#Ratio of NDVI (normalized differential vegetation index) to annual maximum
'Ratio of NDVI (normalized differential vegetation index) to annual maximum' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500233
#Tendency of specific humidity
'Tendency of specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 207 ;
	}

#paramId: 500234
#Water vapor flux
'Water vapor flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 208 ;
	}

#paramId: 500235
#Coriolis parameter
'Coriolis parameter' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	}

#paramId: 500239
#Delay of the GPS signal through the (total) atmos.
'Delay of the GPS signal through the (total) atmos.' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 192 ;
	}

#paramId: 500240
#Delay of the GPS signal through wet atmos.
'Delay of the GPS signal through wet atmos.' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 193 ;
	}

#paramId: 500241
#Delay of the GPS signal through dry atmos.
'Delay of the GPS signal through dry atmos.' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 194 ;
	}

#paramId: 500279
#U-momentum flux due to SSO-effects (mean over forecast time)
'U-momentum flux due to SSO-effects (mean over forecast time)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500280
#U-momentum flux due to SSO-effects
'U-momentum flux due to SSO-effects' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}

#paramId: 500281
#V-momentum flux due to SSO-effects (mean over forecast time)
'V-momentum flux due to SSO-effects (mean over forecast time)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500282
#V-momentum flux due to SSO-effects
'V-momentum flux due to SSO-effects' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}

#paramId: 500288
#Absolute vorticity advection
'Absolute vorticity advection' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 197 ;
	}

#paramId: 500289
#Kombination Niederschlag-Bewoelkung-Blauthermik (cl_typ.tab)
'Kombination Niederschlag-Bewoelkung-Blauthermik (cl_typ.tab)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 194 ;
	}

#paramId: 500291
#Hoehe der Konvektionsuntergrenze ueber nn
'Hoehe der Konvektionsuntergrenze ueber nn' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 24 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500293
#geostrophische Vorticityadvektion
'geostrophische Vorticityadvektion' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 0 ;
	}

#paramId: 500294
#Geostrophic thickness advection
'Geostrophic thickness advection' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 1 ;
	}

#paramId: 500295
#Schichtdickenadvektion
'Schichtdickenadvektion' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 2 ;
	}

#paramId: 500296
#Winddivergenz
'Winddivergenz' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 3 ;
	}

#paramId: 500297
#Q-Vektor senkrecht zu den Isothermen
'Q-Vektor senkrecht zu den Isothermen' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 4 ;
	}

#paramId: 500298
#Isentrope potentielle Vorticity
'Isentrope potentielle Vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 107 ;
	}

#paramId: 500299
#Wind X-Komponente auf isentropen Flaechen
'Wind X-Komponente auf isentropen Flaechen' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 5 ;
	}

#paramId: 500300
#Wind Y-Komponente auf isentropen Flaechen
'Wind Y-Komponente auf isentropen Flaechen' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 6 ;
	}

#paramId: 500306
#Modified cloud depth for media
'Modified cloud depth for media' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 198 ;
	}

#paramId: 500307
#Modified cloud cover for media
'Modified cloud cover for media' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 199 ;
	}

#paramId: 500322
#RMS of difference "first guess - analysis" of kinetic energy
'RMS of difference "first guess - analysis" of kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500323
#RMS of difference "initialized analysis - analysis" of kinetic energy
'RMS of difference "initialized analysis - analysis" of kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500437
#Probability of 1h total precipitation >= 10mm
'Probability of 1h total precipitation >= 10mm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500438
#Probability of 1h total precipitation >= 25mm
'Probability of 1h total precipitation >= 25mm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500439
#Probability of 6h total precipitation >= 20mm
'Probability of 6h total precipitation >= 20mm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500440
#Probability of 6h total precipitation >= 35mm
'Probability of 6h total precipitation >= 35mm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500441
#Probability of 12h total precipitation >= 25mm
'Probability of 12h total precipitation >= 25mm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500442
#Probability of 12h total precipitation >= 40mm
'Probability of 12h total precipitation >= 40mm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500443
#Probability of 12h total precipitation >= 70mm
'Probability of 12h total precipitation >= 70mm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500444
#Probability of 6h accumulated snow >=0.5cm
'Probability of 6h accumulated snow >=0.5cm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500445
#Probability of 6h accumulated snow >= 5cm
'Probability of 6h accumulated snow >= 5cm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500446
#Probability of 6h accumulated snow >= 10cm
'Probability of 6h accumulated snow >= 10cm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500447
#Probability of 12h accumulated snow >=0.5cm
'Probability of 12h accumulated snow >=0.5cm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500448
#Probability of 12h accumulated snow >= 10cm
'Probability of 12h accumulated snow >= 10cm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500449
#Probability of 12h accumulated snow >= 15cm
'Probability of 12h accumulated snow >= 15cm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500450
#Probability of 12h accumulated snow >= 25cm
'Probability of 12h accumulated snow >= 25cm' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500451
#Probability of 1h maximum wind gust speed >= 14m/s
'Probability of 1h maximum wind gust speed >= 14m/s' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 132 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500452
#Probability of 1h maximum wind gust speed >= 18m/s
'Probability of 1h maximum wind gust speed >= 18m/s' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 134 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500453
#Probability of 1h maximum wind gust speed >= 25m/s
'Probability of 1h maximum wind gust speed >= 25m/s' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 136 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500454
#Probability of 1h maximum wind gust speed >= 29m/s
'Probability of 1h maximum wind gust speed >= 29m/s' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 137 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500455
#Probability of 1h maximum wind gust speed >= 33m/s
'Probability of 1h maximum wind gust speed >= 33m/s' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 138 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500456
#Probability of 1h maximum wind gust speed >= 39m/s
'Probability of 1h maximum wind gust speed >= 39m/s' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 139 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500457
#Probability of black ice during 1h
'Probability of black ice during 1h' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 191 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500458
#Probability of thunderstorm during 1h
'Probability of thunderstorm during 1h' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 197 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500459
#Probability of heavy thunderstorm during 1h
'Probability of heavy thunderstorm during 1h' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500460
#Probability of severe thunderstorm during 1h
'Probability of severe thunderstorm during 1h' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 199 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500461
#Probability of snowdrift during 12h
'Probability of snowdrift during 12h' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 212 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500462
#Probability of strong snowdrift during 12h
'Probability of strong snowdrift during 12h' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 213 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500463
#Probability of temperature < 0 deg C during 1h
'Probability of temperature < 0 deg C during 1h' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 232 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500464
#Probability of temperature <= -10 deg C during 6h
'Probability of temperature <= -10 deg C during 6h' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 236 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500465
#UV Index, clear sky; corrected for albedo, aerosol and altitude
'UV Index, clear sky; corrected for albedo, aerosol and altitude' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	}

#paramId: 500466
#Basic UV Index, clear sky; MSL, fixed albedo, fixed aerosol
'Basic UV Index, clear sky; MSL, fixed albedo, fixed aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	}

#paramId: 500467
#UV Index, clouded sky; corrected for albedo, aerosol, altitude and clouds
'UV Index, clouded sky; corrected for albedo, aerosol, altitude and clouds' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 197 ;
	}

#paramId: 500471
#Time of maximum of UV Index, clouded
'Time of maximum of UV Index, clouded' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500472
#Type of convection (0..4)
'Type of convection (0..4)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 201 ;
	}

#paramId: 500473
#perceived temperature
'perceived temperature' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 1 ;
	}

#paramId: 500478
#probability to perceive sultriness
'probability to perceive sultriness' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 3 ;
	}

#paramId: 500479
#value of isolation of clothes
'value of isolation of clothes' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 2 ;
	}

#paramId: 500480
#Downward direct short wave radiation flux at surface (mean over forecast time)
'Downward direct short wave radiation flux at surface (mean over forecast time)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500481
#Downward diffusive short wave radiation flux at surface (mean over forecast time)
'Downward diffusive short wave radiation flux at surface (mean over forecast time)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 199 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500503
#Icing Base (hft) - Icing Degree Composit
'Icing Base (hft) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500504
#Icing Max Base (hft) - Icing Degree Composit
'Icing Max Base (hft) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500505
#Icing Max Top (hft) - Icing Degree Composit
'Icing Max Top (hft) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500506
#Icing Top (hft) - Icing Degree Composit
'Icing Top (hft) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500507
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Degree Composit
'Icing Vertical Code (1=continuous,2=discontinuous) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 199 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500508
#Icing Max Code (1=light,2=moderate,3=severe) - Icing Degree Composit
'Icing Max Code (1=light,2=moderate,3=severe) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 200 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500509
#Icing Base (hft) - Icing Scenario Composit
'Icing Base (hft) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 201 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500510
#Icing Signifikant Base (hft) - Icing Scenario Composit
'Icing Signifikant Base (hft) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 202 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500511
#Icing Signifikant Top (hft) - Icing Scenario Composit
'Icing Signifikant Top (hft) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 203 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500512
#Icing Top (hft) - Icing Scenario Composit
'Icing Top (hft) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 204 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500513
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Scenario Composit
'Icing Vertical Code (1=continuous,2=discontinuous) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 205 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500514
#Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Icing Scenario Composit
'Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 206 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500515
#Icing Base (hft) - Icing Degree Composit
'Icing Base (hft) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500516
#Icing Max Base (hft) - Icing Degree Composit
'Icing Max Base (hft) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500517
#Icing Max Top (hft) - Icing Degree Composit
'Icing Max Top (hft) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500518
#Icing Top (hft) - Icing Degree Composit
'Icing Top (hft) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500519
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Degree Composit
'Icing Vertical Code (1=continuous,2=discontinuous) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 199 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500520
#Icing Max Code (1=light,2=moderate,3=severe) - Icing Degree Composit
'Icing Max Code (1=light,2=moderate,3=severe) - Icing Degree Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 200 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500521
#Icing Base (hft) - Icing Scenario Composit
'Icing Base (hft) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 201 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500522
#Icing Signifikant Base (hft) - Icing Scenario Composit
'Icing Signifikant Base (hft) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 202 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500523
#Icing Signifikant Top (hft) - Icing Scenario Composit
'Icing Signifikant Top (hft) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 203 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500524
#Icing Top (hft) - Icing Scenario Composit
'Icing Top (hft) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 204 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500525
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Scenario Composit
'Icing Vertical Code (1=continuous,2=discontinuous) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 205 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500526
#Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Icing Scenario Composit
'Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Icing Scenario Composit' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 206 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500527
#Icing Degree Code (1=light,2=moderate,3=severe)
'Icing Degree Code (1=light,2=moderate,3=severe)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 207 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500528
#Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)
'Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 208 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500529
#Icing Degree Code (1=light,2=moderate,3=severe)
'Icing Degree Code (1=light,2=moderate,3=severe)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 207 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500530
#Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)
'Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 208 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500531
#current weather (symbol number: 0..9)
'current weather (symbol number: 0..9)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 209 ;
	}

#paramId: 500538
#cloud type
'cloud type' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500540
#cloud top temperature
'cloud top temperature' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}

#paramId: 500541
#Relative vorticity, u-component
'Relative vorticity, u-component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 198 ;
	}

#paramId: 500542
#Relative vorticity, v-component
'Relative vorticity, v-component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 199 ;
	}

#paramId: 500550
#Potentielle Vorticity (auf Druckflaechen, nicht isentrop)
'Potentielle Vorticity (auf Druckflaechen, nicht isentrop)' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 23 ;
	}

#paramId: 500551
#geostrophische Vorticity
'geostrophische Vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 7 ;
	}

#paramId: 500552
#Forcing rechte Seite Omegagleichung
'Forcing rechte Seite Omegagleichung' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 8 ;
	}

#paramId: 500553
#Q-Vektor X-Komponente (geostrophisch)
'Q-Vektor X-Komponente (geostrophisch)' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 9 ;
	}

#paramId: 500554
#Q-Vektor Y-Komponente (geostrophisch)
'Q-Vektor Y-Komponente (geostrophisch)' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 10 ;
	}

#paramId: 500555
#Divergenz Q (geostrophisch)
'Divergenz Q (geostrophisch)' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 11 ;
	}

#paramId: 500556
#Q-Vektor senkrecht zu d. Isothermen (geostrophisch)
'Q-Vektor senkrecht zu d. Isothermen (geostrophisch)' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 12 ;
	}

#paramId: 500557
#Q-Vektor parallel zu d. Isothermen (geostrophisch)
'Q-Vektor parallel zu d. Isothermen (geostrophisch)' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 13 ;
	}

#paramId: 500558
#Divergenz Qn geostrophisch
'Divergenz Qn geostrophisch' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 14 ;
	}

#paramId: 500559
#Divergenz Qs geostrophisch
'Divergenz Qs geostrophisch' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 15 ;
	}

#paramId: 500560
#Frontogenesefunktion
'Frontogenesefunktion' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 16 ;
	}

#paramId: 500562
#Divergenz
'Divergenz' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 17 ;
	}

#paramId: 500563
#Q-Vektor parallel zu den Isothermen
'Q-Vektor parallel zu den Isothermen' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 18 ;
	}

#paramId: 500564
#Divergenz Qn
'Divergenz Qn' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 19 ;
	}

#paramId: 500565
#Divergenz Qs
'Divergenz Qs' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 20 ;
	}

#paramId: 500566
#Frontogenesis function
'Frontogenesis function' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 21 ;
	}

#paramId: 500567
#Clear Air Turbulence Index
'Clear Air Turbulence Index' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 22 ;
	}

#paramId: 500570
#Dry convection top index
'Dry convection top index' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 202 ;
	}

#paramId: 500572
#Tidal tendencies
'Tidal tendencies' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500573
#Sea surface temperature interpolated in time in C
'Sea surface temperature interpolated in time in C' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}

#paramId: 500575
#3 hour pressure change
'3 hour pressure change' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}

#paramId: 500577
#Variance of soil moisture content
'Variance of soil moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 6 ;
	}

#paramId: 500578
#Covariance of soil moisture content
'Covariance of soil moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 6 ;
	}

#paramId: 500585
#Eddy Dissipation Rate
'Eddy Dissipation Rate' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 216 ;
	}

#paramId: 500586
#Ellrod Index
'Ellrod Index' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 217 ;
	}

#paramId: 500591
#Niederschlagsdargebot: potential water supply (rain and snow melt) from snowpack - accumulation
'Niederschlagsdargebot: potential water supply (rain and snow melt) from snowpack - accumulation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 209 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500620
#Prob Gewitter
'Prob Gewitter' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500621
#Prob Starkes Gewitter
'Prob Starkes Gewitter' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500622
#Prob Schweres Gewitter
'Prob Schweres Gewitter' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 3 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500623
#Prob Dauerregen
'Prob Dauerregen' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500624
#Prob Ergiebiger Dauerregen
'Prob Ergiebiger Dauerregen' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 5 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500625
#Prob Extrem ergiebiger Dauerregen
'Prob Extrem ergiebiger Dauerregen' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 6 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500626
#Prob Schneeverwehung
'Prob Schneeverwehung' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 7 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500627
#Prob Starke Schneeverwehung
'Prob Starke Schneeverwehung' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 8 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500628
#Prob Glaette
'Prob Glaette' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 9 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500629
#Prob oertlich Glatteis
'Prob oertlich Glatteis' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 10 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500630
#Prob Glatteis
'Prob Glatteis' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500631
#Prob Nebel (ueberoertl. Sichtweite < 150 m)
'Prob Nebel (ueberoertl. Sichtweite < 150 m)' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 12 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500632
#Prob Tauwetter
'Prob Tauwetter' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 13 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500633
#Prob Starkes Tauwetter
'Prob Starkes Tauwetter' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 14 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500634
#Wake-production of TKE due to sub-grid scale orography
'Wake-production of TKE due to sub-grid scale orography' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 220 ;
	}

#paramId: 500635
#Shear-production of TKE due to separated horizontal shear modes
'Shear-production of TKE due to separated horizontal shear modes' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 221 ;
	}

#paramId: 500636
#Buoyancy-production of TKE due to sub-grid scale convection
'Buoyancy-production of TKE due to sub-grid scale convection' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 219 ;
	}

#paramId: 500637
#Production of TKE
'Production of TKE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 218 ;
	}

#paramId: 500638
#Atmospheric resistance
'Atmospheric resistance' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 200 ;
	}

#paramId: 500639
#Height of thermals above MSL
'Height of thermals above MSL' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 197 ;
	}

#paramId: 500640
#Mass concentration of dust (minimum mode)
'Mass concentration of dust (minimum mode)' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 33 ;
	}

#paramId: 500643
#Mass concentration of dust (medium mode)
'Mass concentration of dust (medium mode)' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 34 ;
	}

#paramId: 500644
#Mass concentration of dust (maximum mode)
'Mass concentration of dust (maximum mode)' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 35 ;
	}

#paramId: 500645
#Number concentration of dust (minimum mode)
'Number concentration of dust (minimum mode)' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 72 ;
	}

#paramId: 500646
#Number concentration of dust (medium mode)
'Number concentration of dust (medium mode)' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 73 ;
	}

#paramId: 500647
#Number concentration of dust (maximum mode)
'Number concentration of dust (maximum mode)' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 74 ;
	}

#paramId: 500648
#Mass concentration of dust (sum of all modes)
'Mass concentration of dust (sum of all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 251 ;
	}

#paramId: 500649
#Number concentration of dust (sum of all modes)
'Number concentration of dust (sum of all modes)' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 252 ;
	}

#paramId: 500650
#DUMMY_1
'DUMMY_1' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 1 ;
	}

#paramId: 500651
#DUMMY_2
'DUMMY_2' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 2 ;
	}

#paramId: 500652
#DUMMY_3
'DUMMY_3' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 3 ;
	}

#paramId: 500654
#DUMMY_4
'DUMMY_4' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 4 ;
	}

#paramId: 500655
#DUMMY_5
'DUMMY_5' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 5 ;
	}

#paramId: 500656
#DUMMY_6
'DUMMY_6' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 6 ;
	}

#paramId: 500657
#DUMMY_7
'DUMMY_7' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 7 ;
	}

#paramId: 500658
#DUMMY_8
'DUMMY_8' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 8 ;
	}

#paramId: 500659
#DUMMY_9
'DUMMY_9' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 9 ;
	}

#paramId: 500660
#DUMMY_10
'DUMMY_10' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 10 ;
	}

#paramId: 500661
#DUMMY_11
'DUMMY_11' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 11 ;
	}

#paramId: 500662
#DUMMY_12
'DUMMY_12' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 12 ;
	}

#paramId: 500663
#DUMMY_13
'DUMMY_13' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 13 ;
	}

#paramId: 500664
#DUMMY_14
'DUMMY_14' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 14 ;
	}

#paramId: 500665
#DUMMY_15
'DUMMY_15' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 15 ;
	}

#paramId: 500666
#DUMMY_16
'DUMMY_16' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 16 ;
	}

#paramId: 500667
#DUMMY_17
'DUMMY_17' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 17 ;
	}

#paramId: 500668
#DUMMY_18
'DUMMY_18' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 18 ;
	}

#paramId: 500669
#DUMMY_19
'DUMMY_19' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 19 ;
	}

#paramId: 500670
#DUMMY_20
'DUMMY_20' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 20 ;
	}

#paramId: 500671
#DUMMY_21
'DUMMY_21' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 21 ;
	}

#paramId: 500672
#DUMMY_22
'DUMMY_22' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 22 ;
	}

#paramId: 500673
#DUMMY_23
'DUMMY_23' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 23 ;
	}

#paramId: 500674
#DUMMY_24
'DUMMY_24' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 24 ;
	}

#paramId: 500675
#DUMMY_25
'DUMMY_25' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 25 ;
	}

#paramId: 500676
#DUMMY_26
'DUMMY_26' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 26 ;
	}

#paramId: 500677
#DUMMY_27
'DUMMY_27' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 27 ;
	}

#paramId: 500678
#DUMMY_28
'DUMMY_28' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 28 ;
	}

#paramId: 500679
#DUMMY_29
'DUMMY_29' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 29 ;
	}

#paramId: 500680
#DUMMY_30
'DUMMY_30' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 30 ;
	}

#paramId: 500681
#DUMMY_31
'DUMMY_31' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 31 ;
	}

#paramId: 500682
#DUMMY_32
'DUMMY_32' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 32 ;
	}

#paramId: 500683
#DUMMY_33
'DUMMY_33' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 33 ;
	}

#paramId: 500684
#DUMMY_34
'DUMMY_34' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 34 ;
	}

#paramId: 500685
#DUMMY_35
'DUMMY_35' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 35 ;
	}

#paramId: 500686
#DUMMY_36
'DUMMY_36' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 36 ;
	}

#paramId: 500687
#DUMMY_37
'DUMMY_37' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 37 ;
	}

#paramId: 500688
#DUMMY_38
'DUMMY_38' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 38 ;
	}

#paramId: 500689
#DUMMY_39
'DUMMY_39' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 39 ;
	}

#paramId: 500690
#DUMMY_40
'DUMMY_40' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 40 ;
	}

#paramId: 500691
#DUMMY_41
'DUMMY_41' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 41 ;
	}

#paramId: 500692
#DUMMY_42
'DUMMY_42' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 42 ;
	}

#paramId: 500693
#DUMMY_43
'DUMMY_43' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 43 ;
	}

#paramId: 500694
#DUMMY_44
'DUMMY_44' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 44 ;
	}

#paramId: 500695
#DUMMY_45
'DUMMY_45' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 45 ;
	}

#paramId: 500696
#DUMMY_46
'DUMMY_46' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 46 ;
	}

#paramId: 500697
#DUMMY_47
'DUMMY_47' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 47 ;
	}

#paramId: 500698
#DUMMY_48
'DUMMY_48' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 48 ;
	}

#paramId: 500699
#DUMMY_49
'DUMMY_49' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 49 ;
	}

#paramId: 500700
#DUMMY_50
'DUMMY_50' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 50 ;
	}

#paramId: 500701
#DUMMY_51
'DUMMY_51' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 51 ;
	}

#paramId: 500702
#DUMMY_52
'DUMMY_52' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 52 ;
	}

#paramId: 500703
#DUMMY_53
'DUMMY_53' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 53 ;
	}

#paramId: 500704
#DUMMY_54
'DUMMY_54' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 54 ;
	}

#paramId: 500705
#DUMMY_55
'DUMMY_55' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 55 ;
	}

#paramId: 500706
#DUMMY_56
'DUMMY_56' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 56 ;
	}

#paramId: 500707
#DUMMY_57
'DUMMY_57' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 57 ;
	}

#paramId: 500708
#DUMMY_58
'DUMMY_58' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 58 ;
	}

#paramId: 500709
#DUMMY_59
'DUMMY_59' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 59 ;
	}

#paramId: 500710
#DUMMY_60
'DUMMY_60' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 60 ;
	}

#paramId: 500711
#DUMMY_61
'DUMMY_61' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 61 ;
	}

#paramId: 500712
#DUMMY_62
'DUMMY_62' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 62 ;
	}

#paramId: 500713
#DUMMY_63
'DUMMY_63' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 63 ;
	}

#paramId: 500714
#DUMMY_64
'DUMMY_64' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 64 ;
	}

#paramId: 500715
#DUMMY_65
'DUMMY_65' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 65 ;
	}

#paramId: 500716
#DUMMY_66
'DUMMY_66' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 66 ;
	}

#paramId: 500717
#DUMMY_67
'DUMMY_67' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 67 ;
	}

#paramId: 500718
#DUMMY_68
'DUMMY_68' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 68 ;
	}

#paramId: 500719
#DUMMY_69
'DUMMY_69' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 69 ;
	}

#paramId: 500720
#DUMMY_70
'DUMMY_70' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 70 ;
	}

#paramId: 500721
#DUMMY_71
'DUMMY_71' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 71 ;
	}

#paramId: 500722
#DUMMY_72
'DUMMY_72' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 72 ;
	}

#paramId: 500723
#DUMMY_73
'DUMMY_73' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 73 ;
	}

#paramId: 500724
#DUMMY_74
'DUMMY_74' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 74 ;
	}

#paramId: 500725
#DUMMY_75
'DUMMY_75' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 75 ;
	}

#paramId: 500726
#DUMMY_76
'DUMMY_76' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 76 ;
	}

#paramId: 500727
#DUMMY_77
'DUMMY_77' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 77 ;
	}

#paramId: 500728
#DUMMY_78
'DUMMY_78' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 78 ;
	}

#paramId: 500729
#DUMMY_79
'DUMMY_79' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 79 ;
	}

#paramId: 500730
#DUMMY_80
'DUMMY_80' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 80 ;
	}

#paramId: 500731
#DUMMY_81
'DUMMY_81' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 81 ;
	}

#paramId: 500732
#DUMMY_82
'DUMMY_82' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 82 ;
	}

#paramId: 500733
#DUMMY_83
'DUMMY_83' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 83 ;
	}

#paramId: 500734
#DUMMY_84
'DUMMY_84' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 84 ;
	}

#paramId: 500735
#DUMMY_85
'DUMMY_85' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 85 ;
	}

#paramId: 500736
#DUMMY_86
'DUMMY_86' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 86 ;
	}

#paramId: 500737
#DUMMY_87
'DUMMY_87' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 87 ;
	}

#paramId: 500738
#DUMMY_88
'DUMMY_88' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 88 ;
	}

#paramId: 500739
#DUMMY_89
'DUMMY_89' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 89 ;
	}

#paramId: 500740
#DUMMY_90
'DUMMY_90' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 90 ;
	}

#paramId: 500741
#DUMMY_91
'DUMMY_91' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 91 ;
	}

#paramId: 500742
#DUMMY_92
'DUMMY_92' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 92 ;
	}

#paramId: 500743
#DUMMY_93
'DUMMY_93' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 93 ;
	}

#paramId: 500744
#DUMMY_94
'DUMMY_94' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 94 ;
	}

#paramId: 500745
#DUMMY_95
'DUMMY_95' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 95 ;
	}

#paramId: 500746
#DUMMY_96
'DUMMY_96' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 96 ;
	}

#paramId: 500747
#DUMMY_97
'DUMMY_97' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 97 ;
	}

#paramId: 500748
#DUMMY_98
'DUMMY_98' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 98 ;
	}

#paramId: 500749
#DUMMY_99
'DUMMY_99' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 99 ;
	}

#paramId: 500750
#DUMMY_100
'DUMMY_100' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 100 ;
	}

#paramId: 500751
#DUMMY_101
'DUMMY_101' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 101 ;
	}

#paramId: 500752
#DUMMY_102
'DUMMY_102' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 102 ;
	}

#paramId: 500753
#DUMMY_103
'DUMMY_103' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 103 ;
	}

#paramId: 500754
#DUMMY_104
'DUMMY_104' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 104 ;
	}

#paramId: 500755
#DUMMY_105
'DUMMY_105' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 105 ;
	}

#paramId: 500756
#DUMMY_106
'DUMMY_106' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 106 ;
	}

#paramId: 500757
#DUMMY_107
'DUMMY_107' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 107 ;
	}

#paramId: 500758
#DUMMY_108
'DUMMY_108' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 108 ;
	}

#paramId: 500759
#DUMMY_109
'DUMMY_109' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 109 ;
	}

#paramId: 500760
#DUMMY_110
'DUMMY_110' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 110 ;
	}

#paramId: 500761
#DUMMY_111
'DUMMY_111' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 111 ;
	}

#paramId: 500762
#DUMMY_112
'DUMMY_112' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 112 ;
	}

#paramId: 500763
#DUMMY_113
'DUMMY_113' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 113 ;
	}

#paramId: 500764
#DUMMY_114
'DUMMY_114' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 114 ;
	}

#paramId: 500765
#DUMMY_115
'DUMMY_115' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 115 ;
	}

#paramId: 500766
#DUMMY_116
'DUMMY_116' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 116 ;
	}

#paramId: 500767
#DUMMY_117
'DUMMY_117' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 117 ;
	}

#paramId: 500768
#DUMMY_118
'DUMMY_118' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 118 ;
	}

#paramId: 500769
#DUMMY_119
'DUMMY_119' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 119 ;
	}

#paramId: 500770
#DUMMY_120
'DUMMY_120' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 120 ;
	}

#paramId: 500771
#DUMMY_121
'DUMMY_121' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 121 ;
	}

#paramId: 500772
#DUMMY_122
'DUMMY_122' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 122 ;
	}

#paramId: 500773
#DUMMY_123
'DUMMY_123' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 123 ;
	}

#paramId: 500774
#DUMMY_124
'DUMMY_124' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 124 ;
	}

#paramId: 500775
#DUMMY_125
'DUMMY_125' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 125 ;
	}

#paramId: 500776
#DUMMY_126
'DUMMY_126' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 126 ;
	}

#paramId: 500777
#DUMMY_127
'DUMMY_127' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 127 ;
	}

#paramId: 500778
#DUMMY_128
'DUMMY_128' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 128 ;
	}

#paramId: 500779
#DUMMY_129
'DUMMY_129' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 129 ;
	}

#paramId: 500780
#DUMMY_130
'DUMMY_130' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 130 ;
	}

#paramId: 500781
#DUMMY_131
'DUMMY_131' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 131 ;
	}

#paramId: 500782
#DUMMY_132
'DUMMY_132' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 132 ;
	}

#paramId: 500783
#DUMMY_133
'DUMMY_133' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 133 ;
	}

#paramId: 500784
#DUMMY_134
'DUMMY_134' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 134 ;
	}

#paramId: 500785
#DUMMY_135
'DUMMY_135' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 135 ;
	}

#paramId: 500786
#DUMMY_136
'DUMMY_136' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 136 ;
	}

#paramId: 500787
#DUMMY_137
'DUMMY_137' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 137 ;
	}

#paramId: 500788
#DUMMY_138
'DUMMY_138' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 138 ;
	}

#paramId: 500789
#DUMMY_139
'DUMMY_139' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 139 ;
	}

#paramId: 500790
#DUMMY_140
'DUMMY_140' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 140 ;
	}

#paramId: 500791
#DUMMY_141
'DUMMY_141' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 141 ;
	}

#paramId: 500792
#DUMMY_142
'DUMMY_142' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 142 ;
	}

#paramId: 500793
#DUMMY_143
'DUMMY_143' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 143 ;
	}

#paramId: 500794
#DUMMY_144
'DUMMY_144' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 144 ;
	}

#paramId: 500795
#DUMMY_145
'DUMMY_145' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 145 ;
	}

#paramId: 500796
#DUMMY_146
'DUMMY_146' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 146 ;
	}

#paramId: 500797
#DUMMY_147
'DUMMY_147' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 147 ;
	}

#paramId: 500798
#DUMMY_148
'DUMMY_148' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 148 ;
	}

#paramId: 500799
#DUMMY_149
'DUMMY_149' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 149 ;
	}

#paramId: 500800
#DUMMY_150
'DUMMY_150' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 150 ;
	}

#paramId: 500801
#DUMMY_151
'DUMMY_151' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 151 ;
	}

#paramId: 500802
#DUMMY_152
'DUMMY_152' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 152 ;
	}

#paramId: 500803
#DUMMY_153
'DUMMY_153' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 153 ;
	}

#paramId: 500804
#DUMMY_154
'DUMMY_154' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 154 ;
	}

#paramId: 500805
#DUMMY_155
'DUMMY_155' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 155 ;
	}

#paramId: 500806
#DUMMY_156
'DUMMY_156' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 156 ;
	}

#paramId: 500807
#DUMMY_157
'DUMMY_157' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 157 ;
	}

#paramId: 500808
#DUMMY_158
'DUMMY_158' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 158 ;
	}

#paramId: 500809
#DUMMY_159
'DUMMY_159' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 159 ;
	}

#paramId: 500810
#DUMMY_160
'DUMMY_160' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 160 ;
	}

#paramId: 500811
#DUMMY_161
'DUMMY_161' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 161 ;
	}

#paramId: 500812
#DUMMY_162
'DUMMY_162' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 162 ;
	}

#paramId: 500813
#DUMMY_163
'DUMMY_163' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 163 ;
	}

#paramId: 500814
#DUMMY_164
'DUMMY_164' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 164 ;
	}

#paramId: 500815
#DUMMY_165
'DUMMY_165' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 165 ;
	}

#paramId: 500816
#DUMMY_166
'DUMMY_166' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 166 ;
	}

#paramId: 500817
#DUMMY_167
'DUMMY_167' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 167 ;
	}

#paramId: 500818
#DUMMY_168
'DUMMY_168' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 168 ;
	}

#paramId: 500819
#DUMMY_169
'DUMMY_169' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 169 ;
	}

#paramId: 500820
#DUMMY_170
'DUMMY_170' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 170 ;
	}

#paramId: 500821
#DUMMY_171
'DUMMY_171' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 171 ;
	}

#paramId: 500822
#DUMMY_172
'DUMMY_172' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 172 ;
	}

#paramId: 500823
#DUMMY_173
'DUMMY_173' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 173 ;
	}

#paramId: 500824
#DUMMY_174
'DUMMY_174' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 174 ;
	}

#paramId: 500825
#DUMMY_175
'DUMMY_175' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 175 ;
	}

#paramId: 500826
#DUMMY_176
'DUMMY_176' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 176 ;
	}

#paramId: 500827
#DUMMY_177
'DUMMY_177' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 177 ;
	}

#paramId: 500828
#DUMMY_178
'DUMMY_178' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 178 ;
	}

#paramId: 500829
#DUMMY_179
'DUMMY_179' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 179 ;
	}

#paramId: 500830
#DUMMY_180
'DUMMY_180' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 180 ;
	}

#paramId: 500831
#DUMMY_181
'DUMMY_181' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 181 ;
	}

#paramId: 500832
#DUMMY_182
'DUMMY_182' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 182 ;
	}

#paramId: 500833
#DUMMY_183
'DUMMY_183' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 183 ;
	}

#paramId: 500834
#DUMMY_184
'DUMMY_184' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 184 ;
	}

#paramId: 500835
#DUMMY_185
'DUMMY_185' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 185 ;
	}

#paramId: 500836
#DUMMY_186
'DUMMY_186' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 186 ;
	}

#paramId: 500837
#DUMMY_187
'DUMMY_187' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 187 ;
	}

#paramId: 500838
#DUMMY_188
'DUMMY_188' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 188 ;
	}

#paramId: 500839
#DUMMY_189
'DUMMY_189' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 189 ;
	}

#paramId: 500840
#DUMMY_190
'DUMMY_190' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 190 ;
	}

#paramId: 500841
#DUMMY_191
'DUMMY_191' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 191 ;
	}

#paramId: 500842
#DUMMY_192
'DUMMY_192' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 192 ;
	}

#paramId: 500843
#DUMMY_193
'DUMMY_193' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 193 ;
	}

#paramId: 500844
#DUMMY_194
'DUMMY_194' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 194 ;
	}

#paramId: 500845
#DUMMY_195
'DUMMY_195' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 195 ;
	}

#paramId: 500846
#DUMMY_196
'DUMMY_196' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 196 ;
	}

#paramId: 500847
#DUMMY_197
'DUMMY_197' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 197 ;
	}

#paramId: 500848
#DUMMY_198
'DUMMY_198' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 198 ;
	}

#paramId: 500849
#DUMMY_199
'DUMMY_199' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 199 ;
	}

#paramId: 500850
#DUMMY_200
'DUMMY_200' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 200 ;
	}

#paramId: 500851
#DUMMY_201
'DUMMY_201' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 201 ;
	}

#paramId: 500852
#DUMMY_202
'DUMMY_202' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 202 ;
	}

#paramId: 500853
#DUMMY_203
'DUMMY_203' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 203 ;
	}

#paramId: 500854
#DUMMY_204
'DUMMY_204' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 204 ;
	}

#paramId: 500855
#DUMMY_205
'DUMMY_205' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 205 ;
	}

#paramId: 500856
#DUMMY_206
'DUMMY_206' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 206 ;
	}

#paramId: 500857
#DUMMY_207
'DUMMY_207' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 207 ;
	}

#paramId: 500858
#DUMMY_208
'DUMMY_208' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 208 ;
	}

#paramId: 500859
#DUMMY_209
'DUMMY_209' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 209 ;
	}

#paramId: 500860
#DUMMY_210
'DUMMY_210' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 210 ;
	}

#paramId: 500861
#DUMMY_211
'DUMMY_211' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 211 ;
	}

#paramId: 500862
#DUMMY_212
'DUMMY_212' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 212 ;
	}

#paramId: 500863
#DUMMY_213
'DUMMY_213' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 213 ;
	}

#paramId: 500864
#DUMMY_214
'DUMMY_214' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 214 ;
	}

#paramId: 500865
#DUMMY_215
'DUMMY_215' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 215 ;
	}

#paramId: 500866
#DUMMY_216
'DUMMY_216' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 216 ;
	}

#paramId: 500867
#DUMMY_217
'DUMMY_217' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 217 ;
	}

#paramId: 500868
#DUMMY_218
'DUMMY_218' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 218 ;
	}

#paramId: 500869
#DUMMY_219
'DUMMY_219' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 219 ;
	}

#paramId: 500870
#DUMMY_220
'DUMMY_220' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 220 ;
	}

#paramId: 500871
#DUMMY_221
'DUMMY_221' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 221 ;
	}

#paramId: 500872
#DUMMY_222
'DUMMY_222' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 222 ;
	}

#paramId: 500873
#DUMMY_223
'DUMMY_223' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 223 ;
	}

#paramId: 500874
#DUMMY_224
'DUMMY_224' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 224 ;
	}

#paramId: 500875
#DUMMY_225
'DUMMY_225' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 225 ;
	}

#paramId: 500876
#DUMMY_226
'DUMMY_226' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 226 ;
	}

#paramId: 500877
#DUMMY_227
'DUMMY_227' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 227 ;
	}

#paramId: 500878
#DUMMY_228
'DUMMY_228' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 228 ;
	}

#paramId: 500879
#DUMMY_229
'DUMMY_229' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 229 ;
	}

#paramId: 500880
#DUMMY_230
'DUMMY_230' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 230 ;
	}

#paramId: 500881
#DUMMY_231
'DUMMY_231' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 231 ;
	}

#paramId: 500882
#DUMMY_232
'DUMMY_232' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 232 ;
	}

#paramId: 500883
#DUMMY_233
'DUMMY_233' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 233 ;
	}

#paramId: 500884
#DUMMY_234
'DUMMY_234' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 234 ;
	}

#paramId: 500885
#DUMMY_235
'DUMMY_235' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 235 ;
	}

#paramId: 500886
#DUMMY_236
'DUMMY_236' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 236 ;
	}

#paramId: 500887
#DUMMY_237
'DUMMY_237' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 237 ;
	}

#paramId: 500888
#DUMMY_238
'DUMMY_238' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 238 ;
	}

#paramId: 500889
#DUMMY_239
'DUMMY_239' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 239 ;
	}

#paramId: 500890
#DUMMY_240
'DUMMY_240' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 240 ;
	}

#paramId: 500891
#DUMMY_241
'DUMMY_241' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 241 ;
	}

#paramId: 500892
#DUMMY_242
'DUMMY_242' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 242 ;
	}

#paramId: 500893
#DUMMY_243
'DUMMY_243' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 243 ;
	}

#paramId: 500894
#DUMMY_244
'DUMMY_244' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 244 ;
	}

#paramId: 500895
#DUMMY_245
'DUMMY_245' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 245 ;
	}

#paramId: 500896
#DUMMY_246
'DUMMY_246' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 246 ;
	}

#paramId: 500897
#DUMMY_247
'DUMMY_247' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 247 ;
	}

#paramId: 500898
#DUMMY_248
'DUMMY_248' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 248 ;
	}

#paramId: 500899
#DUMMY_249
'DUMMY_249' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 249 ;
	}

#paramId: 500900
#DUMMY_250
'DUMMY_250' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 250 ;
	}

#paramId: 500901
#DUMMY_251
'DUMMY_251' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 251 ;
	}

#paramId: 500902
#DUMMY_252
'DUMMY_252' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 252 ;
	}

#paramId: 500903
#DUMMY_253
'DUMMY_253' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 253 ;
	}

#paramId: 500904
#DUMMY_254
'DUMMY_254' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 254 ;
	}

#paramId: 502332
#Liquid water content in snow - multi level
'Liquid water content in snow - multi level' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 210 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502339
#Downward direct short wave radiation flux at surface
'Downward direct short wave radiation flux at surface' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502344
#Albedo - diffusive solar - time average (UV: 0.3 - 0.7 m-6)
'Albedo - diffusive solar - time average (UV: 0.3 - 0.7 m-6)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 222 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 502345
#Albedo - diffusive solar (UV: 0.3 - 0.7 m-6)
'Albedo - diffusive solar (UV: 0.3 - 0.7 m-6)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 222 ;
	}

#paramId: 502346
#Albedo - near infrared - time average (0.7 - 5.0 m-6)
'Albedo - near infrared - time average (0.7 - 5.0 m-6) ' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 223 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 502347
#Albedo - near infrared (0.7 - 5.0 m-6)
'Albedo - near infrared (0.7 - 5.0 m-6)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 223 ;
	}

#paramId: 502352
#Eddy Dissipation Rate Total Col-Max. Upper FIR
'Eddy Dissipation Rate Total Col-Max. Upper FIR' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 224 ;
	}

#paramId: 502353
#Eddy Dissipation Rate Total Col-Max. Lower UIR
'Eddy Dissipation Rate Total Col-Max. Lower UIR' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 225 ;
	}

#paramId: 502354
#Eddy Dissipation Rate Total Col-Max. Upper UIR
'Eddy Dissipation Rate Total Col-Max. Upper UIR' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 226 ;
	}

#paramId: 503049
#Eddy dissipitation rate of TKE
'Eddy dissipitation rate of TKE' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 227 ;
	}

#paramId: 503050
#Radar precipitation rate
'Radar precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 195 ;
	}

#paramId: 503052
#Radar quality information
'Radar quality information' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 196 ;
	}

#paramId: 503053
#Radar blacklist
'Radar blacklist' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 197 ;
	}

#paramId: 503054
#Height of radar beam above ground
'Height of radar beam above ground' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 198 ;
	}

#paramId: 503055
#Specific humidity (diagnostic)
'Specific humidity (diagnostic)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 211 ;
	}

#paramId: 503056
#Specific cloud water content (diagnostic)
'Specific cloud water content (diagnostic)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 212 ;
	}

#paramId: 503057
#Specific cloud ice content (diagnostic)
'Specific cloud ice content (diagnostic) ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 213 ;
	}

#paramId: 503058
#Total column integrated water vapour (diagnostic)
'Total column integrated water vapour (diagnostic) ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 214 ;
	}

#paramId: 503059
#Total column integrated cloud water (diagnostic)
'Total column integrated cloud water (diagnostic) ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 215 ;
	}

#paramId: 503060
#Total column integrated cloud ice (diagnostic)
'Total column integrated cloud ice (diagnostic) ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 216 ;
	}

#paramId: 503061
#Downward diffusive short wave radiation flux at surface (mean over forecast time)
'Downward diffusive short wave radiation flux at surface (mean over forecast time)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503068
#precipitation, qualified,BRD
'precipitation, qualified,BRD' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503069
#precipitation,BRD
'precipitation,BRD' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503070
#precipitation phase,BRD
'precipitation phase,BRD' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503071
#hail flag,BRD
'hail flag,BRD' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 195 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503072
#snow_rate,BRD
'snow_rate,BRD' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503073
#snow_rate,qualified,BRD
'snow_rate,qualified,BRD' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 197 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503074
#Area weights for regular lon-lat grid
'Area weights for regular lon-lat grid ' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 193 ;
	}

#paramId: 503078
#Relative humidity over mixed phase
'Relative humidity over mixed phase' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 220 ;
	}

#paramId: 503079
#Soil moisture index (multilayers)
'Soil moisture index (multilayers)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503096
#Peak frequency (interpolated)
'Peak frequency (interpolated)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	}

#paramId: 503115
#Specific number concentration of rain
'Specific number concentration of rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 228 ;
	}

#paramId: 503116
#Number density of rain
'Number density of rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 229 ;
	}

#paramId: 503117
#Specific number concentration of snow
'Specific number concentration of snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 217 ;
	}

#paramId: 503118
#Specific number concentration of graupel
'Specific number concentration of graupel' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 218 ;
	}

#paramId: 503119
#Specific number concentration of hail
'Specific number concentration of hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 219 ;
	}

#paramId: 503120
#Number density of snow
'Number density of snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 221 ;
	}

#paramId: 503121
#Number density of graupel
'Number density of graupel' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 222 ;
	}

#paramId: 503122
#Number density of hail
'Number density of hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 223 ;
	}

#paramId: 503123
#Mass density of rain
'Mass density of rain ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 224 ;
	}

#paramId: 503124
#Mass density of snow
'Mass density of snow ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 225 ;
	}

#paramId: 503125
#Mass density of graupel
'Mass density of graupel' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 226 ;
	}

#paramId: 503126
#Mass density of cloud droplets
'Mass density of cloud droplets' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 203 ;
	}

#paramId: 503127
#Mass density of cloud ice
'Mass density of cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 204 ;
	}

#paramId: 503128
#Mass density of hail
'Mass density of hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 227 ;
	}

#paramId: 503137
#Eddy Dissipation Rate Total Col-Max. Lower FIR
'Eddy Dissipation Rate Total Col-Max. Lower FIR' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 228 ;
	}

#paramId: 503142
#Lightning Potential Index
'Lightning Potential Index' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 192 ;
	}

#paramId: 503143
#Rain drain from snowpack - accumulation
'Rain drain from snowpack - accumulation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 230 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503146
#Height of -10 degree Celsius isotherm
'Height of -10 degree Celsius isotherm' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}

#paramId: 503147
# probability density function of EDP for turbulence  greater well defined threshold and model grid box
' probability density function of EDP for turbulence  greater well defined threshold and model grid box' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 229 ;
	}

#paramId: 503148
#Adedokun 2 Index
'Adedokun 2 Index' = {
	 discipline = 215 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	}

#paramId: 503149
#Downward direct short wave radiation flux at surface on horizontal plane (time average)
'Downward direct short wave radiation flux at surface on horizontal plane (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 201 ;
	}

#paramId: 503150
#Gauss Boaga Coordinates West to East,East Sector
'Gauss Boaga Coordinates West to East,East Sector' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 194 ;
	}

#paramId: 503151
#Gauss Boaga Coordinates South to North,East Sector
'Gauss Boaga Coordinates South to North,East Sector' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 195 ;
	}

#paramId: 503152
#Gauss Boaga Coordinates West to East, West Sector
'Gauss Boaga Coordinates West to East, West Sector' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 196 ;
	}

#paramId: 503153
#Gauss Boaga Coordinates South to North, West Sector
'Gauss Boaga Coordinates South to North, West Sector' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 197 ;
	}

#paramId: 503156
#Ellrod and Knapp turbulence index1
'Ellrod and Knapp turbulence index1' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 230 ;
	}

#paramId: 503157
#Ellrod and Knapp turbulence index2
'Ellrod and Knapp turbulence index2' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 231 ;
	}

#paramId: 503158
#Deformation of horizontal wind field
'Deformation of horizontal wind field' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 29 ;
	}

#paramId: 503159
#Divergence trend (scaled divergence tendency needed for CAT_DVI)
'Divergence trend (scaled divergence tendency needed for CAT_DVI)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 232 ;
	}

#paramId: 503160
#Divergence modified turbulence index (Ellrod and Knox)
'Divergence modified turbulence index (Ellrod and Knox)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 233 ;
	}

#paramId: 503161
#Cloud ice ratio qi/(qc+qi)
'Cloud ice ratio qi/(qc+qi)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 231 ;
	}

#paramId: 503162
#Percentage of convective precipitation (from total prec)
'Percentage of convective precipitation (from total prec)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 232 ;
	}

#paramId: 503163
#Deep convection index
'Deep convection index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503164
#Wind direction in azimuth class
'Wind direction in azimuth class' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}

#paramId: 503165
#Wind direction in azimuth class
'Wind direction in azimuth class' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503167
#Possible astronomical maximum of sunshine
'Possible astronomical maximum of sunshine' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503168
#Relative duration of sunshine (DURSUN * 100 / DURSUN_M)
'Relative duration of sunshine (DURSUN * 100 / DURSUN_M)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 206 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503171
#Enthalpy
'Enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 195 ;
	}

#paramId: 503172
#2m Enthalpy
'2m Enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503175
#Downward short wave radiation flux at surface on horizontal plane (time average)
'Downward short wave radiation flux at surface on horizontal plane (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 201 ;
	}

#paramId: 503176
#Downward short wave radiation flux at surface on vertical surface facing east (time average)
'Downward short wave radiation flux at surface on vertical surface facing east (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 202 ;
	}

#paramId: 503177
#Downward short wave radiation flux at surface on vertical surface facing north (time average)
'Downward short wave radiation flux at surface on vertical surface facing north (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 203 ;
	}

#paramId: 503178
#Downward short wave radiation flux at surface on vertical surface facing south (time average)
'Downward short wave radiation flux at surface on vertical surface facing south (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 204 ;
	}

#paramId: 503179
#Downward short wave radiation flux at surface on vertical surface facing west (time average)
'Downward short wave radiation flux at surface on vertical surface facing west (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 205 ;
	}

#paramId: 503180
#Along-wind Lagrangian time scale (Hanna)
'Along-wind Lagrangian time scale (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}

#paramId: 503181
#Cross-wind Lagrangian time scale (Hanna)
'Cross-wind Lagrangian time scale (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 503182
#Vertical Lagrangian time scale (Hanna)
'Vertical Lagrangian time scale (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}

#paramId: 503183
#Zonal Lagrangian time scale (direct) (Hanna)
'Zonal Lagrangian time scale (direct) (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}

#paramId: 503184
#Meridional Lagrangian time scale (direct) (Hanna)
'Meridional Lagrangian time scale (direct) (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}

#paramId: 503185
#Vertical Lagrangian time scale (direct) (Hanna)
'Vertical Lagrangian time scale (direct) (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}

#paramId: 503187
#Height of level of free convection of mixed (mean) layer parcel
'Height of level of free convection of mixed (mean) layer parcel' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 192 ;
	 typeOfFirstFixedSurface = 194 ;
	}

#paramId: 503188
#Luminosity
'Luminosity' = {
	 discipline = 215 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	}

#paramId: 503189
#Downward long-wave radiation flux at surface based on T_2M (time average)
'Downward long-wave radiation flux at surface based on T_2M (time average)' = {
	 discipline = 215 ;
	 parameterCategory = 5 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503190
#Downward long-wave radiation flux at surface based on T_G (time average)
'Downward long-wave radiation flux at surface based on T_G (time average)' = {
	 discipline = 215 ;
	 parameterCategory = 5 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503191
#Downward long-wave radiation flux at surface based on T_SO(0) (time average)
'Downward long-wave radiation flux at surface based on T_SO(0) (time average)' = {
	 discipline = 215 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503194
#Pressure difference between cloud base and cloud top
'Pressure difference between cloud base and cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	 typeOfSecondFixedSurface = 2 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 503198
#Along-wind velocity fluctuation (Hanna)
'Along-wind velocity fluctuation (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}

#paramId: 503199
#Cross-wind velocity fluctuation (Hanna)
'Cross-wind velocity fluctuation (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}

#paramId: 503200
#Vertical velocity fluctuation (Hanna)
'Vertical velocity fluctuation (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 9 ;
	}

#paramId: 503201
#Zonal velocity fluctuation (Hanna)
'Zonal velocity fluctuation (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}

#paramId: 503202
#Meridional velocity fluctuation (Hanna)
'Meridional velocity fluctuation (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	}

#paramId: 503203
#Vertical velocity fluctuation (Hanna)
'Vertical velocity fluctuation (Hanna)' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 503205
#Percentage of precipitation in snow (from total prec.)
'Percentage of precipitation in snow (from total prec.)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 233 ;
	}

#paramId: 503206
#Thunderstorm index for Switzerland (night time)
'Thunderstorm index for Switzerland (night time)' = {
	 discipline = 215 ;
	 parameterCategory = 7 ;
	 parameterNumber = 1 ;
	}

#paramId: 503207
#Thunderstorm index for Switzerland (day time)
'Thunderstorm index for Switzerland (day time)' = {
	 discipline = 215 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	}

#paramId: 503208
#Swiss coordinate (south-north)
'Swiss coordinate (south-north)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 198 ;
	}

#paramId: 503209
#Swiss coordinate (west-east)
'Swiss coordinate (west-east)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 199 ;
	}

#paramId: 503217
#2m temperature, corrected in presence of snow
'2m temperature, corrected in presence of snow' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503218
#Universal thermal climate index without direct incident short wave radiation
'Universal thermal climate index without direct incident short wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	}

#paramId: 503222
#Relative geostrophic vorticity
'Relative geostrophic vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 26 ;
	}

#paramId: 503223
#Relative geostrophic vorticity advection
'Relative geostrophic vorticity advection' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 27 ;
	}

#paramId: 503226
#Wind divergence (3D)
'Wind divergence (3D)' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 28 ;
	}

#paramId: 503227
#Mean vertical wind shear for specified layer or layer-mean vertical wind shear
'Mean vertical wind shear for specified layer or layer-mean vertical wind shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 201 ;
	}

#paramId: 503228
#Norm of (vertical) wind shear vector between two levels
'Norm of (vertical) wind shear vector between two levels' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 202 ;
	}

#paramId: 503282
#Diagnostic total column of activity concentration of radionuclides
'Diagnostic total column of activity concentration of radionuclides' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503283
#Liquid water potential temperature variance
'Liquid water potential temperature variance' = {
	 discipline = 0 ;
	 parameterCategory = 198 ;
	 parameterNumber = 0 ;
	}

#paramId: 503284
#Total water specific humidity variance
'Total water specific humidity variance' = {
	 discipline = 0 ;
	 parameterCategory = 198 ;
	 parameterNumber = 1 ;
	}

#paramId: 503285
#Liquid water potential temperature - total water specific humidity covariance
'Liquid water potential temperature - total water specific humidity covariance' = {
	 discipline = 0 ;
	 parameterCategory = 198 ;
	 parameterNumber = 2 ;
	}

#paramId: 503286
#Impervious (paved or sealed) surface fraction
'Impervious (paved or sealed) surface fraction' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}

#paramId: 503287
#Antropogenic heat flux (e.g. urban heating, traffic)
'Antropogenic heat flux (e.g. urban heating, traffic)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}

#paramId: 503292
#Sea ice albedo - diffusive solar (0.3 - 5.0 m-6)
'Sea ice albedo - diffusive solar (0.3 - 5.0 m-6)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 234 ;
	}

#paramId: 503299
#Sky-view-factor
'Sky-view-factor' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 0 ;
	}

#paramId: 503300
#Horizon angle - topography
'Horizon angle - topography' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 1 ;
	}

#paramId: 503301
#Slope aspect - topography
'Slope aspect - topography' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 3 ;
	}

#paramId: 503302
#Slope angle - topography
'Slope angle - topography' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 2 ;
	}

#paramId: 503339
#Threshold friction velocity
'Threshold friction velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 203 ;
	}

#paramId: 503342
#Maximum rotation amplitude (positive or negative) (over given time interval and column)
'Maximum rotation amplitude (positive or negative) (over given time interval and column)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503343
#Maximum updraft track (over given time interval and column)
'Maximum updraft track (over given time interval and column)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503348
#Maximum of Lightning Potential Index (over given time interval)
'Maximum of Lightning Potential Index (over given time interval)' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503351
#mean radiation temperature of an environment assumed black body related to standing human
'mean radiation temperature of an environment assumed black body related to standing human' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 4 ;
	}

#paramId: 503355
#Maximum 10m dynamical gust
'Maximum 10m dynamical gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503356
#Maximum 10m convective gust
'Maximum 10m convective gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503358
#Standard deviation of saturation deficit
'Standard deviation of saturation deficit' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 234 ;
	}

#paramId: 503359
#Evaporation of plants (integrated since "nightly reset")
'Evaporation of plants (integrated since "nightly reset")' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 198 ;
	}

#paramId: 503363
#Number of birch (betula) pollen in the reservoir (previous timestep)
'Number of birch (betula) pollen in the reservoir (previous timestep)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62101 ;
	}

#paramId: 503364
#Number of birch (betula) pollen released into the reservoir (new)
'Number of birch (betula) pollen released into the reservoir (new)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62101 ;
	}

#paramId: 503365
#Sum of released birch (betula) pollen into the reservoir (daily sum)
'Sum of released birch (betula) pollen into the reservoir (daily sum)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62101 ;
	}

#paramId: 503366
#State of the birch (betula) season (eq.zero before and after season, the higher, the more plants are flowering)
'State of the birch (betula) season (eq.zero before and after season, the higher, the more plants are flowering)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62101 ;
	}

#paramId: 503367
#Height correction for emission (decreasing emission with height) for birch (betula)
'Height correction for emission (decreasing emission with height) for birch (betula) ' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503369
#Cumulated weighted 2m temperature sum of daily values for birch (betula) pollen
'Cumulated weighted 2m temperature sum of daily values for birch (betula) pollen' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62101 ;
	}

#paramId: 503370
#Cumulated 2m temperature sum threshold for the start of birch (betula) pollen season (climatological)
'Cumulated 2m temperature sum threshold for the start of birch (betula) pollen season (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503371
#Cumulated 2m temperature sum threshold for the end of birch (betula) pollen season (climatological)
'Cumulated 2m temperature sum threshold for the end of birch (betula) pollen season (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503372
#Number of days since the start of birch (betula) pollen season (if present day is outside the season: length of current season)
'Number of days since the start of birch (betula) pollen season (if present day is outside the season: length of current season)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62101 ;
	}

#paramId: 503373
#Length of birch (betula) pollen season
'Length of birch (betula) pollen season' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62101 ;
	}

#paramId: 503374
#Pollen number emission flux for birch (betula)
'Pollen number emission flux for birch (betula) ' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62101 ;
	}

#paramId: 503377
#Number of alder (alnus) pollen in the reservoir (previous timestep)
'Number of alder (alnus) pollen in the reservoir (previous timestep)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62100 ;
	}

#paramId: 503378
#Number of alder (alnus) pollen released into the reservoir (new)
'Number of alder (alnus) pollen released into the reservoir (new)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62100 ;
	}

#paramId: 503379
#Sum of released alder (alnus) pollen into the reservoir (daily sum)
'Sum of released alder (alnus) pollen into the reservoir (daily sum)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62100 ;
	}

#paramId: 503380
#State of the alder (alnus) season (eq.zero before and after season, the higher, the more plants are flowering)
'State of the alder (alnus) season (eq.zero before and after season, the higher, the more plants are flowering)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62100 ;
	}

#paramId: 503381
#Height correction for emission (decreasing emission with height) for alder (alnus)
'Height correction for emission (decreasing emission with height) for alder (alnus) ' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503383
#Cumulated weighted 2m temperature sum of daily values for alder (alnus) pollen
'Cumulated weighted 2m temperature sum of daily values for alder (alnus) pollen' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62100 ;
	}

#paramId: 503384
#Cumulated 2m temperature sum threshold for the start of  alder (alnus) pollen season (climatological)
'Cumulated 2m temperature sum threshold for the start of  alder (alnus) pollen season (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503385
#Cumulated 2m temperature sum threshold for the end of  alder (alnus) pollen season (climatological)
'Cumulated 2m temperature sum threshold for the end of  alder (alnus) pollen season (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503386
#Number of days since the start of alder (alnus) pollen season (if present day is in the season: zero outside season)
'Number of days since the start of alder (alnus) pollen season (if present day is in the season: zero outside season)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62100 ;
	}

#paramId: 503387
#Number of days since the start of alder (alnus) pollen season (if present day is outside the season: length of current season)
'Number of days since the start of alder (alnus) pollen season (if present day is outside the season: length of current season)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62100 ;
	}

#paramId: 503388
#Length of alder (alnus) pollen season
'Length of alder (alnus) pollen season' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62100 ;
	}

#paramId: 503389
#Pollen number emission flux for alder (alnus)
'Pollen number emission flux for alder (alnus) ' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62100 ;
	}

#paramId: 503392
#Number of grasses (poaceae) pollen in the reservoir (previous timestep)
'Number of grasses (poaceae) pollen in the reservoir (previous timestep)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62300 ;
	}

#paramId: 503393
#Number of grasses (poaceae) pollen released into the reservoir (new)
'Number of grasses (poaceae) pollen released into the reservoir (new)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62300 ;
	}

#paramId: 503394
#Sum of released grasses (poaceae) pollen into the reservoir (daily sum)
'Sum of released grasses (poaceae) pollen into the reservoir (daily sum)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62300 ;
	}

#paramId: 503395
#State of the grasses (poaceae) season (eq.zero before and after season, the higher, the more plants are flowering)
'State of the grasses (poaceae) season (eq.zero before and after season, the higher, the more plants are flowering)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62300 ;
	}

#paramId: 503396
#Height correction for emission (decreasing emission with height) for grasses (poaceae)
'Height correction for emission (decreasing emission with height) for grasses (poaceae) ' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503398
#Cumulated weighted 2m temperature sum of daily values for grasses (poaceae) pollen
'Cumulated weighted 2m temperature sum of daily values for grasses (poaceae) pollen' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62300 ;
	}

#paramId: 503399
#Cumulated 2m temperature sum threshold for the start of  grasses (poaceae) pollen season (climatological)
'Cumulated 2m temperature sum threshold for the start of  grasses (poaceae) pollen season (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503400
#Cumulated 2m temperature sum threshold for the end of  grasses (poaceae) pollen season (climatological)
'Cumulated 2m temperature sum threshold for the end of  grasses (poaceae) pollen season (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503401
#Number of days since the start of grasses (poaceae) pollen season (if present day is in the season: zero outside season)
'Number of days since the start of grasses (poaceae) pollen season (if present day is in the season: zero outside season)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62300 ;
	}

#paramId: 503402
#Number of days since the start of grasses (poaceae) pollen season (if present day is outside the season: length of current season)
'Number of days since the start of grasses (poaceae) pollen season (if present day is outside the season: length of current season)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62300 ;
	}

#paramId: 503403
#Length of grasses (poaceae) pollen season
'Length of grasses (poaceae) pollen season' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62300 ;
	}

#paramId: 503404
#Pollen number emission flux for grasses (poaceae)
'Pollen number emission flux for grasses (poaceae) ' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62300 ;
	}

#paramId: 503407
#Number of ragweed  (ambrosia) pollen in the reservoir (previous timestep)
'Number of ragweed  (ambrosia) pollen in the reservoir (previous timestep)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62200 ;
	}

#paramId: 503408
#Number of ragweed  (ambrosia) pollen released into the reservoir (new)
'Number of ragweed  (ambrosia) pollen released into the reservoir (new)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62200 ;
	}

#paramId: 503409
#Sum of released ragweed  (ambrosia) pollen into the reservoir (daily sum)
'Sum of released ragweed  (ambrosia) pollen into the reservoir (daily sum)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62200 ;
	}

#paramId: 503410
#State of the ragweed  (ambrosia) season (eq.zero before and after season, the higher, the more plants are flowering)
'State of the ragweed  (ambrosia) season (eq.zero before and after season, the higher, the more plants are flowering)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62200 ;
	}

#paramId: 503411
#Height correction for emission (decreasing emission with height) for ragweed  (ambrosia)
'Height correction for emission (decreasing emission with height) for ragweed  (ambrosia) ' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503413
#Cumulated weighted 2m temperature sum of daily values for ragweed  (ambrosia) pollen
'Cumulated weighted 2m temperature sum of daily values for ragweed  (ambrosia) pollen' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62200 ;
	}

#paramId: 503414
#Cumulated 2m temperature sum threshold for the start of  ragweed  (ambrosia) pollen season (climatological)
'Cumulated 2m temperature sum threshold for the start of  ragweed  (ambrosia) pollen season (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503415
#Cumulated 2m temperature sum threshold for the end of  ragweed  (ambrosia) pollen season (climatological)
'Cumulated 2m temperature sum threshold for the end of  ragweed  (ambrosia) pollen season (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503416
#Number of days since the start of ragweed  (ambrosia) pollen season (if present day is in the season: zero outside season)
'Number of days since the start of ragweed  (ambrosia) pollen season (if present day is in the season: zero outside season)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62200 ;
	}

#paramId: 503417
#Number of days since the start of ragweed  (ambrosia) pollen season (if present day is outside the season: length of current season)
'Number of days since the start of ragweed  (ambrosia) pollen season (if present day is outside the season: length of current season)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62200 ;
	}

#paramId: 503418
#Length of ragweed  (ambrosia) pollen season
'Length of ragweed  (ambrosia) pollen season' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62200 ;
	}

#paramId: 503419
#Pollen number emission flux for ragweed  (ambrosia)
'Pollen number emission flux for ragweed  (ambrosia) ' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62200 ;
	}

#paramId: 503420
#Number of days since the start of birch (betula) pollen season (if present day is in the season: zero outside season)
'Number of days since the start of birch (betula) pollen season (if present day is in the season: zero outside season)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62101 ;
	}

#paramId: 503424
#Random pattern for  the stochastically perturbed parametrization tendencies (SPPT) scheme at levels without tapering. If multi-scale random patterns are used, RAPA_SPPT is the sum of those.
'Random pattern for  the stochastically perturbed parametrization tendencies (SPPT) scheme at levels without tapering. If multi-scale random patterns are used, RAPA_SPPT is the sum of those.' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 235 ;
	}

#paramId: 503425
#Skin conductivity (ratio ground heat flux to temperature difference soil-skin layer)
'Skin conductivity (ratio ground heat flux to temperature difference soil-skin layer)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 199 ;
	}

#paramId: 503426
#Maximum snow height during contiguous accumulating snow period (coupled with snow age)
'Maximum snow height during contiguous accumulating snow period (coupled with snow age)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 235 ;
	}

#paramId: 503427
#U-component of (vertical) wind shear vector between two levels
'U-component of (vertical) wind shear vector between two levels' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 208 ;
	}

#paramId: 503428
#V-component of (vertical) wind shear vector between two levels
'V-component of (vertical) wind shear vector between two levels' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 209 ;
	}

#paramId: 503440
#Accumulated wet deposition of dust if rain reaches the surface for mode 1
'Accumulated wet deposition of dust if rain reaches the surface for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 203 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503441
#Accumulated wet deposition of dust if rain reaches the surface for mode 2
'Accumulated wet deposition of dust if rain reaches the surface for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 203 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503442
#Accumulated wet deposition of dust if rain reaches the surface for mode 3
'Accumulated wet deposition of dust if rain reaches the surface for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 203 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503446
#Accumulated dry deposition of dust number concentration for mode 1
'Accumulated dry deposition of dust number concentration for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503447
#Accumulated dry deposition of dust number concentration for mode 2
'Accumulated dry deposition of dust number concentration for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503448
#Accumulated dry deposition of dust number concentration for mode 3
'Accumulated dry deposition of dust number concentration for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503449
#Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 1
'Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503450
#Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 2
'Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503451
#Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 3
'Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503452
#Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 1
'Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503453
#Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 2
'Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503454
#Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 3
'Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503455
#Accumulated sedimentation of dust number concentration for mode 1
'Accumulated sedimentation of dust number concentration for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 208 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503456
#Accumulated sedimentation of dust number concentration for mode 2
'Accumulated sedimentation of dust number concentration for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 208 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503457
#Accumulated sedimentation of dust number concentration for mode 3
'Accumulated sedimentation of dust number concentration for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 208 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503460
#Mineral dust backscatter (not attenuated, for given wave length)
'Mineral dust backscatter (not attenuated, for given wave length)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 209 ;
	 aerosolType = 62001 ;
	}

#paramId: 503463
#Volcanic ash backscatter (not attenuated, for given wave length)
'Volcanic ash backscatter (not attenuated, for given wave length)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 209 ;
	 aerosolType = 62025 ;
	}

#paramId: 503464
#Accumulated wet deposition by convective precipitation of dust number concentration for mode 3
'Accumulated wet deposition by convective precipitation of dust number concentration for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503465
#Accumulated wet deposition by convective precipitation of dust number concentration for mode 2
'Accumulated wet deposition by convective precipitation of dust number concentration for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503466
#Accumulated wet deposition by convective precipitation of dust number concentration for mode 1
'Accumulated wet deposition by convective precipitation of dust number concentration for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503549
#Swiss coordinate LV 95 (south-north)
'Swiss coordinate LV 95 (south-north)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 200 ;
	}

#paramId: 503550
#Swiss coordinate LV 95 (west-east)
'Swiss coordinate LV 95 (west-east)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 201 ;
	}

#paramId: 503555
#Average hail diameter
'Average hail diameter' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 238 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503556
#Standard deviation of hail diameter
'Standard deviation of hail diameter' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 238 ;
	 typeOfStatisticalProcessing = 6 ;
	}

#paramId: 503557
#Maximum hail diameter
'Maximum hail diameter' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 238 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503558
#Duration of updraft
'Duration of updraft' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 210 ;
	}

#paramId: 503559
#Updraft mask
'Updraft mask' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 211 ;
	}

#paramId: 503582
#Frequency of winds in defined wind sector for defined time interval
'Frequency of winds in defined wind sector for defined time interval' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 11 ;
	 typeOfSecondFixedSurface = 233 ;
	 typeOfFirstFixedSurface = 233 ;
	}

#paramId: 503585
#10m wind speed in wind sector (time average)
'10m wind speed in wind sector (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfSecondFixedSurface = 233 ;
	 typeOfFirstFixedSurface = 233 ;
	}

#paramId: 503586
#10m wind speed in wind sector (time maximum)
'10m wind speed in wind sector (time maximum)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 233 ;
	 typeOfFirstFixedSurface = 233 ;
	}

#paramId: 503588
#Downward direct short-wave radiation flux at surface on a plane normal to the sun (time average)
'Downward direct short-wave radiation flux at surface on a plane normal to the sun (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 206 ;
	}

#paramId: 503589
#Downward direct short-wave radiation flux at surface on a plane normal to the sun without orographic shading (time average)
'Downward direct short-wave radiation flux at surface on a plane normal to the sun without orographic shading (time average)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 207 ;
	}

#paramId: 503590
#Solar elevation angle
'Solar elevation angle' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 202 ;
	}

#paramId: 503591
#Solar azimuth angle
'Solar azimuth angle' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 203 ;
	}

#paramId: 503592
#Turbulence intensity (time maximum)
'Turbulence intensity (time maximum)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 236 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503603
#Soil water mass flux at layer interfaces (sum of conductive and diffusive fluxes)
'Soil water mass flux at layer interfaces (sum of conductive and diffusive fluxes)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503604
#Ground water runoff rate, aquifer
'Ground water runoff rate, aquifer' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503605
#Water table depth
'Water table depth' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 177 ;
	}

#paramId: 503606
#Soil moisture saturation level
'Soil moisture saturation level' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 177 ;
	}

#paramId: 503607
#Slope of orography (using average of maximum gradient in different directions)
'Slope of orography (using average of maximum gradient in different directions)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}

#paramId: 503608
#Total column zonal water flux
'Total column zonal water flux ' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 236 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503609
#Total column meridional water flux
'Total column meridional water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 237 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503610
#Total column zonal water flux - time average
'Total column zonal water flux - time average' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 236 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503611
#Total column meridional water flux - time average
'Total column meridional water flux - time average' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 237 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503612
#Number of active clouds per horizontal unit area
'Number of active clouds per horizontal unit area' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 210 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503613
#Number of passive clouds per horizontal unit area
'Number of passive clouds per horizontal unit area' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 211 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503614
#Cloud base mass flux associated with active clouds
'Cloud base mass flux associated with active clouds' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503615
#Cloud base mass flux associated with passive clouds
'Cloud base mass flux associated with passive clouds' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503619
#Single scan reflectivity - observation
'Single scan reflectivity - observation' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 200 ;
	 typeOfGeneratingProcess = 8 ;
	}

#paramId: 503620
#Single scan reflectivity - simulation
'Single scan reflectivity - simulation' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 198 ;
	}

#paramId: 503622
#Lightning Potential Index from convection scheme, modified by convection index
'Lightning Potential Index from convection scheme, modified by convection index' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 193 ;
	}

#paramId: 503623
#Maximum Lightning Potential Index from convection scheme, modified by convection index
'Maximum Lightning Potential Index from convection scheme, modified by convection index' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503625
#Mass median diameter of dust for mode 1
'Mass median diameter of dust for mode 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 220 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503626
#Mass median diameter of dust for mode 2
'Mass median diameter of dust for mode 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 220 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503627
#Mass median diameter of dust for mode 3
'Mass median diameter of dust for mode 3' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 220 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503638
#Number of hazel (corylus) pollen in the reservoir (previous timestep)
'Number of hazel (corylus) pollen in the reservoir (previous timestep)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62104 ;
	}

#paramId: 503639
#Number of hazel (corylus) pollen released into the reservoir (new)
'Number of hazel (corylus) pollen released into the reservoir (new)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62104 ;
	}

#paramId: 503640
#State of the hazel (corylus) season (eq.zero before and after season, the higher, the more plants are flowering)
'State of the hazel (corylus) season (eq.zero before and after season, the higher, the more plants are flowering)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62104 ;
	}

#paramId: 503641
#Height correction for emission (decreasing emission with height) for hazel (corylus)
'Height correction for emission (decreasing emission with height) for hazel (corylus)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503642
#Sum of released hazel (corylus) pollen into the reservoir (daily sum)
'Sum of released hazel (corylus) pollen into the reservoir (daily sum)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62104 ;
	}

#paramId: 503644
#Cumulated weighted 2m temperature sum of daily values for hazel (corylus) pollen
'Cumulated weighted 2m temperature sum of daily values for hazel (corylus) pollen' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62104 ;
	}

#paramId: 503645
#Cumulated 2m temperature sum threshold for the start of hazel (corylus) pollen season (climatological)
'Cumulated 2m temperature sum threshold for the start of hazel (corylus) pollen season (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503646
#Cumulated 2m temperature sum threshold for the end of hazel (corylus) pollen season (climatological)
'Cumulated 2m temperature sum threshold for the end of hazel (corylus) pollen season (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503647
#Number of days since the start of hazel (corylus) pollen season (if present day is in the season: zero outside season)
'Number of days since the start of hazel (corylus) pollen season (if present day is in the season: zero outside season)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62104 ;
	}

#paramId: 503648
#Length of hazel (corylus) pollen season
'Length of hazel (corylus) pollen season' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62104 ;
	}

#paramId: 503649
#Pollen number emission flux for hazel (corylus)
'Pollen number emission flux for hazel (corylus)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62104 ;
	}

#paramId: 503650
#Number of days since the start of hazel (corylus) pollen season (if present day is outside the season: length of current season)
'Number of days since the start of hazel (corylus) pollen season (if present day is outside the season: length of current season)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62104 ;
	}

#paramId: 503652
#Emission tuning factor for birch (betula) pollen
'Emission tuning factor for birch (betula) pollen' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62101 ;
	}

#paramId: 503653
#Emission tuning factor for alder (alnus) pollen
'Emission tuning factor for alder (alnus) pollen' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62100 ;
	}

#paramId: 503654
#Emission tuning factor for grasses (poaceae) pollen
'Emission tuning factor for grasses (poaceae) pollen' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62300 ;
	}

#paramId: 503655
#Emission tuning factor for ragweed (ambrosia) pollen
'Emission tuning factor for ragweed (ambrosia) pollen' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62200 ;
	}

#paramId: 503656
#Emission tuning factor for hazel (corylus) pollen
'Emission tuning factor for hazel (corylus) pollen' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62104 ;
	}

#paramId: 503658
#Height of new snow (without settling)
'Height of new snow (without settling)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 207 ;
	}

#paramId: 503659
#Volumetric ice content of snow layer - multi level
'Volumetric ice content of snow layer - multi level' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	 constituentType = 63000 ;
	}

#paramId: 503660
#Volumetric water content of snow layer - multi level
'Volumetric water content of snow layer - multi level' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	 constituentType = 62002 ;
	}

#paramId: 503661
#Volumetric air content of snow layer - multi level
'Volumetric air content of snow layer - multi level' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	 constituentType = 63001 ;
	}

#paramId: 503663
#Number of snow layer - multi level
'Number of snow layer - multi level' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 206 ;
	}

#paramId: 503665
#Building area fraction (proportion: 0=no building, 1=whole urban area)
'Building area fraction (proportion: 0=no building, 1=whole urban area)' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 0 ;
	}

#paramId: 503666
#Street canyon aspect (height - width) ratio
'Street canyon aspect (height - width) ratio' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 1 ;
	}

#paramId: 503667
#Height of building
'Height of building' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 2 ;
	}

#paramId: 503668
#Urban material thermal albedo
'Urban material thermal albedo' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 3 ;
	}

#paramId: 503669
#Urban material shortwave (solar) albedo
'Urban material shortwave (solar) albedo' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 4 ;
	}

#paramId: 503670
#Volumetric heat capacity of urban material (capacity x density)
'Volumetric heat capacity of urban material (capacity x density)' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 5 ;
	}

#paramId: 503671
#Heat conductivity of urban material
'Heat conductivity of urban material' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 6 ;
	}

#paramId: 503704
#Potential flight distance PFD (gliding)
'Potential flight distance PFD (gliding)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 240 ;
	}

#paramId: 503705
#Lifting ratio VST (gliding)
'Lifting ratio VST (gliding)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 241 ;
	}

#paramId: 503710
#U-component of mean wind (vertical mean over specified layer)
'U-component of mean wind (vertical mean over specified layer)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 212 ;
	}

#paramId: 503711
#V-component of mean wind (vertical mean over specified layer)
'V-component of mean wind (vertical mean over specified layer)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 213 ;
	}

#paramId: 503712
#Extreme weather index of snow amount, grid-scale plus convective
'Extreme weather index of snow amount, grid-scale plus convective' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 240 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503713
#Extreme weather index of maximum Wind 10m
'Extreme weather index of maximum Wind 10m' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 214 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503714
#Extreme weather index of total precipitation (Accumulation)
'Extreme weather index of total precipitation (Accumulation)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 239 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503715
#Cloud cover for use in radiative transfer (modified where large hydrometeors are present)
'Cloud cover for use in radiative transfer (modified where large hydrometeors are present)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 215 ;
	}

#paramId: 503716
#Snow temperature at node (i.e. at snow layer interface or boundary) - multi level
'Snow temperature at node (i.e. at snow layer interface or boundary) - multi level' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 208 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503717
#Volumetric ice content of snow layer (for use in tile approach) - multi level
'Volumetric ice content of snow layer (for use in tile approach) - multi level' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 209 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503718
#Volumetric water content of snow layer (for use in tile approach) - multi level
'Volumetric water content of snow layer (for use in tile approach) - multi level' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503719
#Volumetric air content of snow layer (for use in tile approach) - multi level
'Volumetric air content of snow layer (for use in tile approach) - multi level' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 211 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503720
#Probability for freezing precipitation/wet snow
'Probability for freezing precipitation/wet snow' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 242 ;
	}

#paramId: 503721
#Probability for freezing precipitation with wind
'Probability for freezing precipitation with wind' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 243 ;
	}

#paramId: 503732
#NowCastMIX-AutoWARN (Warnpolygone: Gewitter, Starkregen, Schnee, gefrierender Regen)
'NowCastMIX-AutoWARN (Warnpolygone: Gewitter, Starkregen, Schnee, gefrierender Regen)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 220 ;
	}

#paramId: 503733
#NowCastMIX-AutoWARN (Schneepolygon-Attribute)
'NowCastMIX-AutoWARN (Schneepolygon-Attribute)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 221 ;
	}

#paramId: 503734
#NowCastMIX-Aviation (Konvektiver Status, Radolan-Gebiet)
'NowCastMIX-Aviation (Konvektiver Status, Radolan-Gebiet)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 222 ;
	}

#paramId: 503735
#NowCastMIX-Aviation (Konvektiver Status, EuCOM-Gebiet)
'NowCastMIX-Aviation (Konvektiver Status, EuCOM-Gebiet)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 223 ;
	}

#paramId: 503736
#NowCastMIX-Winterwetter (Schnee, gefrierender Regen, Radolan-Gebiet)
'NowCastMIX-Winterwetter (Schnee, gefrierender Regen, Radolan-Gebiet)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 224 ;
	}

#paramId: 503740
#NowCastMIX-AutoWARN (Gewitter-Warnkeulen mit variablen L??ngen)
'NowCastMIX-AutoWARN (Gewitter-Warnkeulen mit variablen L??ngen)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 225 ;
	}

#paramId: 503741
#NowCastMIX-Aviation (Starkregen, Radolan-Gebiet)
'NowCastMIX-Aviation (Starkregen, Radolan-Gebiet)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 226 ;
	}

#paramId: 503742
#NowCastMIX-AutoWARN (Schneefallgrenze)
'NowCastMIX-AutoWARN (Schneefallgrenze)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 227 ;
	}

#paramId: 503745
#Net short wave radiation flux at surface on horizontal plane including orographic shading
'Net short wave radiation flux at surface on horizontal plane including orographic shading' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503746
#Net short wave radiation flux at surface on tangent plane to terrain including orographic shading
'Net short wave radiation flux at surface on tangent plane to terrain including orographic shading' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503747
#Upward diffusive short wave radiation flux at surface on horizontal plane including orographic shading
'Upward diffusive short wave radiation flux at surface on horizontal plane including orographic shading' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503748
#Upward diffusive short wave radiation flux at surface on tangent plane to terrain including orographic shading
'Upward diffusive short wave radiation flux at surface on tangent plane to terrain including orographic shading' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503749
#Photosynthetically active radiation at surface on tangent plane to terrain including orographic shading
'Photosynthetically active radiation at surface on tangent plane to terrain including orographic shading' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503750
#Net short wave radiation flux at surface on horizontal plane including orographic shading - time average
'Net short wave radiation flux at surface on horizontal plane including orographic shading - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503751
#Net short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'Net short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503752
#Downward direct short wave radiation flux at surface on horizontal plane including orographic shading - time average
'Downward direct short wave radiation flux at surface on horizontal plane including orographic shading - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503753
#Downward direct short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'Downward direct short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503754
#Downward short wave radiation flux at surface on horizontal plane including orographic shading - time average
'Downward short wave radiation flux at surface on horizontal plane including orographic shading - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503755
#Downward short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'Downward short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503756
#Upward diffusive short wave radiation flux at surface on horizontal plane including orographic shading - time average
'Upward diffusive short wave radiation flux at surface on horizontal plane including orographic shading - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503757
#Upward diffusive short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'Upward diffusive short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503758
#Photosynthetically active radiation at surface on tangent plane to terrain including orographic shading - time average
'Photosynthetically active radiation at surface on tangent plane to terrain including orographic shading - time average' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503761
#Snow depth over sea ice (total depth)
'Snow depth over sea ice (total depth)' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	}

#paramId: 503762
#Stretching factor of rescaled height coordinate zstar - ocean modelling
'Stretching factor of rescaled height coordinate zstar - ocean modelling' = {
	 discipline = 10 ;
	 parameterCategory = 192 ;
	 parameterNumber = 20 ;
	}

#paramId: 503765
#Temperature in lowest model layer - time-filtered assimilation increment, daytime weighting
'Temperature in lowest model layer - time-filtered assimilation increment, daytime weighting' = {
	 discipline = 0 ;
	 parameterCategory = 210 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503766
#Relative Humidity in lowest model layer - time-filtered assimilation increment, daytime weighting
'Relative Humidity in lowest model layer - time-filtered assimilation increment, daytime weighting' = {
	 discipline = 0 ;
	 parameterCategory = 210 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503767
#NowCastMIX-Aviation-XL (Konvektiver Status, EuCOM-XL-Gebiet)
'NowCastMIX-Aviation-XL (Konvektiver Status, EuCOM-XL-Gebiet)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 228 ;
	}

#paramId: 503768
#Mean mass diameter of cloud droplets (mean mass with respect to particle size distribution)
'Mean mass diameter of cloud droplets (mean mass with respect to particle size distribution)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 241 ;
	}

#paramId: 503769
#Mean mass diameter of rain (mean mass with respect to particle size distribution)
'Mean mass diameter of rain (mean mass with respect to particle size distribution)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 242 ;
	}

#paramId: 503770
#Mean mass diameter of cloud ice (mean mass with respect to particle size distribution)
'Mean mass diameter of cloud ice (mean mass with respect to particle size distribution)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 243 ;
	}

#paramId: 503771
#Mean mass diameter of snow (mean mass with respect to particle size distribution)
'Mean mass diameter of snow (mean mass with respect to particle size distribution)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 244 ;
	}

#paramId: 503772
#Mean mass diameter of graupel (mean mass with respect to particle size distribution)
'Mean mass diameter of graupel (mean mass with respect to particle size distribution)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 245 ;
	}

#paramId: 503773
#Cold-skin temperature deviation from analyzed sea-surface temperature (SST) at sea surface
'Cold-skin temperature deviation from analyzed sea-surface temperature (SST) at sea surface' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 160 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 503774
#Warm-layer temperature deviation from analyzed sea-surface temperature (SST) at sea surface
'Warm-layer temperature deviation from analyzed sea-surface temperature (SST) at sea surface' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 160 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 503775
#2m Temperature - time-filtered such that the diurnal cycle is partly smoothed out
'2m Temperature - time-filtered such that the diurnal cycle is partly smoothed out' = {
	 discipline = 0 ;
	 parameterCategory = 210 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503776
#Saturated hydraulic conductivity of soil
'Saturated hydraulic conductivity of soil' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 212 ;
	}

#paramId: 503777
#Water retention curve of soil - inverse air entry suction (Mualem-Van-Genuchten alpha parameter)
'Water retention curve of soil - inverse air entry suction (Mualem-Van-Genuchten alpha parameter)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 213 ;
	}

#paramId: 503778
#Water retention curve of soil - pore-size distribution (Mualem-Van-Genuchten n parameter)
'Water retention curve of soil - pore-size distribution (Mualem-Van-Genuchten n parameter)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 214 ;
	}

#paramId: 503779
#Volumetric air dryness point of soil
'Volumetric air dryness point of soil' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 215 ;
	}

#paramId: 503780
#Volumetric field capacity of soil
'Volumetric field capacity of soil' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 216 ;
	}

#paramId: 503783
#Sea water turbulent kinetic energy
'Sea water turbulent kinetic energy' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}

