# Automatically generated by ./create_defs.grib2.chemsplit.pl, do not edit
#Total precipitation of at least 1 mm
'131060' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 5 mm
'131061' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 5 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 10 mm
'131062' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 10 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 20 mm
'131063' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 20 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 40 mm
'131082' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 40 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 60 mm
'131083' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 60 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 80 mm
'131084' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 80 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 100 mm
'131085' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 100 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 150 mm
'131086' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 150 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 200 mm
'131087' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 200 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 300 mm
'131088' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 3 ;
	 scaleFactorOfLowerLimit = -2 ;
	 probabilityType = 3 ;
	}
#Stream function
'1' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}
#Velocity potential
'2' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}
#Potential temperature
'3' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Wind speed
'10' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}
#Surface photosynthetically active radiation, clear sky
'20' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Unbalanced component of temperature
'21' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}
#Unbalanced component of logarithm of surface pressure
'22' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 31 ;
	}
#Unbalanced component of divergence
'23' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 45 ;
	}
#Lake cover
'26' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#Low vegetation cover
'27' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	}
#High vegetation cover
'28' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	}
#Type of low vegetation
'29' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	}
#Type of high vegetation
'30' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	}
#Sea ice area fraction
'31' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Snow density
'33' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	}
#Sea surface temperature
'34' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Soil type
'43' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}
#Surface direct normal short-wave (solar) radiation
'47' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated magnitude of turbulent surface stress
'48' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Large-scale precipitation fraction
'50' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Montgomery potential
'53' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}
#Pressure
'54' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}
#Surface downward UV radiation
'57' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Photosynthetically active radiation at the surface
'58' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective available potential energy
'59' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Potential vorticity
'60' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	}
#Leaf area index, low vegetation
'66' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	}
#Leaf area index, high vegetation
'67' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	}
#Standard deviation of filtered subgrid orography (climatological)
'74' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 38 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Specific rain water content
'75' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	}
#Specific snow water content
'76' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	}
#Eta-coordinate vertical velocity
'77' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	}
#Total column cloud liquid water
'78' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column cloud ice water
'79' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Surface emissivity
'124' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Geopotential
'129' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}
#Temperature
'130' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#U component of wind
'131' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#V component of wind
'132' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}
#Specific humidity
'133' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Surface pressure
'134' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Vertical velocity
'135' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}
#Total column water
'136' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated water vapour
'137' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Vorticity (relative)
'138' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}
#Time-integrated boundary layer dissipation
'145' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated surface sensible heat net flux
'146' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated surface latent heat net flux
'147' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Charnock
'148' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 76 ;
	}
#Surface net radiation (SW and LW)
'149' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Top net radiation (SW and LW)
'150' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Mean sea level pressure
'151' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	}
#Divergence
'155' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	}
#Geopotential height
'156' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}
#Relative humidity
'157' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Boundary layer height
'159' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	}
#Standard deviation of sub-gridscale orography
'160' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	}
#Anisotropy of sub-gridscale orography
'161' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 24 ;
	}
#Angle of sub-gridscale orography
'162' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	}
#Slope of sub-gridscale orography
'163' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	}
#10 metre U wind component
'165' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#10 metre V wind component
'166' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#2 metre temperature
'167' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#2 metre dewpoint temperature
'168' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Surface short-wave (solar) radiation downwards
'169' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Land-sea mask
'172' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface roughness (climatological)
'173' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Surface long-wave (thermal) radiation downwards
'175' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net short-wave (solar) radiation
'176' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net long-wave (thermal) radiation
'177' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Top net short-wave (solar) radiation
'178' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Top net long-wave (thermal) radiation
'179' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated eastward turbulent surface stress
'180' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated northward turbulent surface stress
'181' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Sunshine duration
'189' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Brightness temperature
'194' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 4 ;
	}
#Eastward gravity wave surface stress
'195' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Northward gravity wave surface stress
'196' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Gravity wave dissipation
'197' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Ozone mass mixing ratio
'203' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	}
#10 metre wind speed
'207' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Top net short-wave (solar) radiation, clear sky
'208' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Top net long-wave (thermal) radiation, clear sky
'209' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net short-wave (solar) radiation, clear sky
'210' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net long-wave (thermal) radiation, clear sky
'211' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#TOA incident short-wave (solar) radiation
'212' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Vertically integrated moisture divergence
'213' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Instantaneous eastward turbulent surface stress
'229' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous northward turbulent surface stress
'230' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous surface sensible heat net flux
'231' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous moisture flux
'232' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Logarithm of surface roughness length for heat (climatological)
'234' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Skin temperature
'235' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Temperature of snow layer
'238' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	}
#Forecast surface roughness
'244' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Forecast logarithm of surface roughness for heat
'245' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Specific cloud liquid water content
'246' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	}
#Specific cloud ice water content
'247' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	}
#Fraction of cloud cover
'248' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	}
#Large-scale precipitation
'3062' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snow depth
'3066' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Low cloud cover
'3073' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	}
#Medium cloud cover
'3074' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	}
#High cloud cover
'3075' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	}
#Total precipitation of at least 25 mm
'131098' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 25 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 50 mm
'131099' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 50 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre wind gust of at least 10 m/s
'131100' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfLowerLimit = 10 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre convective gust of at least 25 m/s
'131256' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfLowerLimit = 25 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Probability of temperature standardized anomaly greater than 1 standard deviation
'133093' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Probability of temperature standardized anomaly greater than 1.5 standard deviation
'133094' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = 15 ;
	 scaleFactorOfLowerLimit = 1 ;
	 probabilityType = 3 ;
	}
#Probability of temperature standardized anomaly greater than 2 standard deviation
'133095' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = 2 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Probability of temperature standardized anomaly less than -1 standard deviation
'133096' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = -1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 0 ;
	}
#Probability of temperature standardized anomaly less than -1.5 standard deviation
'133097' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = -15 ;
	 scaleFactorOfLowerLimit = 1 ;
	 probabilityType = 0 ;
	}
#Probability of temperature standardized anomaly less than -2 standard deviation
'133098' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = -2 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 0 ;
	}
#Wave induced mean sea level correction
'140098' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 87 ;
	}
#Ratio of wave angular and frequency width
'140099' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 80 ;
	}
#Number of events in freak waves statistics
'140100' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 89 ;
	}
#U-component of atmospheric surface momentum flux
'140101' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 103 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#V-component of atmospheric surface momentum flux
'140102' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 104 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#U-component of surface momentum flux into ocean
'140103' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 90 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#V-component of surface momentum flux into ocean
'140104' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 91 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Wave turbulent energy flux into ocean
'140105' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 92 ;
	}
#Wave directional width of first swell partition
'140106' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	}
#Wave frequency width of first swell partition
'140107' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	}
#Wave directional width of second swell partition
'140108' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	}
#Wave frequency width of second swell partition
'140109' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	}
#Wave directional width of third swell partition
'140110' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	}
#Wave frequency width of third swell partition
'140111' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	}
#Wave energy flux magnitude
'140112' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 78 ;
	}
#Wave energy flux mean direction
'140113' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 79 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds
'140114' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 12 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds
'140115' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 12 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 14 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds
'140116' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 14 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 17 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds
'140117' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 17 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 21 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds
'140118' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 21 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 25 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds
'140119' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 25 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 30 ;
	}
#Significant wave height of all waves with period larger than 10s
'140120' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 3 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	}
#Significant wave height of first swell partition
'140121' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	}
#Mean wave direction of first swell partition
'140122' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	}
#Mean wave period of first swell partition
'140123' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	}
#Significant wave height of second swell partition
'140124' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	}
#Mean wave direction of second swell partition
'140125' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	}
#Mean wave period of second swell partition
'140126' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	}
#Significant wave height of third swell partition
'140127' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	}
#Mean wave direction of third swell partition
'140128' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	}
#Mean wave period of third swell partition
'140129' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	}
#Time domain maximum individual crest height
'140131' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 94 ;
	}
#Time domain maximum individual wave height
'140132' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 95 ;
	}
#Space time maximum individual crest height
'140133' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 96 ;
	}
#Space time maximum individual wave height
'140134' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 97 ;
	}
#Peak wave period of wind waves
'140135' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	}
#Peak wave period of total swell
'140136' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	}
#Peak wave period of first swell partition
'140137' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 65 ;
	}
#Peak wave period of second swell partition
'140138' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 66 ;
	}
#Peak wave period of third swell partition
'140139' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 67 ;
	}
#Peak wave direction (total)
'140140' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	}
#Peak wave direction of wind waves
'140141' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 71 ;
	}
#Peak wave direction of total swell
'140142' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 72 ;
	}
#Peak wave direction of first swell partition
'140143' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 68 ;
	}
#Peak wave direction of second swell partition
'140144' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 69 ;
	}
#Peak wave direction of third swell partition
'140145' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 70 ;
	}
#Whitecap fraction
'140146' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 73 ;
	}
#Benjamin-Feir index 2D
'140147' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 99 ;
	}
#Crest-trough correlation
'140148' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 100 ;
	}
#X component of the wave radiative stress to sea ice
'140149' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 101 ;
	}
#Y component of the wave radiative stress to sea ice
'140150' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 102 ;
	}
#Wave Spectral Skewness
'140207' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 77 ;
	}
#Free convective velocity over the oceans
'140208' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 81 ;
	}
#Air density over the oceans
'140209' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 82 ;
	}
#Normalized energy flux into waves
'140211' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 83 ;
	}
#Normalized energy flux into ocean
'140212' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 85 ;
	}
#Normalized stress into ocean
'140214' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 84 ;
	}
#Time-mean wave induced mean sea level correction
'141098' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 87 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ratio of wave angular and frequency width
'141099' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 80 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean number of events in freak waves statistics
'141100' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 89 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U-component of atmospheric surface momentum flux
'141101' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 103 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V-component of atmospheric surface momentum flux
'141102' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 104 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U-component of surface momentum flux into ocean
'141103' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 90 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V-component of surface momentum flux into ocean
'141104' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 91 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave turbulent energy flux into ocean
'141105' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 92 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave directional width of first swell partition
'141106' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave frequency width of first swell partition
'141107' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave directional width of second swell partition
'141108' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave frequency width of second swell partition
'141109' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave directional width of third swell partition
'141110' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave frequency width of third swell partition
'141111' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave energy flux magnitude
'141112' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 78 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave energy flux mean direction
'141113' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant wave height of first swell partition
'141121' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave direction of first swell partition
'141122' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period of first swell partition
'141123' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant wave height of second swell partition
'141124' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave direction of second swell partition
'141125' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period of second swell partition
'141126' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant wave height of third swell partition
'141127' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave direction of third swell partition
'141128' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period of third swell partition
'141129' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean time domain maximum individual crest height
'141131' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 94 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean time domain maximum individual wave height
'141132' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 95 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean space time maximum individual crest height
'141133' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 96 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean space time maximum individual wave height
'141134' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 97 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period of wind waves
'141135' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period of total swell
'141136' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period of first swell partition
'141137' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period of second swell partition
'141138' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period of third swell partition
'141139' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 67 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction (total)
'141140' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction of wind waves
'141141' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction of total swell
'141142' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction of first swell partition
'141143' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 68 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction of second swell partition
'141144' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction of third swell partition
'141145' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean whitecap fraction
'141146' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Benjamin-Feir index 2D
'141147' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 99 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean crest-trough correlation
'141148' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 100 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean X component of the wave radiative stress to sea ice
'141149' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 101 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Y component of the wave radiative stress to sea ice
'141150' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave Spectral Skewness
'141207' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean free convective velocity over the oceans
'141208' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean air density over the oceans
'141209' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean normalized energy flux into waves
'141211' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean normalized energy flux into ocean
'141212' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean normalized stress into ocean
'141214' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U-component surface stokes drift
'141215' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V-component surface stokes drift
'141216' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean period corresponding to maximum individual wave height
'141217' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean envelop-maximum individual wave height
'141218' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period based on first moment
'141220' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean zero-crossing wave period
'141221' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave spectral directional width
'141222' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period based on first moment for wind waves
'141223' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period based on second moment for wind waves
'141224' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave spectral directional width for wind waves
'141225' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period based on first moment for swell
'141226' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period based on second moment for swell
'141227' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave spectral directional width for swell
'141228' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant height of combined wind waves and swell
'141229' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave direction
'141230' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period
'141231' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period
'141232' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean coefficient of drag with waves
'141233' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant height of wind waves
'141234' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean direction of wind waves
'141235' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean period of wind waves
'141236' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant height of total swell
'141237' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean direction of total swell
'141238' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean period of total swell
'141239' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean square slope of waves
'141244' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre wind speed
'141245' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre wind direction
'141249' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave spectral kurtosis
'141252' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean benjamin-Feir index
'141253' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave spectral peakedness
'141254' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 98 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum wave induced mean sea level correction
'143098' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 87 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ratio of wave angular and frequency width
'143099' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 80 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum number of events in freak waves statistics
'143100' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 89 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum U-component of atmospheric surface momentum flux
'143101' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 103 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum V-component of atmospheric surface momentum flux
'143102' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 104 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum U-component of surface momentum flux into ocean
'143103' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 90 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum V-component of surface momentum flux into ocean
'143104' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 91 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave turbulent energy flux into ocean
'143105' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 92 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave directional width of first swell partition
'143106' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave frequency width of first swell partition
'143107' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave directional width of second swell partition
'143108' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave frequency width of second swell partition
'143109' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave directional width of third swell partition
'143110' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave frequency width of third swell partition
'143111' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave energy flux magnitude
'143112' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 78 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave energy flux mean direction
'143113' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant wave height of first swell partition
'143121' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave direction of first swell partition
'143122' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period of first swell partition
'143123' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant wave height of second swell partition
'143124' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave direction of second swell partition
'143125' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period of second swell partition
'143126' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant wave height of third swell partition
'143127' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave direction of third swell partition
'143128' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period of third swell partition
'143129' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum time domain maximum individual crest height
'143131' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 94 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum time domain maximum individual wave height
'143132' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 95 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum space time maximum individual crest height
'143133' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 96 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum space time maximum individual wave height
'143134' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 97 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period of wind waves
'143135' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period of total swell
'143136' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period of first swell partition
'143137' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period of second swell partition
'143138' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period of third swell partition
'143139' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 67 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction (total)
'143140' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction of wind waves
'143141' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction of total swell
'143142' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction of first swell partition
'143143' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 68 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction of second swell partition
'143144' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction of third swell partition
'143145' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum whitecap fraction
'143146' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum Benjamin-Feir index 2D
'143147' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 99 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum crest-trough correlation
'143148' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 100 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum X component of the wave radiative stress to sea ice
'143149' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 101 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum Y component of the wave radiative stress to sea ice
'143150' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave Spectral Skewness
'143207' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum free convective velocity over the oceans
'143208' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum air density over the oceans
'143209' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum normalized energy flux into waves
'143211' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum normalized energy flux into ocean
'143212' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum normalized stress into ocean
'143214' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum U-component surface stokes drift
'143215' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum V-component surface stokes drift
'143216' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum period corresponding to maximum individual wave height
'143217' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum envelop-maximum individual wave height
'143218' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period based on first moment
'143220' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean zero-crossing wave period
'143221' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave spectral directional width
'143222' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period based on first moment for wind waves
'143223' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period based on second moment for wind waves
'143224' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave spectral directional width for wind waves
'143225' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period based on first moment for swell
'143226' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period based on second moment for swell
'143227' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave spectral directional width for swell
'143228' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant height of combined wind waves and swell
'143229' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave direction
'143230' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period
'143231' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period
'143232' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum coefficient of drag with waves
'143233' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant height of wind waves
'143234' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean direction of wind waves
'143235' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean period of wind waves
'143236' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant height of total swell
'143237' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean direction of total swell
'143238' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean period of total swell
'143239' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean square slope of waves
'143244' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre wind speed
'143245' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre wind direction
'143249' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave spectral kurtosis
'143252' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum benjamin-Feir index
'143253' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave spectral peakedness
'143254' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 98 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum wave induced mean sea level correction
'144098' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 87 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ratio of wave angular and frequency width
'144099' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 80 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum number of events in freak waves statistics
'144100' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 89 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum U-component of atmospheric surface momentum flux
'144101' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 103 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum V-component of atmospheric surface momentum flux
'144102' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 104 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum U-component of surface momentum flux into ocean
'144103' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 90 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum V-component of surface momentum flux into ocean
'144104' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 91 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave turbulent energy flux into ocean
'144105' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 92 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave directional width of first swell partition
'144106' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave frequency width of first swell partition
'144107' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave directional width of second swell partition
'144108' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave frequency width of second swell partition
'144109' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave directional width of third swell partition
'144110' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave frequency width of third swell partition
'144111' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave energy flux magnitude
'144112' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 78 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave energy flux mean direction
'144113' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant wave height of first swell partition
'144121' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave direction of first swell partition
'144122' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period of first swell partition
'144123' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant wave height of second swell partition
'144124' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave direction of second swell partition
'144125' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period of second swell partition
'144126' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant wave height of third swell partition
'144127' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave direction of third swell partition
'144128' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period of third swell partition
'144129' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum time domain maximum individual crest height
'144131' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 94 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum time domain maximum individual wave height
'144132' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 95 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum space time maximum individual crest height
'144133' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 96 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum space time maximum individual wave height
'144134' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 97 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period of wind waves
'144135' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period of total swell
'144136' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period of first swell partition
'144137' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period of second swell partition
'144138' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period of third swell partition
'144139' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 67 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction (total)
'144140' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction of wind waves
'144141' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction of total swell
'144142' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction of first swell partition
'144143' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 68 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction of second swell partition
'144144' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction of third swell partition
'144145' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum whitecap fraction
'144146' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum Benjamin-Feir index 2D
'144147' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 99 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum crest-trough correlation
'144148' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 100 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum X component of the wave radiative stress to sea ice
'144149' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 101 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum Y component of the wave radiative stress to sea ice
'144150' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave Spectral Skewness
'144207' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum free convective velocity over the oceans
'144208' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum air density over the oceans
'144209' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum normalized energy flux into waves
'144211' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum normalized energy flux into ocean
'144212' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum normalized stress into ocean
'144214' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum U-component surface stokes drift
'144215' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum V-component surface stokes drift
'144216' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum period corresponding to maximum individual wave height
'144217' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum envelop-maximum individual wave height
'144218' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period based on first moment
'144220' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean zero-crossing wave period
'144221' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave spectral directional width
'144222' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period based on first moment for wind waves
'144223' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period based on second moment for wind waves
'144224' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave spectral directional width for wind waves
'144225' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period based on first moment for swell
'144226' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period based on second moment for swell
'144227' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave spectral directional width for swell
'144228' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant height of combined wind waves and swell
'144229' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave direction
'144230' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period
'144231' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period
'144232' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum coefficient of drag with waves
'144233' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant height of wind waves
'144234' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean direction of wind waves
'144235' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean period of wind waves
'144236' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant height of total swell
'144237' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean direction of total swell
'144238' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean period of total swell
'144239' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean square slope of waves
'144244' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre wind speed
'144245' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre wind direction
'144249' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave spectral kurtosis
'144252' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum benjamin-Feir index
'144253' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave spectral peakedness
'144254' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 98 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation wave induced mean sea level correction
'145098' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 87 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ratio of wave angular and frequency width
'145099' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 80 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation number of events in freak waves statistics
'145100' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 89 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation U-component of atmospheric surface momentum flux
'145101' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 103 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation V-component of atmospheric surface momentum flux
'145102' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 104 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation U-component of surface momentum flux into ocean
'145103' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 90 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation V-component of surface momentum flux into ocean
'145104' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 91 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave turbulent energy flux into ocean
'145105' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 92 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave directional width of first swell partition
'145106' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave frequency width of first swell partition
'145107' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave directional width of second swell partition
'145108' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave frequency width of second swell partition
'145109' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave directional width of third swell partition
'145110' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave frequency width of third swell partition
'145111' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave energy flux magnitude
'145112' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 78 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave energy flux mean direction
'145113' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant wave height of first swell partition
'145121' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave direction of first swell partition
'145122' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period of first swell partition
'145123' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant wave height of second swell partition
'145124' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave direction of second swell partition
'145125' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period of second swell partition
'145126' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant wave height of third swell partition
'145127' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave direction of third swell partition
'145128' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period of third swell partition
'145129' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation time domain maximum individual crest height
'145131' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 94 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation time domain maximum individual wave height
'145132' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 95 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation space time maximum individual crest height
'145133' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 96 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation space time maximum individual wave height
'145134' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 97 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period of wind waves
'145135' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period of total swell
'145136' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period of first swell partition
'145137' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period of second swell partition
'145138' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period of third swell partition
'145139' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 67 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction (total)
'145140' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction of wind waves
'145141' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction of total swell
'145142' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction of first swell partition
'145143' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 68 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction of second swell partition
'145144' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction of third swell partition
'145145' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation whitecap fraction
'145146' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation Benjamin-Feir index 2D
'145147' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 99 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation crest-trough correlation
'145148' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 100 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation X component of the wave radiative stress to sea ice
'145149' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 101 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation Y component of the wave radiative stress to sea ice
'145150' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave Spectral Skewness
'145207' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation free convective velocity over the oceans
'145208' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation air density over the oceans
'145209' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation normalized energy flux into waves
'145211' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation normalized energy flux into ocean
'145212' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation normalized stress into ocean
'145214' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation U-component surface stokes drift
'145215' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation V-component surface stokes drift
'145216' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation period corresponding to maximum individual wave height
'145217' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation envelop-maximum individual wave height
'145218' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period based on first moment
'145220' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean zero-crossing wave period
'145221' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave spectral directional width
'145222' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period based on first moment for wind waves
'145223' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period based on second moment for wind waves
'145224' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave spectral directional width for wind waves
'145225' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period based on first moment for swell
'145226' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period based on second moment for swell
'145227' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave spectral directional width for swell
'145228' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant height of combined wind waves and swell
'145229' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave direction
'145230' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period
'145231' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period
'145232' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation coefficient of drag with waves
'145233' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant height of wind waves
'145234' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean direction of wind waves
'145235' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean period of wind waves
'145236' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant height of total swell
'145237' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean direction of total swell
'145238' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean period of total swell
'145239' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean square slope of waves
'145244' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre wind speed
'145245' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre wind direction
'145249' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave spectral kurtosis
'145252' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation benjamin-Feir index
'145253' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave spectral peakedness
'145254' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 98 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Mean sea water temperature in the upper 300 m
'151127' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Total column vertically-integrated divergence of water geopotential flux
'162031' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward enthalpy flux
'162032' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward enthalpy flux
'162033' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of enthalpy flux
'162034' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of water enthalpy flux
'162035' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of water vapour flux
'162036' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of cloud liquid water flux
'162037' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of cloud ice water flux
'162038' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of rain flux
'162039' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of snow flux
'162040' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward cloud liquid water flux
'162041' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward cloud liquid water flux
'162042' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward cloud ice water flux
'162043' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward cloud ice water flux
'162044' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward rain flux
'162046' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward rain flux
'162047' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward snow flux
'162048' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward snow flux
'162049' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated net source of ozone
'162050' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	}
#Total column vertically-integrated water enthalpy
'162093' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Temperature tendency due to short-wave radiation
'162150' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}
#Temperature tendency due to long-wave radiation
'162151' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}
#Temperature tendency due to short-wave radiation, clear sky
'162152' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}
#Temperature tendency due to long-wave radiation, clear sky
'162153' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}
#Updraught mass flux
'162154' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	}
#Downdraught mass flux
'162155' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	}
#Updraught detrainment rate
'162156' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	}
#Downdraught detrainment rate
'162157' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	}
#Total precipitation flux
'162158' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	}
#Turbulent diffusion coefficient for heat
'162159' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}
#Temperature tendency due to parametrisations
'162160' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	}
#Specific humidity tendency due to parametrisations
'162161' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	}
#Eastward wind tendency due to parametrisations
'162162' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	}
#Northward wind tendency due to parametrisations
'162163' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	}
#2 metre specific humidity
'174096' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Injection height (from IS4FIRES)
'210060' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	}
#Mean height of maximum injection
'210119' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 39 ;
	}
#Plume top height above surface
'210120' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 42 ;
	}
#UV visible albedo for diffuse radiation (climatological)
'210198' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 55 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation (climatological)
'210199' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, geometric component (climatological)
'210200' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, isotropic component (climatological)
'210201' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, volumetric component (climatological)
'210202' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 59 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Plume bottom height above surface
'210242' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 41 ;
	}
#Near IR albedo for diffuse radiation (climatological)
'210260' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 9 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation (climatological)
'210261' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 10 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, geometric component (climatological)
'210262' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, isotropic component (climatological)
'210263' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 12 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, volumetric component (climatological)
'210264' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Random pattern 1 for SPP scheme
'213101' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 1 ;
	}
#Random pattern 2 for SPP scheme
'213102' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 2 ;
	}
#Random pattern 3 for SPP scheme
'213103' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 3 ;
	}
#Random pattern 4 for SPP scheme
'213104' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 4 ;
	}
#Random pattern 5 for SPP scheme
'213105' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 5 ;
	}
#Random pattern 6 for SPP scheme
'213106' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 6 ;
	}
#Random pattern 7 for SPP scheme
'213107' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 7 ;
	}
#Random pattern 8 for SPP scheme
'213108' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 8 ;
	}
#Random pattern 9 for SPP scheme
'213109' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 9 ;
	}
#Random pattern 10 for SPP scheme
'213110' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 10 ;
	}
#Random pattern 11 for SPP scheme
'213111' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 11 ;
	}
#Random pattern 12 for SPP scheme
'213112' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 12 ;
	}
#Random pattern 13 for SPP scheme
'213113' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 13 ;
	}
#Random pattern 14 for SPP scheme
'213114' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 14 ;
	}
#Random pattern 15 for SPP scheme
'213115' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 15 ;
	}
#Random pattern 16 for SPP scheme
'213116' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 16 ;
	}
#Random pattern 17 for SPP scheme
'213117' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 17 ;
	}
#Random pattern 18 for SPP scheme
'213118' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 18 ;
	}
#Random pattern 19 for SPP scheme
'213119' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 19 ;
	}
#Random pattern 20 for SPP scheme
'213120' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 20 ;
	}
#Random pattern 21 for SPP scheme
'213121' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 21 ;
	}
#Random pattern 22 for SPP scheme
'213122' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 22 ;
	}
#Random pattern 23 for SPP scheme
'213123' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 23 ;
	}
#Random pattern 24 for SPP scheme
'213124' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 24 ;
	}
#Random pattern 25 for SPP scheme
'213125' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 25 ;
	}
#Random pattern 26 for SPP scheme
'213126' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 26 ;
	}
#Random pattern 27 for SPP scheme
'213127' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 27 ;
	}
#Random pattern 28 for SPP scheme
'213128' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 28 ;
	}
#Random pattern 29 for SPP scheme
'213129' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 29 ;
	}
#Random pattern 30 for SPP scheme
'213130' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 30 ;
	}
#Random pattern 31 for SPP scheme
'213131' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 31 ;
	}
#Random pattern 32 for SPP scheme
'213132' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 32 ;
	}
#Random pattern 33 for SPP scheme
'213133' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 33 ;
	}
#Random pattern 34 for SPP scheme
'213134' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 34 ;
	}
#Random pattern 35 for SPP scheme
'213135' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 35 ;
	}
#Random pattern 36 for SPP scheme
'213136' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 36 ;
	}
#Random pattern 37 for SPP scheme
'213137' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 37 ;
	}
#Random pattern 38 for SPP scheme
'213138' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 38 ;
	}
#Random pattern 39 for SPP scheme
'213139' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 39 ;
	}
#Random pattern 40 for SPP scheme
'213140' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 40 ;
	}
#Random pattern 41 for SPP scheme
'213141' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 41 ;
	}
#Random pattern 42 for SPP scheme
'213142' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 42 ;
	}
#Random pattern 43 for SPP scheme
'213143' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 43 ;
	}
#Random pattern 44 for SPP scheme
'213144' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 44 ;
	}
#Random pattern 45 for SPP scheme
'213145' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 45 ;
	}
#Random pattern 46 for SPP scheme
'213146' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 46 ;
	}
#Random pattern 47 for SPP scheme
'213147' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 47 ;
	}
#Random pattern 48 for SPP scheme
'213148' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 48 ;
	}
#Random pattern 49 for SPP scheme
'213149' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 49 ;
	}
#Random pattern 50 for SPP scheme
'213150' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 50 ;
	}
#Random pattern 51 for SPP scheme
'213151' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 51 ;
	}
#Random pattern 52 for SPP scheme
'213152' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 52 ;
	}
#Random pattern 53 for SPP scheme
'213153' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 53 ;
	}
#Random pattern 54 for SPP scheme
'213154' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 54 ;
	}
#Random pattern 55 for SPP scheme
'213155' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 55 ;
	}
#Random pattern 56 for SPP scheme
'213156' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 56 ;
	}
#Random pattern 57 for SPP scheme
'213157' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 57 ;
	}
#Random pattern 58 for SPP scheme
'213158' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 58 ;
	}
#Random pattern 59 for SPP scheme
'213159' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 59 ;
	}
#Random pattern 60 for SPP scheme
'213160' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 60 ;
	}
#Random pattern 61 for SPP scheme
'213161' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 61 ;
	}
#Random pattern 62 for SPP scheme
'213162' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 62 ;
	}
#Random pattern 63 for SPP scheme
'213163' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 63 ;
	}
#Random pattern 64 for SPP scheme
'213164' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 64 ;
	}
#Random pattern 65 for SPP scheme
'213165' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 65 ;
	}
#Random pattern 66 for SPP scheme
'213166' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 66 ;
	}
#Random pattern 67 for SPP scheme
'213167' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 67 ;
	}
#Random pattern 68 for SPP scheme
'213168' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 68 ;
	}
#Random pattern 69 for SPP scheme
'213169' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 69 ;
	}
#Random pattern 70 for SPP scheme
'213170' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 70 ;
	}
#Random pattern 71 for SPP scheme
'213171' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 71 ;
	}
#Random pattern 72 for SPP scheme
'213172' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 72 ;
	}
#Random pattern 73 for SPP scheme
'213173' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 73 ;
	}
#Random pattern 74 for SPP scheme
'213174' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 74 ;
	}
#Random pattern 75 for SPP scheme
'213175' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 75 ;
	}
#Random pattern 76 for SPP scheme
'213176' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 76 ;
	}
#Random pattern 77 for SPP scheme
'213177' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 77 ;
	}
#Random pattern 78 for SPP scheme
'213178' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 78 ;
	}
#Random pattern 79 for SPP scheme
'213179' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 79 ;
	}
#Random pattern 80 for SPP scheme
'213180' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 80 ;
	}
#Random pattern 81 for SPP scheme
'213181' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 81 ;
	}
#Random pattern 82 for SPP scheme
'213182' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 82 ;
	}
#Random pattern 83 for SPP scheme
'213183' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 83 ;
	}
#Random pattern 84 for SPP scheme
'213184' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 84 ;
	}
#Random pattern 85 for SPP scheme
'213185' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 85 ;
	}
#Random pattern 86 for SPP scheme
'213186' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 86 ;
	}
#Random pattern 87 for SPP scheme
'213187' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 87 ;
	}
#Random pattern 88 for SPP scheme
'213188' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 88 ;
	}
#Random pattern 89 for SPP scheme
'213189' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 89 ;
	}
#Random pattern 90 for SPP scheme
'213190' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 90 ;
	}
#Random pattern 91 for SPP scheme
'213191' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 91 ;
	}
#Random pattern 92 for SPP scheme
'213192' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 92 ;
	}
#Random pattern 93 for SPP scheme
'213193' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 93 ;
	}
#Random pattern 94 for SPP scheme
'213194' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 94 ;
	}
#Random pattern 95 for SPP scheme
'213195' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 95 ;
	}
#Random pattern 96 for SPP scheme
'213196' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 96 ;
	}
#Random pattern 97 for SPP scheme
'213197' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 97 ;
	}
#Random pattern 98 for SPP scheme
'213198' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 98 ;
	}
#Random pattern 99 for SPP scheme
'213199' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 99 ;
	}
#Random pattern 100 for SPP scheme
'213200' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 100 ;
	}
#Random pattern 101 for SPP scheme
'213201' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 101 ;
	}
#Random pattern 102 for SPP scheme
'213202' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 102 ;
	}
#Random pattern 103 for SPP scheme
'213203' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 103 ;
	}
#Random pattern 104 for SPP scheme
'213204' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 104 ;
	}
#Random pattern 105 for SPP scheme
'213205' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 105 ;
	}
#Random pattern 106 for SPP scheme
'213206' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 106 ;
	}
#Random pattern 107 for SPP scheme
'213207' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 107 ;
	}
#Random pattern 108 for SPP scheme
'213208' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 108 ;
	}
#Random pattern 109 for SPP scheme
'213209' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 109 ;
	}
#Random pattern 110 for SPP scheme
'213210' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 110 ;
	}
#Random pattern 111 for SPP scheme
'213211' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 111 ;
	}
#Random pattern 112 for SPP scheme
'213212' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 112 ;
	}
#Random pattern 113 for SPP scheme
'213213' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 113 ;
	}
#Random pattern 114 for SPP scheme
'213214' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 114 ;
	}
#Random pattern 115 for SPP scheme
'213215' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 115 ;
	}
#Random pattern 116 for SPP scheme
'213216' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 116 ;
	}
#Random pattern 117 for SPP scheme
'213217' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 117 ;
	}
#Random pattern 118 for SPP scheme
'213218' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 118 ;
	}
#Random pattern 119 for SPP scheme
'213219' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 119 ;
	}
#Random pattern 120 for SPP scheme
'213220' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 120 ;
	}
#Random pattern 121 for SPP scheme
'213221' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 121 ;
	}
#Cosine of solar zenith angle
'214001' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#UV biologically effective dose
'214002' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#UV biologically effective dose clear-sky
'214003' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Atmosphere emission mass flux of Volcanic sulfur dioxide
'219221' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 8 ;
	 is_chemical_srcsink = 1 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Atmosphere emission mass flux of Aromatic peroxy radical
'219222' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 60029 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Ethyne
'219223' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 10010 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Acetonitrile
'219224' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 10007 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Methyl peroxy nitrate
'219225' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 10055 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Hydrogen cyanide
'219226' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 10006 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Hydroperoxy aldehydes type 1
'219227' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 60058 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Hydroperoxy aldehydes type 2
'219228' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 60059 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Isoprene peroxy type B
'219229' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 60056 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Isoprene peroxy type D
'219230' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 60057 ;
	 is_chemical = 1 ;
	}
#Geometric height of -10 degrees C atmospheric isothermal level above ground
'228020' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Surface direct short-wave (solar) radiation
'228021' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface direct short-wave radiation, clear sky
'228022' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Cloud base height
'228023' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 2 ;
	}
#Geometric height of 0 degrees C atmospheric isothermal level above ground
'228024' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Instantaneous 10 metre wind gust
'228029' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Relative humidity with respect to water
'228030' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	}
#Relative humidity with respect to ice
'228031' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 94 ;
	}
#Snow albedo
'228032' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	}
#Fraction of convective precipitation cover
'228034' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 37 ;
	}
#2 metre relative humidity with respect to water
'228037' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Liquid water content in snow pack
'228038' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	}
#Convective available potential energy shear
'228044' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Tropopause pressure
'228045' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Height of convective cloud top
'228046' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	}
#Height of zero-degree wet-bulb temperature
'228047' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 44 ;
	}
#Height of one-degree wet-bulb temperature
'228048' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 45 ;
	}
#Instantaneous total lightning flash density
'228050' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Instantaneous cloud-to-ground lightning flash density
'228052' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Unbalanced component of specific humidity
'228054' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 118 ;
	}
#Unbalanced component of specific cloud liquid water content
'228055' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 119 ;
	}
#Unbalanced component of specific cloud ice water content
'228056' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 120 ;
	}
#Soil moisture top 20 cm
'228086' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Soil moisture top 100 cm
'228087' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Total column supercooled liquid water
'228088' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 167 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column rain water
'228089' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column snow water
'228090' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Ice temperature
'228094' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}
#Soil temperature top 20 cm
'228095' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Soil temperature top 100 cm
'228096' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Atmosphere emission mass flux of Methane from Wetlands
'228104' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 2 ;
	 is_chemical_srcsink = 1 ;
	 sourceSinkChemicalPhysicalProcess = 10 ;
	}
#Accumulated mass emission of methane from Wetlands
'228109' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 2 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical_srcsink = 1 ;
	 sourceSinkChemicalPhysicalProcess = 10 ;
	}
#Surface short-wave (solar) radiation downward clear-sky
'228129' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface long-wave (thermal) radiation downward clear-sky
'228130' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective precipitation
'228143' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Water runoff and drainage
'228205' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	}
#Instantaneous large-scale precipitation fraction
'228217' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Convective rain rate
'228218' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Large scale rain rate
'228219' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Convective snowfall rate water equivalent
'228220' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Large scale snowfall rate water equivalent
'228221' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Mixed-layer CAPE in the lowest 50 hPa
'228231' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Mixed-layer CIN in the lowest 50 hPa
'228232' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Mixed-layer CAPE in the lowest 100 hPa
'228233' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Mixed-layer CIN in the lowest 100 hPa
'228234' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Most-unstable CAPE
'228235' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	}
#Most-unstable CIN
'228236' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	}
#Departure level of the most unstable parcel expressed as Pressure
'228237' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	}
#Urban cover
'229001' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	}
#Road Cover
'229002' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	}
#Building cover
'229003' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 2 ;
	}
#Building height
'229004' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	}
#Vertical-to-horizontal area ratio
'229005' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	}
#Standard deviation of building height
'229006' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	}
#Wetland cover
'229007' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 45 ;
	}
#Wetland type
'229008' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	}
#Irrigation cover
'229009' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	}
#C4 crop cover
'229010' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	}
#C4 grass cover
'229011' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	}
#Accumulated freezing rain water equivalent
'231001' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Runoff water equivalent (surface plus subsurface)
'231002' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snow evaporation water equivalent
'231003' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Potential evaporation rate
'231004' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Potential evaporation
'231005' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Tile fraction
'231006' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	}
#Tile percentage
'231007' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 37 ;
	}
#Forecast logarithm of surface roughness length for moisture
'231008' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface runoff rate
'231009' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface runoff
'231010' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Sub-surface runoff rate
'231011' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Sub-surface runoff
'231012' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Reflectance in 0.4 micron channel
'231013' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 30 ;
	}
#Vertical divergence
'231014' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 59 ;
	}
#Drag thermal coefficient
'231015' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Drag evaporation coefficient
'231016' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Pressure departure from hydrostatic state
'231017' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 46 ;
	}
#Surface net radiation flux (SW and LW)
'231018' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Top net radiation flux (SW and LW)
'231019' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Global irradiance on tilted surfaces
'231021' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 47 ;
	}
#Eady growth rate
'231022' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 22 ;
	}
#Tropical cyclones track density
'231023' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 4 ;
	}
#Canopy air temperature
'231024' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 63 ;
	}
#Soil wetness index (total layer)
'231025' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 151 ;
	}
#Soil wetness index (root zone)
'231026' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	}
#Soil wetness index (layer)
'231027' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 151 ;
	 typeOfSecondFixedSurface = 151 ;
	}
#Distance downward from roof surface
'231028' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 6 ;
	}
#Distance inward from outer wall surface
'231029' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 7 ;
	}
#Distance downward from road surface
'231030' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 8 ;
	}
#Renewable power capacity
'231031' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Renewable power production rate
'231032' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Renewable power production
'231033' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Wind power capacity
'231034' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Wind power production rate
'231035' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Wind power production
'231036' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Solar photovoltaic (PV) power capacity
'231037' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Solar photovoltaic (PV) power production rate
'231038' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Solar photovoltaic (PV) power production
'231039' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Graupel (snow pellets) precipitation
'231040' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total lightning flash density
'231041' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Pressure at cloud base
'231045' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 2 ;
	}
#Geometric height of adiabatic condensation level above ground
'231046' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 5 ;
	}
#Geometric height of free convection level above ground
'231047' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 14 ;
	}
#Geometric height of neutral buoyancy level above ground
'231048' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 16 ;
	}
#Geometric height of 3 degrees C atmospheric isothermal level above ground
'231049' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27615 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Roof temperature
'231050' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 185 ;
	}
#Wall temperature
'231051' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 186 ;
	}
#Road temperature
'231052' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 187 ;
	}
#Snow depth water equivalent on roof
'231053' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 185 ;
	}
#Snow depth water equivalent on road
'231054' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 187 ;
	}
#Urban canyon temperature
'231055' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 187 ;
	 typeOfSecondFixedSurface = 185 ;
	}
#Urban canyon specific humidity
'231056' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 187 ;
	 typeOfSecondFixedSurface = 185 ;
	}
#Convective snowfall water equivalent
'231057' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Large-scale snowfall water equivalent
'231058' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Lake surface temperature
'231059' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Surface bulk Richardson number
'231060' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface roughness for heat
'231063' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface roughness for moisture
'231064' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 48 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Snow evaporation rate water equivalent
'231065' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Radar reflectivity
'231066' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 4 ;
	}
#Pressure at cloud ceiling
'231067' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 19 ;
	 scaledValueOfFirstFixedSurface = 50 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Visibility through precipitation
'231068' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 51 ;
	}
#Geometric height of 0 degrees C theta level above ground
'231069' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Geometric height of 1 degree C theta level above ground
'231070' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27415 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Geometric height of 1.5 degrees C theta level above ground
'231071' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27465 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Volumetric soil moisture (root zone)
'231072' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	}
#Thunderstorm hazard index
'231500' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}
#Surface water flooding hazard index
'231501' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	}
#Polluted air hazard index
'231502' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	}
#Storm surge hazard index
'231503' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	}
#Cold wave hazard index
'231504' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	}
#Frost (hoar frost) hazard index
'231505' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 43 ;
	}
#Heatwave hazard index
'231506' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 47 ;
	}
#Wind hazard index
'231507' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	}
#Wildfires hazard index
'231508' = {
	 discipline = 20 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	}
#Burned area
'232000' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}
#Burning area
'232001' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 20 ;
	}
#Burnable area
'232002' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	}
#Un-burnable area
'232003' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	}
#Fuel load
'232004' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	}
#Combustion completeness
'232005' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	}
#Fuel moisture content
'232006' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 25 ;
	}
#Live leaf fuel load
'232007' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	}
#Live wood fuel load 
'232008' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 28 ;
	}
#Dead leaf fuel load
'232009' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 29 ;
	}
#Dead wood fuel load
'232010' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 30 ;
	}
#Live fuel moisture content
'232011' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 31 ;
	}
#Fine dead leaf moisture content
'232012' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 32 ;
	}
#Dense dead leaf moisture content
'232013' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 33 ;
	}
#Fine dead wood moisture content
'232014' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 34 ;
	}
#Dense dead wood moisture content
'232015' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 35 ;
	}
#Live fuel moisture content in low vegetation
'232016' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 37 ;
	}
#Live fuel moisture content in high vegetation
'232017' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 38 ;
	}
#Time-integrated total column vertically-integrated eastward geopotential flux
'233000' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward geopotential flux
'233001' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of water geopotential flux
'233002' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of geopotential flux
'233003' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward enthalpy flux
'233004' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward enthalpy flux
'233005' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward kinetic energy flux
'233006' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward kinetic energy flux
'233007' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward total energy flux
'233008' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward total energy flux
'233009' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of enthalpy flux
'233010' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of kinetic energy flux
'233011' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of total energy flux
'233012' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of water enthalpy flux
'233013' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of mass flux
'233014' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward mass flux
'233015' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward mass flux
'233016' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of water vapour flux
'233017' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of cloud liquid water flux
'233018' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of cloud ice water flux
'233019' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of rain flux
'233020' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of snow flux
'233021' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward water vapour flux
'233022' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward water vapour flux
'233023' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward cloud liquid water flux
'233024' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward cloud liquid water flux
'233025' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward cloud ice water flux
'233026' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward cloud ice water flux
'233027' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward rain flux
'233028' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward rain flux
'233029' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward snow flux
'233030' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward snow flux
'233031' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean temperature tendency due to short-wave radiation
'235001' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature tendency due to long-wave radiation
'235002' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature tendency due to short wave radiation, clear sky
'235003' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature tendency due to long-wave radiation, clear sky
'235004' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature tendency due to parametrisations
'235005' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific humidity tendency due to parametrisations
'235006' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward wind tendency due to parametrisations
'235007' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward wind tendency due to parametrisations
'235008' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean updraught mass flux
'235009' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean downdraught mass flux
'235010' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean updraught detrainment rate
'235011' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean downdraught detrainment rate
'235012' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total precipitation flux
'235013' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean turbulent diffusion coefficient for heat
'235014' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time integral of rain flux
'235015' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time integral of surface eastward momentum flux
'235017' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time integral of surface northward momentum flux
'235018' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time integral of surface latent heat evaporation flux
'235019' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean surface runoff rate
'235020' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sub-surface runoff rate
'235021' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface photosynthetically active radiation flux, clear sky
'235022' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow evaporation rate water equivalent
'235023' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow melt rate
'235024' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean magnitude of turbulent surface stress
'235025' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean large-scale precipitation fraction
'235026' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward UV radiation flux
'235027' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface photosynthetically active radiation flux
'235028' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean large-scale precipitation rate
'235029' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean convective precipitation rate
'235030' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total snowfall rate water equivalent
'235031' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean boundary layer dissipation
'235032' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface sensible heat flux
'235033' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface latent heat flux
'235034' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward short-wave radiation flux
'235035' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward long-wave radiation flux
'235036' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface net short-wave radiation flux
'235037' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface net long-wave radiation flux
'235038' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean top net short-wave radiation flux
'235039' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean top net long-wave radiation flux
'235040' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward turbulent surface stress
'235041' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward turbulent surface stress
'235042' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean moisture flux
'235043' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sunshine duration fraction
'235044' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Time-mean eastward gravity wave surface stress
'235045' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward gravity wave surface stress
'235046' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean gravity wave dissipation
'235047' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean runoff rate water equivalent (surface plus subsurface)
'235048' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean top net short-wave radiation flux, clear sky
'235049' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean top net long-wave radiation flux, clear sky
'235050' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface net short-wave radiation flux, clear sky
'235051' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface net long-wave radiation flux, clear sky
'235052' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time mean top downward short-wave radiation flux
'235053' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated moisture divergence flux
'235054' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total precipitation rate
'235055' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean convective snowfall rate water equivalent
'235056' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean large scale snowfall rate water equivalent
'235057' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface direct short-wave radiation flux
'235058' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface direct short-wave radiation flux, clear sky
'235059' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean surface diffuse short-wave radiation flux
'235060' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward short-wave radiation flux, clear sky
'235068' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward long-wave radiation flux, clear sky
'235069' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean potential evaporation rate
'235070' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time integral of surface latent heat sublimation flux
'235071' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time integral of evapotranspiration flux
'235073' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean evapotranspiration rate
'235074' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time integral of potential evapotranspiration rate
'235075' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean potential evapotranspiration rate
'235076' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean volumetric soil moisture
'235077' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow depth water equivalent
'235078' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean skin temperature
'235079' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow density
'235080' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean low vegetation cover
'235081' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean high vegetation cover
'235082' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice area fraction
'235083' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface temperature
'235084' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean leaf area index, low vegetation
'235085' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean leaf area index, high vegetation
'235086' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column liquid water
'235087' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column cloud ice water
'235088' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 2 metre specific humidity
'235089' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake mix-layer temperature
'235090' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake mix-layer depth
'235091' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 2 metre relative humidity
'235092' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean fraction of snow cover
'235093' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 121 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil temperature
'235094' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wind speed
'235097' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean pressure
'235098' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean charnock
'235099' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean potential vorticity
'235100' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific rain water content
'235101' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific snow water content
'235102' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eta-coordinate vertical velocity
'235103' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean visibility
'235105' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wind direction
'235106' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column snow water
'235107' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean low cloud cover
'235108' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean medium cloud cover
'235109' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean high cloud cover
'235110' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column rain water
'235111' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil moisture top 20 cm
'235113' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil moisture top 100 cm
'235114' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil temperature top 20 cm
'235115' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil temperature top 100 cm
'235116' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean most-unstable CAPE
'235117' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean volumetric soil moisture top 20 cm
'235118' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean volumetric soil moisture top 100 cm
'235119' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated graupel (snow pellets)
'235120' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geopotential
'235129' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature
'235130' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U component of wind
'235131' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V component of wind
'235132' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific humidity
'235133' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface pressure
'235134' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertical velocity
'235135' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column water
'235136' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated water vapour
'235137' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vorticity (relative)
'235138' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface net radiation flux (SW and LW)
'235149' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean top net radiation flux (SW and LW)
'235150' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean sea level pressure
'235151' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean divergence
'235155' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean relative humidity
'235157' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean boundary layer height
'235159' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre U wind component
'235165' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre V wind component
'235166' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 2 metre dewpoint temperature
'235168' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sunshine
'235189' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ozone mass mixing ratio
'235203' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature of snow layer
'235238' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean forecast surface roughness
'235244' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean forecast logarithm of surface roughness for heat
'235245' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific cloud liquid water content
'235246' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific cloud ice water content
'235247' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean fraction of cloud cover
'235248' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean K index
'235257' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total totals index
'235258' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre wind direction
'235261' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean clear air turbulence (CAT)
'235262' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean forecast albedo
'235263' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean potential temperature
'235269' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean discharge from rivers or streams
'235270' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil wetness index (total layer)
'235271' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 151 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil wetness index (root zone)
'235272' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil wetness index(layer)
'235273' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 151 ;
	 typeOfSecondFixedSurface = 151 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodplain depth
'235274' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodplain flooded fraction
'235275' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodplain flooded area
'235276' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river fraction
'235277' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river area
'235278' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean fraction of river coverage plus river related flooding
'235279' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean area of river coverage plus river related flooding
'235280' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean UV visible albedo for direct radiation (climatological)
'235281' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean UV visible albedo for diffuse radiation (climatological)
'235282' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean near IR albedo for direct radiation (climatological)
'235283' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean near IR albedo for diffuse radiation (climatological)
'235284' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean snow albedo
'235285' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean montgomery potential
'235286' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean convective available potential energy
'235287' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total cloud cover
'235288' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean skin reservoir content
'235289' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column integrated ozone
'235290' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated kinetic energy
'235291' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated enthalpy
'235292' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated potential + internal energy
'235293' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated potential+internal+latent energy
'235294' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated total energy
'235295' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated water enthalpy
'235296' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean UV visible albedo for direct radiation, isotropic component (climatological)
'235297' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean UV visible albedo for direct radiation, volumetric component (climatological)
'235298' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean UV visible albedo for direct radiation, geometric component (climatological)
'235299' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean near IR albedo for direct radiation, isotropic component (climatological)
'235300' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean near IR albedo for direct radiation, volumetric component (climatological)
'235301' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean near IR albedo for direct radiation, geometric component (climatological)
'235302' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean convective inhibition
'235303' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean friction velocity
'235304' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake bottom temperature
'235305' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake total layer temperature
'235306' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake shape factor
'235307' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake ice surface temperature
'235308' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake ice total depth
'235309' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean minimum vertical gradient of refractivity inside trapping layer
'235310' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean vertical gradient of refractivity inside trapping layer
'235311' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean duct base height
'235312' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 41 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean trapping layer base height
'235313' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean trapping layer top height
'235314' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of -10 degrees C atmospheric isothermal level above ground
'235315' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean cloud base height
'235316' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of 0 degrees C atmospheric isothermal level above ground
'235317' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre wind gust
'235318' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean relative humidity with respect to water
'235319' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 2 metre relative humidity with respect to water
'235320' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean convective available potential energy shear
'235321' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean tropopause pressure
'235322' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean height of convective cloud top
'235323' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean height of zero-degree wet-bulb temperature
'235324' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean height of one-degree wet-bulb temperature
'235325' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total lightning flash density
'235326' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column supercooled liquid water
'235327' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 167 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre U-component of neutral wind
'235328' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre V-component of neutral wind
'235329' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean convective rain rate
'235330' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean large scale rain rate
'235331' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mixed-layer CAPE in the lowest 50 hPa
'235332' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mixed-layer CIN in the lowest 50 hPa
'235333' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mixed-layer CAPE in the lowest 100 hPa
'235334' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mixed-layer CIN in the lowest 100 hPa
'235335' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean departure level of the most unstable parcel expressed as Pressure
'235336' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ceiling
'235337' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column integrated saturation specific humidity with respect to water
'235338' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 169 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface direct normal short-wave radiation flux
'235339' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean cosine of solar zenith angle
'235340' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean freezing rain precipitation rate
'235341' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward geopotential flux
'235342' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward geopotential flux
'235343' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of water geopotential flux
'235344' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of geopotential flux
'235345' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward enthalpy flux
'235346' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward enthalpy flux
'235347' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward kinetic energy flux
'235348' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward kinetic energy flux
'235349' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward total energy flux
'235350' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward total energy flux
'235351' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of enthalpy flux
'235352' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of kinetic energy flux
'235353' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of total energy flux
'235354' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of water enthalpy flux
'235355' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of mass flux
'235356' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward mass flux
'235357' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward mass flux
'235358' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of water vapour flux
'235359' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of cloud liquid water flux
'235360' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of cloud ice water flux
'235361' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of rain flux
'235362' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of snow flux
'235363' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward water vapour flux
'235364' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward water vapour flux
'235365' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward cloud liquid water flux
'235366' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward cloud liquid water flux
'235367' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward cloud ice water flux
'235368' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward cloud ice water flux
'235369' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward rain flux
'235370' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward rain flux
'235371' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward snow flux
'235372' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward snow flux
'235373' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward ozone flux
'235374' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward ozone flux
'235375' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of ozone flux
'235376' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated net source of ozone
'235377' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward turbulent surface stress due to orographic form drag
'235378' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward turbulent surface stress due to orographic form drag
'235379' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward turbulent surface stress due to surface roughness
'235380' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward turbulent surface stress due to surface roughness
'235381' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean visibility through precipitation
'235382' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean cloud-to-ground lightning flash density
'235383' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean land surface heat net flux
'235386' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface direct normal short-wave radiation flux, clear sky
'235387' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre convective gust
'235388' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre turbulent gust
'235389' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of 0 degrees C theta level above ground
'235390' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of 1 degree C theta level above ground
'235391' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27415 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of 1.5 degrees C theta level above ground
'235392' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27465 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vegetation
'235393' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean leaf area index
'235394' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface roughness for heat
'235395' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Reciprocal Obukhov length
'235396' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of 3 degrees C atmospheric isothermal level above ground
'235397' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27615 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river storage of water
'235398' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodplain storage of water
'235399' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river depth
'235400' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river outflow of water
'235401' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodplain outflow of water
'235402' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodpath outflow of water
'235403' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface diffuse short-wave radiation flux, clear sky
'235404' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean volumetric soil moisture (root zone)
'235405' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-integrated land surface heat net flux
'236386' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated surface direct normal short-wave radiation flux, clear sky
'236387' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-maximum temperature tendency due to short-wave radiation
'237001' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature tendency due to long-wave radiation
'237002' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature tendency due to short wave radiation, clear sky
'237003' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature tendency due to long-wave radiation, clear sky
'237004' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature tendency due to parametrisations
'237005' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific humidity tendency due to parametrisations
'237006' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward wind tendency due to parametrisations
'237007' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward wind tendency due to parametrisations
'237008' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum updraught mass flux
'237009' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum downdraught mass flux
'237010' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum updraught detrainment rate
'237011' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum downdraught detrainment rate
'237012' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total precipitation flux
'237013' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum turbulent diffusion coefficient for heat
'237014' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface photosynthetically active radiation flux, clear sky
'237022' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow evaporation rate water equivalent
'237023' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow melt rate
'237024' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum magnitude of turbulent surface stress
'237025' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum large-scale precipitation fraction
'237026' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward UV radiation flux
'237027' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface photosynthetically active radiation flux
'237028' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum large-scale precipitation rate
'237029' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum convective precipitation rate
'237030' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total snowfall rate water equivalent
'237031' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum boundary layer dissipation
'237032' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface sensible heat flux
'237033' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface latent heat flux
'237034' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward short-wave radiation flux
'237035' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward long-wave radiation flux
'237036' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface net short-wave radiation flux
'237037' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface net long-wave radiation flux
'237038' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum top net short-wave radiation flux
'237039' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum top net long-wave radiation flux
'237040' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward turbulent surface stress
'237041' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward turbulent surface stress
'237042' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum moisture flux
'237043' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward gravity wave surface stress
'237045' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward gravity wave surface stress
'237046' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum gravity wave dissipation
'237047' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum runoff rate water equivalent (surface plus subsurface)
'237048' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum top net short-wave radiation flux, clear sky
'237049' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum top net long-wave radiation flux, clear sky
'237050' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface net short-wave radiation flux, clear sky
'237051' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface net long-wave radiation flux, clear sky
'237052' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time mean top downward short-wave radiation flux
'237053' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated moisture divergence flux
'237054' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total precipitation rate
'237055' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum convective snowfall rate water equivalent
'237056' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum large scale snowfall rate water equivalent
'237057' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface direct short-wave radiation flux
'237058' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface direct short-wave radiation flux, clear sky
'237059' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward short-wave radiation flux, clear sky
'237068' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward long-wave radiation flux, clear sky
'237069' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum potential evaporation rate
'237070' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum volumetric soil moisture
'237077' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow depth water equivalent
'237078' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum skin temperature
'237079' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow density
'237080' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice area fraction
'237083' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea surface temperature
'237084' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column cloud liquid water
'237087' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column cloud ice water
'237088' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 2 metre specific humidity
'237089' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake mix-layer temperature
'237090' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake mix-layer depth
'237091' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 2 metre relative humidity
'237092' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum soil temperature
'237094' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wind speed
'237097' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum pressure
'237098' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum charnock
'237099' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum potential vorticity
'237100' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific rain water content
'237101' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific snow water content
'237102' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eta-coordinate vertical velocity
'237103' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum visibility
'237105' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wind direction
'237106' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column snow water
'237107' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum low cloud cover
'237108' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum medium cloud cover
'237109' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum high cloud cover
'237110' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column rain water
'237111' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum most-unstable CAPE
'237117' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated graupel (snow pellets)
'237120' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geopotential
'237129' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature
'237130' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum u component of wind
'237131' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum v component of wind
'237132' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific humidity
'237133' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface pressure
'237134' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vertical velocity
'237135' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column water
'237136' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated water vapour
'237137' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vorticity (relative)
'237138' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean sea level pressure
'237151' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum divergence
'237155' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum relative humidity
'237157' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum boundary layer height
'237159' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre U wind component
'237165' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre V wind component
'237166' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 2 metre temperature
'237167' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 2 metre dewpoint temperature
'237168' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sunshine
'237189' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ozone mass mixing ratio
'237203' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre wind speed
'237207' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature of snow layer
'237238' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum forecast surface roughness
'237244' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum forecast logarithm of surface roughness for heat
'237245' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific cloud liquid water content
'237246' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific cloud ice water content
'237247' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum fraction of cloud cover
'237248' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum k index
'237257' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total totals index
'237258' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre wind direction
'237261' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum clear air turbulence (CAT)
'237262' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum forecast albedo
'237263' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum potential temperature
'237269' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum UV visible albedo for direct radiation (climatological)
'237281' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum UV visible albedo for diffuse radiation (climatological)
'237282' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum near IR albedo for direct radiation (climatological)
'237283' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum near IR albedo for diffuse radiation (climatological)
'237284' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum snow albedo
'237285' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum montgomery potential
'237286' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum convective available potential energy
'237287' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total cloud cover
'237288' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum skin reservoir content
'237289' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column integrated ozone
'237290' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated kinetic energy
'237291' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated enthalpy
'237292' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated potential + internal energy
'237293' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated potential+internal+latent energy
'237294' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated total energy
'237295' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated water enthalpy
'237296' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum UV visible albedo for direct radiation, isotropic component (climatological)
'237297' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum UV visible albedo for direct radiation, volumetric component (climatological)
'237298' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum UV visible albedo for direct radiation, geometric component (climatological)
'237299' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum near IR albedo for direct radiation, isotropic component (climatological)
'237300' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum near IR albedo for direct radiation, volumetric component (climatological)
'237301' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum near IR albedo for direct radiation, geometric component (climatological)
'237302' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum convective inhibition
'237303' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum friction velocity
'237304' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake bottom temperature
'237305' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake total layer temperature
'237306' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake shape factor
'237307' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake ice surface temperature
'237308' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake ice total depth
'237309' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum minimum vertical gradient of refractivity inside trapping layer
'237310' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean vertical gradient of refractivity inside trapping layer
'237311' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum duct base height
'237312' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 41 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum trapping layer base height
'237313' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum trapping layer top height
'237314' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of -10 degrees C atmospheric isothermal level above ground
'237315' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum cloud base height
'237316' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of 0 degrees C atmospheric isothermal level above ground
'237317' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre wind gust
'237318' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum relative humidity with respect to water
'237319' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 2 metre relative humidity with respect to water
'237320' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum convective available potential energy shear
'237321' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum tropopause pressure
'237322' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum height of convective cloud top
'237323' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum height of zero-degree wet-bulb temperature
'237324' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum height of one-degree wet-bulb temperature
'237325' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total lightning flash density
'237326' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column supercooled liquid water
'237327' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 167 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre U-component of neutral wind
'237328' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre V-component of neutral wind
'237329' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum convective rain rate
'237330' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum large scale rain rate
'237331' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mixed-layer CAPE in the lowest 50 hPa
'237332' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mixed-layer CIN in the lowest 50 hPa
'237333' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mixed-layer CAPE in the lowest 100 hPa
'237334' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mixed-layer CIN in the lowest 100 hPa
'237335' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum departure level of the most unstable parcel expressed as Pressure
'237336' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ceiling
'237337' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column integrated saturation specific humidity with respect to water
'237338' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 169 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface direct normal short-wave radiation flux
'237339' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum cosine of solar zenith angle
'237340' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum freezing rain precipitation rate
'237341' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward geopotential flux
'237342' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward geopotential flux
'237343' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of water geopotential flux
'237344' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of geopotential flux
'237345' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward enthalpy flux
'237346' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward enthalpy flux
'237347' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward kinetic energy flux
'237348' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward kinetic energy flux
'237349' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward total energy flux
'237350' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward total energy flux
'237351' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of enthalpy flux
'237352' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of kinetic energy flux
'237353' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of total energy flux
'237354' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of water enthalpy flux
'237355' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of mass flux
'237356' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward mass flux
'237357' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward mass flux
'237358' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of water vapour flux
'237359' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of cloud liquid water flux
'237360' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of cloud ice water flux
'237361' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of rain flux
'237362' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of snow flux
'237363' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward water vapour flux
'237364' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward water vapour flux
'237365' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward cloud liquid water flux
'237366' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward cloud liquid water flux
'237367' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward cloud ice water flux
'237368' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward cloud ice water flux
'237369' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward rain flux
'237370' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward rain flux
'237371' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward snow flux
'237372' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward snow flux
'237373' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward ozone flux
'237374' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward ozone flux
'237375' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of ozone flux
'237376' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated net source of ozone
'237377' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward turbulent surface stress due to orographic form drag
'237378' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward turbulent surface stress due to orographic form drag
'237379' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward turbulent surface stress due to surface roughness
'237380' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward turbulent surface stress due to surface roughness
'237381' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum visibility through precipitation
'237382' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre eastward wind gust
'237384' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre northward wind gust
'237385' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum land surface heat net flux
'237386' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface direct normal short-wave radiation flux, clear sky
'237387' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre convective gust
'237388' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre turbulent gust
'237389' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of 0 degrees C theta level above ground
'237390' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of 1 degree C theta level above ground
'237391' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27415 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of 1.5 degrees C theta level above ground
'237392' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27465 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vegetation
'237393' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum leaf area index
'237394' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface roughness for heat
'237395' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum Reciprocal Obukhov length
'237396' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of 3 degrees C atmospheric isothermal level above ground
'237397' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27615 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface diffuse short-wave radiation flux, clear sky
'237404' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum volumetric soil moisture (root zone)
'237405' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum temperature tendency due to short-wave radiation
'238001' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature tendency due to long-wave radiation
'238002' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature tendency due to short wave radiation, clear sky
'238003' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature tendency due to long-wave radiation, clear sky
'238004' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature tendency due to parametrisations
'238005' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific humidity tendency due to parametrisations
'238006' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward wind tendency due to parametrisations
'238007' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward wind tendency due to parametrisations
'238008' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum updraught mass flux
'238009' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum downdraught mass flux
'238010' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum updraught detrainment rate
'238011' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum downdraught detrainment rate
'238012' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total precipitation flux
'238013' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum turbulent diffusion coefficient for heat
'238014' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface photosynthetically active radiation flux, clear sky
'238022' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snow evaporation rate
'238023' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snowmelt rate
'238024' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum magnitude of turbulent surface stress
'238025' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum large-scale precipitation fraction
'238026' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward UV radiation flux
'238027' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface photosynthetically active radiation flux
'238028' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum large-scale precipitation rate
'238029' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum convective precipitation rate
'238030' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snowfall rate
'238031' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum boundary layer dissipation
'238032' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface sensible heat flux
'238033' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface latent heat flux
'238034' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward short-wave radiation flux
'238035' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward long-wave radiation flux
'238036' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface net short-wave radiation flux
'238037' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface net long-wave radiation flux
'238038' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum top net short-wave radiation flux
'238039' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum top net long-wave radiation flux
'238040' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward turbulent surface stress
'238041' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward turbulent surface stress
'238042' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum evaporation rate
'238043' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward gravity wave surface stress
'238045' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward gravity wave surface stress
'238046' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum gravity wave dissipation
'238047' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum runoff rate
'238048' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum top net short-wave radiation flux, clear sky
'238049' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum top net long-wave radiation flux, clear sky
'238050' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface net short-wave radiation flux, clear sky
'238051' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface net long-wave radiation flux, clear sky
'238052' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum top downward short-wave radiation flux
'238053' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated moisture divergence
'238054' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total precipitation rate
'238055' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum convective snowfall rate water equivalent
'238056' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum large scale snowfall rate water equivalent
'238057' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface direct short-wave radiation flux
'238058' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface direct short-wave radiation flux, clear sky
'238059' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward short-wave radiation flux, clear sky
'238068' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward long-wave radiation flux, clear sky
'238069' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum potential evaporation rate
'238070' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum volumetric soil moisture
'238077' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snow depth water equivalent
'238078' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum skin temperature
'238079' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snow density
'238080' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice area fraction
'238083' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea surface temperature
'238084' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column cloud liquid water
'238087' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column cloud ice water
'238088' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 2 metre specific humidity
'238089' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake mix-layer temperature
'238090' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake mix-layer depth
'238091' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 2 metre relative humidity
'238092' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum soil temperature
'238094' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wind speed
'238097' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum pressure
'238098' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum charnock
'238099' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum potential vorticity
'238100' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific rain water content
'238101' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific snow water content
'238102' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eta-coordinate vertical velocity
'238103' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum visibility
'238105' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wind direction
'238106' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column snow water
'238107' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum low cloud cover
'238108' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum medium cloud cover
'238109' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum high cloud cover
'238110' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column rain water
'238111' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum most-unstable CAPE
'238117' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated graupel (snow pellets)
'238120' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geopotential
'238129' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature
'238130' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum u component of wind
'238131' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum v component of wind
'238132' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific humidity
'238133' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface pressure
'238134' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertical velocity
'238135' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column water
'238136' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated water vapour
'238137' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vorticity (relative)
'238138' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean sea level pressure
'238151' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum divergence
'238155' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum relative humidity
'238157' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum boundary layer height
'238159' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre U wind component
'238165' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre V wind component
'238166' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 2 metre temperature
'238167' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 2 metre dewpoint temperature
'238168' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sunshine
'238189' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ozone mass mixing ratio
'238203' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre wind speed
'238207' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature of snow layer
'238238' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum forecast surface roughness
'238244' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum forecast logarithm of surface roughness for heat
'238245' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific cloud liquid water content
'238246' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific cloud ice water content
'238247' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum fraction of cloud cover
'238248' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum k index
'238257' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total totals index
'238258' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre wind direction
'238261' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum clear air turbulence (CAT)
'238262' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum forecast albedo
'238263' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum potential temperature
'238269' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum UV visible albedo for direct radiation (climatological)
'238281' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum UV visible albedo for diffuse radiation (climatological)
'238282' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum near IR albedo for direct radiation (climatological)
'238283' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum near IR albedo for diffuse radiation (climatological)
'238284' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum snow albedo
'238285' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum montgomery potential
'238286' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum convective available potential energy
'238287' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total cloud cover
'238288' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum skin reservoir content
'238289' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column integrated ozone
'238290' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated kinetic energy
'238291' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated enthalpy
'238292' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated potential + internal energy
'238293' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertical integral of potential+internal+latent energy
'238294' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated total energy
'238295' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated water enthalpy
'238296' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum UV visible albedo for direct radiation, isotropic component (climatological)
'238297' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum UV visible albedo for direct radiation, volumetric component (climatological)
'238298' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum UV visible albedo for direct radiation, geometric component (climatological)
'238299' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum near IR albedo for direct radiation, isotropic component (climatological)
'238300' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum near IR albedo for direct radiation, volumetric component (climatological)
'238301' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum near IR albedo for direct radiation, geometric component (climatological)
'238302' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum convective inhibition
'238303' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum friction velocity
'238304' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake bottom temperature
'238305' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake total layer temperature
'238306' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake shape factor
'238307' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake ice surface temperature
'238308' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake ice total depth
'238309' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum minimum vertical gradient of refractivity inside trapping layer
'238310' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean vertical gradient of refractivity inside trapping layer
'238311' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum duct base height
'238312' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 41 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum trapping layer base height
'238313' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum trapping layer top height
'238314' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of -10 degrees C atmospheric isothermal level above ground
'238315' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum cloud base height
'238316' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of 0 degrees C atmospheric isothermal level above ground
'238317' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre wind gust
'238318' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum relative humidity with respect to water
'238319' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 2 metre relative humidity with respect to water
'238320' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum convective available potential energy shear
'238321' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum tropopause pressure
'238322' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum height of convective cloud top
'238323' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum height of zero-degree wet-bulb temperature
'238324' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum height of one-degree wet-bulb temperature
'238325' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total lightning flash density
'238326' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column supercooled liquid water
'238327' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 167 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre U-component of neutral wind
'238328' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre V-component of neutral wind
'238329' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum convective rain rate
'238330' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum large scale rain rate
'238331' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mixed-layer CAPE in the lowest 50 hPa
'238332' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mixed-layer CIN in the lowest 50 hPa
'238333' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mixed-layer CAPE in the lowest 100 hPa
'238334' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mixed-layer CIN in the lowest 100 hPa
'238335' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum departure level of the most unstable parcel expressed as Pressure
'238336' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ceiling
'238337' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column integrated saturation specific humidity with respect to water
'238338' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 169 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum direct solar radiation flux
'238339' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum cosine of solar zenith angle
'238340' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum freezing rain rate water equivalent
'238341' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated eastward geopotential flux
'238342' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated northward geopotential flux
'238343' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of water geopotential flux
'238344' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of geopotential flux
'238345' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated eastward enthalpy flux
'238346' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated northward enthalpy flux
'238347' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated eastward kinetic energy flux
'238348' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated northward kinetic energy flux
'238349' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated eastward total energy flux
'238350' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated northward total energy flux
'238351' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of enthalpy flux
'238352' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of kinetic energy flux
'238353' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of total energy flux
'238354' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of water enthalpy flux
'238355' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of mass flux
'238356' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward mass flux
'238357' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward mass flux
'238358' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of water vapour flux
'238359' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of cloud liquid water flux
'238360' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of cloud ice water flux
'238361' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of rain flux
'238362' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of snow flux
'238363' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward water vapour flux
'238364' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward water vapour flux
'238365' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward cloud liquid water flux
'238366' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward cloud liquid water flux
'238367' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward cloud ice water flux
'238368' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward cloud ice water flux
'238369' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward rain flux
'238370' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward rain flux
'238371' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward snow flux
'238372' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward snow flux
'238373' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward ozone flux
'238374' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward ozone flux
'238375' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of ozone flux
'238376' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated net source of ozone
'238377' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward turbulent surface stress due to orographic form drag
'238378' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward turbulent surface stress due to orographic form drag
'238379' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward turbulent surface stress due to surface roughness
'238380' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward turbulent surface stress due to surface roughness
'238381' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum visibility through precipitation
'238382' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum land surface heat net flux
'238386' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface direct normal short-wave radiation flux, clear sky
'238387' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre convective gust
'238388' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre turbulent gust
'238389' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of 0 degrees C theta level above ground
'238390' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of 1 degree C theta level above ground
'238391' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27415 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of 1.5 degrees C theta level above ground
'238392' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27465 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vegetation
'238393' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum leaf area index
'238394' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface roughness for heat
'238395' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum Reciprocal Obukhov length
'238396' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of 3 degrees C atmospheric isothermal level above ground
'238397' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27615 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface diffuse short-wave radiation flux, clear sky
'238404' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum volumetric soil moisture (root zone)
'238405' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation temperature tendency due to short-wave radiation
'239001' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature tendency due to long-wave radiation
'239002' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature tendency due to short wave radiation, clear sky
'239003' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature tendency due to long-wave radiation, clear sky
'239004' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature tendency due to parametrisations
'239005' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific humidity tendency due to parametrisations
'239006' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward wind tendency due to parametrisations
'239007' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward wind tendency due to parametrisations
'239008' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation updraught mass flux
'239009' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation downdraught mass flux
'239010' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation updraught detrainment rate
'239011' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation downdraught detrainment rate
'239012' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total precipitation flux
'239013' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation turbulent diffusion coefficient for heat
'239014' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface photosynthetically active radiation flux, clear sky
'239022' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snow evaporation rate
'239023' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snowmelt rate
'239024' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation magnitude of turbulent surface stress
'239025' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation large-scale precipitation fraction
'239026' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward UV radiation flux
'239027' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface photosynthetically active radiation flux
'239028' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation large-scale precipitation rate
'239029' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation convective precipitation rate
'239030' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snowfall rate
'239031' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation boundary layer dissipation
'239032' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface sensible heat flux
'239033' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface latent heat flux
'239034' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward short-wave radiation flux
'239035' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward long-wave radiation flux
'239036' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface net short-wave radiation flux
'239037' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface net long-wave radiation flux
'239038' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation top net short-wave radiation flux
'239039' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation top net long-wave radiation flux
'239040' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward turbulent surface stress
'239041' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward turbulent surface stress
'239042' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation evaporation rate
'239043' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward gravity wave surface stress
'239045' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward gravity wave surface stress
'239046' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation gravity wave dissipation
'239047' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation runoff rate
'239048' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation top net short-wave radiation flux, clear sky
'239049' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation top net long-wave radiation flux, clear sky
'239050' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface net short-wave radiation flux, clear sky
'239051' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface net long-wave radiation flux, clear sky
'239052' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation top downward short-wave radiation flux
'239053' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated moisture divergence
'239054' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total precipitation rate
'239055' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation convective snowfall rate water equivalent
'239056' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation large scale snowfall rate water equivalent
'239057' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface direct short-wave radiation flux
'239058' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface direct short-wave radiation flux, clear sky
'239059' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward short-wave radiation flux, clear sky
'239068' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward long-wave radiation flux, clear sky
'239069' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation potential evaporation rate
'239070' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation volumetric soil moisture
'239077' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snow depth water equivalent
'239078' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation skin temperature
'239079' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snow density
'239080' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice area fraction
'239083' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea surface temperature
'239084' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column cloud liquid water
'239087' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column cloud ice water
'239088' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 2 metre specific humidity
'239089' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake mix-layer temperature
'239090' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake mix-layer depth
'239091' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation soil temperature
'239094' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wind speed
'239097' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation pressure
'239098' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation charnock
'239099' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation potential vorticity
'239100' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific rain water content
'239101' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific snow water content
'239102' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eta-coordinate vertical velocity
'239103' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation visibility
'239105' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wind direction
'239106' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column snow water
'239107' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation low cloud cover
'239108' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation medium cloud cover
'239109' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation high cloud cover
'239110' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column rain water
'239111' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation most-unstable CAPE
'239117' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated graupel (snow pellets)
'239120' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geopotential
'239129' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature
'239130' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation u component of wind
'239131' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation v component of wind
'239132' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific humidity
'239133' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface pressure
'239134' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertical velocity
'239135' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column water
'239136' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated water vapour
'239137' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vorticity (relative)
'239138' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean sea level pressure
'239151' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation divergence
'239155' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation relative humidity
'239157' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation boundary layer height
'239159' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre U wind component
'239165' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre V wind component
'239166' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 2 metre temperature
'239167' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 2 metre dewpoint temperature
'239168' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sunshine
'239189' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ozone mass mixing ratio
'239203' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre wind speed
'239207' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature of snow layer
'239238' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation forecast surface roughness
'239244' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation forecast logarithm of surface roughness for heat
'239245' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific cloud liquid water content
'239246' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific cloud ice water content
'239247' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation fraction of cloud cover
'239248' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation k index
'239257' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total totals index
'239258' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre wind direction
'239261' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation clear air turbulence (CAT)
'239262' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation forecast albedo
'239263' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation potential temperature
'239269' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation UV visible albedo for direct radiation (climatological)
'239281' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation UV visible albedo for diffuse radiation (climatological)
'239282' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation near IR albedo for direct radiation (climatological)
'239283' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation near IR albedo for diffuse radiation (climatological)
'239284' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation snow albedo
'239285' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation montgomery potential
'239286' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation convective available potential energy
'239287' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total cloud cover
'239288' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation skin reservoir content
'239289' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column integrated ozone
'239290' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated kinetic energy
'239291' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated enthalpy
'239292' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated potential + internal energy
'239293' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertical integral of potential+internal+latent energy
'239294' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated total energy
'239295' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated water enthalpy
'239296' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation UV visible albedo for direct radiation, isotropic component (climatological)
'239297' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation UV visible albedo for direct radiation, volumetric component (climatological)
'239298' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation UV visible albedo for direct radiation, geometric component (climatological)
'239299' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation near IR albedo for direct radiation, isotropic component (climatological)
'239300' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation near IR albedo for direct radiation, volumetric component (climatological)
'239301' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation near IR albedo for direct radiation, geometric component (climatological)
'239302' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation convective inhibition
'239303' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation friction velocity
'239304' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake bottom temperature
'239305' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake total layer temperature
'239306' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake shape factor
'239307' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake ice surface temperature
'239308' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake ice total depth
'239309' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation minimum vertical gradient of refractivity inside trapping layer
'239310' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean vertical gradient of refractivity inside trapping layer
'239311' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation duct base height
'239312' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 41 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation trapping layer base height
'239313' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation trapping layer top height
'239314' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of -10 degrees C atmospheric isothermal level above ground
'239315' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation cloud base height
'239316' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of 0 degrees C atmospheric isothermal level above ground
'239317' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre wind gust
'239318' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation relative humidity with respect to water
'239319' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 2 metre relative humidity with respect to water
'239320' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation convective available potential energy shear
'239321' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation tropopause pressure
'239322' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation height of convective cloud top
'239323' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation height of zero-degree wet-bulb temperature
'239324' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation height of one-degree wet-bulb temperature
'239325' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total lightning flash density
'239326' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column supercooled liquid water
'239327' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 167 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre U-component of neutral wind
'239328' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre V-component of neutral wind
'239329' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation convective rain rate
'239330' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation large scale rain rate
'239331' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mixed-layer CAPE in the lowest 50 hPa
'239332' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mixed-layer CIN in the lowest 50 hPa
'239333' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mixed-layer CAPE in the lowest 100 hPa
'239334' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mixed-layer CIN in the lowest 100 hPa
'239335' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation departure level of the most unstable parcel expressed as Pressure
'239336' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ceiling
'239337' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column integrated saturation specific humidity with respect to water
'239338' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 169 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation direct solar radiation flux
'239339' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation cosine of solar zenith angle
'239340' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation freezing rain rate water equivalent
'239341' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated eastward geopotential flux
'239342' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated northward geopotential flux
'239343' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of water geopotential flux
'239344' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of geopotential flux
'239345' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated eastward enthalpy flux
'239346' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated northward enthalpy flux
'239347' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated eastward kinetic energy flux
'239348' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated northward kinetic energy flux
'239349' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated eastward total energy flux
'239350' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated northward total energy flux
'239351' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of enthalpy flux
'239352' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of kinetic energy flux
'239353' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of total energy flux
'239354' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of water enthalpy flux
'239355' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of mass flux
'239356' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward mass flux
'239357' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward mass flux
'239358' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of water vapour flux
'239359' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of cloud liquid water flux
'239360' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of cloud ice water flux
'239361' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of rain flux
'239362' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of snow flux
'239363' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward water vapour flux
'239364' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward water vapour flux
'239365' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward cloud liquid water flux
'239366' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward cloud liquid water flux
'239367' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward cloud ice water flux
'239368' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward cloud ice water flux
'239369' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward rain flux
'239370' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward rain flux
'239371' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward snow flux
'239372' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward snow flux
'239373' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward ozone flux
'239374' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward ozone flux
'239375' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of ozone flux
'239376' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated net source of ozone
'239377' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward turbulent surface stress due to orographic form drag
'239378' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward turbulent surface stress due to orographic form drag
'239379' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward turbulent surface stress due to surface roughness
'239380' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward turbulent surface stress due to surface roughness
'239381' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation land surface heat net flux
'239386' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface direct normal short-wave radiation flux, clear sky
'239387' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre convective gust
'239388' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre turbulent gust
'239389' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of 0 degrees C theta level above ground
'239390' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of 1 degree C theta level above ground
'239391' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27415 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of 1.5 degrees C theta level above ground
'239392' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27465 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vegetation
'239393' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation leaf area index
'239394' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface roughness for heat
'239395' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation Reciprocal Obukhov length
'239396' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of 3 degrees C atmospheric isothermal level above ground
'239397' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27615 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface diffuse short-wave radiation flux, clear sky
'239404' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation volumetric soil moisture (root zone)
'239405' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Cross sectional area of flow in channel
'240011' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	}
#Side flow into river channel
'240012' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Discharge from rivers or streams
'240013' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#River storage of water
'240014' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Floodplain storage of water
'240015' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Days since last observation
'240017' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 3 ;
	}
#Frost index
'240018' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 24 ;
	}
#Depth of water on soil surface
'240020' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Upstream accumulated precipitation
'240021' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Upstream accumulated snow melt
'240022' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Snow depth at elevation bands
'240026' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	}
#Groundwater upper storage
'240028' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Groundwater lower storage
'240029' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Lake depth
'240030' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	}
#River depth
'240031' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	}
#River outflow of water
'240032' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	}
#Floodplain outflow of water
'240033' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}
#Floodpath outflow of water
'240034' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}
#Floodplain depth
'240035' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	}
#Floodplain flooded fraction
'240036' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	}
#Floodplain flooded area
'240037' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	}
#River fraction
'240038' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	}
#River area
'240039' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	}
#Fraction of river coverage plus river related flooding
'240040' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	}
#Area of river coverage plus river related flooding
'240041' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	}
#Latitude
'250001' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	}
#Longitude
'250002' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	}
#Latitude on T grid
'250003' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 1 ;
	}
#Longitude on T grid
'250004' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 1 ;
	}
#Latitude on U grid
'250005' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 2 ;
	}
#Longitude on U grid
'250006' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 2 ;
	}
#Latitude on V grid
'250007' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 3 ;
	}
#Longitude on V grid
'250008' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 3 ;
	}
#Latitude on W grid
'250009' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 4 ;
	}
#Longitude on W grid
'250010' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 4 ;
	}
#Latitude on F grid
'250011' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 5 ;
	}
#Longitude on F grid
'250012' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 5 ;
	}
#Total column vertically-integrated graupel (snow pellets)
'260001' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Surface latent heat net flux
'260002' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Heat index
'260004' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Wind chill factor
'260005' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Snow phase change heat flux
'260007' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Vapor pressure
'260008' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}
#Large scale precipitation (non-convective)
'260009' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}
#Snowfall rate water equivalent
'260010' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}
#Convective snow
'260011' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	}
#Large scale snow
'260012' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	}
#Snow age
'260013' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	}
#Absolute humidity
'260014' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 18 ;
	}
#Precipitation type
'260015' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	}
#Integrated liquid water
'260016' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 20 ;
	}
#Condensate
'260017' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 21 ;
	}
#Cloud mixing ratio
'260018' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 22 ;
	}
#Ice water mixing ratio
'260019' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 23 ;
	}
#Rain mixing ratio
'260020' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	}
#Snow mixing ratio
'260021' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 25 ;
	}
#Horizontal moisture convergence
'260022' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 26 ;
	}
#Total snowfall
'260025' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Precipitable water category
'260026' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 30 ;
	}
#Hail
'260027' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 31 ;
	}
#Graupel (snow pellets)
'260028' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 32 ;
	}
#Categorical rain
'260029' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 33 ;
	}
#Categorical freezing rain
'260030' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 34 ;
	}
#Categorical ice pellets
'260031' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 35 ;
	}
#Categorical snow
'260032' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 36 ;
	}
#Convective precipitation rate
'260033' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Horizontal moisture divergence
'260034' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 38 ;
	}
#Percent frozen precipitation
'260035' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 39 ;
	}
#Potential evaporation
'260036' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 40 ;
	}
#Snow cover
'260038' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 42 ;
	}
#Rain fraction of total cloud water
'260039' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 43 ;
	}
#Rime factor
'260040' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 44 ;
	}
#Total column integrated rain
'260041' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	}
#Total column integrated snow
'260042' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	}
#Large scale water precipitation (non-convective)
'260043' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 47 ;
	}
#Convective water precipitation
'260044' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 48 ;
	}
#Total water precipitation
'260045' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 49 ;
	}
#Total snow precipitation
'260046' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total column water (Vertically integrated total water (vapour + cloud water/ice))
'260047' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	}
#Total precipitation rate
'260048' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total snowfall rate water equivalent
'260049' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Large scale precipitation rate
'260050' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total snowfall rate
'260053' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 57 ;
	}
#Convective snowfall rate
'260054' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 58 ;
	}
#Large scale snowfall rate
'260055' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 59 ;
	}
#Water equivalent of accumulated snow depth (deprecated)
'260056' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}
#Rain precipitation rate
'260058' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 65 ;
	}
#Snow precipitation rate
'260059' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	}
#Freezing rain precipitation rate
'260060' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Ice pellets precipitation rate
'260061' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 68 ;
	}
#Wind speed (gust)
'260065' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	}
#u-component of wind (gust)
'260066' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	}
#v-component of wind (gust)
'260067' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	}
#Vertical speed shear
'260068' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	}
#Horizontal momentum flux
'260069' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 26 ;
	}
#U-component storm motion
'260070' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 27 ;
	}
#V-component storm motion
'260071' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 28 ;
	}
#Drag coefficient
'260072' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	}
#Frictional velocity
'260073' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	}
#Pressure reduced to MSL
'260074' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}
#Altimeter setting
'260076' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}
#Thickness
'260077' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}
#Pressure altitude
'260078' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}
#Density altitude
'260079' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}
#5-wave geopotential height
'260080' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}
#Instantaneous eastward gravity wave surface stress
'260081' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous northward gravity wave surface stress
'260082' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#5-wave geopotential height anomaly
'260084' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}
#Net short-wave radiation flux (top of atmosphere)
'260086' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}
#Surface downward short-wave radiation flux
'260087' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface upward short-wave radiation flux
'260088' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface net short-wave radiation flux
'260089' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface photosynthetically active radiation flux
'260090' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface net short-wave radiation flux, clear sky
'260091' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface downward UV radiation flux
'260092' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#UV index (under clear sky)
'260093' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	}
#UV index
'260094' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 51 ;
	}
#Surface downward long-wave radiation flux
'260097' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface upward long-wave radiation flux
'260098' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface net long-wave radiation flux
'260099' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface net long-wave radiation flux, clear sky
'260100' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Cloud Ice
'260101' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	}
#Cloud water
'260102' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 6 ;
	}
#Cloud amount
'260103' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 7 ;
	}
#Cloud type
'260104' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 8 ;
	}
#Thunderstorm maximum tops
'260105' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 9 ;
	}
#Thunderstorm coverage
'260106' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 10 ;
	}
#Cloud top
'260108' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 12 ;
	}
#Ceiling
'260109' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	}
#Non-convective cloud cover
'260110' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 14 ;
	}
#Cloud work function
'260111' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 15 ;
	}
#Convective cloud efficiency
'260112' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 16 ;
	}
#Total condensate
'260113' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 17 ;
	}
#Total column-integrated cloud water
'260114' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 18 ;
	}
#Total column-integrated cloud ice
'260115' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 19 ;
	}
#Total column-integrated condensate
'260116' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 20 ;
	}
#Ice fraction of total condensate
'260117' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 21 ;
	}
#Cloud ice mixing ratio
'260118' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 23 ;
	}
#Sunshine
'260119' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Horizontal extent of cumulonimbus (CB)
'260120' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 25 ;
	}
#K index
'260121' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	}
#KO index
'260122' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 3 ;
	}
#Total totals index
'260123' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	}
#Sweat index
'260124' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 5 ;
	}
#Storm relative helicity
'260125' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 8 ;
	}
#Energy helicity index
'260126' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 9 ;
	}
#Surface lifted index
'260127' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 10 ;
	}
#Best (4-layer) lifted index
'260128' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 11 ;
	}
#Aerosol type
'260129' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 0 ;
	}
#Total ozone
'260130' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 0 ;
	}
#Total column integrated ozone
'260132' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Base spectrum width
'260133' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 0 ;
	}
#Base reflectivity
'260134' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	}
#Base radial velocity
'260135' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 2 ;
	}
#Vertically-integrated liquid
'260136' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 3 ;
	}
#Layer-maximum base reflectivity
'260137' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 4 ;
	}
#Precipitation from radar
'260138' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Air concentration of Caesium 137
'260139' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 0 ;
	}
#Air concentration of Iodine 131
'260140' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 1 ;
	}
#Air concentration of radioactive pollutant
'260141' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 2 ;
	}
#Ground deposition of Caesium 137
'260142' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 3 ;
	}
#Ground deposition of Iodine 131
'260143' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 4 ;
	}
#Ground deposition of radioactive pollutant
'260144' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 5 ;
	}
#Time-integrated air concentration of caesium pollutant
'260145' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 6 ;
	}
#Time-integrated air concentration of iodine pollutant
'260146' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 7 ;
	}
#Time-integrated air concentration of radioactive pollutant
'260147' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 8 ;
	}
#Volcanic ash
'260148' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 4 ;
	}
#Icing top
'260149' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 5 ;
	}
#Icing base
'260150' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 6 ;
	}
#Icing
'260151' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 7 ;
	}
#Turbulence top
'260152' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 8 ;
	}
#Turbulence base
'260153' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 9 ;
	}
#Turbulence
'260154' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 10 ;
	}
#Turbulent kinetic energy
'260155' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 11 ;
	}
#Planetary boundary layer regime
'260156' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 12 ;
	}
#Contrail intensity
'260157' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 13 ;
	}
#Contrail engine type
'260158' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 14 ;
	}
#Contrail top
'260159' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 15 ;
	}
#Contrail base
'260160' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 16 ;
	}
#Snow free albedo
'260162' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 18 ;
	}
#Icing
'260163' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 20 ;
	}
#In-cloud turbulence
'260164' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 21 ;
	}
#Relative clear air turbulence (RCAT)
'260165' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 22 ;
	}
#Supercooled large droplet probability
'260166' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 23 ;
	}
#Arbitrary text string
'260167' = {
	 discipline = 0 ;
	 parameterCategory = 190 ;
	 parameterNumber = 0 ;
	}
#Seconds prior to initial reference time (defined in Section 1)
'260168' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}
#Flash flood guidance
'260169' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Flash flood runoff (Encoded as an accumulation over a floating subinterval of time)
'260170' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Remotely sensed snow cover
'260171' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Elevation of snow covered terrain
'260172' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Snow water equivalent percent of normal
'260173' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Baseflow-groundwater runoff
'260174' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Storm surface runoff
'260175' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Conditional percent precipitation amount fractile for an overall period (Encoded as an accumulation)
'260176' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Percent precipitation in a sub-period of an overall period
'260177' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Probability of 0.01 inch of precipitation (POP)
'260178' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}
#Vegetation
'260180' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Water runoff
'260181' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Evapotranspiration
'260182' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Model terrain height
'260183' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Land use
'260184' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Ground heat flux
'260186' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Moisture availability
'260187' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Exchange coefficient
'260188' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Plant canopy surface water
'260189' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Blackadar mixing length scale
'260190' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Canopy conductance
'260191' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Minimal stomatal resistance
'260192' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Solar parameter in canopy conductance
'260193' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}
#Temperature parameter in canopy conductance
'260194' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}
#Soil moisture parameter in canopy conductance
'260195' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}
#Humidity parameter in canopy conductance
'260196' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}
#Column-integrated soil water
'260197' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}
#Heat flux
'260198' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}
#Volumetric soil moisture
'260199' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}
#Volumetric wilting point
'260200' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}
#Number of soil layers in root zone
'260206' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	}
#Liquid volumetric soil moisture (non-frozen)
'260210' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}
#Volumetric transpiration stress-onset (soil moisture)
'260211' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}
#Transpiration stress-onset (soil moisture)
'260212' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}
#Volumetric direct evaporation cease (soil moisture)
'260213' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}
#Direct evaporation cease (soil moisture)
'260214' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}
#Soil porosity
'260215' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}
#Volumetric saturation of soil moisture
'260216' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	}
#Saturation of soil moisture
'260217' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	}
#Estimated precipitation
'260218' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Instantaneous rain rate
'260219' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Cloud top height
'260220' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}
#Cloud top height quality indicator
'260221' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}
#Estimated u component of wind
'260222' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}
#Estimated v component of wind
'260223' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}
#Number of pixels used
'260224' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 6 ;
	}
#Solar zenith angle
'260225' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}
#Relative azimuth angle
'260226' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 8 ;
	}
#Reflectance in 0.6 micron channel
'260227' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}
#Reflectance in 0.8 micron channel
'260228' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}
#Reflectance in 1.6 micron channel
'260229' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Reflectance in 3.9 micron channel
'260230' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}
#Atmospheric divergence
'260231' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}
#Direction of wind waves
'260232' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Primary wave direction
'260233' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Primary wave mean period
'260234' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Secondary wave mean period
'260235' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Current direction
'260236' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Current speed
'260237' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Geometric vertical velocity
'260238' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 9 ;
	}
#Seconds prior to initial reference time (defined in Section 1)
'260241' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}
#2 metre relative humidity
'260242' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Apparent temperature
'260255' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}
#Haines Index
'260256' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 2 ;
	}
#Cloud cover
'260257' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	}
#Evaporation
'260259' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#10 metre wind direction
'260260' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Surface direct short-wave radiation flux
'260262' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface diffuse short-wave radiation flux
'260263' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Fraction of snow cover
'260289' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 121 ;
	}
#Clear air turbulence (CAT)
'260290' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	}
#Mountain wave turbulence (eddy dissipation rate)
'260291' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 28 ;
	}
#Specific rain water content (convective)
'260292' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 144 ;
	}
#Specific snow water content (convective)
'260293' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 145 ;
	}
#Glacier mask
'260294' = {
	 discipline = 2 ;
	 parameterCategory = 5 ;
	 parameterNumber = 0 ;
	}
#Soil temperature
'260360' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	}
#Surface downward short-wave radiation flux, clear sky
'260361' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface upward short-wave radiation flux, clear sky
'260362' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface downward long-wave radiation flux, clear sky
'260363' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Soil heat flux
'260364' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 26 ;
	}
#Percolation rate
'260365' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Soil depth
'260367' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	}
#Soil moisture
'260368' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}
#Leaf Area Index
'260373' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Accumulated surface upward short-wave radiation flux, clear sky
'260427' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Percolation
'260430' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 177 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Evapotranspiration rate
'260433' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Potential evapotranspiration rate
'260436' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Runoff rate water equivalent (surface plus subsurface)
'260443' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	}
#Snow melt rate
'260475' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Forecast albedo
'260509' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	}
#Cloudy brightness temperature
'260510' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	}
#Clear-sky brightness temperature
'260511' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	}
#Cloudy reflectance
'260512' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 31 ;
	}
#Clear reflectance
'260513' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 32 ;
	}
#Scaled radiance
'260530' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Scaled albedo
'260531' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Scaled brightness temperature
'260532' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Scaled precipitable water
'260533' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Scaled lifted index
'260534' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Scaled cloud top pressure
'260535' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Scaled skin temperature
'260536' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Cloud mask
'260537' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Pixel scene type
'260538' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Fire detection indicator
'260539' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Forest fire weather index (as defined by the Canadian Forest Service)
'260540' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 5 ;
	}
#Fine fuel moisture code (as defined by the Canadian Forest Service)
'260541' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 6 ;
	}
#Duff moisture code (as defined by the Canadian Forest Service)
'260542' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	}
#Drought code (as defined by the Canadian Forest Service)
'260543' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	}
#Initial fire spread index (as defined by the Canadian Forest Service)
'260544' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	}
#Fire buildup index (as defined by the Canadian Forest Service)
'260545' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	}
#Fire daily severity rating (as defined by the Canadian Forest Service)
'260546' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	}
#Cloudy radiance (with respect to wave number)
'260550' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	}
#Clear-sky radiance (with respect to wave number)
'260551' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	}
#Wind speed
'260552' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	}
#Aerosol optical thickness at 0.635 um
'260553' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 20 ;
	}
#Aerosol optical thickness at 0.810 um
'260554' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 21 ;
	}
#Aerosol optical thickness at 1.640 um
'260555' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 22 ;
	}
#Angstrom coefficient
'260556' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 23 ;
	}
#Keetch-Byram drought index
'260557' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	}
#Drought factor (as defined by the Australian forest service)
'260558' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	}
#Rate of spread (as defined by the Australian forest service)
'260559' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	}
#Fire danger index (as defined by the Australian forest service)
'260560' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 15 ;
	}
#Spread component (as defined by the U.S Forest Service National Fire-Danger Rating System)
'260561' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 16 ;
	}
#Burning index (as defined by the U.S Forest Service National Fire-Danger Rating System)
'260562' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 17 ;
	}
#Ignition component (as defined by the U.S Forest Service National Fire-Danger Rating System)
'260563' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	}
#Energy release component (as defined by the U.S Forest Service National Fire-Danger Rating System)
'260564' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 19 ;
	}
#Volumetric soil ice
'260644' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 38 ;
	}
#Time integral of total solid precipitation flux
'260645' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 128 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Fog
'260648' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Time-integrated eastward turbulent surface stress due to orographic form drag
'260652' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated northward turbulent surface stress due to orographic form drag
'260653' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated eastward turbulent surface stress due to surface roughness
'260654' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated northward turbulent surface stress due to surface roughness
'260655' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Saturation specific humidity with respect to water
'260656' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 168 ;
	}
#Total column integrated saturation specific humidity with respect to water
'260657' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 169 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Standardised Precipitation Index (SPI)
'260658' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 0 ;
	}
#Standardised Precipitation Evapotranspiration Index (SPEI)
'260659' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 1 ;
	}
#Standardised Streamflow Index (SSFI)
'260660' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 2 ;
	}
#Standardised Reservoir Supply Index (SRSI)
'260661' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 3 ;
	}
#Standardised Water-level Index (SWI)
'260662' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 4 ;
	}
#Standardised Snowmelt and Rain Index (SMRI)
'260663' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 5 ;
	}
#Streamflow Drought Index (SDI)
'260664' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 6 ;
	}
#Volumetric soil moisture top 20 cm
'260665' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Volumetric soil moisture top 100 cm
'260666' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Surface photosynthetically active radiation flux, clear sky
'260667' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface direct normal short-wave radiation flux
'260668' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Instantaneous magnitude of turbulent surface stress
'260669' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous boundary layer dissipation
'260670' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	}
#Top net short-wave radiation flux
'260671' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Top net long-wave radiation flux
'260672' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Instantaneous gravity wave dissipation
'260673' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	}
#Top net short-wave radiation flux, clear sky
'260674' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Top net long-wave radiation flux, clear sky
'260675' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Top downward short-wave radiation flux
'260676' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Surface direct short-wave radiation flux, clear sky
'260677' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous eastward turbulent surface stress due to orographic form drag
'260678' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous northward turbulent surface stress due to orographic form drag
'260679' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous eastward turbulent surface stress due to surface roughness
'260680' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous northward turbulent surface stress due to surface roughness
'260681' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Time-severity precipitation type
'260682' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 100 ;
	}
#Time-mode precipitation type
'260683' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 101 ;
	}
#Land surface heat net flux
'260684' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface direct normal short-wave radiation flux, clear sky
'260685' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#10 metre convective gust
'260686' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#10 metre turbulent gust
'260687' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Reciprocal Obukhov length
'260688' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 22 ;
	}
#Precipitation rate from radar
'260689' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 17 ;
	}
#Radar data quality index
'260690' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 18 ;
	}
#Radar data quality flag
'260691' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 19 ;
	}
#Precipitation rate from forecasted radar imagery
'260692' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 6 ;
	}
#Precipitation from forecasted radar imagery
'260693' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface diffuse short-wave radiation flux, clear sky
'260694' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Universal thermal climate index
'261001' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Mean radiant temperature
'261002' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Fraction of Malaria cases
'261003' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Malaria circumsporozoite protein ratio
'261004' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Plasmodium falciparum entomological inoculation rate
'261005' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}
#Human bite rate by anopheles vectors
'261006' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}
#Malaria immunity ratio
'261007' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}
#Falciparum parasite ratio
'261008' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}
#Detectable falciparum parasite ratio (after day 10)
'261009' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 6 ;
	}
#Anopheles vector to host ratio
'261010' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}
#Anopheles vector density
'261011' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 8 ;
	}
#Fraction of malarial vector reproductive habitat
'261012' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}
#Population density
'261013' = {
	 discipline = 20 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}
#Wet bulb globe temperature
'261014' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Globe temperature
'261015' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Humidex
'261016' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Effective temperature
'261017' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Normal effective temperature
'261018' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Standard effective temperature
'261019' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Physiological equivalent temperature
'261020' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Saturation water vapour pressure
'261021' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 32 ;
	}
#Wet-bulb potential temperature
'261022' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	}
#Wet-bulb temperature
'261023' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}
#Excess heat factor
'261024' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Excess cold factor
'261025' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Sea ice thickness
'262000' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}
#Sea ice area fraction
'262001' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Eastward sea ice velocity
'262003' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Northward sea ice velocity
'262004' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice albedo
'262005' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice surface temperature
'262006' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice growth
'262007' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice volume per unit area
'262008' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Snow volume over sea ice per unit area
'262009' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Vertically averaged sea ice temperature
'262010' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Snow temperature over sea ice
'262011' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice temperature at the sea ice and snow interface
'262012' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 175 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Underside ice temperature
'262013' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 176 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice heat content
'262014' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Snow heat content over sea ice
'262015' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice freeboard thickness
'262016' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Sea ice melt pond fraction
'262017' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice melt pond depth
'262018' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice melt pond volume per unit area
'262019' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice fraction tendency due to parameterization
'262020' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#X-component of sea ice velocity
'262021' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Y-component of sea ice velocity
'262022' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice temperature
'262024' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}
#Sea ice breakup memory
'262025' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	}
#Sea surface practical salinity
'262100' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}
#Sea surface temperature
'262101' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Depth of 14 C isotherm
'262102' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 28715 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Depth of 17 C isotherm
'262103' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29015 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Depth of 20 C isotherm
'262104' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Depth of 26 C isotherm
'262105' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29915 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Depth of 28 C isotherm
'262106' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 30115 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Barotropic stream function
'262107' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Surface downward heat flux
'262108' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}
#Northward surface stress
'262109' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	}
#Eastward surface stress
'262110' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}
#Y-component of surface stress
'262111' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#X-component of surface stress
'262112' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by sigma theta 0.01 kg m-3
'262113' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by sigma theta 0.03 kg m-3
'262114' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 3 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by sigma theta 0.125 kg m-3
'262115' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 125 ;
	 scaleFactorOfFirstFixedSurface = 3 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by temperature 0.2 C
'262116' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by temperature 0.5 C
'262117' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Average sea water practical salinity in the upper 300 m
'262118' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Average sea water practical salinity in the upper 700 m
'262119' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Total column average sea water practical salinity
'262120' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Vertically-integrated heat content in the upper 300 m
'262121' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Vertically-integrated heat content in the upper 700 m
'262122' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Total column of heat content
'262123' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea surface height
'262124' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}
#Steric change in sea surface height
'262125' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Halosteric change in sea surface height
'262126' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Thermosteric change in sea surface height
'262127' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Thermocline depth
'262128' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Bottom pressure equivalent height
'262129' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Net surface upward water flux
'262130' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Fresh water flux into sea water (from rivers)
'262131' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Virtual salt flux into sea water
'262132' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 32 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Heat flux correction
'262133' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Fresh water flux correction
'262134' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 31 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Virtual salt flux correction
'262135' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 33 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Turbocline depth (kz=5e-4)
'262136' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 171 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 4 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Y-component of surface sea water velocity
'262137' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#X-component of surface sea water velocity
'262138' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Northward surface sea water velocity
'262139' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}
#Eastward surface sea water velocity
'262140' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}
#Heat Content surface to 26C isotherm
'262141' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 29915 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	}
#Sea surface height tendency due to parameterization
'262142' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea surface height with inverse barometer correction
'262143' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	}
#Average sea water potential temperature in the upper 300m
'262144' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Sea surface salinity
'262145' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	}
#Vertically integrated sea water practical salinity in the upper 300 m
'262146' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Vertically integrated sea water practical salinity in the upper 700 m
'262147' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Total column vertically integrated sea water practical salinity
'262148' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea surface downward short-wave radiation flux
'262149' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	}
#Sea water practical salinity
'262500' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water potential temperature
'262501' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water sigma theta
'262502' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Y-component of sea water velocity
'262503' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#X-component of sea water velocity
'262504' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Northward sea water velocity
'262505' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Eastward sea water velocity
'262506' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Upward sea water velocity
'262507' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea water potential temperature tendency due to newtonian relaxation
'262508' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water salinity tendency due to newtonian relaxation
'262509' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water temperature tendency due to parameterization
'262510' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water salinity tendency due to parameterization
'262511' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Eastward sea water velocity tendency due to parameterization
'262512' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 38 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Northward sea water velocity tendency due to parameterization
'262513' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water temperature tendency due to direct bias correction
'262514' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water salinity tendency due to direct bias correction
'262515' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water salinity
'262516' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Northward mass transport
'262517' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Eastward mass transport
'262518' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water depth
'262519' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water upward mass transport
'262520' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water age since surface contact
'262521' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water downward short-wave radiation flux
'262522' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Net short wave radiation rate at sea surface
'262900' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Wind stress at sea surface
'262901' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 49 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Wind speed at 10m above sea surface
'262902' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Neutral drag coefficient at 10m above sea surface
'262903' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Total precipitation rate at sea surface
'262904' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Snow precipitation rate at sea surface
'262905' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Eastward component of wind stress over sea ice
'262906' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Northward component of wind stress over sea ice
'262907' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#U-component of wind stress over sea ice
'262908' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#V-component of wind stress over sea ice
'262909' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Time-mean sea ice thickness
'263000' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice area fraction
'263001' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward sea ice velocity
'263003' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward sea ice velocity
'263004' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice albedo
'263005' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice surface temperature
'263006' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice growth
'263007' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice volume per unit area
'263008' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow volume over sea ice per unit area
'263009' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertically averaged sea ice temperature
'263010' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow temperature over sea ice
'263011' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice temperature at the sea ice and snow interface
'263012' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 175 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean underside ice temperature
'263013' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 176 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice heat content
'263014' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow heat content over sea ice
'263015' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice freeboard thickness
'263016' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice melt pond fraction
'263017' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice melt pond depth
'263018' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice melt pond volume per unit area
'263019' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice fraction tendency due to parameterization
'263020' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean X-component of sea ice velocity
'263021' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Y-component of sea ice velocity
'263022' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice temperature
'263024' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice breakup memory
'263025' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface practical salinity
'263100' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface temperature
'263101' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth of 14 C isotherm
'263102' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 28715 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth of 17 C isotherm
'263103' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29015 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth of 20 C isotherm
'263104' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth of 26 C isotherm
'263105' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29915 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth of 28 C isotherm
'263106' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 30115 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean barotropic stream function
'263107' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward heat flux
'263108' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward surface stress
'263109' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward surface stress
'263110' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time mean Y-component of surface stress
'263111' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean X-component of surface stress
'263112' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ocean mixed layer depth defined by sigma theta 0.01 kg m-3
'263113' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ocean mixed layer depth defined by sigma theta 0.03 kg m-3
'263114' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 3 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ocean mixed layer depth defined by sigma theta 0.125 kg m-3
'263115' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 125 ;
	 scaleFactorOfFirstFixedSurface = 3 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ocean mixed layer depth defined by temperature 0.2 C
'263116' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ocean mixed layer depth defined by temperature 0.5 C
'263117' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean average sea water practical salinity in the upper 300 m
'263118' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean average sea water practical salinity in the upper 700 m
'263119' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column average sea water practical salinity
'263120' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertically-integrated heat content in the upper 300 m
'263121' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertically-integrated heat content in the upper 700 m
'263122' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column heat content
'263123' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface height
'263124' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean steric change in sea surface height
'263125' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean halosteric change in sea surface height
'263126' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean thermosteric change in sea surface height
'263127' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean thermocline depth
'263128' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean bottom pressure equivalent height
'263129' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean net surface upward water flux
'263130' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean fresh water flux into sea water (from rivers)
'263131' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean virtual salt flux into sea water
'263132' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 32 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean heat flux correction
'263133' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean fresh water flux correction
'263134' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 31 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean virtual salt flux correction
'263135' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 33 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean turbocline depth (kz=5e-4)
'263136' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 171 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 4 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Y-component of surface sea water velocity
'263137' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean X-component of surface sea water velocity
'263138' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward surface sea water velocity
'263139' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward surface sea water velocity
'263140' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean heat content surface to 26C isotherm
'263141' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 29915 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface height tendency due to parameterization
'263142' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface height with inverse barometer correction
'263143' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean average sea water potential temperature in the upper 300m
'263144' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface salinity
'263145' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertically integrated sea water practical salinity in the upper 300 m
'263146' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertically integrated sea water practical salinity in the upper 700 m
'263147' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically integrated sea water practical salinity
'263148' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface downward short-wave radiation flux
'263149' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water practical salinity
'263500' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water potential temperature
'263501' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water sigma theta
'263502' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Y-component of sea water velocity
'263503' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean X-component of sea water velocity
'263504' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward sea water velocity
'263505' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward sea water velocity
'263506' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean upward sea water velocity
'263507' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water potential temperature tendency due to newtonian relaxation
'263508' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water salinity tendency due to newtonian relaxation
'263509' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water temperature tendency due to parameterization
'263510' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water salinity tendency due to parameterization
'263511' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward sea water velocity tendency due to parameterization
'263512' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 38 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward sea water velocity tendency due to parameterization
'263513' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water temperature tendency due to direct bias correction
'263514' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water salinity tendency due to direct bias correction
'263515' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water salinity
'263516' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward mass transport
'263517' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward mass transport
'263518' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water depth
'263519' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water upward mass transport
'263520' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water age since surface contact
'263521' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water downward short-wave radiation flux
'263522' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean net short wave radiation rate at sea surface
'263900' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wind stress at sea surface
'263901' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 49 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wind speed at 10m above sea surface
'263902' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean neutral drag coefficient at 10m above sea surface
'263903' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total precipitation rate at sea surface
'263904' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow precipitation rate at sea surface
'263905' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward component of wind stress over sea ice
'263906' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward component of wind stress over sea ice
'263907' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U-component of wind stress over sea ice
'263908' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V-component of wind stress over sea ice
'263909' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-accumulated net short wave radiation at sea surface
'264900' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-accumulated total precipitation at sea surface
'264904' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-accumulated snow precipitation at sea surface
'264905' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-maximum sea ice temperature
'265024' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water depth
'265519' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum sea ice temperature
'266024' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water depth
'266519' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation sea ice temperature
'267024' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water depth
'267519' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Virtual temperature
'300012' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Mass density
'400000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	}
#Time-mean mass density
'400001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum mass density
'400003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum mass density
'400004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation mass density
'400005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Total column vertically-integrated mass density
'401000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Time-mean total column vertically-integrated mass density
'401001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum total column vertically-integrated mass density
'401003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum total column vertically-integrated mass density
'401004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation total column vertically-integrated mass density
'401005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Mass mixing ratio
'402000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	}
#Time-mean mass mixing ratio
'402001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum mass mixing ratio
'402003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum mass mixing ratio
'402004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation mass mixing ratio
'402005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Emission mass flux
'403000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 255 ;
	}
#Time-mean emission mass flux
'403001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 255 ;
	}
#Time-maximum emission mass flux
'403003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 255 ;
	}
#Time-minimum emission mass flux
'403004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 255 ;
	}
#Time-standard-deviation emission mass flux
'403005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 255 ;
	}
#Dry deposition velocity
'404000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	}
#Time-mean dry deposition velocity
'404001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum dry deposition velocity
'404003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum dry deposition velocity
'404004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation dry deposition velocity
'404005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Wet deposition mass flux
'405000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	}
#Time-mean wet deposition mass flux
'405001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum wet deposition mass flux
'405003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum wet deposition mass flux
'405004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation wet deposition mass flux
'405005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Dry deposition mass flux
'406000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	}
#Time-mean dry deposition mass flux
'406001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum dry deposition mass flux
'406003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum dry deposition mass flux
'406004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation dry deposition mass flux
'406005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Sedimentation mass flux
'407000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	}
#Time-mean sedimentation mass flux
'407001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum sedimentation mass flux
'407003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum sedimentation mass flux
'407004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation sedimentation mass flux
'407005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Volume mixing ratio
'408000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 52 ;
	}
#Time-mean volume mixing ratio
'408001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum volume mixing ratio
'408003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum volume mixing ratio
'408004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation volume mixing ratio
'408005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Volume-mean total column mixing ratio
'409000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 84 ;
	}
#Time-mean volume-mean total column mixing ratio
'409001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum volume-mean total column mixing ratio
'409003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum volume-mean total column mixing ratio
'409004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation volume-mean total column mixing ratio
'409005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Wet deposition mass flux by large-scale precipitation
'410000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	}
#Time-mean wet deposition mass flux by large-scale precipitation
'410001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum wet deposition mass flux by large-scale precipitation
'410003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum wet deposition mass flux by large-scale precipitation
'410004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation wet deposition mass flux by large-scale precipitation
'410005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Wet deposition mass flux by convective precipitation
'411000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	}
#Time-mean wet deposition mass flux by convective precipitation
'411001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum wet deposition mass flux by convective precipitation
'411003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum wet deposition mass flux by convective precipitation
'411004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation wet deposition mass flux by convective precipitation
'411005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Emission mass flux from vegetation
'412000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 34 ;
	}
#Time-mean emission mass flux from vegetation
'412001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 34 ;
	}
#Time-maximum emission mass flux from vegetation
'412003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 34 ;
	}
#Time-minimum emission mass flux from vegetation
'412004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 34 ;
	}
#Time-standard-deviation emission mass flux from vegetation
'412005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 34 ;
	}
#Emission mass flux from natural sources
'413000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 6 ;
	}
#Time-mean emission mass flux from natural sources
'413001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 6 ;
	}
#Time-maximum emission mass flux from natural sources
'413003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 6 ;
	}
#Time-minimum emission mass flux from natural sources
'413004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 6 ;
	}
#Time-standard-deviation emission mass flux from natural sources
'413005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 6 ;
	}
#Emission mass flux from anthropogenic sources
'414000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 4 ;
	}
#Time-mean emission mass flux from anthropogenic sources
'414001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 4 ;
	}
#Time-maximum emission mass flux from anthropogenic sources
'414003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 4 ;
	}
#Time-minimum emission mass flux from anthropogenic sources
'414004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 4 ;
	}
#Time-standard-deviation emission mass flux from anthropogenic sources
'414005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 4 ;
	}
#Emission mass flux from elevated anthropogenic sources
'415000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 12 ;
	}
#Time-mean emission mass flux from elevated anthropogenic sources
'415001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 12 ;
	}
#Time-maximum emission mass flux from elevated anthropogenic sources
'415003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 12 ;
	}
#Time-minimum emission mass flux from elevated anthropogenic sources
'415004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 12 ;
	}
#Time-standard-deviation emission mass flux from elevated anthropogenic sources
'415005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 12 ;
	}
#Emission mass flux from surface anthropogenic sources
'416000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 13 ;
	}
#Time-mean emission mass flux from surface anthropogenic sources
'416001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 13 ;
	}
#Time-maximum emission mass flux from surface anthropogenic sources
'416003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 13 ;
	}
#Time-minimum emission mass flux from surface anthropogenic sources
'416004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 13 ;
	}
#Time-standard-deviation emission mass flux from surface anthropogenic sources
'416005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 13 ;
	}
#Emission mass flux from biomass burning
'417000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 35 ;
	}
#Time-mean emission mass flux from biomass burning
'417001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 35 ;
	}
#Time-maximum emission mass flux from biomass burning
'417003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 35 ;
	}
#Time-minimum emission mass flux from biomass burning
'417004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 35 ;
	}
#Time-standard-deviation emission mass flux from biomass burning
'417005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 35 ;
	}
#Emission from aviation
'418000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 1 ;
	}
#Time-mean emission from aviation
'418001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 1 ;
	}
#Time-maximum emission from aviation
'418003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 1 ;
	}
#Time-minimum emission from aviation
'418004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 1 ;
	}
#Time-standard-deviation emission from aviation
'418005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 1 ;
	}
#Emission mass flux from agriculture livestock
'419000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 14 ;
	}
#Time-mean emission mass flux from agriculture livestock
'419001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 14 ;
	}
#Time-maximum emission mass flux from agriculture livestock
'419003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 14 ;
	}
#Time-minimum emission mass flux from agriculture livestock
'419004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 14 ;
	}
#Time-standard-deviation emission mass flux from agriculture livestock
'419005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 14 ;
	}
#Emission mass flux from agriculture soils
'420000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 15 ;
	}
#Time-mean emission mass flux from agriculture soils
'420001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 15 ;
	}
#Time-maximum emission mass flux from agriculture soils
'420003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 15 ;
	}
#Time-minimum emission mass flux from agriculture soils
'420004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 15 ;
	}
#Time-standard-deviation emission mass flux from agriculture soils
'420005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 15 ;
	}
#Emission mass flux from agricultural waste burning
'421000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 16 ;
	}
#Time-mean emission mass flux from agricultural waste burning
'421001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 16 ;
	}
#Time-maximum emission mass flux from agricultural waste burning
'421003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 16 ;
	}
#Time-minimum emission mass flux from agricultural waste burning
'421004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 16 ;
	}
#Time-standard-deviation emission mass flux from agricultural waste burning
'421005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 16 ;
	}
#Emission mass flux from residential, commercial and other combustion
'422000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 18 ;
	}
#Time-mean emission mass flux from residential, commercial and other combustion
'422001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 18 ;
	}
#Time-maximum emission mass flux from residential, commercial and other combustion
'422003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 18 ;
	}
#Time-minimum emission mass flux from residential, commercial and other combustion
'422004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 18 ;
	}
#Time-standard-deviation emission mass flux from residential, commercial and other combustion
'422005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 18 ;
	}
#Emission mass flux from power generation
'423000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 19 ;
	}
#Time-mean emission mass flux from power generation
'423001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 19 ;
	}
#Time-maximum emission mass flux from power generation
'423003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 19 ;
	}
#Time-minimum emission mass flux from power generation
'423004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 19 ;
	}
#Time-standard-deviation emission mass flux from power generation
'423005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 19 ;
	}
#Emission mass flux from fugitives
'424000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 21 ;
	}
#Time-mean emission mass flux from fugitives
'424001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 21 ;
	}
#Time-maximum emission mass flux from fugitives
'424003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 21 ;
	}
#Time-minimum emission mass flux from fugitives
'424004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 21 ;
	}
#Time-standard-deviation emission mass flux from fugitives
'424005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 21 ;
	}
#Emission mass flux from industrial process
'425000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 22 ;
	}
#Time-mean emission mass flux from industrial process
'425001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 22 ;
	}
#Time-maximum emission mass flux from industrial process
'425003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 22 ;
	}
#Time-minimum emission mass flux from industrial process
'425004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 22 ;
	}
#Time-standard-deviation emission mass flux from industrial process
'425005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 22 ;
	}
#Emission mass flux from solvents
'426000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 23 ;
	}
#Time-mean emission mass flux from solvents
'426001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 23 ;
	}
#Time-maximum emission mass flux from solvents
'426003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 23 ;
	}
#Time-minimum emission mass flux from solvents
'426004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 23 ;
	}
#Time-standard-deviation emission mass flux from solvents
'426005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 23 ;
	}
#Emission mass flux from ships
'427000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 24 ;
	}
#Time-mean emission mass flux from ships
'427001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 24 ;
	}
#Time-maximum emission mass flux from ships
'427003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 24 ;
	}
#Time-minimum emission mass flux from ships
'427004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 24 ;
	}
#Time-standard-deviation emission mass flux from ships
'427005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 24 ;
	}
#Emission mass flux from wastes (solid and water)
'428000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 25 ;
	}
#Time-mean emission mass flux from wastes (solid and water)
'428001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 25 ;
	}
#Time-maximum emission mass flux from wastes (solid and water)
'428003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 25 ;
	}
#Time-minimum emission mass flux from wastes (solid and water)
'428004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 25 ;
	}
#Time-standard-deviation emission mass flux from wastes (solid and water)
'428005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 25 ;
	}
#Emission mass flux from off-road transportation
'429000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 27 ;
	}
#Time-mean emission mass flux from off-road transportation
'429001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 27 ;
	}
#Time-maximum emission mass flux from off-road transportation
'429003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 27 ;
	}
#Time-minimum emission mass flux from off-road transportation
'429004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 27 ;
	}
#Time-standard-deviation emission mass flux from off-road transportation
'429005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 27 ;
	}
#Emission mass flux from road transportation
'430000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 26 ;
	}
#Time-mean emission mass flux from road transportation
'430001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 26 ;
	}
#Time-maximum emission mass flux from road transportation
'430003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 26 ;
	}
#Time-minimum emission mass flux from road transportation
'430004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 26 ;
	}
#Time-standard-deviation emission mass flux from road transportation
'430005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 26 ;
	}
#Emission mass flux from super power stations
'431000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 20 ;
	}
#Time-mean emission mass flux from super power stations
'431001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 20 ;
	}
#Time-maximum emission mass flux from super power stations
'431003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 20 ;
	}
#Time-minimum emission mass flux from super power stations
'431004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 20 ;
	}
#Time-standard-deviation emission mass flux from super power stations
'431005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 20 ;
	}
#Emission mass flux from settlements
'432000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 36 ;
	}
#Time-mean emission mass flux from settlements
'432001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 36 ;
	}
#Time-maximum emission mass flux from settlements
'432003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 36 ;
	}
#Time-minimum emission mass flux from settlements
'432004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 36 ;
	}
#Time-standard-deviation emission mass flux from settlements
'432005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 36 ;
	}
#Emission mass flux from volcanoes
'433000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-mean emission mass flux from volcanoes
'433001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-maximum emission mass flux from volcanoes
'433003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-minimum emission mass flux from volcanoes
'433004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-standard-deviation emission mass flux from volcanoes
'433005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Emission mass flux from wetlands
'434000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 10 ;
	}
#Time-mean emission mass flux from wetlands
'434001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 10 ;
	}
#Time-maximum emission mass flux from wetlands
'434003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 10 ;
	}
#Time-minimum emission mass flux from wetlands
'434004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 10 ;
	}
#Time-standard-deviation emission mass flux from wetlands
'434005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 10 ;
	}
#Net ecosystem exchange flux
'435000' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	}
#Mean net ecosystem exchange flux
'435001' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Accumulated net ecosystem exchange flux
'435002' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-maximum net ecosystem exchange flux
'435003' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum net ecosystem exchange flux
'435004' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation net ecosystem exchange flux
'435005' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Gross primary production flux
'436000' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	}
#Mean gross primary production flux
'436001' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Accumulated gross primary production flux
'436002' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-maximum gross primary production flux
'436003' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum gross primary production flux
'436004' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation gross primary production flux
'436005' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Ecosystem respiration flux
'437000' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	}
#Mean ecosystem respiration flux
'437001' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Accumulated ecosystem respiration flux
'437002' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-maximum ecosystem respiration flux
'437003' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum ecosystem respiration flux
'437004' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation ecosystem respiration flux
'437005' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Emission mass flux from bio fuel
'438000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 8 ;
	}
#Time-mean emission mass flux from bio fuel
'438001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 8 ;
	}
#Time-maximum emission mass flux from bio fuel
'438003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 8 ;
	}
#Time-minimum emission mass flux from bio fuel
'438004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 8 ;
	}
#Time-standard-deviation emission mass flux from bio fuel
'438005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 8 ;
	}
#Emission mass flux from fossil fuel
'439000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 9 ;
	}
#Time-mean emission mass flux from fossil fuel
'439001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 9 ;
	}
#Time-maximum emission mass flux from fossil fuel
'439003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 9 ;
	}
#Time-minimum emission mass flux from fossil fuel
'439004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 9 ;
	}
#Time-standard-deviation emission mass flux from fossil fuel
'439005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 9 ;
	}
#Emission mass flux from other
'440000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 0 ;
	}
#Time-mean emission mass flux from other
'440001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 0 ;
	}
#Time-maximum emission mass flux from other
'440003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 0 ;
	}
#Time-minimum emission mass flux from other
'440004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 0 ;
	}
#Time-standard-deviation emission mass flux from other
'440005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 0 ;
	}
#Emission mass flux from oceans
'441000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 11 ;
	}
#Time-mean emission mass flux from oceans
'441001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 11 ;
	}
#Time-maximum emission mass flux from oceans
'441003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 11 ;
	}
#Time-minimum emission mass flux from oceans
'441004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 11 ;
	}
#Time-standard-deviation emission mass flux from oceans
'441005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 11 ;
	}
#Emission mass flux from soil
'442000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 37 ;
	}
#Time-mean emission mass flux from soil
'442001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 37 ;
	}
#Time-maximum emission mass flux from soil
'442003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 37 ;
	}
#Time-minimum emission mass flux from soil
'442004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 37 ;
	}
#Time-standard-deviation emission mass flux from soil
'442005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 37 ;
	}
#Emission mass flux from wild animals
'443000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 38 ;
	}
#Time-mean emission mass flux from wild animals
'443001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 38 ;
	}
#Time-maximum emission mass flux from wild animals
'443003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 38 ;
	}
#Time-minimum emission mass flux from wild animals
'443004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 38 ;
	}
#Time-standard-deviation emission mass flux from wild animals
'443005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 38 ;
	}
#Accumulated wet deposition mass flux
'444000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated dry deposition mass flux
'445000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Aerosol number density
'450000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	}
#Time-mean aerosol number density
'450001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum aerosol number density
'450003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum aerosol number density
'450004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation aerosol number density
'450005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Mass mixing ratio from volcanoes
'454000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-mean mass mixing ratio from volcanoes
'454001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-maximum mass mixing ratio from volcanoes
'454003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-minimum mass mixing ratio from volcanoes
'454004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-standard-deviation mass mixing ratio from volcanoes
'454005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Total column vertically-integrated mass density from volcanoes
'455000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-mean total column vertically-integrated mass density from volcanoes
'455001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-maximum total column vertically-integrated mass density from volcanoes
'455003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-minimum total column vertically-integrated mass density from volcanoes
'455004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-standard-deviation total column vertically-integrated mass density from volcanoes
'455005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Dry deposition velocity from volcanoes
'456000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-mean dry deposition velocity from volcanoes
'456001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-maximum dry deposition velocity from volcanoes
'456003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-minimum dry deposition velocity from volcanoes
'456004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-standard-deviation dry deposition velocity from volcanoes
'456005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Aerosol optical depth
'457000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	}
#Time-mean aerosol optical depth
'457001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum aerosol optical depth
'457003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum aerosol optical depth
'457004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation aerosol optical depth
'457005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Single scattering albedo
'458000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 103 ;
	}
#Time-mean single scattering albedo
'458001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 103 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum single scattering albedo
'458003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 103 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum single scattering albedo
'458004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 103 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation single scattering albedo
'458005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 103 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Asymmetry Factor
'459000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 104 ;
	}
#Time-mean asymmetry Factor
'459001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 104 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum asymmetry Factor
'459003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 104 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum asymmetry Factor
'459004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 104 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation asymmetry Factor
'459005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 104 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Attenuated aerosol backscatter from top of atmosphere
'460000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	}
#Time-mean attenuated aerosol backscatter from top of atmosphere
'460001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum attenuated aerosol backscatter from top of atmosphere
'460003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum attenuated aerosol backscatter from top of atmosphere
'460004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation attenuated aerosol backscatter from top of atmosphere
'460005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Attenuated aerosol backscatter from ground
'461000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	}
#Time-mean attenuated aerosol backscatter from ground
'461001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum attenuated aerosol backscatter from ground
'461003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum attenuated aerosol backscatter from ground
'461004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation attenuated aerosol backscatter from ground
'461005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Aerosol extinction coefficient
'462000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 105 ;
	}
#Time-mean aerosol extinction coefficient
'462001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 105 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum aerosol extinction coefficient
'462003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 105 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum aerosol extinction coefficient
'462004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 105 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation aerosol extinction coefficient
'462005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 105 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Emission mass flux from commercial buildings heating
'463000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 30 ;
	}
#Time-mean emission mass flux from commercial buildings heating
'463001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 30 ;
	}
#Time-maximum emission mass flux from commercial buildings heating
'463003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 30 ;
	}
#Time-minimum emission mass flux from commercial buildings heating
'463004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 30 ;
	}
#Time-standard-deviation emission mass flux from commercial buildings heating
'463005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 30 ;
	}
#Emission mass flux from residential heating
'464000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 31 ;
	}
#Time-mean emission mass flux from residential heating
'464001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 31 ;
	}
#Time-maximum emission mass flux from residential heating
'464003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 31 ;
	}
#Time-minimum emission mass flux from residential heating
'464004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 31 ;
	}
#Time-standard-deviation emission mass flux from residential heating
'464005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 31 ;
	}
#Emission mass flux from oil refineries and transformation industry
'465000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 32 ;
	}
#Time-mean emission mass flux from oil refineries and transformation industry
'465001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 32 ;
	}
#Time-maximum emission mass flux from oil refineries and transformation industry
'465003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 32 ;
	}
#Time-minimum emission mass flux from oil refineries and transformation industry
'465004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 32 ;
	}
#Time-standard-deviation emission mass flux from oil refineries and transformation industry
'465005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 32 ;
	}
#Emission mass flux from gas production
'466000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 33 ;
	}
#Time-mean emission mass flux from gas production
'466001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 33 ;
	}
#Time-maximum emission mass flux from gas production
'466003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 33 ;
	}
#Time-minimum emission mass flux from gas production
'466004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 33 ;
	}
#Time-standard-deviation emission mass flux from gas production
'466005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 33 ;
	}
#Mass mixing ratio difference
'467000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 20 ;
	}
#Time-mean mass mixing ratio difference
'467001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 20 ;
	}
#Time-maximum mass mixing ratio difference
'467003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 20 ;
	}
#Time-minimum mass mixing ratio difference
'467004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 20 ;
	}
#Time-standard-deviation mass mixing ratio difference
'467005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 20 ;
	}
#Mass mixing ratio from volcanoes difference
'468000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 20 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-mean mass mixing ratio from volcanoes difference
'468001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 20 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-maximum mass mixing ratio from volcanoes difference
'468003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 20 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-minimum mass mixing ratio from volcanoes difference
'468004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 20 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Time-standard-deviation mass mixing ratio from volcanoes difference
'468005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 20 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Emission mass flux from wild fires
'469000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 5 ;
	}
#Time-mean emission mass flux from wild fires
'469001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	 sourceSinkChemicalPhysicalProcess = 5 ;
	}
#Time-maximum emission mass flux from wild fires
'469003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 sourceSinkChemicalPhysicalProcess = 5 ;
	}
#Time-minimum emission mass flux from wild fires
'469004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	 sourceSinkChemicalPhysicalProcess = 5 ;
	}
#Time-standard-deviation emission mass flux from wild fires
'469005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	 sourceSinkChemicalPhysicalProcess = 5 ;
	}
#Sink mass flux
'470000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 82 ;
	}
#Time-mean sink mass flux
'470001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum sink mass flux
'470003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum sink mass flux
'470004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation sink mass flux
'470005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Source mass flux
'471000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 83 ;
	}
#Time-mean source mass flux
'471001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum source mass flux
'471003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum source mass flux
'471004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation source mass flux
'471005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Absorption aerosol optical thickness
'472000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 112 ;
	}
#Time-mean absorption aerosol optical thickness
'472001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 112 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum absorption aerosol optical thickness
'472003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 112 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum absorption aerosol optical thickness
'472004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 112 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation absorption aerosol optical thickness
'472005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 112 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Tropospheric column vertically-integrated mass density
'473000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 7 ;
	}
#Time-mean tropospheric column vertically-integrated mass density
'473001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum tropospheric column vertically-integrated mass density
'473003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 7 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum tropospheric column vertically-integrated mass density
'473004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 7 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation tropospheric column vertically-integrated mass density
'473005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 7 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Stratospheric column vertically-integrated mass density
'474000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 36 ;
	}
#Time-mean stratospheric column vertically-integrated mass density
'474001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 36 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum stratospheric column vertically-integrated mass density
'474003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 36 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum stratospheric column vertically-integrated mass density
'474004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 36 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation stratospheric column vertically-integrated mass density
'474005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 36 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Aerosol unattenuated backscatter coefficient
'475000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 113 ;
	}
#Time-mean aerosol unattenuated backscatter coefficient
'475001' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 113 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum aerosol unattenuated backscatter coefficient
'475003' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 113 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum aerosol unattenuated backscatter coefficient
'475004' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 113 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation aerosol unattenuated backscatter coefficient
'475005' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 113 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Potential of hydrogen
'476000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 18 ;
	}
#Stratospheric aerosol optical thickness
'477000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 36 ;
	}
#Emission mass flux from lightning
'478000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 77 ;
	 sourceSinkChemicalPhysicalProcess = 2 ;
	}
#Loss rate due to OH
'479000' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 19 ;
	}
#Pressure tendency
'3003' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	}
#ICAO Standard Atmosphere reference height
'3005' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}
#Geometrical height above ground
'3008' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	}
#Standard deviation of height
'3009' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}
#Virtual potential temperature
'3012' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Pseudo-adiabatic potential temperature
'3014' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Dew point temperature
'3017' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Lapse rate
'3019' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Visibility
'3020' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	}
#Radar spectra (1)
'3021' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 6 ;
	}
#Radar spectra (2)
'3022' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 7 ;
	}
#Radar spectra (3)
'3023' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 8 ;
	}
#Parcel lifted index (to 500 hPa)
'3024' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	}
#Temperature anomaly
'3025' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Pressure anomaly
'3026' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}
#Geopotential height anomaly
'3027' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}
#Wave spectra (1)
'3028' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Wave spectra (2)
'3029' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Wave spectra (3)
'3030' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Wind direction
'3031' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}
#Sigma coordinate vertical velocity
'3038' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}
#Absolute vorticity
'3041' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}
#Absolute divergence
'3042' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	}
#Vertical u-component shear
'3045' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	}
#Vertical v-component shear
'3046' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	}
#Precipitable water
'3054' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}
#Saturation deficit
'3056' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}
#Precipitation rate
'3059' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}
#Thunderstorm probability
'3060' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 2 ;
	}
#Convective precipitation (water)
'3063' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}
#Mixed layer depth
'3067' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	}
#Transient thermocline depth
'3068' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 2 ;
	}
#Main thermocline anomaly
'3070' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}
#Best lifted index (to 500 hPa)
'3077' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 1 ;
	}
#Soil moisture content
'3086' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Salinity
'3088' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}
#Density
'3089' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}
#Direction of ice drift
'3093' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#Speed of ice drift
'3094' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}
#Ice divergence
'3098' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}
#Snowmelt
'3099' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Direction of swell waves
'3104' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Secondary wave direction
'3109' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Net short-wave radiation flux (surface)
'3111' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	}
#Global radiation flux
'3117' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}
#Radiance (with respect to wave number)
'3119' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 5 ;
	}
#Radiance (with respect to wave length)
'3120' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 6 ;
	}
#Wind mixing energy
'3126' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	}
#Total precipitation less than 0.1 mm
'131064' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 1 ;
	 scaleFactorOfLowerLimit = 1 ;
	 probabilityType = 0 ;
	}
#Total precipitation rate less than 1 mm/day
'131065' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	 scaledValueOfLowerLimit = 115741 ;
	 scaleFactorOfLowerLimit = 10 ;
	 probabilityType = 0 ;
	}
#Total precipitation rate of at least 3 mm/day
'131066' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	 scaledValueOfLowerLimit = 347222 ;
	 scaleFactorOfLowerLimit = 10 ;
	 probabilityType = 3 ;
	}
#Total precipitation rate of at least 5 mm/day
'131067' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	 scaledValueOfLowerLimit = 578704 ;
	 scaleFactorOfLowerLimit = 10 ;
	 probabilityType = 3 ;
	}
#10 metre Wind speed of at least 10 m/s
'131068' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfLowerLimit = 10 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre Wind speed of at least 15 m/s
'131069' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfLowerLimit = 15 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre wind gust of at least 15 m/s
'131070' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfLowerLimit = 15 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre wind gust of at least 20 m/s
'131071' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfLowerLimit = 20 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#2 metre temperature less than 273.15 K
'131073' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfLowerLimit = 27315 ;
	 scaleFactorOfLowerLimit = 2 ;
	 probabilityType = 0 ;
	}
#Significant wave height of at least 2 m
'131074' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 scaledValueOfLowerLimit = 2 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Significant wave height of at least 4 m
'131075' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 scaledValueOfLowerLimit = 4 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Significant wave height of at least 6 m
'131076' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 scaledValueOfLowerLimit = 6 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Significant wave height of at least 8 m
'131077' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 scaledValueOfLowerLimit = 8 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Period corresponding to maximum individual wave height
'140217' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}
#Envelop-maximum individual wave height
'140218' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 93 ;
	}
#Model bathymetry
'140219' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	}
#Mean wave period based on first moment
'140220' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}
#Mean zero-crossing wave period
'140221' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}
#Wave spectral directional width
'140222' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	}
#Mean wave period based on first moment for wind waves
'140223' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	}
#Mean wave period based on second moment for wind waves
'140224' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	}
#Wave spectral directional width for wind waves
'140225' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	}
#Mean wave period based on first moment for swell
'140226' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}
#Mean wave period based on second moment for swell
'140227' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	}
#Wave spectral directional width for swell
'140228' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	}
#Significant height of combined wind waves and swell
'140229' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Mean wave direction
'140230' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Peak wave period
'140231' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	}
#Mean wave period
'140232' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Coefficient of drag with waves
'140233' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Significant height of wind waves
'140234' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Mean direction of wind waves
'140235' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 75 ;
	}
#Mean period of wind waves
'140236' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Significant height of total swell
'140237' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Mean direction of total swell
'140238' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 74 ;
	}
#Mean period of total swell
'140239' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Mean square slope of waves
'140244' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}
#10 metre wind speed
'140245' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Altimeter wave height
'140246' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 37 ;
	}
#Altimeter corrected wave height
'140247' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 38 ;
	}
#Altimeter range relative correction
'140248' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 39 ;
	}
#10 metre wind direction
'140249' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#2D wave spectra (single)
'140251' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 86 ;
	}
#Wave spectral kurtosis
'140252' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	}
#Benjamin-Feir index
'140253' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	}
#Wave spectral peakedness
'140254' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 98 ;
	}
#Skin reservoir content
'160198' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	}
#Total column vertically-integrated mass of atmosphere
'162053' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated kinetic energy
'162059' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated enthalpy
'162060' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated potential + internal energy
'162061' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated potential+internal+latent energy
'162062' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated total energy
'162063' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward mass flux
'162065' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward mass flux
'162066' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward kinetic energy flux
'162067' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward kinetic energy flux
'162068' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward heat flux
'162069' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward heat flux
'162070' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward water vapour flux
'162071' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward water vapour flux
'162072' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward geopotential flux
'162073' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward geopotential flux
'162074' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward total energy flux
'162075' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward total energy flux
'162076' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward ozone flux
'162077' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	}
#Total column vertically-integrated northward ozone flux
'162078' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	}
#Total column vertically-integrated divergence of mass flux
'162081' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of kinetic energy flux
'162082' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated moisture divergence flux
'162084' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of geopotential flux
'162085' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of total energy flux
'162086' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of ozone flux
'162087' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	}
#Time-integrated temperature tendency due to short-wave radiation
'162100' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated temperature tendency due to long-wave radiation
'162101' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated temperature tendency due to short wave radiation, clear sky
'162102' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated temperature tendency due to long-wave radiation, clear sky
'162103' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated updraught mass flux
'162104' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated downdraught mass flux
'162105' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated updraught detrainment rate
'162106' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated downdraught detrainment rate
'162107' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total precipitation flux
'162108' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated turbulent diffusion coefficient for heat
'162109' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated temperature tendency due to parametrisations
'162110' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated specific humidity tendency due to parametrisations
'162111' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated eastward wind tendency due to parametrisations
'162112' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated northward wind tendency due to parametrisations
'162113' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface runoff
'174008' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	}
#Convective inhibition
'228001' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Orography
'228002' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Friction velocity
'228003' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	}
#Time-mean 2 metre temperature
'228004' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre wind speed
'228005' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Lake total depth
'228007' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Lake mix-layer temperature
'228008' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Lake mix-layer depth
'228009' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Lake bottom temperature
'228010' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Lake total layer temperature
'228011' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Lake shape factor
'228012' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}
#Lake ice surface temperature
'228013' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Lake ice total depth
'228014' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Minimum vertical gradient of refractivity inside trapping layer
'228015' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 45 ;
	}
#Mean vertical gradient of refractivity inside trapping layer
'228016' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 44 ;
	}
#Duct base height
'228017' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 41 ;
	}
#Trapping layer base height
'228018' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 42 ;
	}
#Trapping layer top height
'228019' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 43 ;
	}
#10 metre u-component of neutral wind
'228131' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#10 metre v-component of neutral wind
'228132' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Snow depth water equivalent
'228141' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	}
#Snowfall water equivalent
'228144' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total Cloud Cover
'228164' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Field capacity
'228170' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Wilting point
'228171' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Total Precipitation
'228228' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#U-component surface stokes drift
'140215' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}
#V-component surface stokes drift
'140216' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
}
