# Automatically generated by ./create_defs.grib2.mtg2.pl, do not edit
#Total precipitation of at least 1 mm
'Total precipitation of at least 1 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 5 mm
'Total precipitation of at least 5 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 5 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 10 mm
'Total precipitation of at least 10 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 10 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 20 mm
'Total precipitation of at least 20 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 20 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 40 mm
'Total precipitation of at least 40 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 40 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 60 mm
'Total precipitation of at least 60 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 60 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 80 mm
'Total precipitation of at least 80 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 80 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 100 mm
'Total precipitation of at least 100 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 100 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 150 mm
'Total precipitation of at least 150 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 150 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 200 mm
'Total precipitation of at least 200 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 200 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 300 mm
'Total precipitation of at least 300 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 3 ;
	 scaleFactorOfLowerLimit = -2 ;
	 probabilityType = 3 ;
	}
#Stream function
'Stream function' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}
#Velocity potential
'Velocity potential' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}
#Potential temperature
'Potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Wind speed
'Wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}
#Surface photosynthetically active radiation, clear sky
'Surface photosynthetically active radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Unbalanced component of temperature
'Unbalanced component of temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}
#Unbalanced component of logarithm of surface pressure
'Unbalanced component of logarithm of surface pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 31 ;
	}
#Unbalanced component of divergence
'Unbalanced component of divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 45 ;
	}
#Lake cover
'Lake cover' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#Low vegetation cover
'Low vegetation cover' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	}
#High vegetation cover
'High vegetation cover' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	}
#Type of low vegetation
'Type of low vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	}
#Type of high vegetation
'Type of high vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	}
#Sea ice area fraction
'Sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Snow density
'Snow density' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	}
#Sea surface temperature
'Sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Soil type
'Soil type' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}
#Surface direct normal short-wave (solar) radiation
'Surface direct normal short-wave (solar) radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated magnitude of turbulent surface stress
'Time-integrated magnitude of turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Large-scale precipitation fraction
'Large-scale precipitation fraction' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Montgomery potential
'Montgomery potential' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}
#Pressure
'Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}
#Surface downward UV radiation
'Surface downward UV radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Photosynthetically active radiation at the surface
'Photosynthetically active radiation at the surface' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective available potential energy
'Convective available potential energy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Potential vorticity
'Potential vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	}
#Leaf area index, low vegetation
'Leaf area index, low vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	}
#Leaf area index, high vegetation
'Leaf area index, high vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	}
#Standard deviation of filtered subgrid orography (climatological)
'Standard deviation of filtered subgrid orography (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 38 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Specific rain water content
'Specific rain water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	}
#Specific snow water content
'Specific snow water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	}
#Eta-coordinate vertical velocity
'Eta-coordinate vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	}
#Total column cloud liquid water
'Total column cloud liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column cloud ice water
'Total column cloud ice water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Surface emissivity
'Surface emissivity' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Geopotential
'Geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}
#Temperature
'Temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#U component of wind
'U component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#V component of wind
'V component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}
#Specific humidity
'Specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Surface pressure
'Surface pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Vertical velocity
'Vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}
#Total column water
'Total column water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated water vapour
'Total column vertically-integrated water vapour' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Vorticity (relative)
'Vorticity (relative)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}
#Time-integrated boundary layer dissipation
'Time-integrated boundary layer dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated surface sensible heat net flux
'Time-integrated surface sensible heat net flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated surface latent heat net flux
'Time-integrated surface latent heat net flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Charnock
'Charnock' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 76 ;
	}
#Surface net radiation (SW and LW)
'Surface net radiation (SW and LW)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Top net radiation (SW and LW)
'Top net radiation (SW and LW)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Mean sea level pressure
'Mean sea level pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	}
#Divergence
'Divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	}
#Geopotential height
'Geopotential height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}
#Relative humidity
'Relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Boundary layer height
'Boundary layer height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	}
#Standard deviation of sub-gridscale orography
'Standard deviation of sub-gridscale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	}
#Anisotropy of sub-gridscale orography
'Anisotropy of sub-gridscale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 24 ;
	}
#Angle of sub-gridscale orography
'Angle of sub-gridscale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	}
#Slope of sub-gridscale orography
'Slope of sub-gridscale orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	}
#10 metre U wind component
'10 metre U wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#10 metre V wind component
'10 metre V wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#2 metre temperature
'2 metre temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#2 metre dewpoint temperature
'2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Surface short-wave (solar) radiation downwards
'Surface short-wave (solar) radiation downwards' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Land-sea mask
'Land-sea mask' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface roughness (climatological)
'Surface roughness (climatological)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Surface long-wave (thermal) radiation downwards
'Surface long-wave (thermal) radiation downwards' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net short-wave (solar) radiation
'Surface net short-wave (solar) radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net long-wave (thermal) radiation
'Surface net long-wave (thermal) radiation' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Top net short-wave (solar) radiation
'Top net short-wave (solar) radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Top net long-wave (thermal) radiation
'Top net long-wave (thermal) radiation' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated eastward turbulent surface stress
'Time-integrated eastward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated northward turbulent surface stress
'Time-integrated northward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Sunshine duration
'Sunshine duration' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Brightness temperature
'Brightness temperature' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 4 ;
	}
#Eastward gravity wave surface stress
'Eastward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Northward gravity wave surface stress
'Northward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Gravity wave dissipation
'Gravity wave dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Ozone mass mixing ratio
'Ozone mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	}
#10 metre wind speed
'10 metre wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Top net short-wave (solar) radiation, clear sky
'Top net short-wave (solar) radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Top net long-wave (thermal) radiation, clear sky
'Top net long-wave (thermal) radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net short-wave (solar) radiation, clear sky
'Surface net short-wave (solar) radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface net long-wave (thermal) radiation, clear sky
'Surface net long-wave (thermal) radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#TOA incident short-wave (solar) radiation
'TOA incident short-wave (solar) radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Vertically integrated moisture divergence
'Vertically integrated moisture divergence' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Instantaneous eastward turbulent surface stress
'Instantaneous eastward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous northward turbulent surface stress
'Instantaneous northward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous surface sensible heat net flux
'Instantaneous surface sensible heat net flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous moisture flux
'Instantaneous moisture flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Logarithm of surface roughness length for heat (climatological)
'Logarithm of surface roughness length for heat (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Skin temperature
'Skin temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Temperature of snow layer
'Temperature of snow layer' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	}
#Forecast surface roughness
'Forecast surface roughness' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Forecast logarithm of surface roughness for heat
'Forecast logarithm of surface roughness for heat' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Specific cloud liquid water content
'Specific cloud liquid water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	}
#Specific cloud ice water content
'Specific cloud ice water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	}
#Fraction of cloud cover
'Fraction of cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	}
#Large-scale precipitation
'Large-scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snow depth
'Snow depth' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Low cloud cover
'Low cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	}
#Medium cloud cover
'Medium cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	}
#High cloud cover
'High cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	}
#Probability of a tropical storm
'Probability of a tropical storm' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 6 ;
	 probabilityType = 9 ;
	}
#Probability of a hurricane
'Probability of a hurricane' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 5 ;
	 probabilityType = 9 ;
	}
#Probability of a tropical depression
'Probability of a tropical depression' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 7 ;
	 probabilityType = 9 ;
	}
#Total precipitation of at least 25 mm
'Total precipitation of at least 25 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 25 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Total precipitation of at least 50 mm
'Total precipitation of at least 50 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 50 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre wind gust of at least 10 m/s
'10 metre wind gust of at least 10 m/s' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfLowerLimit = 10 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre convective gust of at least 25 m/s
'10 metre convective gust of at least 25 m/s' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfLowerLimit = 25 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Convective available potential energy shear index
'Convective available potential energy shear index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = [102,2] ;
	}
#Water vapour flux index
'Water vapour flux index' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 166 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = [102,0] ;
	}
#Convective available potential energy index
'Convective available potential energy index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = [102,2] ;
	}
#Maximum of significant wave height index
'Maximum of significant wave height index' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = [102,2] ;
	}
#Probability of temperature standardized anomaly greater than 1 standard deviation
'Probability of temperature standardized anomaly greater than 1 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = 1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Probability of temperature standardized anomaly greater than 1.5 standard deviation
'Probability of temperature standardized anomaly greater than 1.5 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = 15 ;
	 scaleFactorOfLowerLimit = 1 ;
	 probabilityType = 3 ;
	}
#Probability of temperature standardized anomaly greater than 2 standard deviation
'Probability of temperature standardized anomaly greater than 2 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = 2 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Probability of temperature standardized anomaly less than -1 standard deviation
'Probability of temperature standardized anomaly less than -1 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = -1 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 0 ;
	}
#Probability of temperature standardized anomaly less than -1.5 standard deviation
'Probability of temperature standardized anomaly less than -1.5 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = -15 ;
	 scaleFactorOfLowerLimit = 1 ;
	 probabilityType = 0 ;
	}
#Probability of temperature standardized anomaly less than -2 standard deviation
'Probability of temperature standardized anomaly less than -2 standard deviation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 10 ;
	 scaledValueOfLowerLimit = -2 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 0 ;
	}
#Wave induced mean sea level correction
'Wave induced mean sea level correction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 87 ;
	}
#Ratio of wave angular and frequency width
'Ratio of wave angular and frequency width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 80 ;
	}
#Number of events in freak waves statistics
'Number of events in freak waves statistics' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 89 ;
	}
#U-component of atmospheric surface momentum flux
'U-component of atmospheric surface momentum flux' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 103 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#V-component of atmospheric surface momentum flux
'V-component of atmospheric surface momentum flux' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 104 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#U-component of surface momentum flux into ocean
'U-component of surface momentum flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 90 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#V-component of surface momentum flux into ocean
'V-component of surface momentum flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 91 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Wave turbulent energy flux into ocean
'Wave turbulent energy flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 92 ;
	}
#Wave directional width of first swell partition
'Wave directional width of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	}
#Wave frequency width of first swell partition
'Wave frequency width of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	}
#Wave directional width of second swell partition
'Wave directional width of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	}
#Wave frequency width of second swell partition
'Wave frequency width of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	}
#Wave directional width of third swell partition
'Wave directional width of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	}
#Wave frequency width of third swell partition
'Wave frequency width of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	}
#Wave energy flux magnitude
'Wave energy flux magnitude' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 78 ;
	}
#Wave energy flux mean direction
'Wave energy flux mean direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 79 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds
'Significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 12 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds
'Significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 12 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 14 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds
'Significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 14 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 17 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds
'Significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 17 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 21 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds
'Significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 21 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 25 ;
	}
#Significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds
'Significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 25 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 30 ;
	}
#Significant wave height of all waves with period larger than 10s
'Significant wave height of all waves with period larger than 10s' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfWavePeriodInterval = 3 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	}
#Significant wave height of first swell partition
'Significant wave height of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	}
#Mean wave direction of first swell partition
'Mean wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	}
#Mean wave period of first swell partition
'Mean wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	}
#Significant wave height of second swell partition
'Significant wave height of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	}
#Mean wave direction of second swell partition
'Mean wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	}
#Mean wave period of second swell partition
'Mean wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	}
#Significant wave height of third swell partition
'Significant wave height of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	}
#Mean wave direction of third swell partition
'Mean wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	}
#Mean wave period of third swell partition
'Mean wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	}
#Time domain maximum individual crest height
'Time domain maximum individual crest height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 94 ;
	}
#Time domain maximum individual wave height
'Time domain maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 95 ;
	}
#Space time maximum individual crest height
'Space time maximum individual crest height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 96 ;
	}
#Space time maximum individual wave height
'Space time maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 97 ;
	}
#Peak wave period of wind waves
'Peak wave period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	}
#Peak wave period of total swell
'Peak wave period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	}
#Peak wave period of first swell partition
'Peak wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 65 ;
	}
#Peak wave period of second swell partition
'Peak wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 66 ;
	}
#Peak wave period of third swell partition
'Peak wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 67 ;
	}
#Peak wave direction (total)
'Peak wave direction (total)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	}
#Peak wave direction of wind waves
'Peak wave direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 71 ;
	}
#Peak wave direction of total swell
'Peak wave direction of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 72 ;
	}
#Peak wave direction of first swell partition
'Peak wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 68 ;
	}
#Peak wave direction of second swell partition
'Peak wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 69 ;
	}
#Peak wave direction of third swell partition
'Peak wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 70 ;
	}
#Whitecap fraction
'Whitecap fraction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 73 ;
	}
#Benjamin-Feir index 2D
'Benjamin-Feir index 2D' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 99 ;
	}
#Crest-trough correlation
'Crest-trough correlation' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 100 ;
	}
#X component of the wave radiative stress to sea ice
'X component of the wave radiative stress to sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 101 ;
	}
#Y component of the wave radiative stress to sea ice
'Y component of the wave radiative stress to sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 102 ;
	}
#Wave Spectral Skewness
'Wave Spectral Skewness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 77 ;
	}
#Free convective velocity over the oceans
'Free convective velocity over the oceans' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 81 ;
	}
#Air density over the oceans
'Air density over the oceans' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 82 ;
	}
#Normalized energy flux into waves
'Normalized energy flux into waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 83 ;
	}
#Normalized energy flux into ocean
'Normalized energy flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 85 ;
	}
#Normalized stress into ocean
'Normalized stress into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 84 ;
	}
#Time-mean wave induced mean sea level correction
'Time-mean wave induced mean sea level correction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 87 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ratio of wave angular and frequency width
'Time-mean ratio of wave angular and frequency width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 80 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean number of events in freak waves statistics
'Time-mean number of events in freak waves statistics' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 89 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U-component of atmospheric surface momentum flux
'Time-mean U-component of atmospheric surface momentum flux' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 103 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V-component of atmospheric surface momentum flux
'Time-mean V-component of atmospheric surface momentum flux' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 104 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U-component of surface momentum flux into ocean
'Time-mean U-component of surface momentum flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 90 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V-component of surface momentum flux into ocean
'Time-mean V-component of surface momentum flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 91 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave turbulent energy flux into ocean
'Time-mean wave turbulent energy flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 92 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave directional width of first swell partition
'Time-mean wave directional width of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave frequency width of first swell partition
'Time-mean wave frequency width of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave directional width of second swell partition
'Time-mean wave directional width of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave frequency width of second swell partition
'Time-mean wave frequency width of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave directional width of third swell partition
'Time-mean wave directional width of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave frequency width of third swell partition
'Time-mean wave frequency width of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave energy flux magnitude
'Time-mean wave energy flux magnitude' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 78 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave energy flux mean direction
'Time-mean wave energy flux mean direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds
'Time-mean significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 12 ;
	}
#Time-mean significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds
'Time-mean significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 12 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 14 ;
	}
#Time-mean significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds
'Time-mean significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 14 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 17 ;
	}
#Time-mean significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds
'Time-mean significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 17 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 21 ;
	}
#Time-mean significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds
'Time-mean significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 21 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 25 ;
	}
#Time-mean significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds
'Time-mean significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 25 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 30 ;
	}
#Time-mean significant wave height of all waves with period larger than 10s
'Time-mean significant wave height of all waves with period larger than 10s' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfWavePeriodInterval = 3 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	}
#Time-mean significant wave height of first swell partition
'Time-mean significant wave height of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave direction of first swell partition
'Time-mean mean wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period of first swell partition
'Time-mean mean wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant wave height of second swell partition
'Time-mean significant wave height of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave direction of second swell partition
'Time-mean mean wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period of second swell partition
'Time-mean mean wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant wave height of third swell partition
'Time-mean significant wave height of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave direction of third swell partition
'Time-mean mean wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period of third swell partition
'Time-mean mean wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean time domain maximum individual crest height
'Time-mean time domain maximum individual crest height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 94 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean time domain maximum individual wave height
'Time-mean time domain maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 95 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean space time maximum individual crest height
'Time-mean space time maximum individual crest height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 96 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean space time maximum individual wave height
'Time-mean space time maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 97 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period of wind waves
'Time-mean peak wave period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period of total swell
'Time-mean peak wave period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period of first swell partition
'Time-mean peak wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period of second swell partition
'Time-mean peak wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period of third swell partition
'Time-mean peak wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 67 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction (total)
'Time-mean peak wave direction (total)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction of wind waves
'Time-mean peak wave direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction of total swell
'Time-mean peak wave direction of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction of first swell partition
'Time-mean peak wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 68 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction of second swell partition
'Time-mean peak wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave direction of third swell partition
'Time-mean peak wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean whitecap fraction
'Time-mean whitecap fraction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Benjamin-Feir index 2D
'Time-mean Benjamin-Feir index 2D' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 99 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean crest-trough correlation
'Time-mean crest-trough correlation' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 100 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean X component of the wave radiative stress to sea ice
'Time-mean X component of the wave radiative stress to sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 101 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Y component of the wave radiative stress to sea ice
'Time-mean Y component of the wave radiative stress to sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave Spectral Skewness
'Time-mean wave Spectral Skewness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean free convective velocity over the oceans
'Time-mean free convective velocity over the oceans' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean air density over the oceans
'Time-mean air density over the oceans' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean normalized energy flux into waves
'Time-mean normalized energy flux into waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean normalized energy flux into ocean
'Time-mean normalized energy flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean normalized stress into ocean
'Time-mean normalized stress into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U-component surface stokes drift
'Time-mean U-component surface stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V-component surface stokes drift
'Time-mean V-component surface stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean period corresponding to maximum individual wave height
'Time-mean period corresponding to maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean envelop-maximum individual wave height
'Time-mean envelop-maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period based on first moment
'Time-mean mean wave period based on first moment' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean zero-crossing wave period
'Time-mean mean zero-crossing wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave spectral directional width
'Time-mean wave spectral directional width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period based on first moment for wind waves
'Time-mean mean wave period based on first moment for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period based on second moment for wind waves
'Time-mean mean wave period based on second moment for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave spectral directional width for wind waves
'Time-mean wave spectral directional width for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period based on first moment for swell
'Time-mean mean wave period based on first moment for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period based on second moment for swell
'Time-mean mean wave period based on second moment for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave spectral directional width for swell
'Time-mean wave spectral directional width for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant height of combined wind waves and swell
'Time-mean significant height of combined wind waves and swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave direction
'Time-mean mean wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean peak wave period
'Time-mean peak wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean wave period
'Time-mean mean wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean coefficient of drag with waves
'Time-mean coefficient of drag with waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant height of wind waves
'Time-mean significant height of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean direction of wind waves
'Time-mean mean direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean period of wind waves
'Time-mean mean period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean significant height of total swell
'Time-mean significant height of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean direction of total swell
'Time-mean mean direction of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean period of total swell
'Time-mean mean period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean square slope of waves
'Time-mean mean square slope of waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre wind speed
'Time-mean 10 metre wind speed' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre wind direction
'Time-mean 10 metre wind direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave spectral kurtosis
'Time-mean wave spectral kurtosis' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean benjamin-Feir index
'Time-mean benjamin-Feir index' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wave spectral peakedness
'Time-mean wave spectral peakedness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 98 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-maximum wave induced mean sea level correction
'Time-maximum wave induced mean sea level correction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 87 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ratio of wave angular and frequency width
'Time-maximum ratio of wave angular and frequency width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 80 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum number of events in freak waves statistics
'Time-maximum number of events in freak waves statistics' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 89 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum U-component of atmospheric surface momentum flux
'Time-maximum U-component of atmospheric surface momentum flux' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 103 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum V-component of atmospheric surface momentum flux
'Time-maximum V-component of atmospheric surface momentum flux' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 104 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum U-component of surface momentum flux into ocean
'Time-maximum U-component of surface momentum flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 90 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum V-component of surface momentum flux into ocean
'Time-maximum V-component of surface momentum flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 91 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave turbulent energy flux into ocean
'Time-maximum wave turbulent energy flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 92 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave directional width of first swell partition
'Time-maximum wave directional width of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave frequency width of first swell partition
'Time-maximum wave frequency width of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave directional width of second swell partition
'Time-maximum wave directional width of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave frequency width of second swell partition
'Time-maximum wave frequency width of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave directional width of third swell partition
'Time-maximum wave directional width of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave frequency width of third swell partition
'Time-maximum wave frequency width of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave energy flux magnitude
'Time-maximum wave energy flux magnitude' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 78 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave energy flux mean direction
'Time-maximum wave energy flux mean direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds
'Time-maximum significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 12 ;
	}
#Time-maximum significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds
'Time-maximum significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 12 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 14 ;
	}
#Time-maximum significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds
'Time-maximum significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 14 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 17 ;
	}
#Time-maximum significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds
'Time-maximum significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 17 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 21 ;
	}
#Time-maximum significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds
'Time-maximum significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 21 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 25 ;
	}
#Time-maximum significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds
'Time-maximum significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 25 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 30 ;
	}
#Time-maximum significant wave height of all waves with period larger than 10s
'Time-maximum significant wave height of all waves with period larger than 10s' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfWavePeriodInterval = 3 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	}
#Time-maximum significant wave height of first swell partition
'Time-maximum significant wave height of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave direction of first swell partition
'Time-maximum mean wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period of first swell partition
'Time-maximum mean wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant wave height of second swell partition
'Time-maximum significant wave height of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave direction of second swell partition
'Time-maximum mean wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period of second swell partition
'Time-maximum mean wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant wave height of third swell partition
'Time-maximum significant wave height of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave direction of third swell partition
'Time-maximum mean wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period of third swell partition
'Time-maximum mean wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum time domain maximum individual crest height
'Time-maximum time domain maximum individual crest height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 94 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum time domain maximum individual wave height
'Time-maximum time domain maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 95 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum space time maximum individual crest height
'Time-maximum space time maximum individual crest height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 96 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum space time maximum individual wave height
'Time-maximum space time maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 97 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period of wind waves
'Time-maximum peak wave period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period of total swell
'Time-maximum peak wave period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period of first swell partition
'Time-maximum peak wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period of second swell partition
'Time-maximum peak wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period of third swell partition
'Time-maximum peak wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 67 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction (total)
'Time-maximum peak wave direction (total)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction of wind waves
'Time-maximum peak wave direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction of total swell
'Time-maximum peak wave direction of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction of first swell partition
'Time-maximum peak wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 68 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction of second swell partition
'Time-maximum peak wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave direction of third swell partition
'Time-maximum peak wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum whitecap fraction
'Time-maximum whitecap fraction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum Benjamin-Feir index 2D
'Time-maximum Benjamin-Feir index 2D' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 99 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum crest-trough correlation
'Time-maximum crest-trough correlation' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 100 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum X component of the wave radiative stress to sea ice
'Time-maximum X component of the wave radiative stress to sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 101 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum Y component of the wave radiative stress to sea ice
'Time-maximum Y component of the wave radiative stress to sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave Spectral Skewness
'Time-maximum wave Spectral Skewness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum free convective velocity over the oceans
'Time-maximum free convective velocity over the oceans' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum air density over the oceans
'Time-maximum air density over the oceans' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum normalized energy flux into waves
'Time-maximum normalized energy flux into waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum normalized energy flux into ocean
'Time-maximum normalized energy flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum normalized stress into ocean
'Time-maximum normalized stress into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum U-component surface stokes drift
'Time-maximum U-component surface stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum V-component surface stokes drift
'Time-maximum V-component surface stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum period corresponding to maximum individual wave height
'Time-maximum period corresponding to maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum envelop-maximum individual wave height
'Time-maximum envelop-maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period based on first moment
'Time-maximum mean wave period based on first moment' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean zero-crossing wave period
'Time-maximum mean zero-crossing wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave spectral directional width
'Time-maximum wave spectral directional width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period based on first moment for wind waves
'Time-maximum mean wave period based on first moment for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period based on second moment for wind waves
'Time-maximum mean wave period based on second moment for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave spectral directional width for wind waves
'Time-maximum wave spectral directional width for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period based on first moment for swell
'Time-maximum mean wave period based on first moment for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period based on second moment for swell
'Time-maximum mean wave period based on second moment for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave spectral directional width for swell
'Time-maximum wave spectral directional width for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant height of combined wind waves and swell
'Time-maximum significant height of combined wind waves and swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave direction
'Time-maximum mean wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum peak wave period
'Time-maximum peak wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean wave period
'Time-maximum mean wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum coefficient of drag with waves
'Time-maximum coefficient of drag with waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant height of wind waves
'Time-maximum significant height of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean direction of wind waves
'Time-maximum mean direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean period of wind waves
'Time-maximum mean period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum significant height of total swell
'Time-maximum significant height of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean direction of total swell
'Time-maximum mean direction of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean period of total swell
'Time-maximum mean period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean square slope of waves
'Time-maximum mean square slope of waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre wind speed
'Time-maximum 10 metre wind speed' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre wind direction
'Time-maximum 10 metre wind direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave spectral kurtosis
'Time-maximum wave spectral kurtosis' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum benjamin-Feir index
'Time-maximum benjamin-Feir index' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wave spectral peakedness
'Time-maximum wave spectral peakedness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 98 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum wave induced mean sea level correction
'Time-minimum wave induced mean sea level correction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 87 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ratio of wave angular and frequency width
'Time-minimum ratio of wave angular and frequency width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 80 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum number of events in freak waves statistics
'Time-minimum number of events in freak waves statistics' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 89 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum U-component of atmospheric surface momentum flux
'Time-minimum U-component of atmospheric surface momentum flux' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 103 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum V-component of atmospheric surface momentum flux
'Time-minimum V-component of atmospheric surface momentum flux' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 104 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum U-component of surface momentum flux into ocean
'Time-minimum U-component of surface momentum flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 90 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum V-component of surface momentum flux into ocean
'Time-minimum V-component of surface momentum flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 91 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave turbulent energy flux into ocean
'Time-minimum wave turbulent energy flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 92 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave directional width of first swell partition
'Time-minimum wave directional width of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave frequency width of first swell partition
'Time-minimum wave frequency width of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave directional width of second swell partition
'Time-minimum wave directional width of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave frequency width of second swell partition
'Time-minimum wave frequency width of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave directional width of third swell partition
'Time-minimum wave directional width of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave frequency width of third swell partition
'Time-minimum wave frequency width of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave energy flux magnitude
'Time-minimum wave energy flux magnitude' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 78 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave energy flux mean direction
'Time-minimum wave energy flux mean direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds
'Time-minimum significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 12 ;
	}
#Time-minimum significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds
'Time-minimum significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 12 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 14 ;
	}
#Time-minimum significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds
'Time-minimum significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 14 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 17 ;
	}
#Time-minimum significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds
'Time-minimum significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 17 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 21 ;
	}
#Time-minimum significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds
'Time-minimum significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 21 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 25 ;
	}
#Time-minimum significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds
'Time-minimum significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 25 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 30 ;
	}
#Time-minimum significant wave height of all waves with period larger than 10s
'Time-minimum significant wave height of all waves with period larger than 10s' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfWavePeriodInterval = 3 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	}
#Time-minimum significant wave height of first swell partition
'Time-minimum significant wave height of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave direction of first swell partition
'Time-minimum mean wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period of first swell partition
'Time-minimum mean wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant wave height of second swell partition
'Time-minimum significant wave height of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave direction of second swell partition
'Time-minimum mean wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period of second swell partition
'Time-minimum mean wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant wave height of third swell partition
'Time-minimum significant wave height of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave direction of third swell partition
'Time-minimum mean wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period of third swell partition
'Time-minimum mean wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum time domain maximum individual crest height
'Time-minimum time domain maximum individual crest height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 94 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum time domain maximum individual wave height
'Time-minimum time domain maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 95 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum space time maximum individual crest height
'Time-minimum space time maximum individual crest height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 96 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum space time maximum individual wave height
'Time-minimum space time maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 97 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period of wind waves
'Time-minimum peak wave period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period of total swell
'Time-minimum peak wave period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period of first swell partition
'Time-minimum peak wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period of second swell partition
'Time-minimum peak wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period of third swell partition
'Time-minimum peak wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 67 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction (total)
'Time-minimum peak wave direction (total)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction of wind waves
'Time-minimum peak wave direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction of total swell
'Time-minimum peak wave direction of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction of first swell partition
'Time-minimum peak wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 68 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction of second swell partition
'Time-minimum peak wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave direction of third swell partition
'Time-minimum peak wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum whitecap fraction
'Time-minimum whitecap fraction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum Benjamin-Feir index 2D
'Time-minimum Benjamin-Feir index 2D' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 99 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum crest-trough correlation
'Time-minimum crest-trough correlation' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 100 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum X component of the wave radiative stress to sea ice
'Time-minimum X component of the wave radiative stress to sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 101 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum Y component of the wave radiative stress to sea ice
'Time-minimum Y component of the wave radiative stress to sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave Spectral Skewness
'Time-minimum wave Spectral Skewness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum free convective velocity over the oceans
'Time-minimum free convective velocity over the oceans' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum air density over the oceans
'Time-minimum air density over the oceans' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum normalized energy flux into waves
'Time-minimum normalized energy flux into waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum normalized energy flux into ocean
'Time-minimum normalized energy flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum normalized stress into ocean
'Time-minimum normalized stress into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum U-component surface stokes drift
'Time-minimum U-component surface stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum V-component surface stokes drift
'Time-minimum V-component surface stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum period corresponding to maximum individual wave height
'Time-minimum period corresponding to maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum envelop-maximum individual wave height
'Time-minimum envelop-maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period based on first moment
'Time-minimum mean wave period based on first moment' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean zero-crossing wave period
'Time-minimum mean zero-crossing wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave spectral directional width
'Time-minimum wave spectral directional width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period based on first moment for wind waves
'Time-minimum mean wave period based on first moment for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period based on second moment for wind waves
'Time-minimum mean wave period based on second moment for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave spectral directional width for wind waves
'Time-minimum wave spectral directional width for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period based on first moment for swell
'Time-minimum mean wave period based on first moment for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period based on second moment for swell
'Time-minimum mean wave period based on second moment for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave spectral directional width for swell
'Time-minimum wave spectral directional width for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant height of combined wind waves and swell
'Time-minimum significant height of combined wind waves and swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave direction
'Time-minimum mean wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum peak wave period
'Time-minimum peak wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean wave period
'Time-minimum mean wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum coefficient of drag with waves
'Time-minimum coefficient of drag with waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant height of wind waves
'Time-minimum significant height of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean direction of wind waves
'Time-minimum mean direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean period of wind waves
'Time-minimum mean period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum significant height of total swell
'Time-minimum significant height of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean direction of total swell
'Time-minimum mean direction of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean period of total swell
'Time-minimum mean period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean square slope of waves
'Time-minimum mean square slope of waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre wind speed
'Time-minimum 10 metre wind speed' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre wind direction
'Time-minimum 10 metre wind direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave spectral kurtosis
'Time-minimum wave spectral kurtosis' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum benjamin-Feir index
'Time-minimum benjamin-Feir index' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wave spectral peakedness
'Time-minimum wave spectral peakedness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 98 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation wave induced mean sea level correction
'Time-standard-deviation wave induced mean sea level correction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 87 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ratio of wave angular and frequency width
'Time-standard-deviation ratio of wave angular and frequency width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 80 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation number of events in freak waves statistics
'Time-standard-deviation number of events in freak waves statistics' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 89 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation U-component of atmospheric surface momentum flux
'Time-standard-deviation U-component of atmospheric surface momentum flux' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 103 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation V-component of atmospheric surface momentum flux
'Time-standard-deviation V-component of atmospheric surface momentum flux' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 104 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation U-component of surface momentum flux into ocean
'Time-standard-deviation U-component of surface momentum flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 90 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation V-component of surface momentum flux into ocean
'Time-standard-deviation V-component of surface momentum flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 91 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave turbulent energy flux into ocean
'Time-standard-deviation wave turbulent energy flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 92 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave directional width of first swell partition
'Time-standard-deviation wave directional width of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave frequency width of first swell partition
'Time-standard-deviation wave frequency width of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave directional width of second swell partition
'Time-standard-deviation wave directional width of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave frequency width of second swell partition
'Time-standard-deviation wave frequency width of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave directional width of third swell partition
'Time-standard-deviation wave directional width of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave frequency width of third swell partition
'Time-standard-deviation wave frequency width of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave energy flux magnitude
'Time-standard-deviation wave energy flux magnitude' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 78 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave energy flux mean direction
'Time-standard-deviation wave energy flux mean direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds
'Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 10 to 12 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 12 ;
	}
#Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds
'Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 12 to 14 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 12 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 14 ;
	}
#Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds
'Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 14 to 17 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 14 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 17 ;
	}
#Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds
'Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 17 to 21 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 17 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 21 ;
	}
#Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds
'Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 21 to 25 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 21 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 25 ;
	}
#Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds
'Time-standard-deviation significant wave height of all waves with periods within the inclusive range from 25 to 30 seconds' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfWavePeriodInterval = 7 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 25 ;
	 scaleFactorOfUpperWavePeriodLimit = 0 ;
	 scaledValueOfUpperWavePeriodLimit = 30 ;
	}
#Time-standard-deviation significant wave height of all waves with period larger than 10s
'Time-standard-deviation significant wave height of all waves with period larger than 10s' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfWavePeriodInterval = 3 ;
	 scaleFactorOfLowerWavePeriodLimit = 0 ;
	 scaledValueOfLowerWavePeriodLimit = 10 ;
	}
#Time-standard-deviation significant wave height of first swell partition
'Time-standard-deviation significant wave height of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave direction of first swell partition
'Time-standard-deviation mean wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period of first swell partition
'Time-standard-deviation mean wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant wave height of second swell partition
'Time-standard-deviation significant wave height of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave direction of second swell partition
'Time-standard-deviation mean wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period of second swell partition
'Time-standard-deviation mean wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant wave height of third swell partition
'Time-standard-deviation significant wave height of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave direction of third swell partition
'Time-standard-deviation mean wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period of third swell partition
'Time-standard-deviation mean wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation time domain maximum individual crest height
'Time-standard-deviation time domain maximum individual crest height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 94 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation time domain maximum individual wave height
'Time-standard-deviation time domain maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 95 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation space time maximum individual crest height
'Time-standard-deviation space time maximum individual crest height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 96 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation space time maximum individual wave height
'Time-standard-deviation space time maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 97 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period of wind waves
'Time-standard-deviation peak wave period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period of total swell
'Time-standard-deviation peak wave period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period of first swell partition
'Time-standard-deviation peak wave period of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period of second swell partition
'Time-standard-deviation peak wave period of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period of third swell partition
'Time-standard-deviation peak wave period of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 67 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction (total)
'Time-standard-deviation peak wave direction (total)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction of wind waves
'Time-standard-deviation peak wave direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction of total swell
'Time-standard-deviation peak wave direction of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction of first swell partition
'Time-standard-deviation peak wave direction of first swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 68 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction of second swell partition
'Time-standard-deviation peak wave direction of second swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave direction of third swell partition
'Time-standard-deviation peak wave direction of third swell partition' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation whitecap fraction
'Time-standard-deviation whitecap fraction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation Benjamin-Feir index 2D
'Time-standard-deviation Benjamin-Feir index 2D' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 99 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation crest-trough correlation
'Time-standard-deviation crest-trough correlation' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 100 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation X component of the wave radiative stress to sea ice
'Time-standard-deviation X component of the wave radiative stress to sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 101 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation Y component of the wave radiative stress to sea ice
'Time-standard-deviation Y component of the wave radiative stress to sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave Spectral Skewness
'Time-standard-deviation wave Spectral Skewness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation free convective velocity over the oceans
'Time-standard-deviation free convective velocity over the oceans' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation air density over the oceans
'Time-standard-deviation air density over the oceans' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 82 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation normalized energy flux into waves
'Time-standard-deviation normalized energy flux into waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation normalized energy flux into ocean
'Time-standard-deviation normalized energy flux into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation normalized stress into ocean
'Time-standard-deviation normalized stress into ocean' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation U-component surface stokes drift
'Time-standard-deviation U-component surface stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation V-component surface stokes drift
'Time-standard-deviation V-component surface stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation period corresponding to maximum individual wave height
'Time-standard-deviation period corresponding to maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation envelop-maximum individual wave height
'Time-standard-deviation envelop-maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period based on first moment
'Time-standard-deviation mean wave period based on first moment' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean zero-crossing wave period
'Time-standard-deviation mean zero-crossing wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave spectral directional width
'Time-standard-deviation wave spectral directional width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period based on first moment for wind waves
'Time-standard-deviation mean wave period based on first moment for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period based on second moment for wind waves
'Time-standard-deviation mean wave period based on second moment for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave spectral directional width for wind waves
'Time-standard-deviation wave spectral directional width for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period based on first moment for swell
'Time-standard-deviation mean wave period based on first moment for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period based on second moment for swell
'Time-standard-deviation mean wave period based on second moment for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave spectral directional width for swell
'Time-standard-deviation wave spectral directional width for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant height of combined wind waves and swell
'Time-standard-deviation significant height of combined wind waves and swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave direction
'Time-standard-deviation mean wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation peak wave period
'Time-standard-deviation peak wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean wave period
'Time-standard-deviation mean wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation coefficient of drag with waves
'Time-standard-deviation coefficient of drag with waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant height of wind waves
'Time-standard-deviation significant height of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean direction of wind waves
'Time-standard-deviation mean direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean period of wind waves
'Time-standard-deviation mean period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation significant height of total swell
'Time-standard-deviation significant height of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean direction of total swell
'Time-standard-deviation mean direction of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean period of total swell
'Time-standard-deviation mean period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean square slope of waves
'Time-standard-deviation mean square slope of waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre wind speed
'Time-standard-deviation 10 metre wind speed' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre wind direction
'Time-standard-deviation 10 metre wind direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave spectral kurtosis
'Time-standard-deviation wave spectral kurtosis' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation benjamin-Feir index
'Time-standard-deviation benjamin-Feir index' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wave spectral peakedness
'Time-standard-deviation wave spectral peakedness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 98 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Mean sea water temperature in the upper 300 m
'Mean sea water temperature in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Total column vertically-integrated divergence of water geopotential flux
'Total column vertically-integrated divergence of water geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward enthalpy flux
'Total column vertically-integrated eastward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward enthalpy flux
'Total column vertically-integrated northward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of enthalpy flux
'Total column vertically-integrated divergence of enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of water enthalpy flux
'Total column vertically-integrated divergence of water enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of water vapour flux
'Total column vertically-integrated divergence of water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of cloud liquid water flux
'Total column vertically-integrated divergence of cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of cloud ice water flux
'Total column vertically-integrated divergence of cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of rain flux
'Total column vertically-integrated divergence of rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of snow flux
'Total column vertically-integrated divergence of snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward cloud liquid water flux
'Total column vertically-integrated eastward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward cloud liquid water flux
'Total column vertically-integrated northward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward cloud ice water flux
'Total column vertically-integrated eastward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward cloud ice water flux
'Total column vertically-integrated northward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward rain flux
'Total column vertically-integrated eastward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward rain flux
'Total column vertically-integrated northward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward snow flux
'Total column vertically-integrated eastward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward snow flux
'Total column vertically-integrated northward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated net source of ozone
'Total column vertically-integrated net source of ozone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	}
#Total column vertically-integrated water enthalpy
'Total column vertically-integrated water enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Temperature tendency due to short-wave radiation
'Temperature tendency due to short-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}
#Temperature tendency due to long-wave radiation
'Temperature tendency due to long-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}
#Temperature tendency due to short-wave radiation, clear sky
'Temperature tendency due to short-wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}
#Temperature tendency due to long-wave radiation, clear sky
'Temperature tendency due to long-wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}
#Updraught mass flux
'Updraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	}
#Downdraught mass flux
'Downdraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	}
#Updraught detrainment rate
'Updraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	}
#Downdraught detrainment rate
'Downdraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	}
#Total precipitation flux
'Total precipitation flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	}
#Turbulent diffusion coefficient for heat
'Turbulent diffusion coefficient for heat' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}
#Temperature tendency due to parametrisations
'Temperature tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	}
#Specific humidity tendency due to parametrisations
'Specific humidity tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	}
#Eastward wind tendency due to parametrisations
'Eastward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	}
#Northward wind tendency due to parametrisations
'Northward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	}
#2 metre specific humidity
'2 metre specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Injection height (from IS4FIRES)
'Injection height (from IS4FIRES)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	}
#Particulate matter d <= 1 um
'Particulate matter d <= 1 um' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 scaleFactorOfSecondSize = missing() ;
	 scaledValueOfFirstSize = 1 ;
	 scaleFactorOfFirstSize = 6 ;
	 typeOfSizeInterval = 5 ;
	 aerosolType = 62026 ;
	 scaledValueOfSecondSize = missing() ;
	 is_aerosol = 1 ;
	}
#Particulate matter d <= 2.5 um
'Particulate matter d <= 2.5 um' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 scaleFactorOfSecondSize = missing() ;
	 scaledValueOfFirstSize = 25 ;
	 scaleFactorOfFirstSize = 7 ;
	 typeOfSizeInterval = 5 ;
	 aerosolType = 62026 ;
	 scaledValueOfSecondSize = missing() ;
	 is_aerosol = 1 ;
	}
#Particulate matter d <= 10 um
'Particulate matter d <= 10 um' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 scaleFactorOfSecondSize = missing() ;
	 scaledValueOfFirstSize = 10 ;
	 scaleFactorOfFirstSize = 6 ;
	 typeOfSizeInterval = 5 ;
	 aerosolType = 62026 ;
	 scaledValueOfSecondSize = missing() ;
	 is_aerosol = 1 ;
	}
#Mean height of maximum injection
'Mean height of maximum injection' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 39 ;
	}
#Plume top height above surface
'Plume top height above surface' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 42 ;
	}
#Volcanic sulfur dioxide mass mixing ratio
'Volcanic sulfur dioxide mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 8 ;
	 is_chemical_srcsink = 1 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#UV visible albedo for diffuse radiation (climatological)
'UV visible albedo for diffuse radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 55 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation (climatological)
'UV visible albedo for direct radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, geometric component (climatological)
'UV visible albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, isotropic component (climatological)
'UV visible albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfGeneratingProcess = 9 ;
	}
#UV visible albedo for direct radiation, volumetric component (climatological)
'UV visible albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 59 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Plume bottom height above surface
'Plume bottom height above surface' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 41 ;
	}
#Ammonium aerosol mass mixing ratio
'Ammonium aerosol mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	}
#Nitrate aerosol optical depth at 550 nm
'Nitrate aerosol optical depth at 550 nm' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 scaleFactorOfFirstWavelength = 8 ;
	 typeOfSizeInterval = 255 ;
	 aerosolType = 62004 ;
	 scaledValueOfFirstWavelength = 55 ;
	 typeOfWavelengthInterval = 11 ;
	 is_aerosol_optical = 1 ;
	}
#Ammonium aerosol optical depth at 550 nm
'Ammonium aerosol optical depth at 550 nm' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 scaleFactorOfFirstWavelength = 8 ;
	 typeOfSizeInterval = 255 ;
	 aerosolType = 62003 ;
	 scaledValueOfFirstWavelength = 55 ;
	 typeOfWavelengthInterval = 11 ;
	 is_aerosol_optical = 1 ;
	}
#Biogenic secondary organic aerosol mass mixing ratio
'Biogenic secondary organic aerosol mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 aerosolType = 62032 ;
	 is_aerosol = 1 ;
	}
#Anthropogenic secondary organic aerosol mass mixing ratio
'Anthropogenic secondary organic aerosol mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 aerosolType = 62033 ;
	 is_aerosol = 1 ;
	}
#Near IR albedo for diffuse radiation (climatological)
'Near IR albedo for diffuse radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 9 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation (climatological)
'Near IR albedo for direct radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 10 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, geometric component (climatological)
'Near IR albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, isotropic component (climatological)
'Near IR albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 12 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Near IR albedo for direct radiation, volumetric component (climatological)
'Near IR albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Volcanic sulfur dioxide mass mixing ratio increment
'Volcanic sulfur dioxide mass mixing ratio increment' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 8 ;
	 typeOfGeneratingProcess = 20 ;
	 is_chemical_srcsink = 1 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Ammonium aerosol mass mixing ratio
'Ammonium aerosol mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 aerosolType = 62003 ;
	 typeOfGeneratingProcess = 20 ;
	 is_aerosol = 1 ;
	}
#Biogenic secondary organic aerosol mass mixing ratio increment
'Biogenic secondary organic aerosol mass mixing ratio increment' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 aerosolType = 62032 ;
	 typeOfGeneratingProcess = 20 ;
	 is_aerosol = 1 ;
	}
#Anthropogenic secondary organic aerosol mass mixing ratio increment
'Anthropogenic secondary organic aerosol mass mixing ratio increment' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 aerosolType = 62033 ;
	 typeOfGeneratingProcess = 20 ;
	 is_aerosol = 1 ;
	}
#Random pattern 1 for SPP scheme
'Random pattern 1 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 1 ;
	}
#Random pattern 2 for SPP scheme
'Random pattern 2 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 2 ;
	}
#Random pattern 3 for SPP scheme
'Random pattern 3 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 3 ;
	}
#Random pattern 4 for SPP scheme
'Random pattern 4 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 4 ;
	}
#Random pattern 5 for SPP scheme
'Random pattern 5 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 5 ;
	}
#Random pattern 6 for SPP scheme
'Random pattern 6 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 6 ;
	}
#Random pattern 7 for SPP scheme
'Random pattern 7 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 7 ;
	}
#Random pattern 8 for SPP scheme
'Random pattern 8 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 8 ;
	}
#Random pattern 9 for SPP scheme
'Random pattern 9 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 9 ;
	}
#Random pattern 10 for SPP scheme
'Random pattern 10 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 10 ;
	}
#Random pattern 11 for SPP scheme
'Random pattern 11 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 11 ;
	}
#Random pattern 12 for SPP scheme
'Random pattern 12 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 12 ;
	}
#Random pattern 13 for SPP scheme
'Random pattern 13 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 13 ;
	}
#Random pattern 14 for SPP scheme
'Random pattern 14 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 14 ;
	}
#Random pattern 15 for SPP scheme
'Random pattern 15 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 15 ;
	}
#Random pattern 16 for SPP scheme
'Random pattern 16 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 16 ;
	}
#Random pattern 17 for SPP scheme
'Random pattern 17 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 17 ;
	}
#Random pattern 18 for SPP scheme
'Random pattern 18 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 18 ;
	}
#Random pattern 19 for SPP scheme
'Random pattern 19 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 19 ;
	}
#Random pattern 20 for SPP scheme
'Random pattern 20 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 20 ;
	}
#Random pattern 21 for SPP scheme
'Random pattern 21 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 21 ;
	}
#Random pattern 22 for SPP scheme
'Random pattern 22 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 22 ;
	}
#Random pattern 23 for SPP scheme
'Random pattern 23 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 23 ;
	}
#Random pattern 24 for SPP scheme
'Random pattern 24 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 24 ;
	}
#Random pattern 25 for SPP scheme
'Random pattern 25 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 25 ;
	}
#Random pattern 26 for SPP scheme
'Random pattern 26 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 26 ;
	}
#Random pattern 27 for SPP scheme
'Random pattern 27 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 27 ;
	}
#Random pattern 28 for SPP scheme
'Random pattern 28 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 28 ;
	}
#Random pattern 29 for SPP scheme
'Random pattern 29 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 29 ;
	}
#Random pattern 30 for SPP scheme
'Random pattern 30 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 30 ;
	}
#Random pattern 31 for SPP scheme
'Random pattern 31 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 31 ;
	}
#Random pattern 32 for SPP scheme
'Random pattern 32 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 32 ;
	}
#Random pattern 33 for SPP scheme
'Random pattern 33 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 33 ;
	}
#Random pattern 34 for SPP scheme
'Random pattern 34 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 34 ;
	}
#Random pattern 35 for SPP scheme
'Random pattern 35 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 35 ;
	}
#Random pattern 36 for SPP scheme
'Random pattern 36 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 36 ;
	}
#Random pattern 37 for SPP scheme
'Random pattern 37 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 37 ;
	}
#Random pattern 38 for SPP scheme
'Random pattern 38 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 38 ;
	}
#Random pattern 39 for SPP scheme
'Random pattern 39 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 39 ;
	}
#Random pattern 40 for SPP scheme
'Random pattern 40 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 40 ;
	}
#Random pattern 41 for SPP scheme
'Random pattern 41 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 41 ;
	}
#Random pattern 42 for SPP scheme
'Random pattern 42 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 42 ;
	}
#Random pattern 43 for SPP scheme
'Random pattern 43 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 43 ;
	}
#Random pattern 44 for SPP scheme
'Random pattern 44 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 44 ;
	}
#Random pattern 45 for SPP scheme
'Random pattern 45 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 45 ;
	}
#Random pattern 46 for SPP scheme
'Random pattern 46 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 46 ;
	}
#Random pattern 47 for SPP scheme
'Random pattern 47 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 47 ;
	}
#Random pattern 48 for SPP scheme
'Random pattern 48 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 48 ;
	}
#Random pattern 49 for SPP scheme
'Random pattern 49 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 49 ;
	}
#Random pattern 50 for SPP scheme
'Random pattern 50 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 50 ;
	}
#Random pattern 51 for SPP scheme
'Random pattern 51 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 51 ;
	}
#Random pattern 52 for SPP scheme
'Random pattern 52 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 52 ;
	}
#Random pattern 53 for SPP scheme
'Random pattern 53 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 53 ;
	}
#Random pattern 54 for SPP scheme
'Random pattern 54 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 54 ;
	}
#Random pattern 55 for SPP scheme
'Random pattern 55 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 55 ;
	}
#Random pattern 56 for SPP scheme
'Random pattern 56 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 56 ;
	}
#Random pattern 57 for SPP scheme
'Random pattern 57 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 57 ;
	}
#Random pattern 58 for SPP scheme
'Random pattern 58 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 58 ;
	}
#Random pattern 59 for SPP scheme
'Random pattern 59 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 59 ;
	}
#Random pattern 60 for SPP scheme
'Random pattern 60 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 60 ;
	}
#Random pattern 61 for SPP scheme
'Random pattern 61 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 61 ;
	}
#Random pattern 62 for SPP scheme
'Random pattern 62 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 62 ;
	}
#Random pattern 63 for SPP scheme
'Random pattern 63 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 63 ;
	}
#Random pattern 64 for SPP scheme
'Random pattern 64 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 64 ;
	}
#Random pattern 65 for SPP scheme
'Random pattern 65 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 65 ;
	}
#Random pattern 66 for SPP scheme
'Random pattern 66 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 66 ;
	}
#Random pattern 67 for SPP scheme
'Random pattern 67 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 67 ;
	}
#Random pattern 68 for SPP scheme
'Random pattern 68 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 68 ;
	}
#Random pattern 69 for SPP scheme
'Random pattern 69 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 69 ;
	}
#Random pattern 70 for SPP scheme
'Random pattern 70 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 70 ;
	}
#Random pattern 71 for SPP scheme
'Random pattern 71 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 71 ;
	}
#Random pattern 72 for SPP scheme
'Random pattern 72 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 72 ;
	}
#Random pattern 73 for SPP scheme
'Random pattern 73 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 73 ;
	}
#Random pattern 74 for SPP scheme
'Random pattern 74 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 74 ;
	}
#Random pattern 75 for SPP scheme
'Random pattern 75 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 75 ;
	}
#Random pattern 76 for SPP scheme
'Random pattern 76 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 76 ;
	}
#Random pattern 77 for SPP scheme
'Random pattern 77 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 77 ;
	}
#Random pattern 78 for SPP scheme
'Random pattern 78 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 78 ;
	}
#Random pattern 79 for SPP scheme
'Random pattern 79 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 79 ;
	}
#Random pattern 80 for SPP scheme
'Random pattern 80 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 80 ;
	}
#Random pattern 81 for SPP scheme
'Random pattern 81 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 81 ;
	}
#Random pattern 82 for SPP scheme
'Random pattern 82 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 82 ;
	}
#Random pattern 83 for SPP scheme
'Random pattern 83 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 83 ;
	}
#Random pattern 84 for SPP scheme
'Random pattern 84 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 84 ;
	}
#Random pattern 85 for SPP scheme
'Random pattern 85 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 85 ;
	}
#Random pattern 86 for SPP scheme
'Random pattern 86 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 86 ;
	}
#Random pattern 87 for SPP scheme
'Random pattern 87 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 87 ;
	}
#Random pattern 88 for SPP scheme
'Random pattern 88 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 88 ;
	}
#Random pattern 89 for SPP scheme
'Random pattern 89 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 89 ;
	}
#Random pattern 90 for SPP scheme
'Random pattern 90 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 90 ;
	}
#Random pattern 91 for SPP scheme
'Random pattern 91 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 91 ;
	}
#Random pattern 92 for SPP scheme
'Random pattern 92 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 92 ;
	}
#Random pattern 93 for SPP scheme
'Random pattern 93 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 93 ;
	}
#Random pattern 94 for SPP scheme
'Random pattern 94 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 94 ;
	}
#Random pattern 95 for SPP scheme
'Random pattern 95 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 95 ;
	}
#Random pattern 96 for SPP scheme
'Random pattern 96 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 96 ;
	}
#Random pattern 97 for SPP scheme
'Random pattern 97 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 97 ;
	}
#Random pattern 98 for SPP scheme
'Random pattern 98 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 98 ;
	}
#Random pattern 99 for SPP scheme
'Random pattern 99 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 99 ;
	}
#Random pattern 100 for SPP scheme
'Random pattern 100 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 100 ;
	}
#Random pattern 101 for SPP scheme
'Random pattern 101 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 101 ;
	}
#Random pattern 102 for SPP scheme
'Random pattern 102 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 102 ;
	}
#Random pattern 103 for SPP scheme
'Random pattern 103 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 103 ;
	}
#Random pattern 104 for SPP scheme
'Random pattern 104 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 104 ;
	}
#Random pattern 105 for SPP scheme
'Random pattern 105 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 105 ;
	}
#Random pattern 106 for SPP scheme
'Random pattern 106 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 106 ;
	}
#Random pattern 107 for SPP scheme
'Random pattern 107 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 107 ;
	}
#Random pattern 108 for SPP scheme
'Random pattern 108 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 108 ;
	}
#Random pattern 109 for SPP scheme
'Random pattern 109 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 109 ;
	}
#Random pattern 110 for SPP scheme
'Random pattern 110 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 110 ;
	}
#Random pattern 111 for SPP scheme
'Random pattern 111 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 111 ;
	}
#Random pattern 112 for SPP scheme
'Random pattern 112 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 112 ;
	}
#Random pattern 113 for SPP scheme
'Random pattern 113 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 113 ;
	}
#Random pattern 114 for SPP scheme
'Random pattern 114 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 114 ;
	}
#Random pattern 115 for SPP scheme
'Random pattern 115 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 115 ;
	}
#Random pattern 116 for SPP scheme
'Random pattern 116 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 116 ;
	}
#Random pattern 117 for SPP scheme
'Random pattern 117 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 117 ;
	}
#Random pattern 118 for SPP scheme
'Random pattern 118 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 118 ;
	}
#Random pattern 119 for SPP scheme
'Random pattern 119 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 119 ;
	}
#Random pattern 120 for SPP scheme
'Random pattern 120 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 120 ;
	}
#Random pattern 121 for SPP scheme
'Random pattern 121 for SPP scheme' = {
	 discipline = 191 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 randomFieldNumber = 121 ;
	}
#Cosine of solar zenith angle
'Cosine of solar zenith angle' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#UV biologically effective dose
'UV biologically effective dose' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#UV biologically effective dose clear-sky
'UV biologically effective dose clear-sky' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Dry deposition of ammonium aerosol
'Dry deposition of ammonium aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	}
#Sedimentation of ammonium aerosol
'Sedimentation of ammonium aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	}
#Wet deposition of ammonium aerosol by large-scale precipitation
'Wet deposition of ammonium aerosol by large-scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	}
#Wet deposition of ammonium aerosol by convective precipitation
'Wet deposition of ammonium aerosol by convective precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	}
#Vertically integrated mass of ammonium aerosol
'Vertically integrated mass of ammonium aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 aerosolType = 62003 ;
	 is_aerosol = 1 ;
	}
#Dry deposition of biogenic secondary organic aerosol
'Dry deposition of biogenic secondary organic aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 12 ;
	 aerosolType = 62032 ;
	 is_aerosol = 1 ;
	}
#Sedimentation of biogenic secondary organic aerosol
'Sedimentation of biogenic secondary organic aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 aerosolType = 62032 ;
	 is_aerosol = 1 ;
	}
#Wet deposition of biogenic secondary organic aerosol by large-scale precipitation
'Wet deposition of biogenic secondary organic aerosol by large-scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 aerosolType = 62032 ;
	 is_aerosol = 1 ;
	}
#Wet deposition of biogenic secondary organic aerosol by convective precipitation
'Wet deposition of biogenic secondary organic aerosol by convective precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 aerosolType = 62032 ;
	 is_aerosol = 1 ;
	}
#Vertically integrated mass of biogenic secondary organic aerosol
'Vertically integrated mass of biogenic secondary organic aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 aerosolType = 62032 ;
	 is_aerosol = 1 ;
	}
#Dry deposition of anthropogenic secondary organic aerosol
'Dry deposition of anthropogenic secondary organic aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 12 ;
	 aerosolType = 62033 ;
	 is_aerosol = 1 ;
	}
#Sedimentation of anthropogenic secondary organic aerosol
'Sedimentation of anthropogenic secondary organic aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 aerosolType = 62033 ;
	 is_aerosol = 1 ;
	}
#Wet deposition of anthropogenic secondary organic aerosol by large-scale precipitation
'Wet deposition of anthropogenic secondary organic aerosol by large-scale precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 aerosolType = 62033 ;
	 is_aerosol = 1 ;
	}
#Wet deposition of anthropogenic secondary organic aerosol by convective precipitation
'Wet deposition of anthropogenic secondary organic aerosol by convective precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 aerosolType = 62033 ;
	 is_aerosol = 1 ;
	}
#Vertically integrated mass of anthropogenic secondary organic aerosol
'Vertically integrated mass of anthropogenic secondary organic aerosol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 aerosolType = 62033 ;
	 is_aerosol = 1 ;
	}
#Secondary organic aerosol optical depth at 550 nm
'Secondary organic aerosol optical depth at 550 nm' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 scaleFactorOfFirstWavelength = 9 ;
	 aerosolType = 62012 ;
	 scaledValueOfFirstWavelength = 550 ;
	 scaledValueOfSecondWavelength = missing() ;
	 typeOfWavelengthInterval = 11 ;
	 scaleFactorOfSecondWavelength = missing() ;
	 is_aerosol_optical = 1 ;
	}
#Ammonia mass mixing ratio
'Ammonia mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 9 ;
	 is_chemical = 1 ;
	}
#Nitrogen monoxide mass mixing ratio
'Nitrogen monoxide mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 11 ;
	 is_chemical = 1 ;
	}
#Aromatic peroxy radical mass mixing ratio
'Aromatic peroxy radical mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 60029 ;
	 is_chemical = 1 ;
	}
#Ethyne mass mixing ratio
'Ethyne mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 10010 ;
	 is_chemical = 1 ;
	}
#Acetonitrile mass mixing ratio
'Acetonitrile mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 10007 ;
	 is_chemical = 1 ;
	}
#Methyl peroxy nitrate mass mixing ratio
'Methyl peroxy nitrate mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 10055 ;
	 is_chemical = 1 ;
	}
#Hydrogen cyanide mass mixing ratio
'Hydrogen cyanide mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 10006 ;
	 is_chemical = 1 ;
	}
#Hydroperoxy aldehydes type 1 mass mixing ratio
'Hydroperoxy aldehydes type 1 mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 60058 ;
	 is_chemical = 1 ;
	}
#Hydroperoxy aldehydes type 2 mass mixing ratio
'Hydroperoxy aldehydes type 2 mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 60059 ;
	 is_chemical = 1 ;
	}
#Isoprene peroxy type B mass mixing ratio
'Isoprene peroxy type B mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 60056 ;
	 is_chemical = 1 ;
	}
#Isoprene peroxy type D mass mixing ratio
'Isoprene peroxy type D mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 60057 ;
	 is_chemical = 1 ;
	}
#Column integrated mass density of Volcanic sulfur dioxide
'Column integrated mass density of Volcanic sulfur dioxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 constituentType = 8 ;
	 is_chemical_srcsink = 1 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Column integrated mass density of Aromatic peroxy radical
'Column integrated mass density of Aromatic peroxy radical' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 constituentType = 60029 ;
	 is_chemical = 1 ;
	}
#Column integrated mass density of Ethyne
'Column integrated mass density of Ethyne' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 constituentType = 10010 ;
	 is_chemical = 1 ;
	}
#Column integrated mass density of Acetonitrile
'Column integrated mass density of Acetonitrile' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 constituentType = 10007 ;
	 is_chemical = 1 ;
	}
#Column integrated mass density of Methyl peroxy nitrate
'Column integrated mass density of Methyl peroxy nitrate' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 constituentType = 10055 ;
	 is_chemical = 1 ;
	}
#Column integrated mass density of Hydrogen cyanide
'Column integrated mass density of Hydrogen cyanide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 constituentType = 10006 ;
	 is_chemical = 1 ;
	}
#Column integrated mass density of Hydroperoxy aldehydes type 1
'Column integrated mass density of Hydroperoxy aldehydes type 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 constituentType = 60058 ;
	 is_chemical = 1 ;
	}
#Column integrated mass density of Hydroperoxy aldehydes type 2
'Column integrated mass density of Hydroperoxy aldehydes type 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 constituentType = 60059 ;
	 is_chemical = 1 ;
	}
#Column integrated mass density of Isoprene peroxy type B
'Column integrated mass density of Isoprene peroxy type B' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 constituentType = 60056 ;
	 is_chemical = 1 ;
	}
#Column integrated mass density of Isoprene peroxy type D
'Column integrated mass density of Isoprene peroxy type D' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 constituentType = 60057 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Volcanic sulfur dioxide
'Atmosphere emission mass flux of Volcanic sulfur dioxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 8 ;
	 is_chemical_srcsink = 1 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Atmosphere emission mass flux of Aromatic peroxy radical
'Atmosphere emission mass flux of Aromatic peroxy radical' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 60029 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Ethyne
'Atmosphere emission mass flux of Ethyne' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 10010 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Acetonitrile
'Atmosphere emission mass flux of Acetonitrile' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 10007 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Methyl peroxy nitrate
'Atmosphere emission mass flux of Methyl peroxy nitrate' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 10055 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Hydrogen cyanide
'Atmosphere emission mass flux of Hydrogen cyanide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 10006 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Hydroperoxy aldehydes type 1
'Atmosphere emission mass flux of Hydroperoxy aldehydes type 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 60058 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Hydroperoxy aldehydes type 2
'Atmosphere emission mass flux of Hydroperoxy aldehydes type 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 60059 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Isoprene peroxy type B
'Atmosphere emission mass flux of Isoprene peroxy type B' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 60056 ;
	 is_chemical = 1 ;
	}
#Atmosphere emission mass flux of Isoprene peroxy type D
'Atmosphere emission mass flux of Isoprene peroxy type D' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 60057 ;
	 is_chemical = 1 ;
	}
#Dry deposition velocity of Volcanic sulfur dioxide
'Dry deposition velocity of Volcanic sulfur dioxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 constituentType = 8 ;
	 is_chemical_srcsink = 1 ;
	 sourceSinkChemicalPhysicalProcess = 7 ;
	}
#Dry deposition velocity of Aromatic peroxy radical
'Dry deposition velocity of Aromatic peroxy radical' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 constituentType = 60029 ;
	 is_chemical = 1 ;
	}
#Dry deposition velocity of Ethyne
'Dry deposition velocity of Ethyne' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 constituentType = 10010 ;
	 is_chemical = 1 ;
	}
#Dry deposition velocity of Acetonitrile
'Dry deposition velocity of Acetonitrile' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 constituentType = 10007 ;
	 is_chemical = 1 ;
	}
#Dry deposition velocity of Methyl peroxy nitrate
'Dry deposition velocity of Methyl peroxy nitrate' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 constituentType = 10055 ;
	 is_chemical = 1 ;
	}
#Dry deposition velocity of Hydrogen cyanide
'Dry deposition velocity of Hydrogen cyanide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 constituentType = 10006 ;
	 is_chemical = 1 ;
	}
#Dry deposition velocity of Hydroperoxy aldehydes type 1
'Dry deposition velocity of Hydroperoxy aldehydes type 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 constituentType = 60058 ;
	 is_chemical = 1 ;
	}
#Dry deposition velocity of Hydroperoxy aldehydes type 2
'Dry deposition velocity of Hydroperoxy aldehydes type 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 constituentType = 60059 ;
	 is_chemical = 1 ;
	}
#Dry deposition velocity of Isoprene peroxy type B
'Dry deposition velocity of Isoprene peroxy type B' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 constituentType = 60056 ;
	 is_chemical = 1 ;
	}
#Dry deposition velocity of Isoprene peroxy type D
'Dry deposition velocity of Isoprene peroxy type D' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 15 ;
	 constituentType = 60057 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Ozone
'Time-integrated dry deposition mass flux of Ozone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Hydrogen peroxide
'Time-integrated dry deposition mass flux of Hydrogen peroxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 19 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Carbon monoxide
'Time-integrated dry deposition mass flux of Carbon monoxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 4 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Nitric acid
'Time-integrated dry deposition mass flux of Nitric acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 17 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Methyl peroxide
'Time-integrated dry deposition mass flux of Methyl peroxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10002 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Formaldehyde
'Time-integrated dry deposition mass flux of Formaldehyde' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 7 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Aldehydes
'Time-integrated dry deposition mass flux of Aldehydes' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 60018 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Peroxyacetyl nitrate
'Time-integrated dry deposition mass flux of Peroxyacetyl nitrate' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10013 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Peroxides
'Time-integrated dry deposition mass flux of Peroxides' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 60019 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Organic nitrates
'Time-integrated dry deposition mass flux of Organic nitrates' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 60020 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Isoprene
'Time-integrated dry deposition mass flux of Isoprene' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10017 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Sulphur dioxide
'Time-integrated dry deposition mass flux of Sulphur dioxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Ammonia
'Time-integrated dry deposition mass flux of Ammonia' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Sulfate
'Time-integrated dry deposition mass flux of Sulfate' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 22 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Ammonium
'Time-integrated dry deposition mass flux of Ammonium' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Methyl glyoxal
'Time-integrated dry deposition mass flux of Methyl glyoxal' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10025 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Nitrogen monoxide
'Time-integrated dry deposition mass flux of Nitrogen monoxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Hydroperoxy radical
'Time-integrated dry deposition mass flux of Hydroperoxy radical' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 14 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Methylperoxy radical
'Time-integrated dry deposition mass flux of Methylperoxy radical' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10001 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Nitrogen dioxide
'Time-integrated dry deposition mass flux of Nitrogen dioxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Nitrate radical
'Time-integrated dry deposition mass flux of Nitrate radical' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 13 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Dinitrogen pentoxide
'Time-integrated dry deposition mass flux of Dinitrogen pentoxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 15 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Pernitric acid
'Time-integrated dry deposition mass flux of Pernitric acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 18 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Methanol
'Time-integrated dry deposition mass flux of Methanol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10004 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Formic acid
'Time-integrated dry deposition mass flux of Formic acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10005 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Methacrylic acid
'Time-integrated dry deposition mass flux of Methacrylic acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10027 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Ethane
'Time-integrated dry deposition mass flux of Ethane' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10008 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Ethanol
'Time-integrated dry deposition mass flux of Ethanol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10011 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Methacrolein
'Time-integrated dry deposition mass flux of Methacrolein' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10028 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Acetone
'Time-integrated dry deposition mass flux of Acetone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10029 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Nitrous acid
'Time-integrated dry deposition mass flux of Nitrous acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 16 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Glycolaldehyde
'Time-integrated dry deposition mass flux of Glycolaldehyde' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10033 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Glyoxal
'Time-integrated dry deposition mass flux of Glyoxal' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10038 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Hydroxyacetone
'Time-integrated dry deposition mass flux of Hydroxyacetone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10041 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of all hydroxy-peroxides products of the reaction of hydroxy-isoprene adducts with O2
'Time-integrated dry deposition mass flux of all hydroxy-peroxides products of the reaction of hydroxy-isoprene adducts with O2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 60032 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Acetonitrile
'Time-integrated dry deposition mass flux of Acetonitrile' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10007 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated dry deposition mass flux of Hydrogen cyanide
'Time-integrated dry deposition mass flux of Hydrogen cyanide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 constituentType = 10006 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Ozone
'Time-integrated wet deposition mass flux of Ozone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Hydrogen peroxide
'Time-integrated wet deposition mass flux of Hydrogen peroxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 19 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Nitric acid
'Time-integrated wet deposition mass flux of Nitric acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 17 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Methyl peroxide
'Time-integrated wet deposition mass flux of Methyl peroxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10002 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Formaldehyde
'Time-integrated wet deposition mass flux of Formaldehyde' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 7 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Aldehydes
'Time-integrated wet deposition mass flux of Aldehydes' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 60018 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Peroxyacetyl nitrate
'Time-integrated wet deposition mass flux of Peroxyacetyl nitrate' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10013 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Peroxides
'Time-integrated wet deposition mass flux of Peroxides' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 60019 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Organic nitrates
'Time-integrated wet deposition mass flux of Organic nitrates' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 60020 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Isoprene
'Time-integrated wet deposition mass flux of Isoprene' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10017 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Sulphur dioxide
'Time-integrated wet deposition mass flux of Sulphur dioxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Ammonia
'Time-integrated wet deposition mass flux of Ammonia' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Sulfate
'Time-integrated wet deposition mass flux of Sulfate' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 22 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Ammonium
'Time-integrated wet deposition mass flux of Ammonium' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Methane sulfonic acid
'Time-integrated wet deposition mass flux of Methane sulfonic acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10024 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Methyl glyoxal
'Time-integrated wet deposition mass flux of Methyl glyoxal' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10025 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Carbon monoxide
'Time-integrated wet deposition mass flux of Carbon monoxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 4 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Lead
'Time-integrated wet deposition mass flux of Lead' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 30296 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Nitrogen monoxide
'Time-integrated wet deposition mass flux of Nitrogen monoxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Hydroperoxy radical
'Time-integrated wet deposition mass flux of Hydroperoxy radical' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 14 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Methylperoxy radical
'Time-integrated wet deposition mass flux of Methylperoxy radical' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10001 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Nitrogen dioxide
'Time-integrated wet deposition mass flux of Nitrogen dioxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Nitrate radical
'Time-integrated wet deposition mass flux of Nitrate radical' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 13 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Dinitrogen pentoxide
'Time-integrated wet deposition mass flux of Dinitrogen pentoxide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 15 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Pernitric acid
'Time-integrated wet deposition mass flux of Pernitric acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 18 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Methanol
'Time-integrated wet deposition mass flux of Methanol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10004 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Formic acid
'Time-integrated wet deposition mass flux of Formic acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10005 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Methacrylic acid
'Time-integrated wet deposition mass flux of Methacrylic acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10027 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Ethane
'Time-integrated wet deposition mass flux of Ethane' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10008 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Ethanol
'Time-integrated wet deposition mass flux of Ethanol' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10011 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Methacrolein
'Time-integrated wet deposition mass flux of Methacrolein' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10028 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Acetone
'Time-integrated wet deposition mass flux of Acetone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10029 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Chlorine nitrate
'Time-integrated wet deposition mass flux of Chlorine nitrate' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 30 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Hypochlorous acid
'Time-integrated wet deposition mass flux of Hypochlorous acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 29 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Hydrogen bromide
'Time-integrated wet deposition mass flux of Hydrogen bromide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 35 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Hypobromous acid
'Time-integrated wet deposition mass flux of Hypobromous acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 36 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Nitrous acid
'Time-integrated wet deposition mass flux of Nitrous acid' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 16 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Toluene and less reactive aromatics
'Time-integrated wet deposition mass flux of Toluene and less reactive aromatics' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10022 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Xylene and more reactive aromatics
'Time-integrated wet deposition mass flux of Xylene and more reactive aromatics' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10023 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Glycolaldehyde
'Time-integrated wet deposition mass flux of Glycolaldehyde' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10033 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Glyoxal
'Time-integrated wet deposition mass flux of Glyoxal' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10038 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Hydroxyacetone
'Time-integrated wet deposition mass flux of Hydroxyacetone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10041 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of all hydroxy-peroxides products of the reaction of hydroxy-isoprene adducts with O2
'Time-integrated wet deposition mass flux of all hydroxy-peroxides products of the reaction of hydroxy-isoprene adducts with O2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 60032 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Bromine nitrate
'Time-integrated wet deposition mass flux of Bromine nitrate' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 37 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Hydrogen chloride
'Time-integrated wet deposition mass flux of Hydrogen chloride' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 20001 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Acetonitrile
'Time-integrated wet deposition mass flux of Acetonitrile' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10007 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Hydrogen cyanide
'Time-integrated wet deposition mass flux of Hydrogen cyanide' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10006 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Hydroperoxy aldehydes type 1
'Time-integrated wet deposition mass flux of Hydroperoxy aldehydes type 1' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10058 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Time-integrated wet deposition mass flux of Hydroperoxy aldehydes type 2
'Time-integrated wet deposition mass flux of Hydroperoxy aldehydes type 2' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 constituentType = 10059 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical = 1 ;
	}
#Geometric height of -10 degrees C atmospheric isothermal level above ground
'Geometric height of -10 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Surface direct short-wave (solar) radiation
'Surface direct short-wave (solar) radiation' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface direct short-wave radiation, clear sky
'Surface direct short-wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Cloud base height
'Cloud base height' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 2 ;
	}
#Geometric height of 0 degrees C atmospheric isothermal level above ground
'Geometric height of 0 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Instantaneous 10 metre wind gust
'Instantaneous 10 metre wind gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Relative humidity with respect to water
'Relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	}
#Relative humidity with respect to ice
'Relative humidity with respect to ice' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 94 ;
	}
#Snow albedo
'Snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	}
#Fraction of convective precipitation cover
'Fraction of convective precipitation cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 37 ;
	}
#2 metre relative humidity with respect to water
'2 metre relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Liquid water content in snow pack
'Liquid water content in snow pack' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	}
#Convective available potential energy shear
'Convective available potential energy shear' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Tropopause pressure
'Tropopause pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Height of convective cloud top
'Height of convective cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	}
#Height of zero-degree wet-bulb temperature
'Height of zero-degree wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 44 ;
	}
#Height of one-degree wet-bulb temperature
'Height of one-degree wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 45 ;
	}
#Instantaneous total lightning flash density
'Instantaneous total lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Instantaneous cloud-to-ground lightning flash density
'Instantaneous cloud-to-ground lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Unbalanced component of specific humidity
'Unbalanced component of specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 118 ;
	}
#Unbalanced component of specific cloud liquid water content
'Unbalanced component of specific cloud liquid water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 119 ;
	}
#Unbalanced component of specific cloud ice water content
'Unbalanced component of specific cloud ice water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 120 ;
	}
#Accumulated Carbon Dioxide Net Ecosystem Exchange
'Accumulated Carbon Dioxide Net Ecosystem Exchange' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Gross Primary Production
'Accumulated Carbon Dioxide Gross Primary Production' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Accumulated Carbon Dioxide Ecosystem Respiration
'Accumulated Carbon Dioxide Ecosystem Respiration' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Carbon dioxide net ecosystem exchange flux
'Carbon dioxide net ecosystem exchange flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	}
#Carbon dioxide gross primary production flux
'Carbon dioxide gross primary production flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	}
#Carbon dioxide ecosystem respiration flux
'Carbon dioxide ecosystem respiration flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	}
#Soil moisture top 20 cm
'Soil moisture top 20 cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Soil moisture top 100 cm
'Soil moisture top 100 cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Total column supercooled liquid water
'Total column supercooled liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 167 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column rain water
'Total column rain water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column snow water
'Total column snow water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Ice temperature
'Ice temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}
#Soil temperature top 20 cm
'Soil temperature top 20 cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Soil temperature top 100 cm
'Soil temperature top 100 cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Atmosphere emission mass flux of Methane from Wetlands
'Atmosphere emission mass flux of Methane from Wetlands' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 2 ;
	 is_chemical_srcsink = 1 ;
	 sourceSinkChemicalPhysicalProcess = 10 ;
	}
#Accumulated mass emission of methane from Wetlands
'Accumulated mass emission of methane from Wetlands' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 2 ;
	 typeOfStatisticalProcessing = 1 ;
	 is_chemical_srcsink = 1 ;
	 sourceSinkChemicalPhysicalProcess = 10 ;
	}
#Surface short-wave (solar) radiation downward clear-sky
'Surface short-wave (solar) radiation downward clear-sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface long-wave (thermal) radiation downward clear-sky
'Surface long-wave (thermal) radiation downward clear-sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Convective precipitation
'Convective precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Water runoff and drainage
'Water runoff and drainage' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	}
#Instantaneous large-scale precipitation fraction
'Instantaneous large-scale precipitation fraction' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Convective rain rate
'Convective rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Large scale rain rate
'Large scale rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Convective snowfall rate water equivalent
'Convective snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Large scale snowfall rate water equivalent
'Large scale snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Mixed-layer CAPE in the lowest 50 hPa
'Mixed-layer CAPE in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Mixed-layer CIN in the lowest 50 hPa
'Mixed-layer CIN in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Mixed-layer CAPE in the lowest 100 hPa
'Mixed-layer CAPE in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Mixed-layer CIN in the lowest 100 hPa
'Mixed-layer CIN in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Most-unstable CAPE
'Most-unstable CAPE' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	}
#Most-unstable CIN
'Most-unstable CIN' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	}
#Departure level of the most unstable parcel expressed as Pressure
'Departure level of the most unstable parcel expressed as Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	}
#Urban cover
'Urban cover' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	}
#Road Cover
'Road Cover' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	}
#Building cover
'Building cover' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 2 ;
	}
#Building height
'Building height' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	}
#Vertical-to-horizontal area ratio
'Vertical-to-horizontal area ratio' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	}
#Standard deviation of building height
'Standard deviation of building height' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	}
#Wetland cover
'Wetland cover' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 45 ;
	}
#Wetland type
'Wetland type' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	}
#Irrigation cover
'Irrigation cover' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	}
#C4 crop cover
'C4 crop cover' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	}
#C4 grass cover
'C4 grass cover' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	}
#Accumulated freezing rain water equivalent
'Accumulated freezing rain water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Runoff water equivalent (surface plus subsurface)
'Runoff water equivalent (surface plus subsurface)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Snow evaporation water equivalent
'Snow evaporation water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Potential evaporation rate
'Potential evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Potential evaporation
'Potential evaporation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Tile fraction
'Tile fraction' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	}
#Tile percentage
'Tile percentage' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 37 ;
	}
#Forecast logarithm of surface roughness length for moisture
'Forecast logarithm of surface roughness length for moisture' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface runoff rate
'Surface runoff rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface runoff
'Surface runoff' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Sub-surface runoff rate
'Sub-surface runoff rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Sub-surface runoff
'Sub-surface runoff' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Reflectance in 0.4 micron channel
'Reflectance in 0.4 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 30 ;
	}
#Vertical divergence
'Vertical divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 59 ;
	}
#Drag thermal coefficient
'Drag thermal coefficient' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Drag evaporation coefficient
'Drag evaporation coefficient' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Pressure departure from hydrostatic state
'Pressure departure from hydrostatic state' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 46 ;
	}
#Surface net radiation flux (SW and LW)
'Surface net radiation flux (SW and LW)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Top net radiation flux (SW and LW)
'Top net radiation flux (SW and LW)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Global irradiance on tilted surfaces
'Global irradiance on tilted surfaces' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 47 ;
	}
#Eady growth rate
'Eady growth rate' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 22 ;
	}
#Tropical cyclones track density
'Tropical cyclones track density' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 4 ;
	}
#Canopy air temperature
'Canopy air temperature' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 63 ;
	}
#Soil wetness index (total layer)
'Soil wetness index (total layer)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 151 ;
	}
#Soil wetness index (root zone)
'Soil wetness index (root zone)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	}
#Soil wetness index (layer)
'Soil wetness index (layer)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 151 ;
	 typeOfSecondFixedSurface = 151 ;
	}
#Distance downward from roof surface
'Distance downward from roof surface' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 6 ;
	}
#Distance inward from outer wall surface
'Distance inward from outer wall surface' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 7 ;
	}
#Distance downward from road surface
'Distance downward from road surface' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 8 ;
	}
#Renewable power capacity
'Renewable power capacity' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Renewable power production rate
'Renewable power production rate' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Renewable power production
'Renewable power production' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Wind power capacity
'Wind power capacity' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Wind power production rate
'Wind power production rate' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Wind power production
'Wind power production' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Solar photovoltaic (PV) power capacity
'Solar photovoltaic (PV) power capacity' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Solar photovoltaic (PV) power production rate
'Solar photovoltaic (PV) power production rate' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Solar photovoltaic (PV) power production
'Solar photovoltaic (PV) power production' = {
	 discipline = 20 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Graupel (snow pellets) precipitation
'Graupel (snow pellets) precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total lightning flash density
'Time-integrated total lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Pressure at cloud base
'Pressure at cloud base' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 2 ;
	}
#Geometric height of adiabatic condensation level above ground
'Geometric height of adiabatic condensation level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 5 ;
	}
#Geometric height of free convection level above ground
'Geometric height of free convection level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 14 ;
	}
#Geometric height of neutral buoyancy level above ground
'Geometric height of neutral buoyancy level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 16 ;
	}
#Geometric height of 3 degrees C atmospheric isothermal level above ground
'Geometric height of 3 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27615 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Roof temperature
'Roof temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 185 ;
	}
#Wall temperature
'Wall temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 186 ;
	}
#Road temperature
'Road temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 187 ;
	}
#Snow depth water equivalent on roof
'Snow depth water equivalent on roof' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 185 ;
	}
#Snow depth water equivalent on road
'Snow depth water equivalent on road' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 187 ;
	}
#Urban canyon temperature
'Urban canyon temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 187 ;
	 typeOfSecondFixedSurface = 185 ;
	}
#Urban canyon specific humidity
'Urban canyon specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 187 ;
	 typeOfSecondFixedSurface = 185 ;
	}
#Convective snowfall water equivalent
'Convective snowfall water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Large-scale snowfall water equivalent
'Large-scale snowfall water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Lake surface temperature
'Lake surface temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Surface bulk Richardson number
'Surface bulk Richardson number' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface roughness for heat
'Surface roughness for heat' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface roughness for moisture
'Surface roughness for moisture' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 48 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Snow evaporation rate water equivalent
'Snow evaporation rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Radar reflectivity
'Radar reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 4 ;
	}
#Pressure at cloud ceiling
'Pressure at cloud ceiling' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 19 ;
	 scaledValueOfFirstFixedSurface = 50 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Visibility through precipitation
'Visibility through precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 51 ;
	}
#Geometric height of 0 degrees C theta level above ground
'Geometric height of 0 degrees C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Geometric height of 1 degree C theta level above ground
'Geometric height of 1 degree C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27415 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Geometric height of 1.5 degrees C theta level above ground
'Geometric height of 1.5 degrees C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27465 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	}
#Volumetric soil moisture (root zone)
'Volumetric soil moisture (root zone)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	}
#Total column vertical-maximum radar precipitation rate
'Total column vertical-maximum radar precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertical-maximum radar reflectivity
'Total column vertical-maximum radar reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Thunderstorm hazard index
'Thunderstorm hazard index' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}
#Surface water flooding hazard index
'Surface water flooding hazard index' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	}
#Polluted air hazard index
'Polluted air hazard index' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	}
#Storm surge hazard index
'Storm surge hazard index' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	}
#Cold wave hazard index
'Cold wave hazard index' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	}
#Frost (hoar frost) hazard index
'Frost (hoar frost) hazard index' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 43 ;
	}
#Heatwave hazard index
'Heatwave hazard index' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 47 ;
	}
#Wind hazard index
'Wind hazard index' = {
	 discipline = 20 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	}
#Wildfires hazard index
'Wildfires hazard index' = {
	 discipline = 20 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	}
#Burned area
'Burned area' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}
#Burning area
'Burning area' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 20 ;
	}
#Burnable area
'Burnable area' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	}
#Un-burnable area
'Un-burnable area' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	}
#Fuel load
'Fuel load' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	}
#Combustion completeness
'Combustion completeness' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	}
#Fuel moisture content
'Fuel moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 25 ;
	}
#Live leaf fuel load
'Live leaf fuel load' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	}
#Live wood fuel load 
'Live wood fuel load ' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 28 ;
	}
#Dead leaf fuel load
'Dead leaf fuel load' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 29 ;
	}
#Dead wood fuel load
'Dead wood fuel load' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 30 ;
	}
#Live fuel moisture content
'Live fuel moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 31 ;
	}
#Fine dead leaf moisture content
'Fine dead leaf moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 32 ;
	}
#Dense dead leaf moisture content
'Dense dead leaf moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 33 ;
	}
#Fine dead wood moisture content
'Fine dead wood moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 34 ;
	}
#Dense dead wood moisture content
'Dense dead wood moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 35 ;
	}
#Live fuel moisture content in low vegetation
'Live fuel moisture content in low vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 37 ;
	}
#Live fuel moisture content in high vegetation
'Live fuel moisture content in high vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 38 ;
	}
#Time-integrated total column vertically-integrated eastward geopotential flux
'Time-integrated total column vertically-integrated eastward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward geopotential flux
'Time-integrated total column vertically-integrated northward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of water geopotential flux
'Time-integrated total column vertically-integrated divergence of water geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of geopotential flux
'Time-integrated total column vertically-integrated divergence of geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward enthalpy flux
'Time-integrated total column vertically-integrated eastward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward enthalpy flux
'Time-integrated total column vertically-integrated northward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward kinetic energy flux
'Time-integrated total column vertically-integrated eastward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward kinetic energy flux
'Time-integrated total column vertically-integrated northward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward total energy flux
'Time-integrated total column vertically-integrated eastward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward total energy flux
'Time-integrated total column vertically-integrated northward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of enthalpy flux
'Time-integrated total column vertically-integrated divergence of enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of kinetic energy flux
'Time-integrated total column vertically-integrated divergence of kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of total energy flux
'Time-integrated total column vertically-integrated divergence of total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of water enthalpy flux
'Time-integrated total column vertically-integrated divergence of water enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of mass flux
'Time-integrated total column vertically-integrated divergence of mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward mass flux
'Time-integrated total column vertically-integrated eastward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward mass flux
'Time-integrated total column vertically-integrated northward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of water vapour flux
'Time-integrated total column vertically-integrated divergence of water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of cloud liquid water flux
'Time-integrated total column vertically-integrated divergence of cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of cloud ice water flux
'Time-integrated total column vertically-integrated divergence of cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of rain flux
'Time-integrated total column vertically-integrated divergence of rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated divergence of snow flux
'Time-integrated total column vertically-integrated divergence of snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward water vapour flux
'Time-integrated total column vertically-integrated eastward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward water vapour flux
'Time-integrated total column vertically-integrated northward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward cloud liquid water flux
'Time-integrated total column vertically-integrated eastward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward cloud liquid water flux
'Time-integrated total column vertically-integrated northward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward cloud ice water flux
'Time-integrated total column vertically-integrated eastward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward cloud ice water flux
'Time-integrated total column vertically-integrated northward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward rain flux
'Time-integrated total column vertically-integrated eastward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward rain flux
'Time-integrated total column vertically-integrated northward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated eastward snow flux
'Time-integrated total column vertically-integrated eastward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total column vertically-integrated northward snow flux
'Time-integrated total column vertically-integrated northward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean temperature tendency due to short-wave radiation
'Time-mean temperature tendency due to short-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature tendency due to long-wave radiation
'Time-mean temperature tendency due to long-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature tendency due to short wave radiation, clear sky
'Time-mean temperature tendency due to short wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature tendency due to long-wave radiation, clear sky
'Time-mean temperature tendency due to long-wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature tendency due to parametrisations
'Time-mean temperature tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific humidity tendency due to parametrisations
'Time-mean specific humidity tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward wind tendency due to parametrisations
'Time-mean eastward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward wind tendency due to parametrisations
'Time-mean northward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean updraught mass flux
'Time-mean updraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean downdraught mass flux
'Time-mean downdraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean updraught detrainment rate
'Time-mean updraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean downdraught detrainment rate
'Time-mean downdraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total precipitation flux
'Time-mean total precipitation flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean turbulent diffusion coefficient for heat
'Time-mean turbulent diffusion coefficient for heat' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time integral of rain flux
'Time integral of rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time integral of surface eastward momentum flux
'Time integral of surface eastward momentum flux' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time integral of surface northward momentum flux
'Time integral of surface northward momentum flux' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time integral of surface latent heat evaporation flux
'Time integral of surface latent heat evaporation flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean surface runoff rate
'Time-mean surface runoff rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sub-surface runoff rate
'Time-mean sub-surface runoff rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface photosynthetically active radiation flux, clear sky
'Time-mean surface photosynthetically active radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow evaporation rate water equivalent
'Time-mean snow evaporation rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow melt rate
'Time-mean snow melt rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean magnitude of turbulent surface stress
'Time-mean magnitude of turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean large-scale precipitation fraction
'Time-mean large-scale precipitation fraction' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward UV radiation flux
'Time-mean surface downward UV radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface photosynthetically active radiation flux
'Time-mean surface photosynthetically active radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean large-scale precipitation rate
'Time-mean large-scale precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean convective precipitation rate
'Time-mean convective precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total snowfall rate water equivalent
'Time-mean total snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean boundary layer dissipation
'Time-mean boundary layer dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface sensible heat flux
'Time-mean surface sensible heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface latent heat flux
'Time-mean surface latent heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward short-wave radiation flux
'Time-mean surface downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward long-wave radiation flux
'Time-mean surface downward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface net short-wave radiation flux
'Time-mean surface net short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface net long-wave radiation flux
'Time-mean surface net long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean top net short-wave radiation flux
'Time-mean top net short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean top net long-wave radiation flux
'Time-mean top net long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward turbulent surface stress
'Time-mean eastward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward turbulent surface stress
'Time-mean northward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean moisture flux
'Time-mean moisture flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sunshine duration fraction
'Time-mean sunshine duration fraction' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Time-mean eastward gravity wave surface stress
'Time-mean eastward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward gravity wave surface stress
'Time-mean northward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean gravity wave dissipation
'Time-mean gravity wave dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean runoff rate water equivalent (surface plus subsurface)
'Time-mean runoff rate water equivalent (surface plus subsurface)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean top net short-wave radiation flux, clear sky
'Time-mean top net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean top net long-wave radiation flux, clear sky
'Time-mean top net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface net short-wave radiation flux, clear sky
'Time-mean surface net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface net long-wave radiation flux, clear sky
'Time-mean surface net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time mean top downward short-wave radiation flux
'Time mean top downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated moisture divergence flux
'Time-mean total column vertically-integrated moisture divergence flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total precipitation rate
'Time-mean total precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean convective snowfall rate water equivalent
'Time-mean convective snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean large scale snowfall rate water equivalent
'Time-mean large scale snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface direct short-wave radiation flux
'Time-mean surface direct short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface direct short-wave radiation flux, clear sky
'Time-mean surface direct short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Mean surface diffuse short-wave radiation flux
'Mean surface diffuse short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward short-wave radiation flux, clear sky
'Time-mean surface downward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward long-wave radiation flux, clear sky
'Time-mean surface downward long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean potential evaporation rate
'Time-mean potential evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time integral of surface latent heat sublimation flux
'Time integral of surface latent heat sublimation flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time integral of evapotranspiration flux
'Time integral of evapotranspiration flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean evapotranspiration rate
'Time-mean evapotranspiration rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time integral of potential evapotranspiration rate
'Time integral of potential evapotranspiration rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-mean potential evapotranspiration rate
'Time-mean potential evapotranspiration rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean volumetric soil moisture
'Time-mean volumetric soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow depth water equivalent
'Time-mean snow depth water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean skin temperature
'Time-mean skin temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow density
'Time-mean snow density' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean low vegetation cover
'Time-mean low vegetation cover' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean high vegetation cover
'Time-mean high vegetation cover' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice area fraction
'Time-mean sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface temperature
'Time-mean sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean leaf area index, low vegetation
'Time-mean leaf area index, low vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean leaf area index, high vegetation
'Time-mean leaf area index, high vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column liquid water
'Time-mean total column liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column cloud ice water
'Time-mean total column cloud ice water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 2 metre specific humidity
'Time-mean 2 metre specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake mix-layer temperature
'Time-mean lake mix-layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake mix-layer depth
'Time-mean lake mix-layer depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 2 metre relative humidity
'Time-mean 2 metre relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean fraction of snow cover
'Time-mean fraction of snow cover' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 121 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil temperature
'Time-mean soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wind speed
'Time-mean wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean pressure
'Time-mean pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean charnock
'Time-mean charnock' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean potential vorticity
'Time-mean potential vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific rain water content
'Time-mean specific rain water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific snow water content
'Time-mean specific snow water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eta-coordinate vertical velocity
'Time-mean eta-coordinate vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean visibility
'Time-mean visibility' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wind direction
'Time-mean wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column snow water
'Time-mean total column snow water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean low cloud cover
'Time-mean low cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean medium cloud cover
'Time-mean medium cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean high cloud cover
'Time-mean high cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column rain water
'Time-mean total column rain water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil moisture top 20 cm
'Time-mean soil moisture top 20 cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil moisture top 100 cm
'Time-mean soil moisture top 100 cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil temperature top 20 cm
'Time-mean soil temperature top 20 cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil temperature top 100 cm
'Time-mean soil temperature top 100 cm' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean most-unstable CAPE
'Time-mean most-unstable CAPE' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean volumetric soil moisture top 20 cm
'Time-mean volumetric soil moisture top 20 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean volumetric soil moisture top 100 cm
'Time-mean volumetric soil moisture top 100 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated graupel (snow pellets)
'Time-mean total column vertically-integrated graupel (snow pellets)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geopotential
'Time-mean geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature
'Time-mean temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U component of wind
'Time-mean U component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V component of wind
'Time-mean V component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific humidity
'Time-mean specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface pressure
'Time-mean surface pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertical velocity
'Time-mean vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column water
'Time-mean total column water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated water vapour
'Time-mean total column vertically-integrated water vapour' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vorticity (relative)
'Time-mean vorticity (relative)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface net radiation flux (SW and LW)
'Time-mean surface net radiation flux (SW and LW)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean top net radiation flux (SW and LW)
'Time-mean top net radiation flux (SW and LW)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean sea level pressure
'Time-mean mean sea level pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean divergence
'Time-mean divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean relative humidity
'Time-mean relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean boundary layer height
'Time-mean boundary layer height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre U wind component
'Time-mean 10 metre U wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre V wind component
'Time-mean 10 metre V wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 2 metre dewpoint temperature
'Time-mean 2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sunshine
'Time-mean sunshine' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ozone mass mixing ratio
'Time-mean ozone mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean temperature of snow layer
'Time-mean temperature of snow layer' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean forecast surface roughness
'Time-mean forecast surface roughness' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean forecast logarithm of surface roughness for heat
'Time-mean forecast logarithm of surface roughness for heat' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific cloud liquid water content
'Time-mean specific cloud liquid water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific cloud ice water content
'Time-mean specific cloud ice water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean fraction of cloud cover
'Time-mean fraction of cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean K index
'Time-mean K index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total totals index
'Time-mean total totals index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre wind direction
'Time-mean 10 metre wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean clear air turbulence (CAT)
'Time-mean clear air turbulence (CAT)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean forecast albedo
'Time-mean forecast albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean potential temperature
'Time-mean potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean discharge from rivers or streams
'Time-mean discharge from rivers or streams' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil wetness index (total layer)
'Time-mean soil wetness index (total layer)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 151 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil wetness index (root zone)
'Time-mean soil wetness index (root zone)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean soil wetness index(layer)
'Time-mean soil wetness index(layer)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 151 ;
	 typeOfSecondFixedSurface = 151 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodplain depth
'Time-mean floodplain depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodplain flooded fraction
'Time-mean floodplain flooded fraction' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodplain flooded area
'Time-mean floodplain flooded area' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river fraction
'Time-mean river fraction' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river area
'Time-mean river area' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean fraction of river coverage plus river related flooding
'Time-mean fraction of river coverage plus river related flooding' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean area of river coverage plus river related flooding
'Time-mean area of river coverage plus river related flooding' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean UV visible albedo for direct radiation (climatological)
'Time-mean UV visible albedo for direct radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean UV visible albedo for diffuse radiation (climatological)
'Time-mean UV visible albedo for diffuse radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean near IR albedo for direct radiation (climatological)
'Time-mean near IR albedo for direct radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean near IR albedo for diffuse radiation (climatological)
'Time-mean near IR albedo for diffuse radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean snow albedo
'Time-mean snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean montgomery potential
'Time-mean montgomery potential' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean convective available potential energy
'Time-mean convective available potential energy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total cloud cover
'Time-mean total cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean skin reservoir content
'Time-mean skin reservoir content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column integrated ozone
'Time-mean total column integrated ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated kinetic energy
'Time-mean total column vertically-integrated kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated enthalpy
'Time-mean total column vertically-integrated enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated potential + internal energy
'Time-mean total column vertically-integrated potential + internal energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated potential+internal+latent energy
'Time-mean total column vertically-integrated potential+internal+latent energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated total energy
'Time-mean total column vertically-integrated total energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated water enthalpy
'Time-mean total column vertically-integrated water enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean UV visible albedo for direct radiation, isotropic component (climatological)
'Time-mean UV visible albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean UV visible albedo for direct radiation, volumetric component (climatological)
'Time-mean UV visible albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean UV visible albedo for direct radiation, geometric component (climatological)
'Time-mean UV visible albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean near IR albedo for direct radiation, isotropic component (climatological)
'Time-mean near IR albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean near IR albedo for direct radiation, volumetric component (climatological)
'Time-mean near IR albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean near IR albedo for direct radiation, geometric component (climatological)
'Time-mean near IR albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-mean convective inhibition
'Time-mean convective inhibition' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean friction velocity
'Time-mean friction velocity' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake bottom temperature
'Time-mean lake bottom temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake total layer temperature
'Time-mean lake total layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake shape factor
'Time-mean lake shape factor' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake ice surface temperature
'Time-mean lake ice surface temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean lake ice total depth
'Time-mean lake ice total depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean minimum vertical gradient of refractivity inside trapping layer
'Time-mean minimum vertical gradient of refractivity inside trapping layer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mean vertical gradient of refractivity inside trapping layer
'Time-mean mean vertical gradient of refractivity inside trapping layer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean duct base height
'Time-mean duct base height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 41 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean trapping layer base height
'Time-mean trapping layer base height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean trapping layer top height
'Time-mean trapping layer top height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of -10 degrees C atmospheric isothermal level above ground
'Time-mean geometric height of -10 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean cloud base height
'Time-mean cloud base height' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of 0 degrees C atmospheric isothermal level above ground
'Time-mean geometric height of 0 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre wind gust
'Time-mean 10 metre wind gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean relative humidity with respect to water
'Time-mean relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 2 metre relative humidity with respect to water
'Time-mean 2 metre relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean convective available potential energy shear
'Time-mean convective available potential energy shear' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean tropopause pressure
'Time-mean tropopause pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean height of convective cloud top
'Time-mean height of convective cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean height of zero-degree wet-bulb temperature
'Time-mean height of zero-degree wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean height of one-degree wet-bulb temperature
'Time-mean height of one-degree wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total lightning flash density
'Time-mean total lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column supercooled liquid water
'Time-mean total column supercooled liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 167 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre U-component of neutral wind
'Time-mean 10 metre U-component of neutral wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre V-component of neutral wind
'Time-mean 10 metre V-component of neutral wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean convective rain rate
'Time-mean convective rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean large scale rain rate
'Time-mean large scale rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mixed-layer CAPE in the lowest 50 hPa
'Time-mean mixed-layer CAPE in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mixed-layer CIN in the lowest 50 hPa
'Time-mean mixed-layer CIN in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mixed-layer CAPE in the lowest 100 hPa
'Time-mean mixed-layer CAPE in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mixed-layer CIN in the lowest 100 hPa
'Time-mean mixed-layer CIN in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean departure level of the most unstable parcel expressed as Pressure
'Time-mean departure level of the most unstable parcel expressed as Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ceiling
'Time-mean ceiling' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column integrated saturation specific humidity with respect to water
'Time-mean total column integrated saturation specific humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 169 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface direct normal short-wave radiation flux
'Time-mean surface direct normal short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean cosine of solar zenith angle
'Time-mean cosine of solar zenith angle' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean freezing rain precipitation rate
'Time-mean freezing rain precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward geopotential flux
'Time-mean total column vertically-integrated eastward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward geopotential flux
'Time-mean total column vertically-integrated northward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of water geopotential flux
'Time-mean total column vertically-integrated divergence of water geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of geopotential flux
'Time-mean total column vertically-integrated divergence of geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward enthalpy flux
'Time-mean total column vertically-integrated eastward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward enthalpy flux
'Time-mean total column vertically-integrated northward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward kinetic energy flux
'Time-mean total column vertically-integrated eastward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward kinetic energy flux
'Time-mean total column vertically-integrated northward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward total energy flux
'Time-mean total column vertically-integrated eastward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward total energy flux
'Time-mean total column vertically-integrated northward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of enthalpy flux
'Time-mean total column vertically-integrated divergence of enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of kinetic energy flux
'Time-mean total column vertically-integrated divergence of kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of total energy flux
'Time-mean total column vertically-integrated divergence of total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of water enthalpy flux
'Time-mean total column vertically-integrated divergence of water enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of mass flux
'Time-mean total column vertically-integrated divergence of mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward mass flux
'Time-mean total column vertically-integrated eastward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward mass flux
'Time-mean total column vertically-integrated northward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of water vapour flux
'Time-mean total column vertically-integrated divergence of water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of cloud liquid water flux
'Time-mean total column vertically-integrated divergence of cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of cloud ice water flux
'Time-mean total column vertically-integrated divergence of cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of rain flux
'Time-mean total column vertically-integrated divergence of rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of snow flux
'Time-mean total column vertically-integrated divergence of snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward water vapour flux
'Time-mean total column vertically-integrated eastward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward water vapour flux
'Time-mean total column vertically-integrated northward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward cloud liquid water flux
'Time-mean total column vertically-integrated eastward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward cloud liquid water flux
'Time-mean total column vertically-integrated northward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward cloud ice water flux
'Time-mean total column vertically-integrated eastward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward cloud ice water flux
'Time-mean total column vertically-integrated northward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward rain flux
'Time-mean total column vertically-integrated eastward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward rain flux
'Time-mean total column vertically-integrated northward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward snow flux
'Time-mean total column vertically-integrated eastward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward snow flux
'Time-mean total column vertically-integrated northward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated eastward ozone flux
'Time-mean total column vertically-integrated eastward ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated northward ozone flux
'Time-mean total column vertically-integrated northward ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated divergence of ozone flux
'Time-mean total column vertically-integrated divergence of ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically-integrated net source of ozone
'Time-mean total column vertically-integrated net source of ozone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward turbulent surface stress due to orographic form drag
'Time-mean eastward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward turbulent surface stress due to orographic form drag
'Time-mean northward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward turbulent surface stress due to surface roughness
'Time-mean eastward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward turbulent surface stress due to surface roughness
'Time-mean northward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean visibility through precipitation
'Time-mean visibility through precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean cloud-to-ground lightning flash density
'Time-mean cloud-to-ground lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean land surface heat net flux
'Time-mean land surface heat net flux' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface direct normal short-wave radiation flux, clear sky
'Time-mean surface direct normal short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre convective gust
'Time-mean 10 metre convective gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre turbulent gust
'Time-mean 10 metre turbulent gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of 0 degrees C theta level above ground
'Time-mean geometric height of 0 degrees C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of 1 degree C theta level above ground
'Time-mean geometric height of 1 degree C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27415 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of 1.5 degrees C theta level above ground
'Time-mean geometric height of 1.5 degrees C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27465 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vegetation
'Time-mean vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean leaf area index
'Time-mean leaf area index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface roughness for heat
'Time-mean surface roughness for heat' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Reciprocal Obukhov length
'Time-mean Reciprocal Obukhov length' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean geometric height of 3 degrees C atmospheric isothermal level above ground
'Time-mean geometric height of 3 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27615 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river storage of water
'Time-mean river storage of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodplain storage of water
'Time-mean floodplain storage of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river depth
'Time-mean river depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river outflow of water
'Time-mean river outflow of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodplain outflow of water
'Time-mean floodplain outflow of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean floodpath outflow of water
'Time-mean floodpath outflow of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface diffuse short-wave radiation flux, clear sky
'Time-mean surface diffuse short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean volumetric soil moisture (root zone)
'Time-mean volumetric soil moisture (root zone)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean liquid water content in snow pack
'Time-mean liquid water content in snow pack' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean most-unstable CIN
'Time-mean most-unstable CIN' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific rain water content (convective)
'Time-mean specific rain water content (convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 144 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean specific snow water content (convective)
'Time-mean specific snow water content (convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 145 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean mixed layer depth
'Time-mean mixed layer depth' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean urban cover
'Time-mean urban cover' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean water surface elevation
'Time-mean water surface elevation' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean groundwater return flow rate
'Time-mean groundwater return flow rate' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean river and floodplain storage
'Time-mean river and floodplain storage' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth-averaged river velocity
'Time-mean depth-averaged river velocity' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-integrated land surface heat net flux
'Time-integrated land surface heat net flux' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated surface direct normal short-wave radiation flux, clear sky
'Time-integrated surface direct normal short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-maximum temperature tendency due to short-wave radiation
'Time-maximum temperature tendency due to short-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature tendency due to long-wave radiation
'Time-maximum temperature tendency due to long-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature tendency due to short wave radiation, clear sky
'Time-maximum temperature tendency due to short wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature tendency due to long-wave radiation, clear sky
'Time-maximum temperature tendency due to long-wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature tendency due to parametrisations
'Time-maximum temperature tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific humidity tendency due to parametrisations
'Time-maximum specific humidity tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward wind tendency due to parametrisations
'Time-maximum eastward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward wind tendency due to parametrisations
'Time-maximum northward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum updraught mass flux
'Time-maximum updraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum downdraught mass flux
'Time-maximum downdraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum updraught detrainment rate
'Time-maximum updraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum downdraught detrainment rate
'Time-maximum downdraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total precipitation flux
'Time-maximum total precipitation flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum turbulent diffusion coefficient for heat
'Time-maximum turbulent diffusion coefficient for heat' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface photosynthetically active radiation flux, clear sky
'Time-maximum surface photosynthetically active radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow evaporation rate water equivalent
'Time-maximum snow evaporation rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow melt rate
'Time-maximum snow melt rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum magnitude of turbulent surface stress
'Time-maximum magnitude of turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum large-scale precipitation fraction
'Time-maximum large-scale precipitation fraction' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward UV radiation flux
'Time-maximum surface downward UV radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface photosynthetically active radiation flux
'Time-maximum surface photosynthetically active radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum large-scale precipitation rate
'Time-maximum large-scale precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum convective precipitation rate
'Time-maximum convective precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total snowfall rate water equivalent
'Time-maximum total snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum boundary layer dissipation
'Time-maximum boundary layer dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface sensible heat flux
'Time-maximum surface sensible heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface latent heat flux
'Time-maximum surface latent heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward short-wave radiation flux
'Time-maximum surface downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward long-wave radiation flux
'Time-maximum surface downward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface net short-wave radiation flux
'Time-maximum surface net short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface net long-wave radiation flux
'Time-maximum surface net long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum top net short-wave radiation flux
'Time-maximum top net short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum top net long-wave radiation flux
'Time-maximum top net long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward turbulent surface stress
'Time-maximum eastward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward turbulent surface stress
'Time-maximum northward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum moisture flux
'Time-maximum moisture flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward gravity wave surface stress
'Time-maximum eastward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward gravity wave surface stress
'Time-maximum northward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum gravity wave dissipation
'Time-maximum gravity wave dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum runoff rate water equivalent (surface plus subsurface)
'Time-maximum runoff rate water equivalent (surface plus subsurface)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum top net short-wave radiation flux, clear sky
'Time-maximum top net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum top net long-wave radiation flux, clear sky
'Time-maximum top net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface net short-wave radiation flux, clear sky
'Time-maximum surface net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface net long-wave radiation flux, clear sky
'Time-maximum surface net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time mean top downward short-wave radiation flux
'Time mean top downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated moisture divergence flux
'Time-maximum total column vertically-integrated moisture divergence flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total precipitation rate
'Time-maximum total precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum convective snowfall rate water equivalent
'Time-maximum convective snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum large scale snowfall rate water equivalent
'Time-maximum large scale snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface direct short-wave radiation flux
'Time-maximum surface direct short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface direct short-wave radiation flux, clear sky
'Time-maximum surface direct short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum carbon dioxide net ecosystem exchange flux
'Time-maximum carbon dioxide net ecosystem exchange flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum carbon dioxide gross primary production flux
'Time-maximum carbon dioxide gross primary production flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum carbon dioxide ecosystem respiration flux
'Time-maximum carbon dioxide ecosystem respiration flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward short-wave radiation flux, clear sky
'Time-maximum surface downward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward long-wave radiation flux, clear sky
'Time-maximum surface downward long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum potential evaporation rate
'Time-maximum potential evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum volumetric soil moisture
'Time-maximum volumetric soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow depth water equivalent
'Time-maximum snow depth water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum skin temperature
'Time-maximum skin temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow density
'Time-maximum snow density' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice area fraction
'Time-maximum sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea surface temperature
'Time-maximum sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum leaf area index, low vegetation
'Time-maximum leaf area index, low vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum leaf area index, high vegetation
'Time-maximum leaf area index, high vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column cloud liquid water
'Time-maximum total column cloud liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column cloud ice water
'Time-maximum total column cloud ice water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 2 metre specific humidity
'Time-maximum 2 metre specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake mix-layer temperature
'Time-maximum lake mix-layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake mix-layer depth
'Time-maximum lake mix-layer depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 2 metre relative humidity
'Time-maximum 2 metre relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum fraction of snow cover
'Time-maximum fraction of snow cover' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 121 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum soil temperature
'Time-maximum soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wind speed
'Time-maximum wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum pressure
'Time-maximum pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum charnock
'Time-maximum charnock' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum potential vorticity
'Time-maximum potential vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific rain water content
'Time-maximum specific rain water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific snow water content
'Time-maximum specific snow water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eta-coordinate vertical velocity
'Time-maximum eta-coordinate vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum visibility
'Time-maximum visibility' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wind direction
'Time-maximum wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column snow water
'Time-maximum total column snow water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum low cloud cover
'Time-maximum low cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum medium cloud cover
'Time-maximum medium cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum high cloud cover
'Time-maximum high cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column rain water
'Time-maximum total column rain water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum most-unstable CAPE
'Time-maximum most-unstable CAPE' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated graupel (snow pellets)
'Time-maximum total column vertically-integrated graupel (snow pellets)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geopotential
'Time-maximum geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature
'Time-maximum temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum u component of wind
'Time-maximum u component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum v component of wind
'Time-maximum v component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific humidity
'Time-maximum specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface pressure
'Time-maximum surface pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vertical velocity
'Time-maximum vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column water
'Time-maximum total column water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated water vapour
'Time-maximum total column vertically-integrated water vapour' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vorticity (relative)
'Time-maximum vorticity (relative)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean sea level pressure
'Time-maximum mean sea level pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum divergence
'Time-maximum divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum relative humidity
'Time-maximum relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum boundary layer height
'Time-maximum boundary layer height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre U wind component
'Time-maximum 10 metre U wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre V wind component
'Time-maximum 10 metre V wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 2 metre temperature
'Time-maximum 2 metre temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 2 metre dewpoint temperature
'Time-maximum 2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sunshine
'Time-maximum sunshine' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ozone mass mixing ratio
'Time-maximum ozone mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre wind speed
'Time-maximum 10 metre wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum temperature of snow layer
'Time-maximum temperature of snow layer' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum forecast surface roughness
'Time-maximum forecast surface roughness' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum forecast logarithm of surface roughness for heat
'Time-maximum forecast logarithm of surface roughness for heat' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific cloud liquid water content
'Time-maximum specific cloud liquid water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific cloud ice water content
'Time-maximum specific cloud ice water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum fraction of cloud cover
'Time-maximum fraction of cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum k index
'Time-maximum k index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total totals index
'Time-maximum total totals index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre wind direction
'Time-maximum 10 metre wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum clear air turbulence (CAT)
'Time-maximum clear air turbulence (CAT)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum forecast albedo
'Time-maximum forecast albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum potential temperature
'Time-maximum potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum UV visible albedo for direct radiation (climatological)
'Time-maximum UV visible albedo for direct radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum UV visible albedo for diffuse radiation (climatological)
'Time-maximum UV visible albedo for diffuse radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum near IR albedo for direct radiation (climatological)
'Time-maximum near IR albedo for direct radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum near IR albedo for diffuse radiation (climatological)
'Time-maximum near IR albedo for diffuse radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum snow albedo
'Time-maximum snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum montgomery potential
'Time-maximum montgomery potential' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum convective available potential energy
'Time-maximum convective available potential energy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total cloud cover
'Time-maximum total cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum skin reservoir content
'Time-maximum skin reservoir content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column integrated ozone
'Time-maximum total column integrated ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated kinetic energy
'Time-maximum total column vertically-integrated kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated enthalpy
'Time-maximum total column vertically-integrated enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated potential + internal energy
'Time-maximum total column vertically-integrated potential + internal energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated potential+internal+latent energy
'Time-maximum total column vertically-integrated potential+internal+latent energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated total energy
'Time-maximum total column vertically-integrated total energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated water enthalpy
'Time-maximum total column vertically-integrated water enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum UV visible albedo for direct radiation, isotropic component (climatological)
'Time-maximum UV visible albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum UV visible albedo for direct radiation, volumetric component (climatological)
'Time-maximum UV visible albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum UV visible albedo for direct radiation, geometric component (climatological)
'Time-maximum UV visible albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum near IR albedo for direct radiation, isotropic component (climatological)
'Time-maximum near IR albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum near IR albedo for direct radiation, volumetric component (climatological)
'Time-maximum near IR albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum near IR albedo for direct radiation, geometric component (climatological)
'Time-maximum near IR albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-maximum convective inhibition
'Time-maximum convective inhibition' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum friction velocity
'Time-maximum friction velocity' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake bottom temperature
'Time-maximum lake bottom temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake total layer temperature
'Time-maximum lake total layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake shape factor
'Time-maximum lake shape factor' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake ice surface temperature
'Time-maximum lake ice surface temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum lake ice total depth
'Time-maximum lake ice total depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum minimum vertical gradient of refractivity inside trapping layer
'Time-maximum minimum vertical gradient of refractivity inside trapping layer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mean vertical gradient of refractivity inside trapping layer
'Time-maximum mean vertical gradient of refractivity inside trapping layer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum duct base height
'Time-maximum duct base height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 41 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum trapping layer base height
'Time-maximum trapping layer base height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum trapping layer top height
'Time-maximum trapping layer top height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of -10 degrees C atmospheric isothermal level above ground
'Time-maximum geometric height of -10 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum cloud base height
'Time-maximum cloud base height' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of 0 degrees C atmospheric isothermal level above ground
'Time-maximum geometric height of 0 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre wind gust
'Time-maximum 10 metre wind gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum relative humidity with respect to water
'Time-maximum relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 2 metre relative humidity with respect to water
'Time-maximum 2 metre relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum convective available potential energy shear
'Time-maximum convective available potential energy shear' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum tropopause pressure
'Time-maximum tropopause pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum height of convective cloud top
'Time-maximum height of convective cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum height of zero-degree wet-bulb temperature
'Time-maximum height of zero-degree wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum height of one-degree wet-bulb temperature
'Time-maximum height of one-degree wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total lightning flash density
'Time-maximum total lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column supercooled liquid water
'Time-maximum total column supercooled liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 167 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre U-component of neutral wind
'Time-maximum 10 metre U-component of neutral wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre V-component of neutral wind
'Time-maximum 10 metre V-component of neutral wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum convective rain rate
'Time-maximum convective rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum large scale rain rate
'Time-maximum large scale rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mixed-layer CAPE in the lowest 50 hPa
'Time-maximum mixed-layer CAPE in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mixed-layer CIN in the lowest 50 hPa
'Time-maximum mixed-layer CIN in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mixed-layer CAPE in the lowest 100 hPa
'Time-maximum mixed-layer CAPE in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mixed-layer CIN in the lowest 100 hPa
'Time-maximum mixed-layer CIN in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum departure level of the most unstable parcel expressed as Pressure
'Time-maximum departure level of the most unstable parcel expressed as Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ceiling
'Time-maximum ceiling' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column integrated saturation specific humidity with respect to water
'Time-maximum total column integrated saturation specific humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 169 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface direct normal short-wave radiation flux
'Time-maximum surface direct normal short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum cosine of solar zenith angle
'Time-maximum cosine of solar zenith angle' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum freezing rain precipitation rate
'Time-maximum freezing rain precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward geopotential flux
'Time-maximum total column vertically-integrated eastward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward geopotential flux
'Time-maximum total column vertically-integrated northward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of water geopotential flux
'Time-maximum total column vertically-integrated divergence of water geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of geopotential flux
'Time-maximum total column vertically-integrated divergence of geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward enthalpy flux
'Time-maximum total column vertically-integrated eastward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward enthalpy flux
'Time-maximum total column vertically-integrated northward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward kinetic energy flux
'Time-maximum total column vertically-integrated eastward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward kinetic energy flux
'Time-maximum total column vertically-integrated northward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward total energy flux
'Time-maximum total column vertically-integrated eastward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward total energy flux
'Time-maximum total column vertically-integrated northward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of enthalpy flux
'Time-maximum total column vertically-integrated divergence of enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of kinetic energy flux
'Time-maximum total column vertically-integrated divergence of kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of total energy flux
'Time-maximum total column vertically-integrated divergence of total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of water enthalpy flux
'Time-maximum total column vertically-integrated divergence of water enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of mass flux
'Time-maximum total column vertically-integrated divergence of mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward mass flux
'Time-maximum total column vertically-integrated eastward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward mass flux
'Time-maximum total column vertically-integrated northward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of water vapour flux
'Time-maximum total column vertically-integrated divergence of water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of cloud liquid water flux
'Time-maximum total column vertically-integrated divergence of cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of cloud ice water flux
'Time-maximum total column vertically-integrated divergence of cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of rain flux
'Time-maximum total column vertically-integrated divergence of rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of snow flux
'Time-maximum total column vertically-integrated divergence of snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward water vapour flux
'Time-maximum total column vertically-integrated eastward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward water vapour flux
'Time-maximum total column vertically-integrated northward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward cloud liquid water flux
'Time-maximum total column vertically-integrated eastward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward cloud liquid water flux
'Time-maximum total column vertically-integrated northward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward cloud ice water flux
'Time-maximum total column vertically-integrated eastward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward cloud ice water flux
'Time-maximum total column vertically-integrated northward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward rain flux
'Time-maximum total column vertically-integrated eastward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward rain flux
'Time-maximum total column vertically-integrated northward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward snow flux
'Time-maximum total column vertically-integrated eastward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward snow flux
'Time-maximum total column vertically-integrated northward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated eastward ozone flux
'Time-maximum total column vertically-integrated eastward ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated northward ozone flux
'Time-maximum total column vertically-integrated northward ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated divergence of ozone flux
'Time-maximum total column vertically-integrated divergence of ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically-integrated net source of ozone
'Time-maximum total column vertically-integrated net source of ozone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward turbulent surface stress due to orographic form drag
'Time-maximum eastward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward turbulent surface stress due to orographic form drag
'Time-maximum northward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward turbulent surface stress due to surface roughness
'Time-maximum eastward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward turbulent surface stress due to surface roughness
'Time-maximum northward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum visibility through precipitation
'Time-maximum visibility through precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum cloud-to-ground lightning flash density
'Time-maximum cloud-to-ground lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre eastward wind gust
'Time-maximum 10 metre eastward wind gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre northward wind gust
'Time-maximum 10 metre northward wind gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum land surface heat net flux
'Time-maximum land surface heat net flux' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface direct normal short-wave radiation flux, clear sky
'Time-maximum surface direct normal short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre convective gust
'Time-maximum 10 metre convective gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum 10 metre turbulent gust
'Time-maximum 10 metre turbulent gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of 0 degrees C theta level above ground
'Time-maximum geometric height of 0 degrees C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of 1 degree C theta level above ground
'Time-maximum geometric height of 1 degree C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27415 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of 1.5 degrees C theta level above ground
'Time-maximum geometric height of 1.5 degrees C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27465 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vegetation
'Time-maximum vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum leaf area index
'Time-maximum leaf area index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface roughness for heat
'Time-maximum surface roughness for heat' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum Reciprocal Obukhov length
'Time-maximum Reciprocal Obukhov length' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum geometric height of 3 degrees C atmospheric isothermal level above ground
'Time-maximum geometric height of 3 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27615 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface diffuse short-wave radiation flux, clear sky
'Time-maximum surface diffuse short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum volumetric soil moisture (root zone)
'Time-maximum volumetric soil moisture (root zone)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum liquid water content in snow pack
'Time-maximum liquid water content in snow pack' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum most-unstable CIN
'Time-maximum most-unstable CIN' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific rain water content (convective)
'Time-maximum specific rain water content (convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 144 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum specific snow water content (convective)
'Time-maximum specific snow water content (convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 145 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum mixed layer depth
'Time-maximum mixed layer depth' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum urban cover
'Time-maximum urban cover' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum temperature tendency due to short-wave radiation
'Time-minimum temperature tendency due to short-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature tendency due to long-wave radiation
'Time-minimum temperature tendency due to long-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature tendency due to short wave radiation, clear sky
'Time-minimum temperature tendency due to short wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature tendency due to long-wave radiation, clear sky
'Time-minimum temperature tendency due to long-wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature tendency due to parametrisations
'Time-minimum temperature tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific humidity tendency due to parametrisations
'Time-minimum specific humidity tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward wind tendency due to parametrisations
'Time-minimum eastward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward wind tendency due to parametrisations
'Time-minimum northward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum updraught mass flux
'Time-minimum updraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum downdraught mass flux
'Time-minimum downdraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum updraught detrainment rate
'Time-minimum updraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum downdraught detrainment rate
'Time-minimum downdraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total precipitation flux
'Time-minimum total precipitation flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum turbulent diffusion coefficient for heat
'Time-minimum turbulent diffusion coefficient for heat' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface photosynthetically active radiation flux, clear sky
'Time-minimum surface photosynthetically active radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snow evaporation rate
'Time-minimum snow evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snowmelt rate
'Time-minimum snowmelt rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum magnitude of turbulent surface stress
'Time-minimum magnitude of turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum large-scale precipitation fraction
'Time-minimum large-scale precipitation fraction' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward UV radiation flux
'Time-minimum surface downward UV radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface photosynthetically active radiation flux
'Time-minimum surface photosynthetically active radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum large-scale precipitation rate
'Time-minimum large-scale precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum convective precipitation rate
'Time-minimum convective precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snowfall rate
'Time-minimum snowfall rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum boundary layer dissipation
'Time-minimum boundary layer dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface sensible heat flux
'Time-minimum surface sensible heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface latent heat flux
'Time-minimum surface latent heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward short-wave radiation flux
'Time-minimum surface downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward long-wave radiation flux
'Time-minimum surface downward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface net short-wave radiation flux
'Time-minimum surface net short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface net long-wave radiation flux
'Time-minimum surface net long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum top net short-wave radiation flux
'Time-minimum top net short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum top net long-wave radiation flux
'Time-minimum top net long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward turbulent surface stress
'Time-minimum eastward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward turbulent surface stress
'Time-minimum northward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum evaporation rate
'Time-minimum evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward gravity wave surface stress
'Time-minimum eastward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward gravity wave surface stress
'Time-minimum northward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum gravity wave dissipation
'Time-minimum gravity wave dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum runoff rate
'Time-minimum runoff rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum top net short-wave radiation flux, clear sky
'Time-minimum top net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum top net long-wave radiation flux, clear sky
'Time-minimum top net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface net short-wave radiation flux, clear sky
'Time-minimum surface net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface net long-wave radiation flux, clear sky
'Time-minimum surface net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum top downward short-wave radiation flux
'Time-minimum top downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated moisture divergence
'Time-minimum vertically integrated moisture divergence' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total precipitation rate
'Time-minimum total precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum convective snowfall rate water equivalent
'Time-minimum convective snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum large scale snowfall rate water equivalent
'Time-minimum large scale snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface direct short-wave radiation flux
'Time-minimum surface direct short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface direct short-wave radiation flux, clear sky
'Time-minimum surface direct short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum carbon dioxide net ecosystem exchange flux
'Time-minimum carbon dioxide net ecosystem exchange flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum carbon dioxide gross primary production flux
'Time-minimum carbon dioxide gross primary production flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum carbon dioxide ecosystem respiration flux
'Time-minimum carbon dioxide ecosystem respiration flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward short-wave radiation flux, clear sky
'Time-minimum surface downward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward long-wave radiation flux, clear sky
'Time-minimum surface downward long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum potential evaporation rate
'Time-minimum potential evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum volumetric soil moisture
'Time-minimum volumetric soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snow depth water equivalent
'Time-minimum snow depth water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum skin temperature
'Time-minimum skin temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snow density
'Time-minimum snow density' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice area fraction
'Time-minimum sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea surface temperature
'Time-minimum sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum leaf area index, low vegetation
'Time-minimum leaf area index, low vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum leaf area index, high vegetation
'Time-minimum leaf area index, high vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column cloud liquid water
'Time-minimum total column cloud liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column cloud ice water
'Time-minimum total column cloud ice water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 2 metre specific humidity
'Time-minimum 2 metre specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake mix-layer temperature
'Time-minimum lake mix-layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake mix-layer depth
'Time-minimum lake mix-layer depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 2 metre relative humidity
'Time-minimum 2 metre relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum fraction of snow cover
'Time-minimum fraction of snow cover' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 121 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum soil temperature
'Time-minimum soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wind speed
'Time-minimum wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum pressure
'Time-minimum pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum charnock
'Time-minimum charnock' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum potential vorticity
'Time-minimum potential vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific rain water content
'Time-minimum specific rain water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific snow water content
'Time-minimum specific snow water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eta-coordinate vertical velocity
'Time-minimum eta-coordinate vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum visibility
'Time-minimum visibility' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wind direction
'Time-minimum wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column snow water
'Time-minimum total column snow water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum low cloud cover
'Time-minimum low cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum medium cloud cover
'Time-minimum medium cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum high cloud cover
'Time-minimum high cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column rain water
'Time-minimum total column rain water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum most-unstable CAPE
'Time-minimum most-unstable CAPE' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated graupel (snow pellets)
'Time-minimum total column vertically-integrated graupel (snow pellets)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geopotential
'Time-minimum geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature
'Time-minimum temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum u component of wind
'Time-minimum u component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum v component of wind
'Time-minimum v component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific humidity
'Time-minimum specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface pressure
'Time-minimum surface pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertical velocity
'Time-minimum vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column water
'Time-minimum total column water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated water vapour
'Time-minimum total column vertically-integrated water vapour' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vorticity (relative)
'Time-minimum vorticity (relative)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean sea level pressure
'Time-minimum mean sea level pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum divergence
'Time-minimum divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum relative humidity
'Time-minimum relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum boundary layer height
'Time-minimum boundary layer height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre U wind component
'Time-minimum 10 metre U wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre V wind component
'Time-minimum 10 metre V wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 2 metre temperature
'Time-minimum 2 metre temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 2 metre dewpoint temperature
'Time-minimum 2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sunshine
'Time-minimum sunshine' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ozone mass mixing ratio
'Time-minimum ozone mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre wind speed
'Time-minimum 10 metre wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum temperature of snow layer
'Time-minimum temperature of snow layer' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum forecast surface roughness
'Time-minimum forecast surface roughness' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum forecast logarithm of surface roughness for heat
'Time-minimum forecast logarithm of surface roughness for heat' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific cloud liquid water content
'Time-minimum specific cloud liquid water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific cloud ice water content
'Time-minimum specific cloud ice water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum fraction of cloud cover
'Time-minimum fraction of cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum k index
'Time-minimum k index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total totals index
'Time-minimum total totals index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre wind direction
'Time-minimum 10 metre wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum clear air turbulence (CAT)
'Time-minimum clear air turbulence (CAT)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum forecast albedo
'Time-minimum forecast albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum potential temperature
'Time-minimum potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum UV visible albedo for direct radiation (climatological)
'Time-minimum UV visible albedo for direct radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum UV visible albedo for diffuse radiation (climatological)
'Time-minimum UV visible albedo for diffuse radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum near IR albedo for direct radiation (climatological)
'Time-minimum near IR albedo for direct radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum near IR albedo for diffuse radiation (climatological)
'Time-minimum near IR albedo for diffuse radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum snow albedo
'Time-minimum snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum montgomery potential
'Time-minimum montgomery potential' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum convective available potential energy
'Time-minimum convective available potential energy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total cloud cover
'Time-minimum total cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum skin reservoir content
'Time-minimum skin reservoir content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column integrated ozone
'Time-minimum total column integrated ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated kinetic energy
'Time-minimum total column vertically-integrated kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated enthalpy
'Time-minimum total column vertically-integrated enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated potential + internal energy
'Time-minimum total column vertically-integrated potential + internal energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertical integral of potential+internal+latent energy
'Time-minimum vertical integral of potential+internal+latent energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated total energy
'Time-minimum total column vertically-integrated total energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated water enthalpy
'Time-minimum total column vertically-integrated water enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum UV visible albedo for direct radiation, isotropic component (climatological)
'Time-minimum UV visible albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum UV visible albedo for direct radiation, volumetric component (climatological)
'Time-minimum UV visible albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum UV visible albedo for direct radiation, geometric component (climatological)
'Time-minimum UV visible albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum near IR albedo for direct radiation, isotropic component (climatological)
'Time-minimum near IR albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum near IR albedo for direct radiation, volumetric component (climatological)
'Time-minimum near IR albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum near IR albedo for direct radiation, geometric component (climatological)
'Time-minimum near IR albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-minimum convective inhibition
'Time-minimum convective inhibition' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum friction velocity
'Time-minimum friction velocity' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake bottom temperature
'Time-minimum lake bottom temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake total layer temperature
'Time-minimum lake total layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake shape factor
'Time-minimum lake shape factor' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake ice surface temperature
'Time-minimum lake ice surface temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum lake ice total depth
'Time-minimum lake ice total depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum minimum vertical gradient of refractivity inside trapping layer
'Time-minimum minimum vertical gradient of refractivity inside trapping layer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mean vertical gradient of refractivity inside trapping layer
'Time-minimum mean vertical gradient of refractivity inside trapping layer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum duct base height
'Time-minimum duct base height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 41 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum trapping layer base height
'Time-minimum trapping layer base height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum trapping layer top height
'Time-minimum trapping layer top height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of -10 degrees C atmospheric isothermal level above ground
'Time-minimum geometric height of -10 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum cloud base height
'Time-minimum cloud base height' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of 0 degrees C atmospheric isothermal level above ground
'Time-minimum geometric height of 0 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre wind gust
'Time-minimum 10 metre wind gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum relative humidity with respect to water
'Time-minimum relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 2 metre relative humidity with respect to water
'Time-minimum 2 metre relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum convective available potential energy shear
'Time-minimum convective available potential energy shear' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum tropopause pressure
'Time-minimum tropopause pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum height of convective cloud top
'Time-minimum height of convective cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum height of zero-degree wet-bulb temperature
'Time-minimum height of zero-degree wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum height of one-degree wet-bulb temperature
'Time-minimum height of one-degree wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total lightning flash density
'Time-minimum total lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column supercooled liquid water
'Time-minimum total column supercooled liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 167 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre U-component of neutral wind
'Time-minimum 10 metre U-component of neutral wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre V-component of neutral wind
'Time-minimum 10 metre V-component of neutral wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum convective rain rate
'Time-minimum convective rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum large scale rain rate
'Time-minimum large scale rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mixed-layer CAPE in the lowest 50 hPa
'Time-minimum mixed-layer CAPE in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mixed-layer CIN in the lowest 50 hPa
'Time-minimum mixed-layer CIN in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mixed-layer CAPE in the lowest 100 hPa
'Time-minimum mixed-layer CAPE in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mixed-layer CIN in the lowest 100 hPa
'Time-minimum mixed-layer CIN in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum departure level of the most unstable parcel expressed as Pressure
'Time-minimum departure level of the most unstable parcel expressed as Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ceiling
'Time-minimum ceiling' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column integrated saturation specific humidity with respect to water
'Time-minimum total column integrated saturation specific humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 169 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum direct solar radiation flux
'Time-minimum direct solar radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum cosine of solar zenith angle
'Time-minimum cosine of solar zenith angle' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum freezing rain rate water equivalent
'Time-minimum freezing rain rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated eastward geopotential flux
'Time-minimum total column vertically-integrated eastward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated northward geopotential flux
'Time-minimum total column vertically-integrated northward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of water geopotential flux
'Time-minimum total column vertically-integrated divergence of water geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of geopotential flux
'Time-minimum total column vertically-integrated divergence of geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated eastward enthalpy flux
'Time-minimum total column vertically-integrated eastward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated northward enthalpy flux
'Time-minimum total column vertically-integrated northward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated eastward kinetic energy flux
'Time-minimum total column vertically-integrated eastward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated northward kinetic energy flux
'Time-minimum total column vertically-integrated northward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated eastward total energy flux
'Time-minimum total column vertically-integrated eastward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated northward total energy flux
'Time-minimum total column vertically-integrated northward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of enthalpy flux
'Time-minimum total column vertically-integrated divergence of enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of kinetic energy flux
'Time-minimum total column vertically-integrated divergence of kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of total energy flux
'Time-minimum total column vertically-integrated divergence of total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically-integrated divergence of water enthalpy flux
'Time-minimum total column vertically-integrated divergence of water enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of mass flux
'Time-minimum vertically integrated divergence of mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward mass flux
'Time-minimum vertically integrated eastward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward mass flux
'Time-minimum vertically integrated northward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of water vapour flux
'Time-minimum vertically integrated divergence of water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of cloud liquid water flux
'Time-minimum vertically integrated divergence of cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of cloud ice water flux
'Time-minimum vertically integrated divergence of cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of rain flux
'Time-minimum vertically integrated divergence of rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of snow flux
'Time-minimum vertically integrated divergence of snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward water vapour flux
'Time-minimum vertically integrated eastward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward water vapour flux
'Time-minimum vertically integrated northward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward cloud liquid water flux
'Time-minimum vertically integrated eastward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward cloud liquid water flux
'Time-minimum vertically integrated northward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward cloud ice water flux
'Time-minimum vertically integrated eastward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward cloud ice water flux
'Time-minimum vertically integrated northward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward rain flux
'Time-minimum vertically integrated eastward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward rain flux
'Time-minimum vertically integrated northward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward snow flux
'Time-minimum vertically integrated eastward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward snow flux
'Time-minimum vertically integrated northward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated eastward ozone flux
'Time-minimum vertically integrated eastward ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated northward ozone flux
'Time-minimum vertically integrated northward ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated divergence of ozone flux
'Time-minimum vertically integrated divergence of ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated net source of ozone
'Time-minimum vertically integrated net source of ozone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward turbulent surface stress due to orographic form drag
'Time-minimum eastward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward turbulent surface stress due to orographic form drag
'Time-minimum northward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward turbulent surface stress due to surface roughness
'Time-minimum eastward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward turbulent surface stress due to surface roughness
'Time-minimum northward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum visibility through precipitation
'Time-minimum visibility through precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum cloud-to-ground lightning flash density
'Time-minimum cloud-to-ground lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum land surface heat net flux
'Time-minimum land surface heat net flux' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface direct normal short-wave radiation flux, clear sky
'Time-minimum surface direct normal short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre convective gust
'Time-minimum 10 metre convective gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum 10 metre turbulent gust
'Time-minimum 10 metre turbulent gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of 0 degrees C theta level above ground
'Time-minimum geometric height of 0 degrees C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of 1 degree C theta level above ground
'Time-minimum geometric height of 1 degree C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27415 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of 1.5 degrees C theta level above ground
'Time-minimum geometric height of 1.5 degrees C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27465 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vegetation
'Time-minimum vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum leaf area index
'Time-minimum leaf area index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface roughness for heat
'Time-minimum surface roughness for heat' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum Reciprocal Obukhov length
'Time-minimum Reciprocal Obukhov length' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum geometric height of 3 degrees C atmospheric isothermal level above ground
'Time-minimum geometric height of 3 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27615 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface diffuse short-wave radiation flux, clear sky
'Time-minimum surface diffuse short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum volumetric soil moisture (root zone)
'Time-minimum volumetric soil moisture (root zone)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum liquid water content in snow pack
'Time-minimum liquid water content in snow pack' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum most-unstable CIN
'Time-minimum most-unstable CIN' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific rain water content (convective)
'Time-minimum specific rain water content (convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 144 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum specific snow water content (convective)
'Time-minimum specific snow water content (convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 145 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum mixed layer depth
'Time-minimum mixed layer depth' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum urban cover
'Time-minimum urban cover' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation temperature tendency due to short-wave radiation
'Time-standard-deviation temperature tendency due to short-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature tendency due to long-wave radiation
'Time-standard-deviation temperature tendency due to long-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature tendency due to short wave radiation, clear sky
'Time-standard-deviation temperature tendency due to short wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature tendency due to long-wave radiation, clear sky
'Time-standard-deviation temperature tendency due to long-wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature tendency due to parametrisations
'Time-standard-deviation temperature tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific humidity tendency due to parametrisations
'Time-standard-deviation specific humidity tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward wind tendency due to parametrisations
'Time-standard-deviation eastward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward wind tendency due to parametrisations
'Time-standard-deviation northward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation updraught mass flux
'Time-standard-deviation updraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation downdraught mass flux
'Time-standard-deviation downdraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation updraught detrainment rate
'Time-standard-deviation updraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation downdraught detrainment rate
'Time-standard-deviation downdraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total precipitation flux
'Time-standard-deviation total precipitation flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation turbulent diffusion coefficient for heat
'Time-standard-deviation turbulent diffusion coefficient for heat' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface photosynthetically active radiation flux, clear sky
'Time-standard-deviation surface photosynthetically active radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snow evaporation rate
'Time-standard-deviation snow evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 148 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snowmelt rate
'Time-standard-deviation snowmelt rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation magnitude of turbulent surface stress
'Time-standard-deviation magnitude of turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation large-scale precipitation fraction
'Time-standard-deviation large-scale precipitation fraction' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward UV radiation flux
'Time-standard-deviation surface downward UV radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface photosynthetically active radiation flux
'Time-standard-deviation surface photosynthetically active radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation large-scale precipitation rate
'Time-standard-deviation large-scale precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation convective precipitation rate
'Time-standard-deviation convective precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snowfall rate
'Time-standard-deviation snowfall rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation boundary layer dissipation
'Time-standard-deviation boundary layer dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface sensible heat flux
'Time-standard-deviation surface sensible heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface latent heat flux
'Time-standard-deviation surface latent heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward short-wave radiation flux
'Time-standard-deviation surface downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward long-wave radiation flux
'Time-standard-deviation surface downward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface net short-wave radiation flux
'Time-standard-deviation surface net short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface net long-wave radiation flux
'Time-standard-deviation surface net long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation top net short-wave radiation flux
'Time-standard-deviation top net short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation top net long-wave radiation flux
'Time-standard-deviation top net long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward turbulent surface stress
'Time-standard-deviation eastward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward turbulent surface stress
'Time-standard-deviation northward turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation evaporation rate
'Time-standard-deviation evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward gravity wave surface stress
'Time-standard-deviation eastward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward gravity wave surface stress
'Time-standard-deviation northward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation gravity wave dissipation
'Time-standard-deviation gravity wave dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation runoff rate
'Time-standard-deviation runoff rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation top net short-wave radiation flux, clear sky
'Time-standard-deviation top net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation top net long-wave radiation flux, clear sky
'Time-standard-deviation top net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface net short-wave radiation flux, clear sky
'Time-standard-deviation surface net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface net long-wave radiation flux, clear sky
'Time-standard-deviation surface net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation top downward short-wave radiation flux
'Time-standard-deviation top downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated moisture divergence
'Time-standard-deviation vertically integrated moisture divergence' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total precipitation rate
'Time-standard-deviation total precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation convective snowfall rate water equivalent
'Time-standard-deviation convective snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation large scale snowfall rate water equivalent
'Time-standard-deviation large scale snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface direct short-wave radiation flux
'Time-standard-deviation surface direct short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface direct short-wave radiation flux, clear sky
'Time-standard-deviation surface direct short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation carbon dioxide net ecosystem exchange flux
'Time-standard-deviation carbon dioxide net ecosystem exchange flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 59 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation carbon dioxide gross primary production flux
'Time-standard-deviation carbon dioxide gross primary production flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 60 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation carbon dioxide ecosystem respiration flux
'Time-standard-deviation carbon dioxide ecosystem respiration flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 61 ;
	 constituentType = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward short-wave radiation flux, clear sky
'Time-standard-deviation surface downward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward long-wave radiation flux, clear sky
'Time-standard-deviation surface downward long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation potential evaporation rate
'Time-standard-deviation potential evaporation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 143 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation volumetric soil moisture
'Time-standard-deviation volumetric soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snow depth water equivalent
'Time-standard-deviation snow depth water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation skin temperature
'Time-standard-deviation skin temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snow density
'Time-standard-deviation snow density' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice area fraction
'Time-standard-deviation sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea surface temperature
'Time-standard-deviation sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation leaf area index, low vegetation
'Time-standard-deviation leaf area index, low vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation leaf area index, high vegetation
'Time-standard-deviation leaf area index, high vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column cloud liquid water
'Time-standard-deviation total column cloud liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column cloud ice water
'Time-standard-deviation total column cloud ice water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 2 metre specific humidity
'Time-standard-deviation 2 metre specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake mix-layer temperature
'Time-standard-deviation lake mix-layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake mix-layer depth
'Time-standard-deviation lake mix-layer depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation fraction of snow cover
'Time-standard-deviation fraction of snow cover' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 121 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation soil temperature
'Time-standard-deviation soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wind speed
'Time-standard-deviation wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation pressure
'Time-standard-deviation pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation charnock
'Time-standard-deviation charnock' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation potential vorticity
'Time-standard-deviation potential vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific rain water content
'Time-standard-deviation specific rain water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 85 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific snow water content
'Time-standard-deviation specific snow water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 86 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eta-coordinate vertical velocity
'Time-standard-deviation eta-coordinate vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation visibility
'Time-standard-deviation visibility' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wind direction
'Time-standard-deviation wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column snow water
'Time-standard-deviation total column snow water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation low cloud cover
'Time-standard-deviation low cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation medium cloud cover
'Time-standard-deviation medium cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation high cloud cover
'Time-standard-deviation high cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column rain water
'Time-standard-deviation total column rain water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation most-unstable CAPE
'Time-standard-deviation most-unstable CAPE' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated graupel (snow pellets)
'Time-standard-deviation total column vertically-integrated graupel (snow pellets)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geopotential
'Time-standard-deviation geopotential' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature
'Time-standard-deviation temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation u component of wind
'Time-standard-deviation u component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation v component of wind
'Time-standard-deviation v component of wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific humidity
'Time-standard-deviation specific humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface pressure
'Time-standard-deviation surface pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertical velocity
'Time-standard-deviation vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column water
'Time-standard-deviation total column water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated water vapour
'Time-standard-deviation total column vertically-integrated water vapour' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vorticity (relative)
'Time-standard-deviation vorticity (relative)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean sea level pressure
'Time-standard-deviation mean sea level pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 101 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation divergence
'Time-standard-deviation divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation relative humidity
'Time-standard-deviation relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation boundary layer height
'Time-standard-deviation boundary layer height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre U wind component
'Time-standard-deviation 10 metre U wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre V wind component
'Time-standard-deviation 10 metre V wind component' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 2 metre temperature
'Time-standard-deviation 2 metre temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 2 metre dewpoint temperature
'Time-standard-deviation 2 metre dewpoint temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sunshine
'Time-standard-deviation sunshine' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ozone mass mixing ratio
'Time-standard-deviation ozone mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre wind speed
'Time-standard-deviation 10 metre wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation temperature of snow layer
'Time-standard-deviation temperature of snow layer' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation forecast surface roughness
'Time-standard-deviation forecast surface roughness' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation forecast logarithm of surface roughness for heat
'Time-standard-deviation forecast logarithm of surface roughness for heat' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific cloud liquid water content
'Time-standard-deviation specific cloud liquid water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 83 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific cloud ice water content
'Time-standard-deviation specific cloud ice water content' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 84 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation fraction of cloud cover
'Time-standard-deviation fraction of cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation k index
'Time-standard-deviation k index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total totals index
'Time-standard-deviation total totals index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre wind direction
'Time-standard-deviation 10 metre wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation clear air turbulence (CAT)
'Time-standard-deviation clear air turbulence (CAT)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation forecast albedo
'Time-standard-deviation forecast albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation potential temperature
'Time-standard-deviation potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation UV visible albedo for direct radiation (climatological)
'Time-standard-deviation UV visible albedo for direct radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation UV visible albedo for diffuse radiation (climatological)
'Time-standard-deviation UV visible albedo for diffuse radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation near IR albedo for direct radiation (climatological)
'Time-standard-deviation near IR albedo for direct radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation near IR albedo for diffuse radiation (climatological)
'Time-standard-deviation near IR albedo for diffuse radiation (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation snow albedo
'Time-standard-deviation snow albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation montgomery potential
'Time-standard-deviation montgomery potential' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation convective available potential energy
'Time-standard-deviation convective available potential energy' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total cloud cover
'Time-standard-deviation total cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation skin reservoir content
'Time-standard-deviation skin reservoir content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column integrated ozone
'Time-standard-deviation total column integrated ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated kinetic energy
'Time-standard-deviation total column vertically-integrated kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated enthalpy
'Time-standard-deviation total column vertically-integrated enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated potential + internal energy
'Time-standard-deviation total column vertically-integrated potential + internal energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertical integral of potential+internal+latent energy
'Time-standard-deviation vertical integral of potential+internal+latent energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated total energy
'Time-standard-deviation total column vertically-integrated total energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated water enthalpy
'Time-standard-deviation total column vertically-integrated water enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation UV visible albedo for direct radiation, isotropic component (climatological)
'Time-standard-deviation UV visible albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation UV visible albedo for direct radiation, volumetric component (climatological)
'Time-standard-deviation UV visible albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 59 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation UV visible albedo for direct radiation, geometric component (climatological)
'Time-standard-deviation UV visible albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation near IR albedo for direct radiation, isotropic component (climatological)
'Time-standard-deviation near IR albedo for direct radiation, isotropic component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 12 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation near IR albedo for direct radiation, volumetric component (climatological)
'Time-standard-deviation near IR albedo for direct radiation, volumetric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation near IR albedo for direct radiation, geometric component (climatological)
'Time-standard-deviation near IR albedo for direct radiation, geometric component (climatological)' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 6 ;
	 typeOfGeneratingProcess = 9 ;
	}
#Time-standard-deviation convective inhibition
'Time-standard-deviation convective inhibition' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation friction velocity
'Time-standard-deviation friction velocity' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake bottom temperature
'Time-standard-deviation lake bottom temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake total layer temperature
'Time-standard-deviation lake total layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake shape factor
'Time-standard-deviation lake shape factor' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake ice surface temperature
'Time-standard-deviation lake ice surface temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation lake ice total depth
'Time-standard-deviation lake ice total depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation minimum vertical gradient of refractivity inside trapping layer
'Time-standard-deviation minimum vertical gradient of refractivity inside trapping layer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mean vertical gradient of refractivity inside trapping layer
'Time-standard-deviation mean vertical gradient of refractivity inside trapping layer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation duct base height
'Time-standard-deviation duct base height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 41 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation trapping layer base height
'Time-standard-deviation trapping layer base height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 42 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation trapping layer top height
'Time-standard-deviation trapping layer top height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 43 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of -10 degrees C atmospheric isothermal level above ground
'Time-standard-deviation geometric height of -10 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation cloud base height
'Time-standard-deviation cloud base height' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of 0 degrees C atmospheric isothermal level above ground
'Time-standard-deviation geometric height of 0 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre wind gust
'Time-standard-deviation 10 metre wind gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation relative humidity with respect to water
'Time-standard-deviation relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 2 metre relative humidity with respect to water
'Time-standard-deviation 2 metre relative humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 93 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation convective available potential energy shear
'Time-standard-deviation convective available potential energy shear' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation tropopause pressure
'Time-standard-deviation tropopause pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 7 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation height of convective cloud top
'Time-standard-deviation height of convective cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation height of zero-degree wet-bulb temperature
'Time-standard-deviation height of zero-degree wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 44 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation height of one-degree wet-bulb temperature
'Time-standard-deviation height of one-degree wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 45 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total lightning flash density
'Time-standard-deviation total lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column supercooled liquid water
'Time-standard-deviation total column supercooled liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 167 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre U-component of neutral wind
'Time-standard-deviation 10 metre U-component of neutral wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre V-component of neutral wind
'Time-standard-deviation 10 metre V-component of neutral wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation convective rain rate
'Time-standard-deviation convective rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation large scale rain rate
'Time-standard-deviation large scale rain rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mixed-layer CAPE in the lowest 50 hPa
'Time-standard-deviation mixed-layer CAPE in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mixed-layer CIN in the lowest 50 hPa
'Time-standard-deviation mixed-layer CIN in the lowest 50 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 5000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mixed-layer CAPE in the lowest 100 hPa
'Time-standard-deviation mixed-layer CAPE in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mixed-layer CIN in the lowest 100 hPa
'Time-standard-deviation mixed-layer CIN in the lowest 100 hPa' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 18 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation departure level of the most unstable parcel expressed as Pressure
'Time-standard-deviation departure level of the most unstable parcel expressed as Pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ceiling
'Time-standard-deviation ceiling' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column integrated saturation specific humidity with respect to water
'Time-standard-deviation total column integrated saturation specific humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 169 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation direct solar radiation flux
'Time-standard-deviation direct solar radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation cosine of solar zenith angle
'Time-standard-deviation cosine of solar zenith angle' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation freezing rain rate water equivalent
'Time-standard-deviation freezing rain rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated eastward geopotential flux
'Time-standard-deviation total column vertically-integrated eastward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated northward geopotential flux
'Time-standard-deviation total column vertically-integrated northward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of water geopotential flux
'Time-standard-deviation total column vertically-integrated divergence of water geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 42 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of geopotential flux
'Time-standard-deviation total column vertically-integrated divergence of geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated eastward enthalpy flux
'Time-standard-deviation total column vertically-integrated eastward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated northward enthalpy flux
'Time-standard-deviation total column vertically-integrated northward enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated eastward kinetic energy flux
'Time-standard-deviation total column vertically-integrated eastward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated northward kinetic energy flux
'Time-standard-deviation total column vertically-integrated northward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated eastward total energy flux
'Time-standard-deviation total column vertically-integrated eastward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated northward total energy flux
'Time-standard-deviation total column vertically-integrated northward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of enthalpy flux
'Time-standard-deviation total column vertically-integrated divergence of enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of kinetic energy flux
'Time-standard-deviation total column vertically-integrated divergence of kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of total energy flux
'Time-standard-deviation total column vertically-integrated divergence of total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically-integrated divergence of water enthalpy flux
'Time-standard-deviation total column vertically-integrated divergence of water enthalpy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of mass flux
'Time-standard-deviation vertically integrated divergence of mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward mass flux
'Time-standard-deviation vertically integrated eastward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward mass flux
'Time-standard-deviation vertically integrated northward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of water vapour flux
'Time-standard-deviation vertically integrated divergence of water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 160 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of cloud liquid water flux
'Time-standard-deviation vertically integrated divergence of cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 161 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of cloud ice water flux
'Time-standard-deviation vertically integrated divergence of cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of rain flux
'Time-standard-deviation vertically integrated divergence of rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 163 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of snow flux
'Time-standard-deviation vertically integrated divergence of snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 164 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward water vapour flux
'Time-standard-deviation vertically integrated eastward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward water vapour flux
'Time-standard-deviation vertically integrated northward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward cloud liquid water flux
'Time-standard-deviation vertically integrated eastward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 152 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward cloud liquid water flux
'Time-standard-deviation vertically integrated northward cloud liquid water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 153 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward cloud ice water flux
'Time-standard-deviation vertically integrated eastward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 154 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward cloud ice water flux
'Time-standard-deviation vertically integrated northward cloud ice water flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 155 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward rain flux
'Time-standard-deviation vertically integrated eastward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 156 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward rain flux
'Time-standard-deviation vertically integrated northward rain flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 157 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward snow flux
'Time-standard-deviation vertically integrated eastward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 158 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward snow flux
'Time-standard-deviation vertically integrated northward snow flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 159 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated eastward ozone flux
'Time-standard-deviation vertically integrated eastward ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated northward ozone flux
'Time-standard-deviation vertically integrated northward ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated divergence of ozone flux
'Time-standard-deviation vertically integrated divergence of ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated net source of ozone
'Time-standard-deviation vertically integrated net source of ozone' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 81 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward turbulent surface stress due to orographic form drag
'Time-standard-deviation eastward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward turbulent surface stress due to orographic form drag
'Time-standard-deviation northward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward turbulent surface stress due to surface roughness
'Time-standard-deviation eastward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward turbulent surface stress due to surface roughness
'Time-standard-deviation northward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation cloud-to-ground lightning flash density
'Time-standard-deviation cloud-to-ground lightning flash density' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation land surface heat net flux
'Time-standard-deviation land surface heat net flux' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface direct normal short-wave radiation flux, clear sky
'Time-standard-deviation surface direct normal short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre convective gust
'Time-standard-deviation 10 metre convective gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation 10 metre turbulent gust
'Time-standard-deviation 10 metre turbulent gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of 0 degrees C theta level above ground
'Time-standard-deviation geometric height of 0 degrees C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of 1 degree C theta level above ground
'Time-standard-deviation geometric height of 1 degree C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27415 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of 1.5 degrees C theta level above ground
'Time-standard-deviation geometric height of 1.5 degrees C theta level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 107 ;
	 scaledValueOfFirstFixedSurface = 27465 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vegetation
'Time-standard-deviation vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation leaf area index
'Time-standard-deviation leaf area index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface roughness for heat
'Time-standard-deviation surface roughness for heat' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation Reciprocal Obukhov length
'Time-standard-deviation Reciprocal Obukhov length' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation geometric height of 3 degrees C atmospheric isothermal level above ground
'Time-standard-deviation geometric height of 3 degrees C atmospheric isothermal level above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 27615 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface diffuse short-wave radiation flux, clear sky
'Time-standard-deviation surface diffuse short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation volumetric soil moisture (root zone)
'Time-standard-deviation volumetric soil moisture (root zone)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 167 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation liquid water content in snow pack
'Time-standard-deviation liquid water content in snow pack' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation most-unstable CIN
'Time-standard-deviation most-unstable CIN' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 17 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific rain water content (convective)
'Time-standard-deviation specific rain water content (convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 144 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation specific snow water content (convective)
'Time-standard-deviation specific snow water content (convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 145 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation mixed layer depth
'Time-standard-deviation mixed layer depth' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation urban cover
'Time-standard-deviation urban cover' = {
	 discipline = 2 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Cross sectional area of flow in channel
'Cross sectional area of flow in channel' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	}
#Side flow into river channel
'Side flow into river channel' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Discharge from rivers or streams
'Discharge from rivers or streams' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#River storage of water
'River storage of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Floodplain storage of water
'Floodplain storage of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Days since last observation
'Days since last observation' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 3 ;
	}
#Frost index
'Frost index' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 24 ;
	}
#Depth of water on soil surface
'Depth of water on soil surface' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Upstream accumulated precipitation
'Upstream accumulated precipitation' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Upstream accumulated snow melt
'Upstream accumulated snow melt' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Snow depth at elevation bands
'Snow depth at elevation bands' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	}
#Groundwater upper storage
'Groundwater upper storage' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Groundwater lower storage
'Groundwater lower storage' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Lake depth
'Lake depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	}
#River depth
'River depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	}
#River outflow of water
'River outflow of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	}
#Floodplain outflow of water
'Floodplain outflow of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}
#Floodpath outflow of water
'Floodpath outflow of water' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}
#Floodplain depth
'Floodplain depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	}
#Floodplain flooded fraction
'Floodplain flooded fraction' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	}
#Floodplain flooded area
'Floodplain flooded area' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	}
#River fraction
'River fraction' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	}
#River area
'River area' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	}
#Fraction of river coverage plus river related flooding
'Fraction of river coverage plus river related flooding' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	}
#Area of river coverage plus river related flooding
'Area of river coverage plus river related flooding' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	}
#Water surface elevation
'Water surface elevation' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}
#Groundwater return flow rate
'Groundwater return flow rate' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}
#River and floodplain storage
'River and floodplain storage' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}
#Depth-averaged river velocity
'Depth-averaged river velocity' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}
#Latitude
'Latitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	}
#Longitude
'Longitude' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	}
#Latitude on T grid
'Latitude on T grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 1 ;
	}
#Longitude on T grid
'Longitude on T grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 1 ;
	}
#Latitude on U grid
'Latitude on U grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 2 ;
	}
#Longitude on U grid
'Longitude on U grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 2 ;
	}
#Latitude on V grid
'Latitude on V grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 3 ;
	}
#Longitude on V grid
'Longitude on V grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 3 ;
	}
#Latitude on W grid
'Latitude on W grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 4 ;
	}
#Longitude on W grid
'Longitude on W grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 4 ;
	}
#Latitude on F grid
'Latitude on F grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 5 ;
	}
#Longitude on F grid
'Longitude on F grid' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 gridDefinitionTemplateNumber = 101 ;
	 numberOfGridInReference = 5 ;
	}
#Total column vertically-integrated graupel (snow pellets)
'Total column vertically-integrated graupel (snow pellets)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Surface latent heat net flux
'Surface latent heat net flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Heat index
'Heat index' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Wind chill factor
'Wind chill factor' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Snow phase change heat flux
'Snow phase change heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Vapor pressure
'Vapor pressure' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}
#Large scale precipitation (non-convective)
'Large scale precipitation (non-convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}
#Snowfall rate water equivalent
'Snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}
#Convective snow
'Convective snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	}
#Large scale snow
'Large scale snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	}
#Snow age
'Snow age' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	}
#Absolute humidity
'Absolute humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 18 ;
	}
#Precipitation type
'Precipitation type' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	}
#Integrated liquid water
'Integrated liquid water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 20 ;
	}
#Condensate
'Condensate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 21 ;
	}
#Cloud mixing ratio
'Cloud mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 22 ;
	}
#Ice water mixing ratio
'Ice water mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 23 ;
	}
#Rain mixing ratio
'Rain mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	}
#Snow mixing ratio
'Snow mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 25 ;
	}
#Horizontal moisture convergence
'Horizontal moisture convergence' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 26 ;
	}
#Total snowfall
'Total snowfall' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Precipitable water category
'Precipitable water category' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 30 ;
	}
#Hail
'Hail' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 31 ;
	}
#Graupel (snow pellets)
'Graupel (snow pellets)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 32 ;
	}
#Categorical rain
'Categorical rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 33 ;
	}
#Categorical freezing rain
'Categorical freezing rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 34 ;
	}
#Categorical ice pellets
'Categorical ice pellets' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 35 ;
	}
#Categorical snow
'Categorical snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 36 ;
	}
#Convective precipitation rate
'Convective precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Horizontal moisture divergence
'Horizontal moisture divergence' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 38 ;
	}
#Percent frozen precipitation
'Percent frozen precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 39 ;
	}
#Potential evaporation
'Potential evaporation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 40 ;
	}
#Snow cover
'Snow cover' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 42 ;
	}
#Rain fraction of total cloud water
'Rain fraction of total cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 43 ;
	}
#Rime factor
'Rime factor' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 44 ;
	}
#Total column integrated rain
'Total column integrated rain' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	}
#Total column integrated snow
'Total column integrated snow' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	}
#Large scale water precipitation (non-convective)
'Large scale water precipitation (non-convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 47 ;
	}
#Convective water precipitation
'Convective water precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 48 ;
	}
#Total water precipitation
'Total water precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 49 ;
	}
#Total snow precipitation
'Total snow precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total column water (Vertically integrated total water (vapour + cloud water/ice))
'Total column water (Vertically integrated total water (vapour + cloud water/ice))' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	}
#Total precipitation rate
'Total precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total snowfall rate water equivalent
'Total snowfall rate water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Large scale precipitation rate
'Large scale precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Total snowfall rate
'Total snowfall rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 57 ;
	}
#Convective snowfall rate
'Convective snowfall rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 58 ;
	}
#Large scale snowfall rate
'Large scale snowfall rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 59 ;
	}
#Water equivalent of accumulated snow depth (deprecated)
'Water equivalent of accumulated snow depth (deprecated)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}
#Rain precipitation rate
'Rain precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 65 ;
	}
#Snow precipitation rate
'Snow precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	}
#Freezing rain precipitation rate
'Freezing rain precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Ice pellets precipitation rate
'Ice pellets precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 68 ;
	}
#Wind speed (gust)
'Wind speed (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	}
#u-component of wind (gust)
'u-component of wind (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	}
#v-component of wind (gust)
'v-component of wind (gust)' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	}
#Vertical speed shear
'Vertical speed shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	}
#Horizontal momentum flux
'Horizontal momentum flux' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 26 ;
	}
#U-component storm motion
'U-component storm motion' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 27 ;
	}
#V-component storm motion
'V-component storm motion' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 28 ;
	}
#Drag coefficient
'Drag coefficient' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	}
#Frictional velocity
'Frictional velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	}
#Pressure reduced to MSL
'Pressure reduced to MSL' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}
#Altimeter setting
'Altimeter setting' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}
#Thickness
'Thickness' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}
#Pressure altitude
'Pressure altitude' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}
#Density altitude
'Density altitude' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}
#5-wave geopotential height
'5-wave geopotential height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}
#Instantaneous eastward gravity wave surface stress
'Instantaneous eastward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous northward gravity wave surface stress
'Instantaneous northward gravity wave surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#5-wave geopotential height anomaly
'5-wave geopotential height anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}
#Net short-wave radiation flux (top of atmosphere)
'Net short-wave radiation flux (top of atmosphere)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}
#Surface downward short-wave radiation flux
'Surface downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface upward short-wave radiation flux
'Surface upward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface net short-wave radiation flux
'Surface net short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface photosynthetically active radiation flux
'Surface photosynthetically active radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface net short-wave radiation flux, clear sky
'Surface net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface downward UV radiation flux
'Surface downward UV radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#UV index (under clear sky)
'UV index (under clear sky)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	}
#UV index
'UV index' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 51 ;
	}
#Surface downward long-wave radiation flux
'Surface downward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface upward long-wave radiation flux
'Surface upward long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface net long-wave radiation flux
'Surface net long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface net long-wave radiation flux, clear sky
'Surface net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Cloud Ice
'Cloud Ice' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	}
#Cloud water
'Cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 6 ;
	}
#Cloud amount
'Cloud amount' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 7 ;
	}
#Cloud type
'Cloud type' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 8 ;
	}
#Thunderstorm maximum tops
'Thunderstorm maximum tops' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 9 ;
	}
#Thunderstorm coverage
'Thunderstorm coverage' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 10 ;
	}
#Cloud top
'Cloud top' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 12 ;
	}
#Ceiling
'Ceiling' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	}
#Non-convective cloud cover
'Non-convective cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 14 ;
	}
#Cloud work function
'Cloud work function' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 15 ;
	}
#Convective cloud efficiency
'Convective cloud efficiency' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 16 ;
	}
#Total condensate
'Total condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 17 ;
	}
#Total column-integrated cloud water
'Total column-integrated cloud water' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 18 ;
	}
#Total column-integrated cloud ice
'Total column-integrated cloud ice' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 19 ;
	}
#Total column-integrated condensate
'Total column-integrated condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 20 ;
	}
#Ice fraction of total condensate
'Ice fraction of total condensate' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 21 ;
	}
#Cloud ice mixing ratio
'Cloud ice mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 23 ;
	}
#Sunshine
'Sunshine' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Horizontal extent of cumulonimbus (CB)
'Horizontal extent of cumulonimbus (CB)' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 25 ;
	}
#K index
'K index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	}
#KO index
'KO index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 3 ;
	}
#Total totals index
'Total totals index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	}
#Sweat index
'Sweat index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 5 ;
	}
#Storm relative helicity
'Storm relative helicity' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 8 ;
	}
#Energy helicity index
'Energy helicity index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 9 ;
	}
#Surface lifted index
'Surface lifted index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 10 ;
	}
#Best (4-layer) lifted index
'Best (4-layer) lifted index' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 11 ;
	}
#Aerosol type
'Aerosol type' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 0 ;
	}
#Total ozone
'Total ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 0 ;
	}
#Total column integrated ozone
'Total column integrated ozone' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Base spectrum width
'Base spectrum width' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 0 ;
	}
#Base reflectivity
'Base reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	}
#Base radial velocity
'Base radial velocity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 2 ;
	}
#Vertically-integrated liquid
'Vertically-integrated liquid' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 3 ;
	}
#Layer-maximum base reflectivity
'Layer-maximum base reflectivity' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 4 ;
	}
#Precipitation from radar
'Precipitation from radar' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Air concentration of Caesium 137
'Air concentration of Caesium 137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 0 ;
	}
#Air concentration of Iodine 131
'Air concentration of Iodine 131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 1 ;
	}
#Air concentration of radioactive pollutant
'Air concentration of radioactive pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 2 ;
	}
#Ground deposition of Caesium 137
'Ground deposition of Caesium 137' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 3 ;
	}
#Ground deposition of Iodine 131
'Ground deposition of Iodine 131' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 4 ;
	}
#Ground deposition of radioactive pollutant
'Ground deposition of radioactive pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 5 ;
	}
#Time-integrated air concentration of caesium pollutant
'Time-integrated air concentration of caesium pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 6 ;
	}
#Time-integrated air concentration of iodine pollutant
'Time-integrated air concentration of iodine pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 7 ;
	}
#Time-integrated air concentration of radioactive pollutant
'Time-integrated air concentration of radioactive pollutant' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 8 ;
	}
#Volcanic ash
'Volcanic ash' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 4 ;
	}
#Icing top
'Icing top' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 5 ;
	}
#Icing base
'Icing base' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 6 ;
	}
#Icing
'Icing' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 7 ;
	}
#Turbulence top
'Turbulence top' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 8 ;
	}
#Turbulence base
'Turbulence base' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 9 ;
	}
#Turbulence
'Turbulence' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 10 ;
	}
#Turbulent kinetic energy
'Turbulent kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 11 ;
	}
#Planetary boundary layer regime
'Planetary boundary layer regime' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 12 ;
	}
#Contrail intensity
'Contrail intensity' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 13 ;
	}
#Contrail engine type
'Contrail engine type' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 14 ;
	}
#Contrail top
'Contrail top' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 15 ;
	}
#Contrail base
'Contrail base' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 16 ;
	}
#Snow free albedo
'Snow free albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 18 ;
	}
#Icing
'Icing' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 20 ;
	}
#In-cloud turbulence
'In-cloud turbulence' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 21 ;
	}
#Relative clear air turbulence (RCAT)
'Relative clear air turbulence (RCAT)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 22 ;
	}
#Supercooled large droplet probability
'Supercooled large droplet probability' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 23 ;
	}
#Arbitrary text string
'Arbitrary text string' = {
	 discipline = 0 ;
	 parameterCategory = 190 ;
	 parameterNumber = 0 ;
	}
#Seconds prior to initial reference time (defined in Section 1)
'Seconds prior to initial reference time (defined in Section 1)' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}
#Flash flood guidance
'Flash flood guidance' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Flash flood runoff (Encoded as an accumulation over a floating subinterval of time)
'Flash flood runoff (Encoded as an accumulation over a floating subinterval of time)' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Remotely sensed snow cover
'Remotely sensed snow cover' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Elevation of snow covered terrain
'Elevation of snow covered terrain' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Snow water equivalent percent of normal
'Snow water equivalent percent of normal' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Baseflow-groundwater runoff
'Baseflow-groundwater runoff' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Storm surface runoff
'Storm surface runoff' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Conditional percent precipitation amount fractile for an overall period (Encoded as an accumulation)
'Conditional percent precipitation amount fractile for an overall period (Encoded as an accumulation)' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Percent precipitation in a sub-period of an overall period
'Percent precipitation in a sub-period of an overall period' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Probability of 0.01 inch of precipitation (POP)
'Probability of 0.01 inch of precipitation (POP)' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}
#Vegetation
'Vegetation' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Water runoff
'Water runoff' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Evapotranspiration
'Evapotranspiration' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Model terrain height
'Model terrain height' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Land use
'Land use' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Ground heat flux
'Ground heat flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Moisture availability
'Moisture availability' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Exchange coefficient
'Exchange coefficient' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Plant canopy surface water
'Plant canopy surface water' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Blackadar mixing length scale
'Blackadar mixing length scale' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Canopy conductance
'Canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Minimal stomatal resistance
'Minimal stomatal resistance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Solar parameter in canopy conductance
'Solar parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}
#Temperature parameter in canopy conductance
'Temperature parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}
#Soil moisture parameter in canopy conductance
'Soil moisture parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}
#Humidity parameter in canopy conductance
'Humidity parameter in canopy conductance' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}
#Column-integrated soil water
'Column-integrated soil water' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}
#Heat flux
'Heat flux' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}
#Volumetric soil moisture
'Volumetric soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}
#Volumetric wilting point
'Volumetric wilting point' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}
#Number of soil layers in root zone
'Number of soil layers in root zone' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	}
#Liquid volumetric soil moisture (non-frozen)
'Liquid volumetric soil moisture (non-frozen)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}
#Volumetric transpiration stress-onset (soil moisture)
'Volumetric transpiration stress-onset (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}
#Transpiration stress-onset (soil moisture)
'Transpiration stress-onset (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}
#Volumetric direct evaporation cease (soil moisture)
'Volumetric direct evaporation cease (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}
#Direct evaporation cease (soil moisture)
'Direct evaporation cease (soil moisture)' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}
#Soil porosity
'Soil porosity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}
#Volumetric saturation of soil moisture
'Volumetric saturation of soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	}
#Saturation of soil moisture
'Saturation of soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	}
#Estimated precipitation
'Estimated precipitation' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Instantaneous rain rate
'Instantaneous rain rate' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Cloud top height
'Cloud top height' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}
#Cloud top height quality indicator
'Cloud top height quality indicator' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}
#Estimated u component of wind
'Estimated u component of wind' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}
#Estimated v component of wind
'Estimated v component of wind' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}
#Number of pixels used
'Number of pixels used' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 6 ;
	}
#Solar zenith angle
'Solar zenith angle' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}
#Relative azimuth angle
'Relative azimuth angle' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 8 ;
	}
#Reflectance in 0.6 micron channel
'Reflectance in 0.6 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}
#Reflectance in 0.8 micron channel
'Reflectance in 0.8 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}
#Reflectance in 1.6 micron channel
'Reflectance in 1.6 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}
#Reflectance in 3.9 micron channel
'Reflectance in 3.9 micron channel' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}
#Atmospheric divergence
'Atmospheric divergence' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}
#Direction of wind waves
'Direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Primary wave direction
'Primary wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}
#Primary wave mean period
'Primary wave mean period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Secondary wave mean period
'Secondary wave mean period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}
#Current direction
'Current direction' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Current speed
'Current speed' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Geometric vertical velocity
'Geometric vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 9 ;
	}
#Seconds prior to initial reference time (defined in Section 1)
'Seconds prior to initial reference time (defined in Section 1)' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}
#2 metre relative humidity
'2 metre relative humidity' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Apparent temperature
'Apparent temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}
#Haines Index
'Haines Index' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 2 ;
	}
#Cloud cover
'Cloud cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	}
#Evaporation
'Evaporation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#10 metre wind direction
'10 metre wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Surface direct short-wave radiation flux
'Surface direct short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface diffuse short-wave radiation flux
'Surface diffuse short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Fraction of snow cover
'Fraction of snow cover' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 121 ;
	}
#Clear air turbulence (CAT)
'Clear air turbulence (CAT)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 29 ;
	}
#Mountain wave turbulence (eddy dissipation rate)
'Mountain wave turbulence (eddy dissipation rate)' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 28 ;
	}
#Specific rain water content (convective)
'Specific rain water content (convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 144 ;
	}
#Specific snow water content (convective)
'Specific snow water content (convective)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 145 ;
	}
#Glacier mask
'Glacier mask' = {
	 discipline = 2 ;
	 parameterCategory = 5 ;
	 parameterNumber = 0 ;
	}
#Soil temperature
'Soil temperature' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	}
#Surface downward short-wave radiation flux, clear sky
'Surface downward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface upward short-wave radiation flux, clear sky
'Surface upward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface downward long-wave radiation flux, clear sky
'Surface downward long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Soil heat flux
'Soil heat flux' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 26 ;
	}
#Percolation rate
'Percolation rate' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Soil depth
'Soil depth' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	}
#Soil moisture
'Soil moisture' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}
#Leaf Area Index
'Leaf Area Index' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Accumulated surface upward short-wave radiation flux, clear sky
'Accumulated surface upward short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Percolation
'Percolation' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 177 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Evapotranspiration rate
'Evapotranspiration rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Potential evapotranspiration rate
'Potential evapotranspiration rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Runoff rate water equivalent (surface plus subsurface)
'Runoff rate water equivalent (surface plus subsurface)' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	}
#Snow melt rate
'Snow melt rate' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Forecast albedo
'Forecast albedo' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	}
#Cloudy brightness temperature
'Cloudy brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	}
#Clear-sky brightness temperature
'Clear-sky brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	}
#Cloudy reflectance
'Cloudy reflectance' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 31 ;
	}
#Clear reflectance
'Clear reflectance' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 32 ;
	}
#Scaled radiance
'Scaled radiance' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Scaled albedo
'Scaled albedo' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Scaled brightness temperature
'Scaled brightness temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Scaled precipitable water
'Scaled precipitable water' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Scaled lifted index
'Scaled lifted index' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Scaled cloud top pressure
'Scaled cloud top pressure' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Scaled skin temperature
'Scaled skin temperature' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Cloud mask
'Cloud mask' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Pixel scene type
'Pixel scene type' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Fire detection indicator
'Fire detection indicator' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Forest fire weather index (as defined by the Canadian Forest Service)
'Forest fire weather index (as defined by the Canadian Forest Service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 5 ;
	}
#Fine fuel moisture code (as defined by the Canadian Forest Service)
'Fine fuel moisture code (as defined by the Canadian Forest Service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 6 ;
	}
#Duff moisture code (as defined by the Canadian Forest Service)
'Duff moisture code (as defined by the Canadian Forest Service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	}
#Drought code (as defined by the Canadian Forest Service)
'Drought code (as defined by the Canadian Forest Service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	}
#Initial fire spread index (as defined by the Canadian Forest Service)
'Initial fire spread index (as defined by the Canadian Forest Service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	}
#Fire buildup index (as defined by the Canadian Forest Service)
'Fire buildup index (as defined by the Canadian Forest Service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	}
#Fire daily severity rating (as defined by the Canadian Forest Service)
'Fire daily severity rating (as defined by the Canadian Forest Service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	}
#Cloudy radiance (with respect to wave number)
'Cloudy radiance (with respect to wave number)' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	}
#Clear-sky radiance (with respect to wave number)
'Clear-sky radiance (with respect to wave number)' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	}
#Wind speed
'Wind speed' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	}
#Aerosol optical thickness at 0.635 um
'Aerosol optical thickness at 0.635 um' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 20 ;
	}
#Aerosol optical thickness at 0.810 um
'Aerosol optical thickness at 0.810 um' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 21 ;
	}
#Aerosol optical thickness at 1.640 um
'Aerosol optical thickness at 1.640 um' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 22 ;
	}
#Angstrom coefficient
'Angstrom coefficient' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 23 ;
	}
#Keetch-Byram drought index
'Keetch-Byram drought index' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	}
#Drought factor (as defined by the Australian forest service)
'Drought factor (as defined by the Australian forest service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 13 ;
	}
#Rate of spread (as defined by the Australian forest service)
'Rate of spread (as defined by the Australian forest service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	}
#Fire danger index (as defined by the Australian forest service)
'Fire danger index (as defined by the Australian forest service)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 15 ;
	}
#Spread component (as defined by the U.S Forest Service National Fire-Danger Rating System)
'Spread component (as defined by the U.S Forest Service National Fire-Danger Rating System)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 16 ;
	}
#Burning index (as defined by the U.S Forest Service National Fire-Danger Rating System)
'Burning index (as defined by the U.S Forest Service National Fire-Danger Rating System)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 17 ;
	}
#Ignition component (as defined by the U.S Forest Service National Fire-Danger Rating System)
'Ignition component (as defined by the U.S Forest Service National Fire-Danger Rating System)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	}
#Energy release component (as defined by the U.S Forest Service National Fire-Danger Rating System)
'Energy release component (as defined by the U.S Forest Service National Fire-Danger Rating System)' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 19 ;
	}
#Probability of fire detection
'Probability of fire detection' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 43 ;
	}
#Probability of ignition from lightning
'Probability of ignition from lightning' = {
	 discipline = 2 ;
	 parameterCategory = 4 ;
	 parameterNumber = 44 ;
	}
#Volumetric soil ice
'Volumetric soil ice' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 38 ;
	}
#Time integral of total solid precipitation flux
'Time integral of total solid precipitation flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 128 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Fog
'Fog' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Time-integrated eastward turbulent surface stress due to orographic form drag
'Time-integrated eastward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated northward turbulent surface stress due to orographic form drag
'Time-integrated northward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated eastward turbulent surface stress due to surface roughness
'Time-integrated eastward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated northward turbulent surface stress due to surface roughness
'Time-integrated northward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Saturation specific humidity with respect to water
'Saturation specific humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 168 ;
	}
#Total column integrated saturation specific humidity with respect to water
'Total column integrated saturation specific humidity with respect to water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 169 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Standardised Precipitation Index (SPI)
'Standardised Precipitation Index (SPI)' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 0 ;
	}
#Standardised Precipitation Evapotranspiration Index (SPEI)
'Standardised Precipitation Evapotranspiration Index (SPEI)' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 1 ;
	}
#Standardised Streamflow Index (SSFI)
'Standardised Streamflow Index (SSFI)' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 2 ;
	}
#Standardised Reservoir Supply Index (SRSI)
'Standardised Reservoir Supply Index (SRSI)' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 3 ;
	}
#Standardised Water-level Index (SWI)
'Standardised Water-level Index (SWI)' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 4 ;
	}
#Standardised Snowmelt and Rain Index (SMRI)
'Standardised Snowmelt and Rain Index (SMRI)' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 5 ;
	}
#Streamflow Drought Index (SDI)
'Streamflow Drought Index (SDI)' = {
	 discipline = 0 ;
	 parameterCategory = 22 ;
	 parameterNumber = 6 ;
	}
#Volumetric soil moisture top 20 cm
'Volumetric soil moisture top 20 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Volumetric soil moisture top 100 cm
'Volumetric soil moisture top 100 cm' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 1 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Surface photosynthetically active radiation flux, clear sky
'Surface photosynthetically active radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface direct normal short-wave radiation flux
'Surface direct normal short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 54 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Instantaneous magnitude of turbulent surface stress
'Instantaneous magnitude of turbulent surface stress' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous boundary layer dissipation
'Instantaneous boundary layer dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	}
#Top net short-wave radiation flux
'Top net short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Top net long-wave radiation flux
'Top net long-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Instantaneous gravity wave dissipation
'Instantaneous gravity wave dissipation' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	}
#Top net short-wave radiation flux, clear sky
'Top net short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Top net long-wave radiation flux, clear sky
'Top net long-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Top downward short-wave radiation flux
'Top downward short-wave radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	}
#Surface direct short-wave radiation flux, clear sky
'Surface direct short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous eastward turbulent surface stress due to orographic form drag
'Instantaneous eastward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 64 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous northward turbulent surface stress due to orographic form drag
'Instantaneous northward turbulent surface stress due to orographic form drag' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 65 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous eastward turbulent surface stress due to surface roughness
'Instantaneous eastward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Instantaneous northward turbulent surface stress due to surface roughness
'Instantaneous northward turbulent surface stress due to surface roughness' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 67 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Time-severity precipitation type
'Time-severity precipitation type' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 100 ;
	}
#Time-mode precipitation type
'Time-mode precipitation type' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	 typeOfStatisticalProcessing = 101 ;
	}
#Land surface heat net flux
'Land surface heat net flux' = {
	 discipline = 2 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Surface direct normal short-wave radiation flux, clear sky
'Surface direct normal short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 62 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#10 metre convective gust
'10 metre convective gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 68 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#10 metre turbulent gust
'10 metre turbulent gust' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 69 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Reciprocal Obukhov length
'Reciprocal Obukhov length' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 22 ;
	}
#Precipitation rate from radar
'Precipitation rate from radar' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 17 ;
	}
#Radar data quality index
'Radar data quality index' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 18 ;
	}
#Radar data quality flag
'Radar data quality flag' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 19 ;
	}
#Precipitation rate from forecasted radar imagery
'Precipitation rate from forecasted radar imagery' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 6 ;
	}
#Precipitation from forecasted radar imagery
'Precipitation from forecasted radar imagery' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface diffuse short-wave radiation flux, clear sky
'Surface diffuse short-wave radiation flux, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 63 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Universal thermal climate index
'Universal thermal climate index' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Mean radiant temperature
'Mean radiant temperature' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Fraction of Malaria cases
'Fraction of Malaria cases' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}
#Malaria circumsporozoite protein ratio
'Malaria circumsporozoite protein ratio' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}
#Plasmodium falciparum entomological inoculation rate
'Plasmodium falciparum entomological inoculation rate' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}
#Human bite rate by anopheles vectors
'Human bite rate by anopheles vectors' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}
#Malaria immunity ratio
'Malaria immunity ratio' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}
#Falciparum parasite ratio
'Falciparum parasite ratio' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}
#Detectable falciparum parasite ratio (after day 10)
'Detectable falciparum parasite ratio (after day 10)' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 6 ;
	}
#Anopheles vector to host ratio
'Anopheles vector to host ratio' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}
#Anopheles vector density
'Anopheles vector density' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 8 ;
	}
#Fraction of malarial vector reproductive habitat
'Fraction of malarial vector reproductive habitat' = {
	 discipline = 20 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}
#Population density
'Population density' = {
	 discipline = 20 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}
#Wet bulb globe temperature
'Wet bulb globe temperature' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Globe temperature
'Globe temperature' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Humidex
'Humidex' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}
#Effective temperature
'Effective temperature' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Normal effective temperature
'Normal effective temperature' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Standard effective temperature
'Standard effective temperature' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Physiological equivalent temperature
'Physiological equivalent temperature' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Saturation water vapour pressure
'Saturation water vapour pressure' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 32 ;
	}
#Wet-bulb potential temperature
'Wet-bulb potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	}
#Wet-bulb temperature
'Wet-bulb temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}
#Excess heat factor
'Excess heat factor' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}
#Excess cold factor
'Excess cold factor' = {
	 discipline = 20 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Sea ice thickness
'Sea ice thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}
#Sea ice area fraction
'Sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Eastward sea ice velocity
'Eastward sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Northward sea ice velocity
'Northward sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice albedo
'Sea ice albedo' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice surface temperature
'Sea ice surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice growth
'Sea ice growth' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice volume per unit area
'Sea ice volume per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Snow volume over sea ice per unit area
'Snow volume over sea ice per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Vertically averaged sea ice temperature
'Vertically averaged sea ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Snow temperature over sea ice
'Snow temperature over sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice temperature at the sea ice and snow interface
'Sea ice temperature at the sea ice and snow interface' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 175 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Underside ice temperature
'Underside ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 176 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice heat content
'Sea ice heat content' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Snow heat content over sea ice
'Snow heat content over sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice freeboard thickness
'Sea ice freeboard thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Sea ice melt pond fraction
'Sea ice melt pond fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice melt pond depth
'Sea ice melt pond depth' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice melt pond volume per unit area
'Sea ice melt pond volume per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice fraction tendency due to parameterization
'Sea ice fraction tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#X-component of sea ice velocity
'X-component of sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Y-component of sea ice velocity
'Y-component of sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea ice temperature
'Sea ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}
#Sea ice breakup memory
'Sea ice breakup memory' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	}
#Sea surface practical salinity
'Sea surface practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}
#Sea surface temperature
'Sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Depth of 14 C isotherm
'Depth of 14 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 28715 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Depth of 17 C isotherm
'Depth of 17 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29015 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Depth of 20 C isotherm
'Depth of 20 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Depth of 26 C isotherm
'Depth of 26 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29915 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Depth of 28 C isotherm
'Depth of 28 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 30115 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Barotropic stream function
'Barotropic stream function' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Surface downward heat flux
'Surface downward heat flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}
#Northward surface stress
'Northward surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	}
#Eastward surface stress
'Eastward surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}
#Y-component of surface stress
'Y-component of surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#X-component of surface stress
'X-component of surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by sigma theta 0.01 kg m-3
'Ocean mixed layer depth defined by sigma theta 0.01 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by sigma theta 0.03 kg m-3
'Ocean mixed layer depth defined by sigma theta 0.03 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 3 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by sigma theta 0.125 kg m-3
'Ocean mixed layer depth defined by sigma theta 0.125 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 125 ;
	 scaleFactorOfFirstFixedSurface = 3 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by temperature 0.2 C
'Ocean mixed layer depth defined by temperature 0.2 C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Ocean mixed layer depth defined by temperature 0.5 C
'Ocean mixed layer depth defined by temperature 0.5 C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Average sea water practical salinity in the upper 300 m
'Average sea water practical salinity in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Average sea water practical salinity in the upper 700 m
'Average sea water practical salinity in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Total column average sea water practical salinity
'Total column average sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Vertically-integrated heat content in the upper 300 m
'Vertically-integrated heat content in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Vertically-integrated heat content in the upper 700 m
'Vertically-integrated heat content in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Total column of heat content
'Total column of heat content' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea surface height
'Sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}
#Steric change in sea surface height
'Steric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Halosteric change in sea surface height
'Halosteric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Thermosteric change in sea surface height
'Thermosteric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Thermocline depth
'Thermocline depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Bottom pressure equivalent height
'Bottom pressure equivalent height' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Net surface upward water flux
'Net surface upward water flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Fresh water flux into sea water (from rivers)
'Fresh water flux into sea water (from rivers)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Virtual salt flux into sea water
'Virtual salt flux into sea water' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 32 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Heat flux correction
'Heat flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Fresh water flux correction
'Fresh water flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 31 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Virtual salt flux correction
'Virtual salt flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 33 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Turbocline depth (kz=5e-4)
'Turbocline depth (kz=5e-4)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 171 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 4 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Y-component of surface sea water velocity
'Y-component of surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#X-component of surface sea water velocity
'X-component of surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Northward surface sea water velocity
'Northward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}
#Eastward surface sea water velocity
'Eastward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}
#Heat Content surface to 26C isotherm
'Heat Content surface to 26C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 29915 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	}
#Sea surface height tendency due to parameterization
'Sea surface height tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea surface height with inverse barometer correction
'Sea surface height with inverse barometer correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	}
#Average sea water potential temperature in the upper 300m
'Average sea water potential temperature in the upper 300m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Sea surface salinity
'Sea surface salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	}
#Vertically integrated sea water practical salinity in the upper 300 m
'Vertically integrated sea water practical salinity in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Vertically integrated sea water practical salinity in the upper 700 m
'Vertically integrated sea water practical salinity in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	}
#Total column vertically integrated sea water practical salinity
'Total column vertically integrated sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea surface downward short-wave radiation flux
'Sea surface downward short-wave radiation flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	}
#Sea water practical salinity
'Sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water potential temperature
'Sea water potential temperature' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water sigma theta
'Sea water sigma theta' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Y-component of sea water velocity
'Y-component of sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#X-component of sea water velocity
'X-component of sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Northward sea water velocity
'Northward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Eastward sea water velocity
'Eastward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Upward sea water velocity
'Upward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Sea water potential temperature tendency due to newtonian relaxation
'Sea water potential temperature tendency due to newtonian relaxation' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water salinity tendency due to newtonian relaxation
'Sea water salinity tendency due to newtonian relaxation' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water temperature tendency due to parameterization
'Sea water temperature tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water salinity tendency due to parameterization
'Sea water salinity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Eastward sea water velocity tendency due to parameterization
'Eastward sea water velocity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 38 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Northward sea water velocity tendency due to parameterization
'Northward sea water velocity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water temperature tendency due to direct bias correction
'Sea water temperature tendency due to direct bias correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water salinity tendency due to direct bias correction
'Sea water salinity tendency due to direct bias correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water salinity
'Sea water salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Northward mass transport
'Northward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Eastward mass transport
'Eastward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water depth
'Sea water depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water upward mass transport
'Sea water upward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water age since surface contact
'Sea water age since surface contact' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Sea water downward short-wave radiation flux
'Sea water downward short-wave radiation flux' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	}
#Net short wave radiation rate at sea surface
'Net short wave radiation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Wind stress at sea surface
'Wind stress at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 49 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Wind speed at 10m above sea surface
'Wind speed at 10m above sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Neutral drag coefficient at 10m above sea surface
'Neutral drag coefficient at 10m above sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Total precipitation rate at sea surface
'Total precipitation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Snow precipitation rate at sea surface
'Snow precipitation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Eastward component of wind stress over sea ice
'Eastward component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Northward component of wind stress over sea ice
'Northward component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#U-component of wind stress over sea ice
'U-component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#V-component of wind stress over sea ice
'V-component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Time-mean sea ice thickness
'Time-mean sea ice thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice area fraction
'Time-mean sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward sea ice velocity
'Time-mean eastward sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward sea ice velocity
'Time-mean northward sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice albedo
'Time-mean sea ice albedo' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice surface temperature
'Time-mean sea ice surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice growth
'Time-mean sea ice growth' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice volume per unit area
'Time-mean sea ice volume per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow volume over sea ice per unit area
'Time-mean snow volume over sea ice per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertically averaged sea ice temperature
'Time-mean vertically averaged sea ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow temperature over sea ice
'Time-mean snow temperature over sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice temperature at the sea ice and snow interface
'Time-mean sea ice temperature at the sea ice and snow interface' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 175 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean underside ice temperature
'Time-mean underside ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 176 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice heat content
'Time-mean sea ice heat content' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow heat content over sea ice
'Time-mean snow heat content over sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice freeboard thickness
'Time-mean sea ice freeboard thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice melt pond fraction
'Time-mean sea ice melt pond fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice melt pond depth
'Time-mean sea ice melt pond depth' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice melt pond volume per unit area
'Time-mean sea ice melt pond volume per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice fraction tendency due to parameterization
'Time-mean sea ice fraction tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean X-component of sea ice velocity
'Time-mean X-component of sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Y-component of sea ice velocity
'Time-mean Y-component of sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice temperature
'Time-mean sea ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea ice breakup memory
'Time-mean sea ice breakup memory' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface practical salinity
'Time-mean sea surface practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface temperature
'Time-mean sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth of 14 C isotherm
'Time-mean depth of 14 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 28715 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth of 17 C isotherm
'Time-mean depth of 17 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29015 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth of 20 C isotherm
'Time-mean depth of 20 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth of 26 C isotherm
'Time-mean depth of 26 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29915 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean depth of 28 C isotherm
'Time-mean depth of 28 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 30115 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean barotropic stream function
'Time-mean barotropic stream function' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean surface downward heat flux
'Time-mean surface downward heat flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward surface stress
'Time-mean northward surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward surface stress
'Time-mean eastward surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time mean Y-component of surface stress
'Time mean Y-component of surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean X-component of surface stress
'Time-mean X-component of surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ocean mixed layer depth defined by sigma theta 0.01 kg m-3
'Time-mean ocean mixed layer depth defined by sigma theta 0.01 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ocean mixed layer depth defined by sigma theta 0.03 kg m-3
'Time-mean ocean mixed layer depth defined by sigma theta 0.03 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 3 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ocean mixed layer depth defined by sigma theta 0.125 kg m-3
'Time-mean ocean mixed layer depth defined by sigma theta 0.125 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 125 ;
	 scaleFactorOfFirstFixedSurface = 3 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ocean mixed layer depth defined by temperature 0.2 C
'Time-mean ocean mixed layer depth defined by temperature 0.2 C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean ocean mixed layer depth defined by temperature 0.5 C
'Time-mean ocean mixed layer depth defined by temperature 0.5 C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean average sea water practical salinity in the upper 300 m
'Time-mean average sea water practical salinity in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean average sea water practical salinity in the upper 700 m
'Time-mean average sea water practical salinity in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column average sea water practical salinity
'Time-mean total column average sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertically-integrated heat content in the upper 300 m
'Time-mean vertically-integrated heat content in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertically-integrated heat content in the upper 700 m
'Time-mean vertically-integrated heat content in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column heat content
'Time-mean total column heat content' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface height
'Time-mean sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean steric change in sea surface height
'Time-mean steric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean halosteric change in sea surface height
'Time-mean halosteric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean thermosteric change in sea surface height
'Time-mean thermosteric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean thermocline depth
'Time-mean thermocline depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean bottom pressure equivalent height
'Time-mean bottom pressure equivalent height' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean net surface upward water flux
'Time-mean net surface upward water flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean fresh water flux into sea water (from rivers)
'Time-mean fresh water flux into sea water (from rivers)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean virtual salt flux into sea water
'Time-mean virtual salt flux into sea water' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 32 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean heat flux correction
'Time-mean heat flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean fresh water flux correction
'Time-mean fresh water flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 31 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean virtual salt flux correction
'Time-mean virtual salt flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 33 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean turbocline depth (kz=5e-4)
'Time-mean turbocline depth (kz=5e-4)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 171 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 4 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Y-component of surface sea water velocity
'Time-mean Y-component of surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean X-component of surface sea water velocity
'Time-mean X-component of surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward surface sea water velocity
'Time-mean northward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward surface sea water velocity
'Time-mean eastward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean heat content surface to 26C isotherm
'Time-mean heat content surface to 26C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 29915 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface height tendency due to parameterization
'Time-mean sea surface height tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface height with inverse barometer correction
'Time-mean sea surface height with inverse barometer correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean average sea water potential temperature in the upper 300m
'Time-mean average sea water potential temperature in the upper 300m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface salinity
'Time-mean sea surface salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertically integrated sea water practical salinity in the upper 300 m
'Time-mean vertically integrated sea water practical salinity in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean vertically integrated sea water practical salinity in the upper 700 m
'Time-mean vertically integrated sea water practical salinity in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total column vertically integrated sea water practical salinity
'Time-mean total column vertically integrated sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea surface downward short-wave radiation flux
'Time-mean sea surface downward short-wave radiation flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water practical salinity
'Time-mean sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water potential temperature
'Time-mean sea water potential temperature' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water sigma theta
'Time-mean sea water sigma theta' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean Y-component of sea water velocity
'Time-mean Y-component of sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean X-component of sea water velocity
'Time-mean X-component of sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward sea water velocity
'Time-mean northward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward sea water velocity
'Time-mean eastward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean upward sea water velocity
'Time-mean upward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water potential temperature tendency due to newtonian relaxation
'Time-mean sea water potential temperature tendency due to newtonian relaxation' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water salinity tendency due to newtonian relaxation
'Time-mean sea water salinity tendency due to newtonian relaxation' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water temperature tendency due to parameterization
'Time-mean sea water temperature tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water salinity tendency due to parameterization
'Time-mean sea water salinity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward sea water velocity tendency due to parameterization
'Time-mean eastward sea water velocity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 38 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward sea water velocity tendency due to parameterization
'Time-mean northward sea water velocity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water temperature tendency due to direct bias correction
'Time-mean sea water temperature tendency due to direct bias correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water salinity tendency due to direct bias correction
'Time-mean sea water salinity tendency due to direct bias correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water salinity
'Time-mean sea water salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward mass transport
'Time-mean northward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward mass transport
'Time-mean eastward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water depth
'Time-mean sea water depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water upward mass transport
'Time-mean sea water upward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water age since surface contact
'Time-mean sea water age since surface contact' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean sea water downward short-wave radiation flux
'Time-mean sea water downward short-wave radiation flux' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean net short wave radiation rate at sea surface
'Time-mean net short wave radiation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wind stress at sea surface
'Time-mean wind stress at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 49 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean wind speed at 10m above sea surface
'Time-mean wind speed at 10m above sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean neutral drag coefficient at 10m above sea surface
'Time-mean neutral drag coefficient at 10m above sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean total precipitation rate at sea surface
'Time-mean total precipitation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean snow precipitation rate at sea surface
'Time-mean snow precipitation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean eastward component of wind stress over sea ice
'Time-mean eastward component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean northward component of wind stress over sea ice
'Time-mean northward component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean U-component of wind stress over sea ice
'Time-mean U-component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean V-component of wind stress over sea ice
'Time-mean V-component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-accumulated net short wave radiation at sea surface
'Time-accumulated net short wave radiation at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-accumulated total precipitation at sea surface
'Time-accumulated total precipitation at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-accumulated snow precipitation at sea surface
'Time-accumulated snow precipitation at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-maximum sea ice thickness
'Time-maximum sea ice thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice area fraction
'Time-maximum sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward sea ice velocity
'Time-maximum eastward sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward sea ice velocity
'Time-maximum northward sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice albedo
'Time-maximum sea ice albedo' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice surface temperature
'Time-maximum sea ice surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice growth
'Time-maximum sea ice growth' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice volume per unit area
'Time-maximum sea ice volume per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow volume over sea ice per unit area
'Time-maximum snow volume over sea ice per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vertically averaged sea ice temperature
'Time-maximum vertically averaged sea ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow temperature over sea ice
'Time-maximum snow temperature over sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice temperature at the sea ice and snow interface
'Time-maximum sea ice temperature at the sea ice and snow interface' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 175 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum underside ice temperature
'Time-maximum underside ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 176 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice heat content
'Time-maximum sea ice heat content' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow heat content over sea ice
'Time-maximum snow heat content over sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice freeboard thickness
'Time-maximum sea ice freeboard thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice melt pond fraction
'Time-maximum sea ice melt pond fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice melt pond depth
'Time-maximum sea ice melt pond depth' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice melt pond volume per unit area
'Time-maximum sea ice melt pond volume per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice fraction tendency due to parameterization
'Time-maximum sea ice fraction tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum X-component of sea ice velocity
'Time-maximum X-component of sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum Y-component of sea ice velocity
'Time-maximum Y-component of sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice temperature
'Time-maximum sea ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea ice breakup memory
'Time-maximum sea ice breakup memory' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea surface practical salinity
'Time-maximum sea surface practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea surface temperature
'Time-maximum sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum depth of 14 C isotherm
'Time-maximum depth of 14 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 28715 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum depth of 17 C isotherm
'Time-maximum depth of 17 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29015 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum depth of 20 C isotherm
'Time-maximum depth of 20 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum depth of 26 C isotherm
'Time-maximum depth of 26 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29915 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum depth of 28 C isotherm
'Time-maximum depth of 28 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 30115 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum barotropic stream function
'Time-maximum barotropic stream function' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum surface downward heat flux
'Time-maximum surface downward heat flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward surface stress
'Time-maximum northward surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward surface stress
'Time-maximum eastward surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum Y-component of surface stress
'Time-maximum Y-component of surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum X-component of surface stress
'Time-maximum X-component of surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ocean mixed layer depth defined by sigma theta 0.01 kg m-3
'Time-maximum ocean mixed layer depth defined by sigma theta 0.01 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ocean mixed layer depth defined by sigma theta 0.03 kg m-3
'Time-maximum ocean mixed layer depth defined by sigma theta 0.03 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 3 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ocean mixed layer depth defined by sigma theta 0.125 kg m-3
'Time-maximum ocean mixed layer depth defined by sigma theta 0.125 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 125 ;
	 scaleFactorOfFirstFixedSurface = 3 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ocean mixed layer depth defined by temperature 0.2 C
'Time-maximum ocean mixed layer depth defined by temperature 0.2 C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum ocean mixed layer depth defined by temperature 0.5 C
'Time-maximum ocean mixed layer depth defined by temperature 0.5 C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum average sea water practical salinity in the upper 300 m
'Time-maximum average sea water practical salinity in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum average sea water practical salinity in the upper 700 m
'Time-maximum average sea water practical salinity in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column average sea water practical salinity
'Time-maximum total column average sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vertically-integrated heat content in the upper 300 m
'Time-maximum vertically-integrated heat content in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vertically-integrated heat content in the upper 700 m
'Time-maximum vertically-integrated heat content in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column of heat content
'Time-maximum total column of heat content' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea surface height
'Time-maximum sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum steric change in sea surface height
'Time-maximum steric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum halosteric change in sea surface height
'Time-maximum halosteric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum thermosteric change in sea surface height
'Time-maximum thermosteric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum thermocline depth
'Time-maximum thermocline depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum bottom pressure equivalent height
'Time-maximum bottom pressure equivalent height' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum net surface upward water flux
'Time-maximum net surface upward water flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum fresh water flux into sea water (from rivers)
'Time-maximum fresh water flux into sea water (from rivers)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum virtual salt flux into sea water
'Time-maximum virtual salt flux into sea water' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 32 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum heat flux correction
'Time-maximum heat flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum fresh water flux correction
'Time-maximum fresh water flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 31 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum virtual salt flux correction
'Time-maximum virtual salt flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 33 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum turbocline depth (kz=5e-4)
'Time-maximum turbocline depth (kz=5e-4)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 171 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 4 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum Y-component of surface sea water velocity
'Time-maximum Y-component of surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum X-component of surface sea water velocity
'Time-maximum X-component of surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward surface sea water velocity
'Time-maximum northward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward surface sea water velocity
'Time-maximum eastward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum heat content surface to 26C isotherm
'Time-maximum heat content surface to 26C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 29915 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea surface height tendency due to parameterization
'Time-maximum sea surface height tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea surface height with inverse barometer correction
'Time-maximum sea surface height with inverse barometer correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum average sea water potential temperature in the upper 300m
'Time-maximum average sea water potential temperature in the upper 300m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea surface salinity
'Time-maximum sea surface salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vertically integrated sea water practical salinity in the upper 300 m
'Time-maximum vertically integrated sea water practical salinity in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum vertically integrated sea water practical salinity in the upper 700 m
'Time-maximum vertically integrated sea water practical salinity in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total column vertically integrated sea water practical salinity
'Time-maximum total column vertically integrated sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea surface downward short-wave radiation flux
'Time-maximum sea surface downward short-wave radiation flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water practical salinity
'Time-maximum sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water potential temperature
'Time-maximum sea water potential temperature' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water sigma theta
'Time-maximum sea water sigma theta' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum Y-component of sea water velocity
'Time-maximum Y-component of sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum X-component of sea water velocity
'Time-maximum X-component of sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward sea water velocity
'Time-maximum northward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward sea water velocity
'Time-maximum eastward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum upward sea water velocity
'Time-maximum upward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water potential temperature tendency due to newtonian relaxation
'Time-maximum sea water potential temperature tendency due to newtonian relaxation' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water salinity tendency due to newtonian relaxation
'Time-maximum sea water salinity tendency due to newtonian relaxation' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water temperature tendency due to parameterization
'Time-maximum sea water temperature tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water salinity tendency due to parameterization
'Time-maximum sea water salinity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward sea water velocity tendency due to parameterization
'Time-maximum eastward sea water velocity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 38 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward sea water velocity tendency due to parameterization
'Time-maximum northward sea water velocity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water temperature tendency due to direct bias correction
'Time-maximum sea water temperature tendency due to direct bias correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water salinity tendency due to direct bias correction
'Time-maximum sea water salinity tendency due to direct bias correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water salinity
'Time-maximum sea water salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward mass transport
'Time-maximum northward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward mass transport
'Time-maximum eastward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water depth
'Time-maximum sea water depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water upward mass transport
'Time-maximum sea water upward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water age since surface contact
'Time-maximum sea water age since surface contact' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum sea water downward short-wave radiation flux
'Time-maximum sea water downward short-wave radiation flux' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum net short wave radiation rate at sea surface
'Time-maximum net short wave radiation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wind stress at sea surface
'Time-maximum wind stress at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 49 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum wind speed at 10m above sea surface
'Time-maximum wind speed at 10m above sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum neutral drag coefficient at 10m above sea surface
'Time-maximum neutral drag coefficient at 10m above sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum total precipitation rate at sea surface
'Time-maximum total precipitation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum snow precipitation rate at sea surface
'Time-maximum snow precipitation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum eastward component of wind stress over sea ice
'Time-maximum eastward component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum northward component of wind stress over sea ice
'Time-maximum northward component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum U-component of wind stress over sea ice
'Time-maximum U-component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-maximum V-component of wind stress over sea ice
'Time-maximum V-component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 2 ;
	}
#Time-minimum sea ice thickness
'Time-minimum sea ice thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice area fraction
'Time-minimum sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward sea ice velocity
'Time-minimum eastward sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward sea ice velocity
'Time-minimum northward sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice albedo
'Time-minimum sea ice albedo' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice surface temperature
'Time-minimum sea ice surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice growth
'Time-minimum sea ice growth' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice volume per unit area
'Time-minimum sea ice volume per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snow volume over sea ice per unit area
'Time-minimum snow volume over sea ice per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically averaged sea ice temperature
'Time-minimum vertically averaged sea ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snow temperature over sea ice
'Time-minimum snow temperature over sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice temperature at the sea ice and snow interface
'Time-minimum sea ice temperature at the sea ice and snow interface' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 175 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum underside ice temperature
'Time-minimum underside ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 176 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice heat content
'Time-minimum sea ice heat content' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snow heat content over sea ice
'Time-minimum snow heat content over sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice freeboard thickness
'Time-minimum sea ice freeboard thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice melt pond fraction
'Time-minimum sea ice melt pond fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice melt pond depth
'Time-minimum sea ice melt pond depth' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice melt pond volume per unit area
'Time-minimum sea ice melt pond volume per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice fraction tendency due to parameterization
'Time-minimum sea ice fraction tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum X-component of sea ice velocity
'Time-minimum X-component of sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum Y-component of sea ice velocity
'Time-minimum Y-component of sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice temperature
'Time-minimum sea ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea ice breakup memory
'Time-minimum sea ice breakup memory' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea surface practical salinity
'Time-minimum sea surface practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea surface temperature
'Time-minimum sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum depth of 14 C isotherm
'Time-minimum depth of 14 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 28715 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum depth of 17 C isotherm
'Time-minimum depth of 17 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29015 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum depth of 20 C isotherm
'Time-minimum depth of 20 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum depth of 26 C isotherm
'Time-minimum depth of 26 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29915 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum depth of 28 C isotherm
'Time-minimum depth of 28 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 30115 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum barotropic stream function
'Time-minimum barotropic stream function' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum surface downward heat flux
'Time-minimum surface downward heat flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward surface stress
'Time-minimum northward surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward surface stress
'Time-minimum eastward surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum Y-component of surface stress
'Time-minimum Y-component of surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum X-component of surface stress
'Time-minimum X-component of surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ocean mixed layer depth defined by sigma theta 0.01 kg m-3
'Time-minimum ocean mixed layer depth defined by sigma theta 0.01 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ocean mixed layer depth defined by sigma theta 0.03 kg m-3
'Time-minimum ocean mixed layer depth defined by sigma theta 0.03 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 3 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ocean mixed layer depth defined by sigma theta 0.125 kg m-3
'Time-minimum ocean mixed layer depth defined by sigma theta 0.125 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 125 ;
	 scaleFactorOfFirstFixedSurface = 3 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ocean mixed layer depth defined by temperature 0.2 C
'Time-minimum ocean mixed layer depth defined by temperature 0.2 C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum ocean mixed layer depth defined by temperature 0.5 C
'Time-minimum ocean mixed layer depth defined by temperature 0.5 C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum average sea water practical salinity in the upper 300 m
'Time-minimum average sea water practical salinity in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum average sea water practical salinity in the upper 700 m
'Time-minimum average sea water practical salinity in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column average sea water practical salinity
'Time-minimum total column average sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically-integrated heat content in the upper 300 m
'Time-minimum vertically-integrated heat content in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically-integrated heat content in the upper 700 m
'Time-minimum vertically-integrated heat content in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column of heat content
'Time-minimum total column of heat content' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea surface height
'Time-minimum sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum steric change in sea surface height
'Time-minimum steric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum halosteric change in sea surface height
'Time-minimum halosteric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum thermosteric change in sea surface height
'Time-minimum thermosteric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum thermocline depth
'Time-minimum thermocline depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum bottom pressure equivalent height
'Time-minimum bottom pressure equivalent height' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum net surface upward water flux
'Time-minimum net surface upward water flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum fresh water flux into sea water (from rivers)
'Time-minimum fresh water flux into sea water (from rivers)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum virtual salt flux into sea water
'Time-minimum virtual salt flux into sea water' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 32 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum heat flux correction
'Time-minimum heat flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum fresh water flux correction
'Time-minimum fresh water flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 31 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum virtual salt flux correction
'Time-minimum virtual salt flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 33 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum turbocline depth (kz=5e-4)
'Time-minimum turbocline depth (kz=5e-4)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 171 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 4 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum Y-component of surface sea water velocity
'Time-minimum Y-component of surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum X-component of surface sea water velocity
'Time-minimum X-component of surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward surface sea water velocity
'Time-minimum northward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward surface sea water velocity
'Time-minimum eastward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum heat content surface to 26C isotherm
'Time-minimum heat content surface to 26C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 29915 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea surface height tendency due to parameterization
'Time-minimum sea surface height tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea surface height with inverse barometer correction
'Time-minimum sea surface height with inverse barometer correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum average sea water potential temperature in the upper 300m
'Time-minimum average sea water potential temperature in the upper 300m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea surface salinity
'Time-minimum sea surface salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated sea water practical salinity in the upper 300 m
'Time-minimum vertically integrated sea water practical salinity in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum vertically integrated sea water practical salinity in the upper 700 m
'Time-minimum vertically integrated sea water practical salinity in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total column vertically integrated sea water practical salinity
'Time-minimum total column vertically integrated sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea surface downward short-wave radiation flux
'Time-minimum sea surface downward short-wave radiation flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water practical salinity
'Time-minimum sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water potential temperature
'Time-minimum sea water potential temperature' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water sigma theta
'Time-minimum sea water sigma theta' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum Y-component of sea water velocity
'Time-minimum Y-component of sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum X-component of sea water velocity
'Time-minimum X-component of sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward sea water velocity
'Time-minimum northward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward sea water velocity
'Time-minimum eastward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum upward sea water velocity
'Time-minimum upward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water potential temperature tendency due to newtonian relaxation
'Time-minimum sea water potential temperature tendency due to newtonian relaxation' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water salinity tendency due to newtonian relaxation
'Time-minimum sea water salinity tendency due to newtonian relaxation' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water temperature tendency due to parameterization
'Time-minimum sea water temperature tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water salinity tendency due to parameterization
'Time-minimum sea water salinity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward sea water velocity tendency due to parameterization
'Time-minimum eastward sea water velocity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 38 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward sea water velocity tendency due to parameterization
'Time-minimum northward sea water velocity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water temperature tendency due to direct bias correction
'Time-minimum sea water temperature tendency due to direct bias correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water salinity tendency due to direct bias correction
'Time-minimum sea water salinity tendency due to direct bias correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water salinity
'Time-minimum sea water salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward mass transport
'Time-minimum northward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward mass transport
'Time-minimum eastward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water depth
'Time-minimum sea water depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water upward mass transport
'Time-minimum sea water upward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water age since surface contact
'Time-minimum sea water age since surface contact' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum sea water downward short-wave radiation flux
'Time-minimum sea water downward short-wave radiation flux' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum net short wave radiation rate at sea surface
'Time-minimum net short wave radiation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wind stress at sea surface
'Time-minimum wind stress at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 49 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum wind speed at 10m above sea surface
'Time-minimum wind speed at 10m above sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum neutral drag coefficient at 10m above sea surface
'Time-minimum neutral drag coefficient at 10m above sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum total precipitation rate at sea surface
'Time-minimum total precipitation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum snow precipitation rate at sea surface
'Time-minimum snow precipitation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum eastward component of wind stress over sea ice
'Time-minimum eastward component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum northward component of wind stress over sea ice
'Time-minimum northward component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum U-component of wind stress over sea ice
'Time-minimum U-component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-minimum V-component of wind stress over sea ice
'Time-minimum V-component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 3 ;
	}
#Time-standard-deviation sea ice thickness
'Time-standard-deviation sea ice thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice area fraction
'Time-standard-deviation sea ice area fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward sea ice velocity
'Time-standard-deviation eastward sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward sea ice velocity
'Time-standard-deviation northward sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice albedo
'Time-standard-deviation sea ice albedo' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice surface temperature
'Time-standard-deviation sea ice surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice growth
'Time-standard-deviation sea ice growth' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice volume per unit area
'Time-standard-deviation sea ice volume per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snow volume over sea ice per unit area
'Time-standard-deviation snow volume over sea ice per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically averaged sea ice temperature
'Time-standard-deviation vertically averaged sea ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snow temperature over sea ice
'Time-standard-deviation snow temperature over sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice temperature at the sea ice and snow interface
'Time-standard-deviation sea ice temperature at the sea ice and snow interface' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 175 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation underside ice temperature
'Time-standard-deviation underside ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 176 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice heat content
'Time-standard-deviation sea ice heat content' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snow heat content over sea ice
'Time-standard-deviation snow heat content over sea ice' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 173 ;
	 typeOfSecondFixedSurface = 175 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice freeboard thickness
'Time-standard-deviation sea ice freeboard thickness' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = 0 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice melt pond fraction
'Time-standard-deviation sea ice melt pond fraction' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice melt pond depth
'Time-standard-deviation sea ice melt pond depth' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice melt pond volume per unit area
'Time-standard-deviation sea ice melt pond volume per unit area' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 188 ;
	 typeOfSecondFixedSurface = 189 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice fraction tendency due to parameterization
'Time-standard-deviation sea ice fraction tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation X-component of sea ice velocity
'Time-standard-deviation X-component of sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation Y-component of sea ice velocity
'Time-standard-deviation Y-component of sea ice velocity' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice temperature
'Time-standard-deviation sea ice temperature' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea ice breakup memory
'Time-standard-deviation sea ice breakup memory' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea surface practical salinity
'Time-standard-deviation sea surface practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea surface temperature
'Time-standard-deviation sea surface temperature' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation depth of 14 C isotherm
'Time-standard-deviation depth of 14 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 28715 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation depth of 17 C isotherm
'Time-standard-deviation depth of 17 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29015 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation depth of 20 C isotherm
'Time-standard-deviation depth of 20 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29315 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation depth of 26 C isotherm
'Time-standard-deviation depth of 26 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 29915 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation depth of 28 C isotherm
'Time-standard-deviation depth of 28 C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 20 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 30115 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation barotropic stream function
'Time-standard-deviation barotropic stream function' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation surface downward heat flux
'Time-standard-deviation surface downward heat flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward surface stress
'Time-standard-deviation northward surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward surface stress
'Time-standard-deviation eastward surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation Y-component of surface stress
'Time-standard-deviation Y-component of surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation X-component of surface stress
'Time-standard-deviation X-component of surface stress' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ocean mixed layer depth defined by sigma theta 0.01 kg m-3
'Time-standard-deviation ocean mixed layer depth defined by sigma theta 0.01 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ocean mixed layer depth defined by sigma theta 0.03 kg m-3
'Time-standard-deviation ocean mixed layer depth defined by sigma theta 0.03 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 3 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ocean mixed layer depth defined by sigma theta 0.125 kg m-3
'Time-standard-deviation ocean mixed layer depth defined by sigma theta 0.125 kg m-3' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 169 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 125 ;
	 scaleFactorOfFirstFixedSurface = 3 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ocean mixed layer depth defined by temperature 0.2 C
'Time-standard-deviation ocean mixed layer depth defined by temperature 0.2 C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation ocean mixed layer depth defined by temperature 0.5 C
'Time-standard-deviation ocean mixed layer depth defined by temperature 0.5 C' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 170 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation average sea water practical salinity in the upper 300 m
'Time-standard-deviation average sea water practical salinity in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation average sea water practical salinity in the upper 700 m
'Time-standard-deviation average sea water practical salinity in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column average sea water practical salinity
'Time-standard-deviation total column average sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically-integrated heat content in the upper 300 m
'Time-standard-deviation vertically-integrated heat content in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically-integrated heat content in the upper 700 m
'Time-standard-deviation vertically-integrated heat content in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column of heat content
'Time-standard-deviation total column of heat content' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea surface height
'Time-standard-deviation sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation steric change in sea surface height
'Time-standard-deviation steric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation halosteric change in sea surface height
'Time-standard-deviation halosteric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation thermosteric change in sea surface height
'Time-standard-deviation thermosteric change in sea surface height' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation thermocline depth
'Time-standard-deviation thermocline depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation bottom pressure equivalent height
'Time-standard-deviation bottom pressure equivalent height' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation net surface upward water flux
'Time-standard-deviation net surface upward water flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation fresh water flux into sea water (from rivers)
'Time-standard-deviation fresh water flux into sea water (from rivers)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 30 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation virtual salt flux into sea water
'Time-standard-deviation virtual salt flux into sea water' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 32 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation heat flux correction
'Time-standard-deviation heat flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation fresh water flux correction
'Time-standard-deviation fresh water flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 31 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation virtual salt flux correction
'Time-standard-deviation virtual salt flux correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 33 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation turbocline depth (kz=5e-4)
'Time-standard-deviation turbocline depth (kz=5e-4)' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 171 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 5 ;
	 scaleFactorOfFirstFixedSurface = 4 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation Y-component of surface sea water velocity
'Time-standard-deviation Y-component of surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation X-component of surface sea water velocity
'Time-standard-deviation X-component of surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward surface sea water velocity
'Time-standard-deviation northward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward surface sea water velocity
'Time-standard-deviation eastward surface sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation heat content surface to 26C isotherm
'Time-standard-deviation heat content surface to 26C isotherm' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 20 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 29915 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea surface height tendency due to parameterization
'Time-standard-deviation sea surface height tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea surface height with inverse barometer correction
'Time-standard-deviation sea surface height with inverse barometer correction' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation average sea water potential temperature in the upper 300m
'Time-standard-deviation average sea water potential temperature in the upper 300m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea surface salinity
'Time-standard-deviation sea surface salinity' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated sea water practical salinity in the upper 300 m
'Time-standard-deviation vertically integrated sea water practical salinity in the upper 300 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 300 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation vertically integrated sea water practical salinity in the upper 700 m
'Time-standard-deviation vertically integrated sea water practical salinity in the upper 700 m' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 160 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 700 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total column vertically integrated sea water practical salinity
'Time-standard-deviation total column vertically integrated sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 9 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea surface downward short-wave radiation flux
'Time-standard-deviation sea surface downward short-wave radiation flux' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water practical salinity
'Time-standard-deviation sea water practical salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water potential temperature
'Time-standard-deviation sea water potential temperature' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water sigma theta
'Time-standard-deviation sea water sigma theta' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation Y-component of sea water velocity
'Time-standard-deviation Y-component of sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation X-component of sea water velocity
'Time-standard-deviation X-component of sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward sea water velocity
'Time-standard-deviation northward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward sea water velocity
'Time-standard-deviation eastward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation upward sea water velocity
'Time-standard-deviation upward sea water velocity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water potential temperature tendency due to newtonian relaxation
'Time-standard-deviation sea water potential temperature tendency due to newtonian relaxation' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water salinity tendency due to newtonian relaxation
'Time-standard-deviation sea water salinity tendency due to newtonian relaxation' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water temperature tendency due to parameterization
'Time-standard-deviation sea water temperature tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water salinity tendency due to parameterization
'Time-standard-deviation sea water salinity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward sea water velocity tendency due to parameterization
'Time-standard-deviation eastward sea water velocity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 38 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward sea water velocity tendency due to parameterization
'Time-standard-deviation northward sea water velocity tendency due to parameterization' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water temperature tendency due to direct bias correction
'Time-standard-deviation sea water temperature tendency due to direct bias correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water salinity tendency due to direct bias correction
'Time-standard-deviation sea water salinity tendency due to direct bias correction' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water salinity
'Time-standard-deviation sea water salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward mass transport
'Time-standard-deviation northward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 46 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward mass transport
'Time-standard-deviation eastward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 47 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water depth
'Time-standard-deviation sea water depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water upward mass transport
'Time-standard-deviation sea water upward mass transport' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water age since surface contact
'Time-standard-deviation sea water age since surface contact' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation sea water downward short-wave radiation flux
'Time-standard-deviation sea water downward short-wave radiation flux' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 58 ;
	 typeOfFirstFixedSurface = 168 ;
	 typeOfSecondFixedSurface = 168 ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation net short wave radiation rate at sea surface
'Time-standard-deviation net short wave radiation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wind stress at sea surface
'Time-standard-deviation wind stress at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 49 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation wind speed at 10m above sea surface
'Time-standard-deviation wind speed at 10m above sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation neutral drag coefficient at 10m above sea surface
'Time-standard-deviation neutral drag coefficient at 10m above sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	 typeOfFirstFixedSurface = 102 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation total precipitation rate at sea surface
'Time-standard-deviation total precipitation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation snow precipitation rate at sea surface
'Time-standard-deviation snow precipitation rate at sea surface' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfFirstFixedSurface = 160 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation eastward component of wind stress over sea ice
'Time-standard-deviation eastward component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 50 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation northward component of wind stress over sea ice
'Time-standard-deviation northward component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 51 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation U-component of wind stress over sea ice
'Time-standard-deviation U-component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Time-standard-deviation V-component of wind stress over sea ice
'Time-standard-deviation V-component of wind stress over sea ice' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 6 ;
	}
#Virtual temperature
'Virtual temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Pressure tendency
'Pressure tendency' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	}
#ICAO Standard Atmosphere reference height
'ICAO Standard Atmosphere reference height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}
#Geometrical height above ground
'Geometrical height above ground' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	}
#Standard deviation of height
'Standard deviation of height' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}
#Virtual potential temperature
'Virtual potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Pseudo-adiabatic potential temperature
'Pseudo-adiabatic potential temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Dew point temperature
'Dew point temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Lapse rate
'Lapse rate' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Visibility
'Visibility' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	}
#Radar spectra (1)
'Radar spectra (1)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 6 ;
	}
#Radar spectra (2)
'Radar spectra (2)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 7 ;
	}
#Radar spectra (3)
'Radar spectra (3)' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 8 ;
	}
#Parcel lifted index (to 500 hPa)
'Parcel lifted index (to 500 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	}
#Temperature anomaly
'Temperature anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Pressure anomaly
'Pressure anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}
#Geopotential height anomaly
'Geopotential height anomaly' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}
#Wave spectra (1)
'Wave spectra (1)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}
#Wave spectra (2)
'Wave spectra (2)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}
#Wave spectra (3)
'Wave spectra (3)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}
#Wind direction
'Wind direction' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}
#Sigma coordinate vertical velocity
'Sigma coordinate vertical velocity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}
#Absolute vorticity
'Absolute vorticity' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}
#Absolute divergence
'Absolute divergence' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	}
#Vertical u-component shear
'Vertical u-component shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	}
#Vertical v-component shear
'Vertical v-component shear' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	}
#Precipitable water
'Precipitable water' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}
#Saturation deficit
'Saturation deficit' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}
#Precipitation rate
'Precipitation rate' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}
#Thunderstorm probability
'Thunderstorm probability' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 2 ;
	}
#Convective precipitation (water)
'Convective precipitation (water)' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}
#Mixed layer depth
'Mixed layer depth' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	}
#Transient thermocline depth
'Transient thermocline depth' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 2 ;
	}
#Main thermocline anomaly
'Main thermocline anomaly' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}
#Best lifted index (to 500 hPa)
'Best lifted index (to 500 hPa)' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 1 ;
	}
#Soil moisture content
'Soil moisture content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Salinity
'Salinity' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}
#Density
'Density' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}
#Direction of ice drift
'Direction of ice drift' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}
#Speed of ice drift
'Speed of ice drift' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}
#Ice divergence
'Ice divergence' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}
#Snowmelt
'Snowmelt' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Direction of swell waves
'Direction of swell waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}
#Secondary wave direction
'Secondary wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}
#Net short-wave radiation flux (surface)
'Net short-wave radiation flux (surface)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	}
#Global radiation flux
'Global radiation flux' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}
#Radiance (with respect to wave number)
'Radiance (with respect to wave number)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 5 ;
	}
#Radiance (with respect to wave length)
'Radiance (with respect to wave length)' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 6 ;
	}
#Wind mixing energy
'Wind mixing energy' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	}
#Total precipitation less than 0.1 mm
'Total precipitation less than 0.1 mm' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 1 ;
	 scaledValueOfLowerLimit = 1 ;
	 scaleFactorOfLowerLimit = 1 ;
	 probabilityType = 0 ;
	}
#Total precipitation rate less than 1 mm/day
'Total precipitation rate less than 1 mm/day' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	 scaledValueOfLowerLimit = 115741 ;
	 scaleFactorOfLowerLimit = 10 ;
	 probabilityType = 0 ;
	}
#Total precipitation rate of at least 3 mm/day
'Total precipitation rate of at least 3 mm/day' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	 scaledValueOfLowerLimit = 347222 ;
	 scaleFactorOfLowerLimit = 10 ;
	 probabilityType = 3 ;
	}
#Total precipitation rate of at least 5 mm/day
'Total precipitation rate of at least 5 mm/day' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 typeOfStatisticalProcessing = 0 ;
	 scaledValueOfLowerLimit = 578704 ;
	 scaleFactorOfLowerLimit = 10 ;
	 probabilityType = 3 ;
	}
#10 metre Wind speed of at least 10 m/s
'10 metre Wind speed of at least 10 m/s' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfLowerLimit = 10 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre Wind speed of at least 15 m/s
'10 metre Wind speed of at least 15 m/s' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfLowerLimit = 15 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre wind gust of at least 15 m/s
'10 metre wind gust of at least 15 m/s' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfLowerLimit = 15 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre wind gust of at least 20 m/s
'10 metre wind gust of at least 20 m/s' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 scaledValueOfLowerLimit = 20 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#2 metre temperature less than 273.15 K
'2 metre temperature less than 273.15 K' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfLowerLimit = 27315 ;
	 scaleFactorOfLowerLimit = 2 ;
	 probabilityType = 0 ;
	}
#Significant wave height of at least 2 m
'Significant wave height of at least 2 m' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 scaledValueOfLowerLimit = 2 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Significant wave height of at least 4 m
'Significant wave height of at least 4 m' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 scaledValueOfLowerLimit = 4 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Significant wave height of at least 6 m
'Significant wave height of at least 6 m' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 scaledValueOfLowerLimit = 6 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#Significant wave height of at least 8 m
'Significant wave height of at least 8 m' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 scaledValueOfLowerLimit = 8 ;
	 scaleFactorOfLowerLimit = 0 ;
	 probabilityType = 3 ;
	}
#10 metre wind gust index
'10 metre wind gust index' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = [102,2] ;
	}
#Snowfall index
'Snowfall index' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = [102,1] ;
	}
#10 metre speed index
'10 metre speed index' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = [102,0] ;
	}
#2 metre temperature index
'2 metre temperature index' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = [102,0] ;
	}
#Maximum temperature at 2 metres index
'Maximum temperature at 2 metres index' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = [102,2] ;
	}
#Minimum temperature at 2 metres index
'Minimum temperature at 2 metres index' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = [102,3] ;
	}
#Total precipitation index
'Total precipitation index' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = [102,1] ;
	}
#Period corresponding to maximum individual wave height
'Period corresponding to maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}
#Envelop-maximum individual wave height
'Envelop-maximum individual wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 93 ;
	}
#Model bathymetry
'Model bathymetry' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	}
#Mean wave period based on first moment
'Mean wave period based on first moment' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}
#Mean zero-crossing wave period
'Mean zero-crossing wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}
#Wave spectral directional width
'Wave spectral directional width' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	}
#Mean wave period based on first moment for wind waves
'Mean wave period based on first moment for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	}
#Mean wave period based on second moment for wind waves
'Mean wave period based on second moment for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	}
#Wave spectral directional width for wind waves
'Wave spectral directional width for wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	}
#Mean wave period based on first moment for swell
'Mean wave period based on first moment for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}
#Mean wave period based on second moment for swell
'Mean wave period based on second moment for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	}
#Wave spectral directional width for swell
'Wave spectral directional width for swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	}
#Significant height of combined wind waves and swell
'Significant height of combined wind waves and swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}
#Mean wave direction
'Mean wave direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}
#Peak wave period
'Peak wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	}
#Mean wave period
'Mean wave period' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}
#Coefficient of drag with waves
'Coefficient of drag with waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}
#Significant height of wind waves
'Significant height of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}
#Mean direction of wind waves
'Mean direction of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 75 ;
	}
#Mean period of wind waves
'Mean period of wind waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}
#Significant height of total swell
'Significant height of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}
#Mean direction of total swell
'Mean direction of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 74 ;
	}
#Mean period of total swell
'Mean period of total swell' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}
#Mean square slope of waves
'Mean square slope of waves' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}
#10 metre wind speed
'10 metre wind speed' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Altimeter wave height
'Altimeter wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 37 ;
	}
#Altimeter corrected wave height
'Altimeter corrected wave height' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 38 ;
	}
#Altimeter range relative correction
'Altimeter range relative correction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 39 ;
	}
#10 metre wind direction
'10 metre wind direction' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#2D wave spectra (single)
'2D wave spectra (single)' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 86 ;
	}
#Wave spectral kurtosis
'Wave spectral kurtosis' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	}
#Benjamin-Feir index
'Benjamin-Feir index' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	}
#Wave spectral peakedness
'Wave spectral peakedness' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 98 ;
	}
#Skin reservoir content
'Skin reservoir content' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	}
#Total column vertically-integrated mass of atmosphere
'Total column vertically-integrated mass of atmosphere' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 39 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated kinetic energy
'Total column vertically-integrated kinetic energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated enthalpy
'Total column vertically-integrated enthalpy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated potential + internal energy
'Total column vertically-integrated potential + internal energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated potential+internal+latent energy
'Total column vertically-integrated potential+internal+latent energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 21 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated total energy
'Total column vertically-integrated total energy' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward mass flux
'Total column vertically-integrated eastward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 36 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward mass flux
'Total column vertically-integrated northward mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 37 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward kinetic energy flux
'Total column vertically-integrated eastward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward kinetic energy flux
'Total column vertically-integrated northward kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward heat flux
'Total column vertically-integrated eastward heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 19 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward heat flux
'Total column vertically-integrated northward heat flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 20 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward water vapour flux
'Total column vertically-integrated eastward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 150 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward water vapour flux
'Total column vertically-integrated northward water vapour flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 151 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward geopotential flux
'Total column vertically-integrated eastward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 40 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward geopotential flux
'Total column vertically-integrated northward geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 41 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward total energy flux
'Total column vertically-integrated eastward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated northward total energy flux
'Total column vertically-integrated northward total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated eastward ozone flux
'Total column vertically-integrated eastward ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 78 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	}
#Total column vertically-integrated northward ozone flux
'Total column vertically-integrated northward ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 79 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	}
#Total column vertically-integrated divergence of mass flux
'Total column vertically-integrated divergence of mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 35 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of kinetic energy flux
'Total column vertically-integrated divergence of kinetic energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 16 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated moisture divergence flux
'Total column vertically-integrated moisture divergence flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 165 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of geopotential flux
'Total column vertically-integrated divergence of geopotential flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 43 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of total energy flux
'Total column vertically-integrated divergence of total energy flux' = {
	 discipline = 0 ;
	 parameterCategory = 21 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Total column vertically-integrated divergence of ozone flux
'Total column vertically-integrated divergence of ozone flux' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 80 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 constituentType = 0 ;
	}
#Time-integrated temperature tendency due to short-wave radiation
'Time-integrated temperature tendency due to short-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated temperature tendency due to long-wave radiation
'Time-integrated temperature tendency due to long-wave radiation' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated temperature tendency due to short wave radiation, clear sky
'Time-integrated temperature tendency due to short wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated temperature tendency due to long-wave radiation, clear sky
'Time-integrated temperature tendency due to long-wave radiation, clear sky' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated updraught mass flux
'Time-integrated updraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 27 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated downdraught mass flux
'Time-integrated downdraught mass flux' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated updraught detrainment rate
'Time-integrated updraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated downdraught detrainment rate
'Time-integrated downdraught detrainment rate' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 30 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated total precipitation flux
'Time-integrated total precipitation flux' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated turbulent diffusion coefficient for heat
'Time-integrated turbulent diffusion coefficient for heat' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated temperature tendency due to parametrisations
'Time-integrated temperature tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated specific humidity tendency due to parametrisations
'Time-integrated specific humidity tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 108 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated eastward wind tendency due to parametrisations
'Time-integrated eastward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Time-integrated northward wind tendency due to parametrisations
'Time-integrated northward wind tendency due to parametrisations' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Surface runoff
'Surface runoff' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	}
#Nitrogen dioxide mass mixing ratio
'Nitrogen dioxide mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 5 ;
	 is_chemical = 1 ;
	}
#Sulphur dioxide mass mixing ratio
'Sulphur dioxide mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 8 ;
	 is_chemical = 1 ;
	}
#Carbon monoxide mass mixing ratio
'Carbon monoxide mass mixing ratio' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 4 ;
	 is_chemical = 1 ;
	}
#Ozone mass mixing ratio (full chemistry scheme)
'Ozone mass mixing ratio (full chemistry scheme)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 0 ;
	 is_chemical = 1 ;
	}
#Nitrogen dioxide mass mixing ratio difference
'Nitrogen dioxide mass mixing ratio difference' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 5 ;
	 typeOfGeneratingProcess = 20 ;
	 is_chemical = 1 ;
	}
#Sulphur dioxide mass mixing ratio difference
'Sulphur dioxide mass mixing ratio difference' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 8 ;
	 typeOfGeneratingProcess = 20 ;
	 is_chemical = 1 ;
	}
#Carbon monoxide mass mixing ratio difference
'Carbon monoxide mass mixing ratio difference' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 4 ;
	 typeOfGeneratingProcess = 20 ;
	 is_chemical = 1 ;
	}
#Ozone mass mixing ratio difference (full chemistry scheme)
'Ozone mass mixing ratio difference (full chemistry scheme)' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 0 ;
	 typeOfGeneratingProcess = 20 ;
	 is_chemical = 1 ;
	}
#Convective inhibition
'Convective inhibition' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Orography
'Orography' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	}
#Friction velocity
'Friction velocity' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	}
#Time-mean 2 metre temperature
'Time-mean 2 metre temperature' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Time-mean 10 metre wind speed
'Time-mean 10 metre wind speed' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	}
#Lake total depth
'Lake total depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Lake mix-layer temperature
'Lake mix-layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Lake mix-layer depth
'Lake mix-layer depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 166 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Lake bottom temperature
'Lake bottom temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Lake total layer temperature
'Lake total layer temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Lake shape factor
'Lake shape factor' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}
#Lake ice surface temperature
'Lake ice surface temperature' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 255 ;
	}
#Lake ice total depth
'Lake ice total depth' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 174 ;
	 typeOfSecondFixedSurface = 176 ;
	 scaledValueOfFirstFixedSurface = missing() ;
	 scaleFactorOfFirstFixedSurface = missing() ;
	 scaledValueOfSecondFixedSurface = missing() ;
	 scaleFactorOfSecondFixedSurface = missing() ;
	}
#Minimum vertical gradient of refractivity inside trapping layer
'Minimum vertical gradient of refractivity inside trapping layer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 45 ;
	}
#Mean vertical gradient of refractivity inside trapping layer
'Mean vertical gradient of refractivity inside trapping layer' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 44 ;
	}
#Duct base height
'Duct base height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 41 ;
	}
#Trapping layer base height
'Trapping layer base height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 42 ;
	}
#Trapping layer top height
'Trapping layer top height' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 43 ;
	}
#10 metre u-component of neutral wind
'10 metre u-component of neutral wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 56 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#10 metre v-component of neutral wind
'10 metre v-component of neutral wind' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 57 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	}
#Snow depth water equivalent
'Snow depth water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	}
#Snowfall water equivalent
'Snowfall water equivalent' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#Total Cloud Cover
'Total Cloud Cover' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	}
#Field capacity
'Field capacity' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Wilting point
'Wilting point' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 scaleFactorOfSecondFixedSurface = 1 ;
	}
#Total Precipitation
'Total Precipitation' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfStatisticalProcessing = 1 ;
	}
#U-component surface stokes drift
'U-component surface stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}
#V-component surface stokes drift
'V-component surface stokes drift' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
}
