# Automatically generated by get_definitionsALL.sql from database PRJ_TDCFDOKU.GRIB_PARAMETER@OFC1MIR.DWD.DE, do not edit! 2025-10-01 06:15
#paramId: 500000
#Pressure (S) (not reduced)
'500000' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500001
#Pressure
'500001' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}

#paramId: 500002
#Pressure Reduced to MSL
'500002' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}

#paramId: 500003
#Pressure Tendency (S)
'500003' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500004
#Geopotential (S)
'500004' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500005
#Geopotential (full lev)
'500005' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 105 ;
	 typeOfFirstFixedSurface = 105 ;
	}

#paramId: 500006
#Geopotential
'500006' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}

#paramId: 500007
#Geometric Height of the earths surface above sea level
'500007' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500008
#Geometric Height of the layer limits above sea level(NN)
'500008' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 101 ;
	}

#paramId: 500009
#Total Column Integrated Ozone
'500009' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 2 ;
	}

#paramId: 500010
#Temperature (G)
'500010' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500011
#2m Temperature
'500011' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500012
#2m Temperature (AV)
'500012' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500013
#Climat. temperature, 2m Temperature
'500013' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 9 ;
	}

#paramId: 500014
#Temperature
'500014' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 500015
#Max 2m Temperature (i)
'500015' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500016
#Min 2m Temperature (i)
'500016' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500017
#2m Dew Point Temperature
'500017' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500018
#2m Dew Point Temperature (AV)
'500018' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500019
#Radar spectra (1)
'500019' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500020
#Wave spectra (1)
'500020' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 500021
#Wave spectra (2)
'500021' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 500022
#Wave spectra (3)
'500022' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 500023
#Wind Direction (DD_10M)
'500023' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500024
#Wind Direction (DD)
'500024' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}

#paramId: 500025
#Wind speed (SP_10M)
'500025' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500026
#Wind speed (SP)
'500026' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}

#paramId: 500027
#U-Component of Wind
'500027' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500028
#U-Component of Wind
'500028' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 500029
#V-Component of Wind
'500029' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500030
#V-Component of Wind
'500030' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}

#paramId: 500031
#Vertical Velocity (Pressure) ( omega=dp/dt )
'500031' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}

#paramId: 500032
#Vertical Velocity (Geometric) (w)
'500032' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 9 ;
	}

#paramId: 500034
#Specific Humidity (2m)
'500034' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500035
#Specific Humidity
'500035' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 500036
#2m Relative Humidity
'500036' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 500037
#Relative Humidity
'500037' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 500038
#Total column integrated water vapour
'500038' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 64 ;
	}

#paramId: 500039
#Evaporation (s)
'500039' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500040
#Total Column-Integrated Cloud Ice
'500040' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 70 ;
	}

#paramId: 500041
#Total Precipitation (Accumulation)
'500041' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500042
#Large-Scale Precipitation (Accumulation)
'500042' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500043
#Convective Precipitation (Accumulation)
'500043' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500044
#Snow depth water equivalent
'500044' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	}

#paramId: 500045
#Snow Depth
'500045' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}

#paramId: 500046
#Total Cloud Cover
'500046' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	}

#paramId: 500047
#Convective Cloud Cover
'500047' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 2 ;
	}

#paramId: 500048
#Cloud Cover (800 hPa - Soil)
'500048' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 800 ;
	}

#paramId: 500049
#Cloud Cover (400 - 800 hPa)
'500049' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 800 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 400 ;
	}

#paramId: 500050
#Cloud Cover (0 - 400 hPa)
'500050' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 400 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500051
#Total Column-Integrated Cloud Water
'500051' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 69 ;
	}

#paramId: 500052
#Convective Snowfall water equivalent (s)
'500052' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500053
#Large-Scale snowfall - water equivalent (Accumulation)
'500053' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500054
#Land Cover (1=land, 0=sea)
'500054' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 500055
#Surface Roughness length Surface Roughness
'500055' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 500056
#Albedo (in short-wave)
'500056' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	}

#paramId: 500057
#Albedo (in short-wave, average)
'500057' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500058
#Soil Temperature  ( 36 cm depth, vv=0h)
'500058' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 36 ;
	}

#paramId: 500059
#Soil Temperature (41 cm depth)
'500059' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 41 ;
	}

#paramId: 500060
#Soil Temperature
'500060' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 9 ;
	}

#paramId: 500061
#Soil Temperature
'500061' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500062
#Column-integrated Soil Moisture
'500062' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 190 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 100 ;
	}

#paramId: 500063
#Column-integrated Soil Moisture (1) 0 -10 cm
'500063' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 10 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500064
#Column-integrated Soil Moisture (2) 10-100cm
'500064' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 100 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500065
#Plant cover
'500065' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 500066
#Water Runoff
'500066' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500068
#Water Runoff (s)
'500068' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500069
#Sea Ice Cover ( 0= free, 1=cover)
'500069' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}

#paramId: 500070
#Sea Ice Thickness
'500070' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}

#paramId: 500071
#Significant height of combined wind waves and swell
'500071' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 500072
#Direction of wind waves
'500072' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 500073
#Significant height of wind waves
'500073' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}

#paramId: 500074
#Mean period of wind waves
'500074' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 500075
#Direction of swell waves
'500075' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}

#paramId: 500076
#Significant height of swell waves
'500076' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}

#paramId: 500077
#Mean period of swell waves
'500077' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}

#paramId: 500078
#Net short wave radiation flux (at the surface)
'500078' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500079
#Net short wave radiation flux (at the surface)
'500079' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500080
#Net long wave radiation flux (m) (at the surface)
'500080' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500081
#Net long wave radiation flux
'500081' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500082
#Net short wave radiation flux (on the model top)
'500082' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500083
#Net short wave radiation flux
'500083' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500084
#Net long wave radiation flux (m) (on the model top)
'500084' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500085
#Net long wave radiation flux
'500085' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 500086
#Latent Heat Net Flux (m)
'500086' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500087
#Sensible Heat Net Flux (m)
'500087' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500088
#Momentum Flux, U-Component (m)
'500088' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500089
#Momentum Flux, V-Component (m)
'500089' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500090
#Photosynthetically active radiation (m) (at the surface)
'500090' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500091
#Photosynthetically active radiation
'500091' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500092
#Solar radiation heating rate
'500092' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}

#paramId: 500093
#Thermal radiation heating rate
'500093' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 192 ;
	}

#paramId: 500094
#Latent heat flux from bare soil
'500094' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500095
#Latent heat flux from plants
'500095' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500097
#Stomatal resistance
'500097' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	}

#paramId: 500098
#Cloud cover
'500098' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	}

#paramId: 500099
#Non-Convective Cloud Cover, grid scale
'500099' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 14 ;
	}

#paramId: 500100
#Cloud Mixing Ratio
'500100' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 22 ;
	}

#paramId: 500101
#Cloud Ice Mixing Ratio
'500101' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 82 ;
	}

#paramId: 500102
#Rain mixing ratio
'500102' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 24 ;
	}

#paramId: 500103
#Snow mixing ratio
'500103' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 25 ;
	}

#paramId: 500104
#Total column integrated rain
'500104' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 45 ;
	}

#paramId: 500105
#Total column integrated snow
'500105' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 46 ;
	}

#paramId: 500106
#Grauple
'500106' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 32 ;
	}

#paramId: 500107
#Total column integrated grauple
'500107' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 74 ;
	}

#paramId: 500108
#Total Column integrated water (all components incl. precipitation)
'500108' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 78 ;
	}

#paramId: 500109
#Vertical integral of divergence of total water content - accumulation
'500109' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500110
#Sub-grid scale cloud water
'500110' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 193 ;
	}

#paramId: 500111
#Sub-grid scale cloud ice
'500111' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 194 ;
	}

#paramId: 500115
#Cloud base above MSL, shallow convection
'500115' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 192 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500116
#Cloud top above MSL, shallow convection
'500116' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 193 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 500117
#Specific cloud liquid water content, convective cloud
'500117' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 195 ;
	}

#paramId: 500118
#Height of Convective Cloud Base above msl
'500118' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 26 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500119
#Height of Convective Cloud Top above msl
'500119' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 27 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 500120
#Base index (vertical level) of main convective cloud
'500120' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500121
#Top index (vertical level) of main convective cloud
'500121' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500122
#Temperature tendency due to convection
'500122' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500123
#Specific humidity tendency due to convection
'500123' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 197 ;
	}

#paramId: 500124
#Zonal wind tendency due to convection
'500124' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	}

#paramId: 500125
#Meridional wind tendency due to convection
'500125' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 193 ;
	}

#paramId: 500126
#Height of top of dry convection above MSL
'500126' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 196 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 500127
#Height of 0 degree Celsius isotherm above msl
'500127' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 4 ;
	}

#paramId: 500128
#Height of snow fall limit above MSL
'500128' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 204 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 4 ;
	}

#paramId: 500129
#Tendency of specific cloud liquid water content due to convection
'500129' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 198 ;
	}

#paramId: 500130
#Tendency of specific cloud ice content due to convection
'500130' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 199 ;
	}

#paramId: 500131
#Specific content of precipitation particles (needed for water loading)
'500131' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 196 ;
	}

#paramId: 500132
#Large scale rain rate
'500132' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	}

#paramId: 500133
#Large scale snowfall rate water equivalent
'500133' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	}

#paramId: 500134
#Large scale rain (Accumulation)
'500134' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500135
#Convective rain rate
'500135' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	}

#paramId: 500136
#Convective snowfall rate water equivalent
'500136' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	}

#paramId: 500137
#Convective rain
'500137' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500138
#rain amount, grid-scale plus convective
'500138' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 65 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500139
#snow amount, grid-scale plus convective
'500139' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 66 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500140
#Temperature tendency due to grid scale precipitation
'500140' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	}

#paramId: 500141
#Specific humidity tendency due to grid scale precipitation
'500141' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 200 ;
	}

#paramId: 500142
#Tendency of specific cloud liquid water content due to grid scale precipitation
'500142' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 201 ;
	}

#paramId: 500143
#Fresh snow factor (weighting function for albedo indicating freshness of snow)
'500143' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 203 ;
	}

#paramId: 500144
#Tendency of specific cloud ice content due to grid scale precipitation
'500144' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 202 ;
	}

#paramId: 500145
#Graupel (snow pellets) precipitation rate
'500145' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	}

#paramId: 500146
#Graupel (snow pellets) precipitation (Accumulation)
'500146' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500147
#Snow density
'500147' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	}

#paramId: 500148
#Pressure perturbation
'500148' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}

#paramId: 500149
#Supercell detection index 1 (rot. up- and downdrafts)
'500149' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 192 ;
	}

#paramId: 500150
#Supercell detection index 2 (only rot. updrafts)
'500150' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 193 ;
	}

#paramId: 500151
#Convective Available Potential Energy, most unstable
'500151' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 193 ;
	}

#paramId: 500152
#Convective Inhibition, most unstable
'500152' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 193 ;
	}

#paramId: 500153
#Convective Available Potential Energy, mean layer
'500153' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 192 ;
	}

#paramId: 500154
#Convective Inhibition, mean layer
'500154' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 192 ;
	}

#paramId: 500155
#Convective turbulent kinetic enery
'500155' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 24 ;
	}

#paramId: 500156
#Tendency of turbulent kinetic energy
'500156' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 192 ;
	}

#paramId: 500157
#Kinetic energy
'500157' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	}

#paramId: 500158
#Turbulent Kinetic Energy
'500158' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 11 ;
	}

#paramId: 500159
#Turbulent diffusioncoefficient for momentum
'500159' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 31 ;
	}

#paramId: 500160
#Turbulent diffusion coefficient for heat (and moisture)
'500160' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}

#paramId: 500161
#Turbulent transfer coefficient for impulse
'500161' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 29 ;
	}

#paramId: 500162
#Turbulent transfer coefficient for heat (and Moisture)
'500162' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}

#paramId: 500163
#mixed layer depth
'500163' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 3 ;
	}

#paramId: 500164
#maximum Wind 10m
'500164' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 500166
#Soil Temperature (multilayer model)
'500166' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500167
#Column-integrated Soil Moisture (multilayers)
'500167' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500168
#soil ice content (multilayers)
'500168' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500169
#Plant Canopy Surface Water
'500169' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}

#paramId: 500170
#Snow temperature (top of snow)
'500170' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}

#paramId: 500171
#Minimal Stomatal Resistance
'500171' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}

#paramId: 500172
#Sea Ice Temperature
'500172' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}

#paramId: 500173
#Base reflectivity
'500173' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500174
#Base reflectivity
'500174' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	}

#paramId: 500175
#Base reflectivity (cmax)
'500175' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500176
#Solution of 2-d Helmholtz equations - needed for restart
'500176' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 192 ;
	}

#paramId: 500177
#Effective transmissivity of solar radiation
'500177' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 193 ;
	}

#paramId: 500178
#Sum of contributions to evaporation
'500178' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}

#paramId: 500179
#Total transpiration from all soil layers
'500179' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}

#paramId: 500180
#Total forcing at soil surface
'500180' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}

#paramId: 500181
#Residuum of soil moisture
'500181' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}

#paramId: 500182
#Mass flux at convective cloud base
'500182' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 205 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500183
#Convective Available Potential Energy
'500183' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	}

#paramId: 500184
#Moisture convergence for Kuo-type closure
'500184' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 206 ;
	}

#paramId: 500185
#Direction of combined wind waves and swell
'500185' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}

#paramId: 500187
#Peak period of total swell
'500187' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	}

#paramId: 500189
#Peak period of wind waves
'500189' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	}

#paramId: 500190
#Peak wave period
'500190' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 34 ;
	}

#paramId: 500191
#Mean period of combined wind waves and swell
'500191' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}

#paramId: 500192
#Inverse mean wave frequency
'500192' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}

#paramId: 500193
#Mean zero-crossing wave period
'500193' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}

#paramId: 500194
#Wave directional width
'500194' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	}

#paramId: 500195
#Analysis error (standard deviation), geopotential (gpm)
'500195' = {
	 discipline = 0 ;
	 parameterCategory = 194 ;
	 parameterNumber = 5 ;
	 typeOfGeneratingProcess = 7 ;
	}

#paramId: 500196
#Analysis error (standard deviation), u-comp. of wind
'500196' = {
	 discipline = 0 ;
	 parameterCategory = 194 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 7 ;
	}

#paramId: 500197
#Analysis error (standard deviation), v-comp. of wind
'500197' = {
	 discipline = 0 ;
	 parameterCategory = 194 ;
	 parameterNumber = 3 ;
	 typeOfGeneratingProcess = 7 ;
	}

#paramId: 500198
#Zonal wind tendency due to sub-grid scale oro.
'500198' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 194 ;
	}

#paramId: 500199
#Meridional wind tendency due to sub-grid scale oro.
'500199' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 195 ;
	}

#paramId: 500200
#Standard deviation of sub-grid scale orography
'500200' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	}

#paramId: 500201
#Anisotropy of sub-gridscale orography
'500201' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 24 ;
	}

#paramId: 500202
#Angle of sub-gridscale orography
'500202' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 21 ;
	}

#paramId: 500203
#Slope of sub-gridscale orography
'500203' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 22 ;
	}

#paramId: 500204
#Surface emissivity
'500204' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	}

#paramId: 500205
#Soil type (1...9, local soilType.table)
'500205' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}

#paramId: 500206
#Leaf area index
'500206' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	}

#paramId: 500207
#root depth of vegetation
'500207' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	}

#paramId: 500208
#Height of ozone maximum (climatological)
'500208' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 192 ;
	}

#paramId: 500209
#Vertically integrated ozone content (climatological)
'500209' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 193 ;
	}

#paramId: 500210
#Plant covering degree in the vegetation phase
'500210' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500211
#Plant covering degree in the quiescent phas
'500211' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 3 ;
	}

#paramId: 500212
#Max Leaf area index
'500212' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500213
#Min Leaf area index
'500213' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 28 ;
	 typeOfStatisticalProcessing = 3 ;
	}

#paramId: 500214
#Orographie + Land-Meer-Verteilung
'500214' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}

#paramId: 500215
#variance of soil moisture content (0-10)
'500215' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 typeOfGeneratingProcess = 6 ;
	}

#paramId: 500216
#variance of soil moisture content (10-100)
'500216' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	 typeOfGeneratingProcess = 6 ;
	}

#paramId: 500217
#evergreen forest
'500217' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	}

#paramId: 500218
#deciduous forest
'500218' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	}

#paramId: 500219
#normalized differential vegetation index
'500219' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500220
#normalized differential vegetation index (NDVI)
'500220' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 31 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500221
#Ratio of monthly mean NDVI (normalized differential vegetation index) to annual maximum
'500221' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500222
#Ratio of NDVI (normalized differential vegetation index) to annual maximum
'500222' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500223
#Total sulfate aerosol
'500223' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62006 ;
	}

#paramId: 500224
#Total sulfate aerosol (12M)
'500224' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62006 ;
	}

#paramId: 500225
#Total soil dust aerosol (climatology)
'500225' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62001 ;
	}

#paramId: 500226
#Total soil dust aerosol (climatology,12M)
'500226' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62001 ;
	}

#paramId: 500227
#Organic aerosol
'500227' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62010 ;
	}

#paramId: 500228
#Organic aerosol (12M)
'500228' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62010 ;
	}

#paramId: 500229
#Black carbon aerosol
'500229' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62009 ;
	}

#paramId: 500230
#Black carbon aerosol (12M)
'500230' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62009 ;
	}

#paramId: 500231
#Sea salt aerosol
'500231' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 constituentType = 62008 ;
	}

#paramId: 500232
#Sea salt aerosol (12M)
'500232' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 62008 ;
	}

#paramId: 500233
#Tendency of specific humidity
'500233' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 207 ;
	}

#paramId: 500234
#Water vapor flux
'500234' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 208 ;
	}

#paramId: 500235
#Coriolis parameter
'500235' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 193 ;
	}

#paramId: 500236
#geographical latitude
'500236' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	}

#paramId: 500237
#geographical longitude
'500237' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	}

#paramId: 500238
#Friction velocity
'500238' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 30 ;
	}

#paramId: 500239
#Delay of the GPS signal through the (total) atmos.
'500239' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 192 ;
	}

#paramId: 500240
#Delay of the GPS signal through wet atmos.
'500240' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 193 ;
	}

#paramId: 500241
#Delay of the GPS signal through dry atmos.
'500241' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 194 ;
	}

#paramId: 500242
#Ozone Mixing Ratio
'500242' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 1 ;
	}

#paramId: 500243
#Air concentration of Ruthenium 103
'500243' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30102 ;
	}

#paramId: 500244
#Ru103 - dry deposition
'500244' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30102 ;
	}

#paramId: 500245
#Ru103 - wet deposition
'500245' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30102 ;
	}

#paramId: 500246
#Air concentration of Strontium 90
'500246' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30067 ;
	}

#paramId: 500247
#Sr90 - dry deposition
'500247' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30067 ;
	}

#paramId: 500248
#Sr90 - wet deposition
'500248' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30067 ;
	}

#paramId: 500249
#Air concentration of Iodine 131 aerosol
'500249' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30141 ;
	}

#paramId: 500250
#I131a - dry deposition
'500250' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30141 ;
	}

#paramId: 500251
#I131a - wet deposition
'500251' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30141 ;
	}

#paramId: 500252
#Air concentration of Caesium 137
'500252' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30172 ;
	}

#paramId: 500253
#Cs137 - dry deposition
'500253' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30172 ;
	}

#paramId: 500255
#Air concentration of Tellurium 132
'500255' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30129 ;
	}

#paramId: 500256
#Te132 - dry deposition
'500256' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30129 ;
	}

#paramId: 500257
#Te132 - wet deposition
'500257' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30129 ;
	}

#paramId: 500258
#Air concentration of Zirconium 95
'500258' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30079 ;
	}

#paramId: 500259
#Zr95 - dry deposition
'500259' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30079 ;
	}

#paramId: 500260
#Zr95 - wet deposition
'500260' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30079 ;
	}

#paramId: 500261
#Air concentration of Krypton 85
'500261' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30059 ;
	}

#paramId: 500262
#Kr85 - dry deposition
'500262' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30059 ;
	}

#paramId: 500263
#Kr85 - wet deposition
'500263' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30059 ;
	}

#paramId: 500264
#TRACER - concentration
'500264' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30000 ;
	}

#paramId: 500265
#TRACER - dry deposition
'500265' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30000 ;
	}

#paramId: 500266
#TRACER - wet deposition
'500266' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30000 ;
	}

#paramId: 500267
#Air concentration of Xenon 133
'500267' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30161 ;
	}

#paramId: 500268
#Xe133 - dry deposition
'500268' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30161 ;
	}

#paramId: 500269
#Xe133 - wet deposition
'500269' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30161 ;
	}

#paramId: 500270
#Air concentration of Iodine 131 elementary gaseous
'500270' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30138 ;
	}

#paramId: 500271
#I131g - dry deposition
'500271' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30138 ;
	}

#paramId: 500272
#I131g - wet deposition
'500272' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30138 ;
	}

#paramId: 500273
#Air concentration of Iodine 131 organic bounded
'500273' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30139 ;
	}

#paramId: 500274
#I131o - dry deposition
'500274' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30139 ;
	}

#paramId: 500275
#I131o - wet deposition
'500275' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30139 ;
	}

#paramId: 500276
#Air concentration of Barium 140
'500276' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30175 ;
	}

#paramId: 500277
#Ba140 - dry deposition
'500277' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30175 ;
	}

#paramId: 500278
#Ba140 - wet deposition
'500278' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30175 ;
	}

#paramId: 500279
#U-momentum flux due to SSO-effects (mean over forecast time)
'500279' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500280
#U-momentum flux due to SSO-effects
'500280' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	}

#paramId: 500281
#V-momentum flux due to SSO-effects (mean over forecast time)
'500281' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 500282
#V-momentum flux due to SSO-effects
'500282' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	}

#paramId: 500283
#Gravity wave dissipation (initialisation)
'500283' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500284
#Gravity wave dissipation (vertical integral)
'500284' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	}

#paramId: 500285
#UV Index, clouded sky, maximum
'500285' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 51 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500286
#Vertical speed shear
'500286' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 25 ;
	}

#paramId: 500287
#storm relative helicity
'500287' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 8 ;
	}

#paramId: 500288
#Absolute vorticity advection
'500288' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 197 ;
	}

#paramId: 500289
#Kombination Niederschlag-Bewoelkung-Blauthermik (cl_typ.tab)
'500289' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 194 ;
	}

#paramId: 500290
#Hoehe der Konvektionsuntergrenze ueber Grund
'500290' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 26 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500291
#Hoehe der Konvektionsuntergrenze ueber nn
'500291' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 24 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 500292
#weather interpretation (WMO)
'500292' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 25 ;
	}

#paramId: 500293
#geostrophische Vorticityadvektion
'500293' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 0 ;
	}

#paramId: 500294
#Geostrophic thickness advection
'500294' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 1 ;
	}

#paramId: 500295
#Schichtdickenadvektion
'500295' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 2 ;
	}

#paramId: 500296
#Winddivergenz
'500296' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 3 ;
	}

#paramId: 500297
#Q-Vektor senkrecht zu den Isothermen
'500297' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 4 ;
	}

#paramId: 500298
#Isentrope potentielle Vorticity
'500298' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 25 ;
	 typeOfFirstFixedSurface = 107 ;
	}

#paramId: 500299
#Wind X-Komponente auf isentropen Flaechen
'500299' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 5 ;
	}

#paramId: 500300
#Wind Y-Komponente auf isentropen Flaechen
'500300' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 6 ;
	}

#paramId: 500301
#Druck einer isentropen Flaeche
'500301' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 107 ;
	}

#paramId: 500302
#KO index
'500302' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 3 ;
	}

#paramId: 500303
#Aequivalentpotentielle Temperatur
'500303' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 500304
#Ceiling
'500304' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 13 ;
	}

#paramId: 500305
#Icing Grade (1=LGT,2=MOD,3=SEV)
'500305' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 7 ;
	}

#paramId: 500306
#Modified cloud depth for media
'500306' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 198 ;
	}

#paramId: 500307
#Modified cloud cover for media
'500307' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 199 ;
	}

#paramId: 500308
#Monthly Mean of RMS of difference FG-AN of pressure reduced to MSL
'500308' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500309
#Monthly Mean of RMS of difference IA-AN of pressure reduced to MSL
'500309' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500310
#Monthly Mean of RMS of difference FG-AN of u-component of wind
'500310' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500311
#Monthly Mean of RMS of difference IA-AN of u-component of wind
'500311' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500312
#Monthly Mean of RMS of difference FG-AN of v-component of wind
'500312' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500313
#Monthly Mean of RMS of difference IA-AN of v-component of wind
'500313' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500314
#Monthly Mean of RMS of difference FG-AN of geopotential
'500314' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500315
#Monthly Mean of RMS of difference IA-AN of geopotential
'500315' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500316
#Monthly Mean of RMS of difference FG-AN of relative humidity
'500316' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500317
#Monthly Mean of RMS of difference IA-AN of relative humidity
'500317' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500318
#Monthly Mean of RMS of difference FG-AN of temperature
'500318' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500319
#Monthly Mean of RMS of difference IA-AN of temperature
'500319' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500320
#Monthly Mean of RMS of difference FG-AN of vert.velocity (pressure)
'500320' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500321
#Monthly Mean of RMS of difference IA-AN of vert.velocity (pressure)
'500321' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500322
#RMS of difference "first guess - analysis" of kinetic energy
'500322' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 201 ;
	}

#paramId: 500323
#RMS of difference "initialized analysis - analysis" of kinetic energy
'500323' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 5 ;
	 typeOfGeneratingProcess = 200 ;
	}

#paramId: 500324
#Synth. Sat. brightness temperature cloudy
'500324' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500325
#Synth. Sat. brightness temperature clear sky
'500325' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500326
#Synth. Sat. radiance cloudy
'500326' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500327
#Synth. Sat. radiance clear sky
'500327' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 52 ;
	 instrumentType = 205 ;
	}

#paramId: 500328
#Synth. Sat. brightness temperature cloudy
'500328' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500329
#Synth. Sat. brightness temperature clear sky
'500329' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500330
#Synth. Sat. radiance cloudy
'500330' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500331
#Synth. Sat. radiance clear sky
'500331' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 53 ;
	 instrumentType = 205 ;
	}

#paramId: 500332
#Synth. Sat. brightness temperature cloudy
'500332' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500333
#Synth. Sat. brightness temperature cloudy
'500333' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500334
#Synth. Sat. brightness temperature clear sky
'500334' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500335
#Synth. Sat. brightness temperature clear sky
'500335' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500336
#Synth. Sat. radiance cloudy
'500336' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500337
#Synth. Sat. radiance cloudy
'500337' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500338
#Synth. Sat. radiance clear sky
'500338' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 86956 ;
	}

#paramId: 500339
#Synth. Sat. radiance clear sky
'500339' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 331 ;
	 satelliteNumber = 54 ;
	 instrumentType = 205 ;
	 scaledValueOfCentralWaveNumber = 156250 ;
	}

#paramId: 500340
#Synth. Sat. brightness temperature cloudy
'500340' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500341
#Synth. Sat. brightness temperature cloudy
'500341' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500342
#Synth. Sat. brightness temperature cloudy
'500342' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500343
#Synth. Sat. brightness temperature cloudy
'500343' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500344
#Synth. Sat. brightness temperature cloudy
'500344' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500345
#Synth. Sat. brightness temperature cloudy
'500345' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500346
#Synth. Sat. brightness temperature cloudy
'500346' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500347
#Synth. Sat. brightness temperature cloudy
'500347' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500348
#Synth. Sat. brightness temperature clear sky
'500348' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500349
#Synth. Sat. brightness temperature clear sky
'500349' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500350
#Synth. Sat. brightness temperature clear sky
'500350' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500351
#Synth. Sat. brightness temperature clear sky
'500351' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500352
#Synth. Sat. brightness temperature clear sky
'500352' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500353
#Synth. Sat. brightness temperature clear sky
'500353' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500354
#Synth. Sat. brightness temperature clear sky
'500354' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500355
#Synth. Sat. brightness temperature clear sky
'500355' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500356
#Synth. Sat. radiance cloudy
'500356' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500357
#Synth. Sat. radiance cloudy
'500357' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500358
#Synth. Sat. radiance cloudy
'500358' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500359
#Synth. Sat. radiance cloudy
'500359' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500360
#Synth. Sat. radiance cloudy
'500360' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500361
#Synth. Sat. radiance cloudy
'500361' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500362
#Synth. Sat. radiance cloudy
'500362' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500363
#Synth. Sat. radiance cloudy
'500363' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500364
#Synth. Sat. radiance clear sky
'500364' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500365
#Synth. Sat. radiance clear sky
'500365' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 82644 ;
	}

#paramId: 500366
#Synth. Sat. radiance clear sky
'500366' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500367
#Synth. Sat. radiance clear sky
'500367' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500368
#Synth. Sat. radiance clear sky
'500368' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500369
#Synth. Sat. radiance clear sky
'500369' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500370
#Synth. Sat. radiance clear sky
'500370' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500371
#Synth. Sat. radiance clear sky
'500371' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500372
#smoothed forecast, temperature
'500372' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500373
#smoothed forecast, maximum temp.
'500373' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500374
#smoothed forecast, minimum temp.
'500374' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500375
#smoothed forecast, dew point temp.
'500375' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500376
#smoothed forecast, u comp. of wind
'500376' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500377
#smoothed forecast, v comp. of wind
'500377' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500378
#smoothed forecast, total precipitation (Accumulation)
'500378' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500379
#smoothed forecast, total cloud cover
'500379' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500380
#smoothed forecast, cloud cover low
'500380' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 800 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500381
#smoothed forecast, cloud cover medium
'500381' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 800 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 400 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500382
#smoothed forecast, cloud cover high
'500382' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = -2 ;
	 scaledValueOfSecondFixedSurface = 400 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = -2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500383
#smoothed forecast, large-scale snowfall
'500383' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500384
#smoothed forecast, soil temperature
'500384' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500385
#smoothed forecast, wind speed (gust)
'500385' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 197 ;
	}

#paramId: 500386
#calibrated forecast, total precipitation  (Accumulation)
'500386' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 198 ;
	}

#paramId: 500387
#calibrated forecast, large-scale snowfall
'500387' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 198 ;
	}

#paramId: 500388
#calibrated forecast, wind speed (gust)
'500388' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 198 ;
	}

#paramId: 500389
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'500389' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 2000000 ;
	}

#paramId: 500390
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'500390' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 625000 ;
	}

#paramId: 500391
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'500391' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 1666666 ;
	}

#paramId: 500392
#Obser. Sat. Meteosat sec. generation Albedo (scaled)
'500392' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 1250000 ;
	}

#paramId: 500393
#Obser. Sat. Meteosat sec. generation brightness temperature
'500393' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 92592 ;
	}

#paramId: 500394
#Obser. Sat. Meteosat sec. generation brightness temperature
'500394' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 83333 ;
	}

#paramId: 500395
#Obser. Sat. Meteosat sec. generation brightness temperature
'500395' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 74626 ;
	}

#paramId: 500396
#Obser. Sat. Meteosat sec. generation brightness temperature
'500396' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 256410 ;
	}

#paramId: 500397
#Obser. Sat. Meteosat sec. generation brightness temperature
'500397' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 114942 ;
	}

#paramId: 500398
#Obser. Sat. Meteosat sec. generation brightness temperature
'500398' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 103092 ;
	}

#paramId: 500399
#Obser. Sat. Meteosat sec. generation brightness temperature
'500399' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 161290 ;
	}

#paramId: 500400
#Obser. Sat. Meteosat sec. generation brightness temperature
'500400' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 8 ;
	 satelliteSeries = 333 ;
	 satelliteNumber = 72 ;
	 instrumentType = 207 ;
	 scaledValueOfCentralWaveNumber = 136986 ;
	}

#paramId: 500401
#Total Precipitation Difference
'500401' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 500404
#
'500404' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500408
#
'500408' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500409
#
'500409' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500410
#
'500410' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500411
#
'500411' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500412
#
'500412' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500416
#
'500416' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 79 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500417
#
'500417' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500418
#
'500418' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500419
#Net short wave radiation flux
'500419' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500420
#Net long wave radiation flux
'500420' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500421
#Net short wave radiation flux (at the surface)
'500421' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500422
#Net long wave radiation flux
'500422' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500423
#
'500423' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500424
#
'500424' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500425
#
'500425' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500428
#Latent Heat Net Flux (m) Initialisation
'500428' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500429
#
'500429' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500430
#Momentum Flux, U-Component (m) Initialisation
'500430' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500431
#Momentum Flux, V-Component (m) Initialisation
'500431' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500432
#Photosynthetically active radiation
'500432' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500433
#
'500433' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500434
#
'500434' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500436
#
'500436' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500437
#Probability of 1h total precipitation >= 10mm
'500437' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500438
#Probability of 1h total precipitation >= 25mm
'500438' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500439
#Probability of 6h total precipitation >= 20mm
'500439' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 14 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500440
#Probability of 6h total precipitation >= 35mm
'500440' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 17 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500441
#Probability of 12h total precipitation >= 25mm
'500441' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500442
#Probability of 12h total precipitation >= 40mm
'500442' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 29 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500443
#Probability of 12h total precipitation >= 70mm
'500443' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 32 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500444
#Probability of 6h accumulated snow >=0.5cm
'500444' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 69 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500445
#Probability of 6h accumulated snow >= 5cm
'500445' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 70 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500446
#Probability of 6h accumulated snow >= 10cm
'500446' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 71 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500447
#Probability of 12h accumulated snow >=0.5cm
'500447' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 72 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500448
#Probability of 12h accumulated snow >= 10cm
'500448' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 74 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500449
#Probability of 12h accumulated snow >= 15cm
'500449' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 75 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500450
#Probability of 12h accumulated snow >= 25cm
'500450' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500451
#Probability of 1h maximum wind gust speed >= 14m/s
'500451' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 132 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500452
#Probability of 1h maximum wind gust speed >= 18m/s
'500452' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 134 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500453
#Probability of 1h maximum wind gust speed >= 25m/s
'500453' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 136 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500454
#Probability of 1h maximum wind gust speed >= 29m/s
'500454' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 137 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500455
#Probability of 1h maximum wind gust speed >= 33m/s
'500455' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 138 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500456
#Probability of 1h maximum wind gust speed >= 39m/s
'500456' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 139 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500457
#Probability of black ice during 1h
'500457' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 191 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500458
#Probability of thunderstorm during 1h
'500458' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 197 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500459
#Probability of heavy thunderstorm during 1h
'500459' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500460
#Probability of severe thunderstorm during 1h
'500460' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 199 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500461
#Probability of snowdrift during 12h
'500461' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 212 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500462
#Probability of strong snowdrift during 12h
'500462' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 213 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500463
#Probability of temperature < 0 deg C during 1h
'500463' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 232 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500464
#Probability of temperature <= -10 deg C during 6h
'500464' = {
	 discipline = 0 ;
	 parameterCategory = 195 ;
	 parameterNumber = 236 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500465
#UV Index, clear sky; corrected for albedo, aerosol and altitude
'500465' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 195 ;
	}

#paramId: 500466
#Basic UV Index, clear sky; MSL, fixed albedo, fixed aerosol
'500466' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 196 ;
	}

#paramId: 500467
#UV Index, clouded sky; corrected for albedo, aerosol, altitude and clouds
'500467' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 197 ;
	}

#paramId: 500468
#UV Index, clear sky, maximum
'500468' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 50 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500469
#Total ozone
'500469' = {
	 discipline = 0 ;
	 parameterCategory = 14 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500471
#Time of maximum of UV Index, clouded
'500471' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 500472
#Type of convection (0..4)
'500472' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 201 ;
	}

#paramId: 500473
#perceived temperature
'500473' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 1 ;
	}

#paramId: 500474
#wind chill factor
'500474' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}

#paramId: 500475
#Water temperature
'500475' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	}

#paramId: 500477
#Absolute Vorticity
'500477' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}

#paramId: 500478
#probability to perceive sultriness
'500478' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 3 ;
	}

#paramId: 500479
#value of isolation of clothes
'500479' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 2 ;
	}

#paramId: 500480
#Downward direct short wave radiation flux at surface (mean over forecast time)
'500480' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500481
#Downward diffusive short wave radiation flux at surface (mean over forecast time)
'500481' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 199 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500482
#Upward diffusive short wave radiation flux at surface ( mean over forecast time)
'500482' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500486
#
'500486' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500487
#Downward direct short wave radiation flux (mean over forecast time) Initialisation
'500487' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500488
#Downward diffusive short wave radiation flux at surface ( mean over forecast time) Initialisation
'500488' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 199 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500489
#Upward diffusive short wave radiation flux at surface ( mean over forecast time) Initialisation
'500489' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500490
#Water Fraction
'500490' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 500491
#Lake depth
'500491' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500492
#Wind fetch
'500492' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 33 ;
	}

#paramId: 500493
#Attenuation coefficient of water with respect to solar radiation
'500493' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500494
#Depth of thermally active layer of bottom sediment
'500494' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfSecondFixedSurface = 164 ;
	 typeOfFirstFixedSurface = 162 ;
	}

#paramId: 500495
#Temperature at the lower boundary of the thermally active layer of bottom sediment
'500495' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 164 ;
	}

#paramId: 500496
#Mean temperature of the water column
'500496' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500497
#Mixed-layer temperature
'500497' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 166 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500498
#Bottom temperature (temperature at the water-bottom sediment interface)
'500498' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 162 ;
	}

#paramId: 500499
#Mixed-layer depth
'500499' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 166 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 500500
#Shape factor with respect to the temperature profile in the thermocline
'500500' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	 typeOfSecondFixedSurface = 162 ;
	 typeOfFirstFixedSurface = 166 ;
	}

#paramId: 500501
#Temperature at the lower boundary of the upper layer of bottom sediment (penetrated by thermal wave)
'500501' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 165 ;
	}

#paramId: 500502
#Sediment thickness of the upper layer of bottom sediments
'500502' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfSecondFixedSurface = 165 ;
	 typeOfFirstFixedSurface = 162 ;
	}

#paramId: 500503
#Icing Base (hft) - Icing Degree Composit
'500503' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500504
#Icing Max Base (hft) - Icing Degree Composit
'500504' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500505
#Icing Max Top (hft) - Icing Degree Composit
'500505' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500506
#Icing Top (hft) - Icing Degree Composit
'500506' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500507
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Degree Composit
'500507' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 199 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500508
#Icing Max Code (1=light,2=moderate,3=severe) - Icing Degree Composit
'500508' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 200 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500509
#Icing Base (hft) - Icing Scenario Composit
'500509' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 201 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500510
#Icing Signifikant Base (hft) - Icing Scenario Composit
'500510' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 202 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500511
#Icing Signifikant Top (hft) - Icing Scenario Composit
'500511' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 203 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500512
#Icing Top (hft) - Icing Scenario Composit
'500512' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 204 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500513
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Scenario Composit
'500513' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 205 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500514
#Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Icing Scenario Composit
'500514' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 206 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500515
#Icing Base (hft) - Icing Degree Composit
'500515' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500516
#Icing Max Base (hft) - Icing Degree Composit
'500516' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 196 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500517
#Icing Max Top (hft) - Icing Degree Composit
'500517' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500518
#Icing Top (hft) - Icing Degree Composit
'500518' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500519
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Degree Composit
'500519' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 199 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500520
#Icing Max Code (1=light,2=moderate,3=severe) - Icing Degree Composit
'500520' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 200 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500521
#Icing Base (hft) - Icing Scenario Composit
'500521' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 201 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500522
#Icing Signifikant Base (hft) - Icing Scenario Composit
'500522' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 202 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500523
#Icing Signifikant Top (hft) - Icing Scenario Composit
'500523' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 203 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500524
#Icing Top (hft) - Icing Scenario Composit
'500524' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 204 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500525
#Icing Vertical Code (1=continuous,2=discontinuous) - Icing Scenario Composit
'500525' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 205 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500526
#Icing Signifikant Code (1=general,2=convective,3=stratiform,4=freezing) - Icing Scenario Composit
'500526' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 206 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500527
#Icing Degree Code (1=light,2=moderate,3=severe)
'500527' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 207 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500528
#Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)
'500528' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 208 ;
	 typeOfGeneratingProcess = 2 ;
	}

#paramId: 500529
#Icing Degree Code (1=light,2=moderate,3=severe)
'500529' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 207 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500530
#Icing Scenario Code (1=general,2=convective,3=stratiform,4=freezing)
'500530' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 208 ;
	 typeOfGeneratingProcess = 0 ;
	}

#paramId: 500531
#current weather (symbol number: 0..9)
'500531' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 209 ;
	}

#paramId: 500538
#cloud type
'500538' = {
	 discipline = 3 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500539
#cloud top height
'500539' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 500540
#cloud top temperature
'500540' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 192 ;
	}

#paramId: 500541
#Relative vorticity, u-component
'500541' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 198 ;
	}

#paramId: 500542
#Relative vorticity, v-component
'500542' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 199 ;
	}

#paramId: 500543
#vertical vorticity
'500543' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 500544
#Potential vorticity
'500544' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 14 ;
	}

#paramId: 500545
#Density
'500545' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}

#paramId: 500546
#Altimeter Settings
'500546' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}

#paramId: 500547
#Convective Precipitation (difference)
'500547' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 37 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 500548
#Soil moisture
'500548' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}

#paramId: 500549
#Soil moisture
'500549' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}

#paramId: 500550
#Potentielle Vorticity (auf Druckflaechen, nicht isentrop)
'500550' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 23 ;
	}

#paramId: 500551
#geostrophische Vorticity
'500551' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 7 ;
	}

#paramId: 500552
#Forcing rechte Seite Omegagleichung
'500552' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 8 ;
	}

#paramId: 500553
#Q-Vektor X-Komponente (geostrophisch)
'500553' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 9 ;
	}

#paramId: 500554
#Q-Vektor Y-Komponente (geostrophisch)
'500554' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 10 ;
	}

#paramId: 500555
#Divergenz Q (geostrophisch)
'500555' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 11 ;
	}

#paramId: 500556
#Q-Vektor senkrecht zu d. Isothermen (geostrophisch)
'500556' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 12 ;
	}

#paramId: 500557
#Q-Vektor parallel zu d. Isothermen (geostrophisch)
'500557' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 13 ;
	}

#paramId: 500558
#Divergenz Qn geostrophisch
'500558' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 14 ;
	}

#paramId: 500559
#Divergenz Qs geostrophisch
'500559' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 15 ;
	}

#paramId: 500560
#Frontogenesefunktion
'500560' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 16 ;
	}

#paramId: 500562
#Divergenz
'500562' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 17 ;
	}

#paramId: 500563
#Q-Vektor parallel zu den Isothermen
'500563' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 18 ;
	}

#paramId: 500564
#Divergenz Qn
'500564' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 19 ;
	}

#paramId: 500565
#Divergenz Qs
'500565' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 20 ;
	}

#paramId: 500566
#Frontogenesis function
'500566' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 21 ;
	}

#paramId: 500567
#Clear Air Turbulence Index
'500567' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 22 ;
	}

#paramId: 500568
#Geopotential height
'500568' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}

#paramId: 500569
#Relative Divergenz
'500569' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 13 ;
	}

#paramId: 500570
#Dry convection top index
'500570' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 202 ;
	}

#paramId: 500572
#Tidal tendencies
'500572' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 192 ;
	}

#paramId: 500573
#Sea surface temperature interpolated in time in C
'500573' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 192 ;
	}

#paramId: 500574
#Logarithm of Pressure
'500574' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 25 ;
	}

#paramId: 500575
#3 hour pressure change
'500575' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 195 ;
	}

#paramId: 500576
#
'500576' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	 typeOfGeneratingProcess = 6 ;
	}

#paramId: 500577
#Variance of soil moisture content
'500577' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 6 ;
	}

#paramId: 500578
#Covariance of soil moisture content
'500578' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 6 ;
	}

#paramId: 500579
#Soil Temperature (layer)
'500579' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 500580
#Soil Moisture Content (0-7 cm)
'500580' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 7 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 500581
#Soil Moisture Content (7-50 cm)
'500581' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 20 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 2 ;
	 scaledValueOfSecondFixedSurface = 50 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 7 ;
	}

#paramId: 500582
#
'500582' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500583
#Min 2m Temperature (i) Initialisation
'500583' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 500584
#Sunshine duration
'500584' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 33 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500585
#Eddy Dissipation Rate
'500585' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 216 ;
	}

#paramId: 500586
#Ellrod Index
'500586' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 217 ;
	}

#paramId: 500588
#Snow melt
'500588' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 16 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500590
#ICAO Standard Atmosphere reference height
'500590' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}

#paramId: 500591
#Niederschlagsdargebot: potential water supply (rain and snow melt) from snowpack - accumulation
'500591' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 209 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 500593
#Global radiation flux
'500593' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}

#paramId: 500594
#exner pressure
'500594' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 26 ;
	}

#paramId: 500595
#normal wind component
'500595' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 34 ;
	}

#paramId: 500596
#tangential wind component
'500596' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 35 ;
	}

#paramId: 500597
#virtual potential temperature
'500597' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}

#paramId: 500598
#Current Direction
'500598' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 500599
#Current Speed
'500599' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 500600
#Prob Windboeen > 25 kn
'500600' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500601
#Prob Windboeen > 27 kn
'500601' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500602
#Prob Sturmboeen > 33 kn
'500602' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500603
#Prob Sturmboeen > 40 kn
'500603' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500604
#Prob Schwere Sturmboeen > 47 kn
'500604' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500605
#Prob Orkanartige Boeen > 55 kn
'500605' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500606
#Prob Orkanboeen > 63 kn
'500606' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500607
#Prob Oberoertliche Orkanboeen > 75 kn
'500607' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 22 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500608
#Prob Starkregen > 10 mm
'500608' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500609
#Prob Heftiger Starkregen > 25 mm
'500609' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500610
#Prob Extrem Heftiger Starkregen > 50 mm
'500610' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500611
#Prob Leichter Schneefall > 0,1 mm
'500611' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500612
#Prob Leichter Schneefall > 0,1 cm
'500612' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500613
#Prob Leichter Schneefall > 0,5 cm
'500613' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500614
#Prob Leichter Schneefall > 1 cm
'500614' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500615
#Prob Schneefall > 5 cm
'500615' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500616
#Prob Starker Schneefall > 10 cm
'500616' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500617
#Prob Extrem starker Schneefall > 25 cm
'500617' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500618
#Prob Frost
'500618' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500619
#Prob Strenger Frost
'500619' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500620
#Prob Gewitter
'500620' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 1 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500621
#Prob Starkes Gewitter
'500621' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 2 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500622
#Prob Schweres Gewitter
'500622' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 3 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500623
#Prob Dauerregen
'500623' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500624
#Prob Ergiebiger Dauerregen
'500624' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 5 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500625
#Prob Extrem ergiebiger Dauerregen
'500625' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 6 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500626
#Prob Schneeverwehung
'500626' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 7 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500627
#Prob Starke Schneeverwehung
'500627' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 8 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500628
#Prob Glaette
'500628' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 9 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500629
#Prob oertlich Glatteis
'500629' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 10 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500630
#Prob Glatteis
'500630' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 11 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500631
#Prob Nebel (ueberoertl. Sichtweite < 150 m)
'500631' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 12 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500632
#Prob Tauwetter
'500632' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 13 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500633
#Prob Starkes Tauwetter
'500633' = {
	 discipline = 0 ;
	 parameterCategory = 196 ;
	 parameterNumber = 14 ;
	 typeOfGeneratingProcess = 5 ;
	}

#paramId: 500634
#Wake-production of TKE due to sub-grid scale orography
'500634' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 220 ;
	}

#paramId: 500635
#Shear-production of TKE due to separated horizontal shear modes
'500635' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 221 ;
	}

#paramId: 500636
#Buoyancy-production of TKE due to sub-grid scale convection
'500636' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 219 ;
	}

#paramId: 500637
#Production of TKE
'500637' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 218 ;
	}

#paramId: 500638
#Atmospheric resistance
'500638' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 200 ;
	}

#paramId: 500639
#Height of thermals above MSL
'500639' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 197 ;
	}

#paramId: 500640
#Mass concentration of dust (minimum mode)
'500640' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 33 ;
	}

#paramId: 500642
#Lapse rate
'500642' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}

#paramId: 500643
#Mass concentration of dust (medium mode)
'500643' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 34 ;
	}

#paramId: 500644
#Mass concentration of dust (maximum mode)
'500644' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 35 ;
	}

#paramId: 500645
#Number concentration of dust (minimum mode)
'500645' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 72 ;
	}

#paramId: 500646
#Number concentration of dust (medium mode)
'500646' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 73 ;
	}

#paramId: 500647
#Number concentration of dust (maximum mode)
'500647' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 74 ;
	}

#paramId: 500648
#Mass concentration of dust (sum of all modes)
'500648' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 251 ;
	}

#paramId: 500649
#Number concentration of dust (sum of all modes)
'500649' = {
	 discipline = 0 ;
	 parameterCategory = 197 ;
	 parameterNumber = 252 ;
	}

#paramId: 500650
#DUMMY_1
'500650' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 1 ;
	}

#paramId: 500651
#DUMMY_2
'500651' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 2 ;
	}

#paramId: 500652
#DUMMY_3
'500652' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 3 ;
	}

#paramId: 500654
#DUMMY_4
'500654' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 4 ;
	}

#paramId: 500655
#DUMMY_5
'500655' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 5 ;
	}

#paramId: 500656
#DUMMY_6
'500656' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 6 ;
	}

#paramId: 500657
#DUMMY_7
'500657' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 7 ;
	}

#paramId: 500658
#DUMMY_8
'500658' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 8 ;
	}

#paramId: 500659
#DUMMY_9
'500659' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 9 ;
	}

#paramId: 500660
#DUMMY_10
'500660' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 10 ;
	}

#paramId: 500661
#DUMMY_11
'500661' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 11 ;
	}

#paramId: 500662
#DUMMY_12
'500662' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 12 ;
	}

#paramId: 500663
#DUMMY_13
'500663' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 13 ;
	}

#paramId: 500664
#DUMMY_14
'500664' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 14 ;
	}

#paramId: 500665
#DUMMY_15
'500665' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 15 ;
	}

#paramId: 500666
#DUMMY_16
'500666' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 16 ;
	}

#paramId: 500667
#DUMMY_17
'500667' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 17 ;
	}

#paramId: 500668
#DUMMY_18
'500668' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 18 ;
	}

#paramId: 500669
#DUMMY_19
'500669' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 19 ;
	}

#paramId: 500670
#DUMMY_20
'500670' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 20 ;
	}

#paramId: 500671
#DUMMY_21
'500671' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 21 ;
	}

#paramId: 500672
#DUMMY_22
'500672' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 22 ;
	}

#paramId: 500673
#DUMMY_23
'500673' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 23 ;
	}

#paramId: 500674
#DUMMY_24
'500674' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 24 ;
	}

#paramId: 500675
#DUMMY_25
'500675' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 25 ;
	}

#paramId: 500676
#DUMMY_26
'500676' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 26 ;
	}

#paramId: 500677
#DUMMY_27
'500677' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 27 ;
	}

#paramId: 500678
#DUMMY_28
'500678' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 28 ;
	}

#paramId: 500679
#DUMMY_29
'500679' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 29 ;
	}

#paramId: 500680
#DUMMY_30
'500680' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 30 ;
	}

#paramId: 500681
#DUMMY_31
'500681' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 31 ;
	}

#paramId: 500682
#DUMMY_32
'500682' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 32 ;
	}

#paramId: 500683
#DUMMY_33
'500683' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 33 ;
	}

#paramId: 500684
#DUMMY_34
'500684' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 34 ;
	}

#paramId: 500685
#DUMMY_35
'500685' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 35 ;
	}

#paramId: 500686
#DUMMY_36
'500686' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 36 ;
	}

#paramId: 500687
#DUMMY_37
'500687' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 37 ;
	}

#paramId: 500688
#DUMMY_38
'500688' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 38 ;
	}

#paramId: 500689
#DUMMY_39
'500689' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 39 ;
	}

#paramId: 500690
#DUMMY_40
'500690' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 40 ;
	}

#paramId: 500691
#DUMMY_41
'500691' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 41 ;
	}

#paramId: 500692
#DUMMY_42
'500692' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 42 ;
	}

#paramId: 500693
#DUMMY_43
'500693' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 43 ;
	}

#paramId: 500694
#DUMMY_44
'500694' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 44 ;
	}

#paramId: 500695
#DUMMY_45
'500695' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 45 ;
	}

#paramId: 500696
#DUMMY_46
'500696' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 46 ;
	}

#paramId: 500697
#DUMMY_47
'500697' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 47 ;
	}

#paramId: 500698
#DUMMY_48
'500698' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 48 ;
	}

#paramId: 500699
#DUMMY_49
'500699' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 49 ;
	}

#paramId: 500700
#DUMMY_50
'500700' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 50 ;
	}

#paramId: 500701
#DUMMY_51
'500701' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 51 ;
	}

#paramId: 500702
#DUMMY_52
'500702' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 52 ;
	}

#paramId: 500703
#DUMMY_53
'500703' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 53 ;
	}

#paramId: 500704
#DUMMY_54
'500704' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 54 ;
	}

#paramId: 500705
#DUMMY_55
'500705' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 55 ;
	}

#paramId: 500706
#DUMMY_56
'500706' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 56 ;
	}

#paramId: 500707
#DUMMY_57
'500707' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 57 ;
	}

#paramId: 500708
#DUMMY_58
'500708' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 58 ;
	}

#paramId: 500709
#DUMMY_59
'500709' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 59 ;
	}

#paramId: 500710
#DUMMY_60
'500710' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 60 ;
	}

#paramId: 500711
#DUMMY_61
'500711' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 61 ;
	}

#paramId: 500712
#DUMMY_62
'500712' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 62 ;
	}

#paramId: 500713
#DUMMY_63
'500713' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 63 ;
	}

#paramId: 500714
#DUMMY_64
'500714' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 64 ;
	}

#paramId: 500715
#DUMMY_65
'500715' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 65 ;
	}

#paramId: 500716
#DUMMY_66
'500716' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 66 ;
	}

#paramId: 500717
#DUMMY_67
'500717' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 67 ;
	}

#paramId: 500718
#DUMMY_68
'500718' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 68 ;
	}

#paramId: 500719
#DUMMY_69
'500719' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 69 ;
	}

#paramId: 500720
#DUMMY_70
'500720' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 70 ;
	}

#paramId: 500721
#DUMMY_71
'500721' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 71 ;
	}

#paramId: 500722
#DUMMY_72
'500722' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 72 ;
	}

#paramId: 500723
#DUMMY_73
'500723' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 73 ;
	}

#paramId: 500724
#DUMMY_74
'500724' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 74 ;
	}

#paramId: 500725
#DUMMY_75
'500725' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 75 ;
	}

#paramId: 500726
#DUMMY_76
'500726' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 76 ;
	}

#paramId: 500727
#DUMMY_77
'500727' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 77 ;
	}

#paramId: 500728
#DUMMY_78
'500728' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 78 ;
	}

#paramId: 500729
#DUMMY_79
'500729' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 79 ;
	}

#paramId: 500730
#DUMMY_80
'500730' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 80 ;
	}

#paramId: 500731
#DUMMY_81
'500731' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 81 ;
	}

#paramId: 500732
#DUMMY_82
'500732' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 82 ;
	}

#paramId: 500733
#DUMMY_83
'500733' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 83 ;
	}

#paramId: 500734
#DUMMY_84
'500734' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 84 ;
	}

#paramId: 500735
#DUMMY_85
'500735' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 85 ;
	}

#paramId: 500736
#DUMMY_86
'500736' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 86 ;
	}

#paramId: 500737
#DUMMY_87
'500737' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 87 ;
	}

#paramId: 500738
#DUMMY_88
'500738' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 88 ;
	}

#paramId: 500739
#DUMMY_89
'500739' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 89 ;
	}

#paramId: 500740
#DUMMY_90
'500740' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 90 ;
	}

#paramId: 500741
#DUMMY_91
'500741' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 91 ;
	}

#paramId: 500742
#DUMMY_92
'500742' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 92 ;
	}

#paramId: 500743
#DUMMY_93
'500743' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 93 ;
	}

#paramId: 500744
#DUMMY_94
'500744' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 94 ;
	}

#paramId: 500745
#DUMMY_95
'500745' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 95 ;
	}

#paramId: 500746
#DUMMY_96
'500746' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 96 ;
	}

#paramId: 500747
#DUMMY_97
'500747' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 97 ;
	}

#paramId: 500748
#DUMMY_98
'500748' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 98 ;
	}

#paramId: 500749
#DUMMY_99
'500749' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 99 ;
	}

#paramId: 500750
#DUMMY_100
'500750' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 100 ;
	}

#paramId: 500751
#DUMMY_101
'500751' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 101 ;
	}

#paramId: 500752
#DUMMY_102
'500752' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 102 ;
	}

#paramId: 500753
#DUMMY_103
'500753' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 103 ;
	}

#paramId: 500754
#DUMMY_104
'500754' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 104 ;
	}

#paramId: 500755
#DUMMY_105
'500755' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 105 ;
	}

#paramId: 500756
#DUMMY_106
'500756' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 106 ;
	}

#paramId: 500757
#DUMMY_107
'500757' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 107 ;
	}

#paramId: 500758
#DUMMY_108
'500758' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 108 ;
	}

#paramId: 500759
#DUMMY_109
'500759' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 109 ;
	}

#paramId: 500760
#DUMMY_110
'500760' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 110 ;
	}

#paramId: 500761
#DUMMY_111
'500761' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 111 ;
	}

#paramId: 500762
#DUMMY_112
'500762' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 112 ;
	}

#paramId: 500763
#DUMMY_113
'500763' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 113 ;
	}

#paramId: 500764
#DUMMY_114
'500764' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 114 ;
	}

#paramId: 500765
#DUMMY_115
'500765' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 115 ;
	}

#paramId: 500766
#DUMMY_116
'500766' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 116 ;
	}

#paramId: 500767
#DUMMY_117
'500767' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 117 ;
	}

#paramId: 500768
#DUMMY_118
'500768' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 118 ;
	}

#paramId: 500769
#DUMMY_119
'500769' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 119 ;
	}

#paramId: 500770
#DUMMY_120
'500770' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 120 ;
	}

#paramId: 500771
#DUMMY_121
'500771' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 121 ;
	}

#paramId: 500772
#DUMMY_122
'500772' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 122 ;
	}

#paramId: 500773
#DUMMY_123
'500773' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 123 ;
	}

#paramId: 500774
#DUMMY_124
'500774' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 124 ;
	}

#paramId: 500775
#DUMMY_125
'500775' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 125 ;
	}

#paramId: 500776
#DUMMY_126
'500776' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 126 ;
	}

#paramId: 500777
#DUMMY_127
'500777' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 127 ;
	}

#paramId: 500778
#DUMMY_128
'500778' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 128 ;
	}

#paramId: 500779
#DUMMY_129
'500779' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 129 ;
	}

#paramId: 500780
#DUMMY_130
'500780' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 130 ;
	}

#paramId: 500781
#DUMMY_131
'500781' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 131 ;
	}

#paramId: 500782
#DUMMY_132
'500782' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 132 ;
	}

#paramId: 500783
#DUMMY_133
'500783' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 133 ;
	}

#paramId: 500784
#DUMMY_134
'500784' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 134 ;
	}

#paramId: 500785
#DUMMY_135
'500785' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 135 ;
	}

#paramId: 500786
#DUMMY_136
'500786' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 136 ;
	}

#paramId: 500787
#DUMMY_137
'500787' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 137 ;
	}

#paramId: 500788
#DUMMY_138
'500788' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 138 ;
	}

#paramId: 500789
#DUMMY_139
'500789' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 139 ;
	}

#paramId: 500790
#DUMMY_140
'500790' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 140 ;
	}

#paramId: 500791
#DUMMY_141
'500791' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 141 ;
	}

#paramId: 500792
#DUMMY_142
'500792' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 142 ;
	}

#paramId: 500793
#DUMMY_143
'500793' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 143 ;
	}

#paramId: 500794
#DUMMY_144
'500794' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 144 ;
	}

#paramId: 500795
#DUMMY_145
'500795' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 145 ;
	}

#paramId: 500796
#DUMMY_146
'500796' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 146 ;
	}

#paramId: 500797
#DUMMY_147
'500797' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 147 ;
	}

#paramId: 500798
#DUMMY_148
'500798' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 148 ;
	}

#paramId: 500799
#DUMMY_149
'500799' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 149 ;
	}

#paramId: 500800
#DUMMY_150
'500800' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 150 ;
	}

#paramId: 500801
#DUMMY_151
'500801' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 151 ;
	}

#paramId: 500802
#DUMMY_152
'500802' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 152 ;
	}

#paramId: 500803
#DUMMY_153
'500803' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 153 ;
	}

#paramId: 500804
#DUMMY_154
'500804' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 154 ;
	}

#paramId: 500805
#DUMMY_155
'500805' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 155 ;
	}

#paramId: 500806
#DUMMY_156
'500806' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 156 ;
	}

#paramId: 500807
#DUMMY_157
'500807' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 157 ;
	}

#paramId: 500808
#DUMMY_158
'500808' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 158 ;
	}

#paramId: 500809
#DUMMY_159
'500809' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 159 ;
	}

#paramId: 500810
#DUMMY_160
'500810' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 160 ;
	}

#paramId: 500811
#DUMMY_161
'500811' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 161 ;
	}

#paramId: 500812
#DUMMY_162
'500812' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 162 ;
	}

#paramId: 500813
#DUMMY_163
'500813' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 163 ;
	}

#paramId: 500814
#DUMMY_164
'500814' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 164 ;
	}

#paramId: 500815
#DUMMY_165
'500815' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 165 ;
	}

#paramId: 500816
#DUMMY_166
'500816' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 166 ;
	}

#paramId: 500817
#DUMMY_167
'500817' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 167 ;
	}

#paramId: 500818
#DUMMY_168
'500818' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 168 ;
	}

#paramId: 500819
#DUMMY_169
'500819' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 169 ;
	}

#paramId: 500820
#DUMMY_170
'500820' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 170 ;
	}

#paramId: 500821
#DUMMY_171
'500821' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 171 ;
	}

#paramId: 500822
#DUMMY_172
'500822' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 172 ;
	}

#paramId: 500823
#DUMMY_173
'500823' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 173 ;
	}

#paramId: 500824
#DUMMY_174
'500824' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 174 ;
	}

#paramId: 500825
#DUMMY_175
'500825' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 175 ;
	}

#paramId: 500826
#DUMMY_176
'500826' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 176 ;
	}

#paramId: 500827
#DUMMY_177
'500827' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 177 ;
	}

#paramId: 500828
#DUMMY_178
'500828' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 178 ;
	}

#paramId: 500829
#DUMMY_179
'500829' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 179 ;
	}

#paramId: 500830
#DUMMY_180
'500830' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 180 ;
	}

#paramId: 500831
#DUMMY_181
'500831' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 181 ;
	}

#paramId: 500832
#DUMMY_182
'500832' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 182 ;
	}

#paramId: 500833
#DUMMY_183
'500833' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 183 ;
	}

#paramId: 500834
#DUMMY_184
'500834' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 184 ;
	}

#paramId: 500835
#DUMMY_185
'500835' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 185 ;
	}

#paramId: 500836
#DUMMY_186
'500836' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 186 ;
	}

#paramId: 500837
#DUMMY_187
'500837' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 187 ;
	}

#paramId: 500838
#DUMMY_188
'500838' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 188 ;
	}

#paramId: 500839
#DUMMY_189
'500839' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 189 ;
	}

#paramId: 500840
#DUMMY_190
'500840' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 190 ;
	}

#paramId: 500841
#DUMMY_191
'500841' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 191 ;
	}

#paramId: 500842
#DUMMY_192
'500842' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 192 ;
	}

#paramId: 500843
#DUMMY_193
'500843' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 193 ;
	}

#paramId: 500844
#DUMMY_194
'500844' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 194 ;
	}

#paramId: 500845
#DUMMY_195
'500845' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 195 ;
	}

#paramId: 500846
#DUMMY_196
'500846' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 196 ;
	}

#paramId: 500847
#DUMMY_197
'500847' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 197 ;
	}

#paramId: 500848
#DUMMY_198
'500848' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 198 ;
	}

#paramId: 500849
#DUMMY_199
'500849' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 199 ;
	}

#paramId: 500850
#DUMMY_200
'500850' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 200 ;
	}

#paramId: 500851
#DUMMY_201
'500851' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 201 ;
	}

#paramId: 500852
#DUMMY_202
'500852' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 202 ;
	}

#paramId: 500853
#DUMMY_203
'500853' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 203 ;
	}

#paramId: 500854
#DUMMY_204
'500854' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 204 ;
	}

#paramId: 500855
#DUMMY_205
'500855' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 205 ;
	}

#paramId: 500856
#DUMMY_206
'500856' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 206 ;
	}

#paramId: 500857
#DUMMY_207
'500857' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 207 ;
	}

#paramId: 500858
#DUMMY_208
'500858' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 208 ;
	}

#paramId: 500859
#DUMMY_209
'500859' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 209 ;
	}

#paramId: 500860
#DUMMY_210
'500860' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 210 ;
	}

#paramId: 500861
#DUMMY_211
'500861' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 211 ;
	}

#paramId: 500862
#DUMMY_212
'500862' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 212 ;
	}

#paramId: 500863
#DUMMY_213
'500863' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 213 ;
	}

#paramId: 500864
#DUMMY_214
'500864' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 214 ;
	}

#paramId: 500865
#DUMMY_215
'500865' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 215 ;
	}

#paramId: 500866
#DUMMY_216
'500866' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 216 ;
	}

#paramId: 500867
#DUMMY_217
'500867' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 217 ;
	}

#paramId: 500868
#DUMMY_218
'500868' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 218 ;
	}

#paramId: 500869
#DUMMY_219
'500869' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 219 ;
	}

#paramId: 500870
#DUMMY_220
'500870' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 220 ;
	}

#paramId: 500871
#DUMMY_221
'500871' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 221 ;
	}

#paramId: 500872
#DUMMY_222
'500872' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 222 ;
	}

#paramId: 500873
#DUMMY_223
'500873' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 223 ;
	}

#paramId: 500874
#DUMMY_224
'500874' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 224 ;
	}

#paramId: 500875
#DUMMY_225
'500875' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 225 ;
	}

#paramId: 500876
#DUMMY_226
'500876' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 226 ;
	}

#paramId: 500877
#DUMMY_227
'500877' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 227 ;
	}

#paramId: 500878
#DUMMY_228
'500878' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 228 ;
	}

#paramId: 500879
#DUMMY_229
'500879' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 229 ;
	}

#paramId: 500880
#DUMMY_230
'500880' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 230 ;
	}

#paramId: 500881
#DUMMY_231
'500881' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 231 ;
	}

#paramId: 500882
#DUMMY_232
'500882' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 232 ;
	}

#paramId: 500883
#DUMMY_233
'500883' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 233 ;
	}

#paramId: 500884
#DUMMY_234
'500884' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 234 ;
	}

#paramId: 500885
#DUMMY_235
'500885' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 235 ;
	}

#paramId: 500886
#DUMMY_236
'500886' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 236 ;
	}

#paramId: 500887
#DUMMY_237
'500887' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 237 ;
	}

#paramId: 500888
#DUMMY_238
'500888' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 238 ;
	}

#paramId: 500889
#DUMMY_239
'500889' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 239 ;
	}

#paramId: 500890
#DUMMY_240
'500890' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 240 ;
	}

#paramId: 500891
#DUMMY_241
'500891' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 241 ;
	}

#paramId: 500892
#DUMMY_242
'500892' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 242 ;
	}

#paramId: 500893
#DUMMY_243
'500893' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 243 ;
	}

#paramId: 500894
#DUMMY_244
'500894' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 244 ;
	}

#paramId: 500895
#DUMMY_245
'500895' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 245 ;
	}

#paramId: 500896
#DUMMY_246
'500896' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 246 ;
	}

#paramId: 500897
#DUMMY_247
'500897' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 247 ;
	}

#paramId: 500898
#DUMMY_248
'500898' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 248 ;
	}

#paramId: 500899
#DUMMY_249
'500899' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 249 ;
	}

#paramId: 500900
#DUMMY_250
'500900' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 250 ;
	}

#paramId: 500901
#DUMMY_251
'500901' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 251 ;
	}

#paramId: 500902
#DUMMY_252
'500902' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 252 ;
	}

#paramId: 500903
#DUMMY_253
'500903' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 253 ;
	}

#paramId: 500904
#DUMMY_254
'500904' = {
	 discipline = 0 ;
	 parameterCategory = 254 ;
	 parameterNumber = 254 ;
	}

#paramId: 500905
#Specific Humidity (S)
'500905' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502307
#Albedo - diffusive solar - time average (0.3 - 5.0 m-6)
'502307' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 18 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 502308
#Albedo - diffusive solar (0.3 - 5.0 m-6)
'502308' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 18 ;
	}

#paramId: 502309
#center latitude
'502309' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 numberOfGridInReference = 1 ;
	}

#paramId: 502310
#center longitude
'502310' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 numberOfGridInReference = 1 ;
	}

#paramId: 502311
#edge midpoint latitude
'502311' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 numberOfGridInReference = 3 ;
	}

#paramId: 502312
#edge midpoint longitude
'502312' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 numberOfGridInReference = 3 ;
	}

#paramId: 502313
#vertex latitude
'502313' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 1 ;
	 numberOfGridInReference = 2 ;
	}

#paramId: 502314
#vertex longitude
'502314' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 2 ;
	 numberOfGridInReference = 2 ;
	}

#paramId: 502315
#Number of cloud droplets per unit mass of air
'502315' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 28 ;
	}

#paramId: 502316
#Number of cloud ice particles per unit mass of air
'502316' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 29 ;
	}

#paramId: 502317
#Latent Heat Net Flux - instant - at surface
'502317' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502318
#Sensible Heat Net Flux - instant - at surface
'502318' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502319
#Latent Heat Net Flux - accumulated _ surface
'502319' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502320
#Sensible Heat Net Flux - accumulated _ surface
'502320' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502321
#Net short wave radiation flux - accumulated _ surface
'502321' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502322
#Net long wave radiation flux - accumulated _  surface
'502322' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502323
#Net long wave radiation flux  - accumulated _ model top
'502323' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 502327
#Net short wave radiation flux - accumulated _ model top
'502327' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 502328
#Snow temperature  - multi level
'502328' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502329
#Snow depth  - multi level
'502329' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502330
#Snow density in  - multi level
'502330' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 61 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502331
#Water equivalent  of accumulated snoe depth in - multi level
'502331' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 60 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502332
#Liquid water content in snow - multi level
'502332' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 210 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 502333
#salinity
'502333' = {
	 discipline = 1 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 502334
#Stream function
'502334' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}

#paramId: 502335
#Velocity potential
'502335' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}

#paramId: 502336
#Skin temperature
'502336' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502339
#Downward direct short wave radiation flux at surface
'502339' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502340
#Snow cover
'502340' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 42 ;
	}

#paramId: 502341
#Cloud Cover (0 - 400 hPa)
'502341' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 40000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 502342
#Cloud Cover (400 - 800 hPa)
'502342' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaledValueOfSecondFixedSurface = 80000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaledValueOfFirstFixedSurface = 40000 ;
	}

#paramId: 502343
#Cloud Cover (800 hPa - Soil)
'502343' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 22 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaledValueOfFirstFixedSurface = 80000 ;
	}

#paramId: 502344
#Albedo - diffusive solar - time average (UV: 0.3 - 0.7 m-6)
'502344' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 222 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 502345
#Albedo - diffusive solar (UV: 0.3 - 0.7 m-6)
'502345' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 222 ;
	}

#paramId: 502346
#Albedo - near infrared - time average (0.7 - 5.0 m-6)
'502346' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 223 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 502347
#Albedo - near infrared (0.7 - 5.0 m-6)
'502347' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 223 ;
	}

#paramId: 502348
#Water Runoff (s)
'502348' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 502349
#Water Runoff
'502349' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 1 ;
	 scaledValueOfFirstFixedSurface = 1 ;
	}

#paramId: 502352
#Eddy Dissipation Rate Total Col-Max. Upper FIR
'502352' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 224 ;
	}

#paramId: 502353
#Eddy Dissipation Rate Total Col-Max. Lower UIR
'502353' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 225 ;
	}

#paramId: 502354
#Eddy Dissipation Rate Total Col-Max. Upper UIR
'502354' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 226 ;
	}

#paramId: 502397
#Virtual Temperature
'502397' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 502424
#Vertical u-component shear
'502424' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 15 ;
	}

#paramId: 502425
#Vertical v-component shear
'502425' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 16 ;
	}

#paramId: 502693
#Potential temperature
'502693' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 502700
#Boundary layer dissipation
'502700' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 20 ;
	}

#paramId: 502701
#Sunshine duration
'502701' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 24 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 502702
#Brightness temperature
'502702' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 4 ;
	}

#paramId: 502703
#Heat index
'502703' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}

#paramId: 502705
#Total column water
'502705' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 51 ;
	}

#paramId: 502706
#Large scale precipitation (non-convective)
'502706' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}

#paramId: 502707
#Snowfall rate water equivalent
'502707' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}

#paramId: 502708
#Convective snow
'502708' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 14 ;
	}

#paramId: 502709
#Large scale snow
'502709' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 15 ;
	}

#paramId: 502710
#Snow age
'502710' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 17 ;
	}

#paramId: 502711
#Absolute humidity
'502711' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 18 ;
	}

#paramId: 502712
#Precipitation type
'502712' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 19 ;
	}

#paramId: 502713
#Integrated liquid water
'502713' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 20 ;
	}

#paramId: 502714
#Condensate
'502714' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 21 ;
	}

#paramId: 502715
#Ice water mixing ratio
'502715' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 23 ;
	}

#paramId: 502717
#Maximum relative humidity
'502717' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 27 ;
	}

#paramId: 502718
#Maximum absolute humidity
'502718' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 28 ;
	}

#paramId: 502719
#Total snowfall
'502719' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 29 ;
	}

#paramId: 502720
#Precipitable water category
'502720' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 30 ;
	}

#paramId: 502721
#Hail
'502721' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 31 ;
	}

#paramId: 502722
#Categorical rain
'502722' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 33 ;
	}

#paramId: 502723
#Categorical freezing rain
'502723' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 34 ;
	}

#paramId: 502724
#Categorical ice pellets
'502724' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 35 ;
	}

#paramId: 502725
#Categorical snow
'502725' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 36 ;
	}

#paramId: 502727
#Percent frozen precipitation
'502727' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 39 ;
	}

#paramId: 502728
#Potential evaporation
'502728' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 40 ;
	}

#paramId: 502729
#Potential evaporation rate
'502729' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 41 ;
	}

#paramId: 502730
#Rain fraction of total cloud water
'502730' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 43 ;
	}

#paramId: 502731
#Rime factor
'502731' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 44 ;
	}

#paramId: 502732
#Large scale water precipitation (non-convective)
'502732' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 47 ;
	}

#paramId: 502733
#Convective water precipitation
'502733' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 48 ;
	}

#paramId: 502734
#Total water precipitation
'502734' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 49 ;
	}

#paramId: 502735
#Total snow precipitation
'502735' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 50 ;
	}

#paramId: 502737
#Snow Fall water equivalent
'502737' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 53 ;
	}

#paramId: 502738
#Convective snowfall rate
'502738' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 58 ;
	}

#paramId: 502739
#Large scale snowfall rate
'502739' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 59 ;
	}

#paramId: 502740
#Water equivalent of accumulated snow depth
'502740' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}

#paramId: 502741
#Freezing rain precipitation rate
'502741' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 67 ;
	}

#paramId: 502742
#Ice pellets precipitation rate
'502742' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 68 ;
	}

#paramId: 502743
#Maximum wind speed
'502743' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 21 ;
	}

#paramId: 502744
#u-component of wind (gust)
'502744' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 23 ;
	}

#paramId: 502745
#v-component of wind (gust)
'502745' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 24 ;
	}

#paramId: 502746
#Horizontal momentum flux
'502746' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 26 ;
	}

#paramId: 502747
#U-component storm motion
'502747' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 27 ;
	}

#paramId: 502748
#V-component storm motion
'502748' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 28 ;
	}

#paramId: 502749
#Thickness
'502749' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}

#paramId: 502751
#Minimum dew point depression
'502751' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}

#paramId: 502752
#Pressure altitude
'502752' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}

#paramId: 502753
#Density altitude
'502753' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}

#paramId: 502754
#5-wave geopotential height
'502754' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}

#paramId: 502755
#Zonal flux of gravity wave stress
'502755' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	}

#paramId: 502756
#Meridional flux of gravity wave stress
'502756' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	}

#paramId: 502757
#Planetary boundary layer height
'502757' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 18 ;
	}

#paramId: 502758
#5-wave geopotential height anomaly
'502758' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 19 ;
	}

#paramId: 502759
#Net short-wave radiation flux (top of atmosphere)
'502759' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}

#paramId: 502760
#Downward short-wave radiation flux
'502760' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	}

#paramId: 502761
#Net short-wave radiation flux, clear sky
'502761' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	}

#paramId: 502762
#Downward UV radiation
'502762' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 12 ;
	}

#paramId: 502763
#Net long wave radiation flux (surface)
'502763' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 0 ;
	}

#paramId: 502764
#Net long wave radiation flux (top of atmosphere)
'502764' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 1 ;
	}

#paramId: 502765
#Downward long-wave radiation flux
'502765' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	}

#paramId: 502766
#Upward long-wave radiation flux
'502766' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	}

#paramId: 502767
#Net long-wave radiation flux, clear sky
'502767' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	}

#paramId: 502768
#Cloud Ice
'502768' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 0 ;
	}

#paramId: 502769
#Cloud water
'502769' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 6 ;
	}

#paramId: 502770
#Cloud amount
'502770' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 7 ;
	}

#paramId: 502771
#Cloud type
'502771' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 8 ;
	}

#paramId: 502772
#Thunderstorm maximum tops
'502772' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 9 ;
	}

#paramId: 502773
#Thunderstorm coverage
'502773' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 10 ;
	}

#paramId: 502774
#Cloud base
'502774' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 11 ;
	}

#paramId: 502775
#Cloud top
'502775' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 12 ;
	}

#paramId: 502776
#Cloud work function
'502776' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 15 ;
	}

#paramId: 502777
#Convective cloud efficiency
'502777' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 16 ;
	}

#paramId: 502778
#Total condensate
'502778' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 17 ;
	}

#paramId: 502779
#Total column-integrated cloud water
'502779' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 18 ;
	}

#paramId: 502780
#Total column-integrated cloud ice
'502780' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 19 ;
	}

#paramId: 502781
#Total column-integrated condensate
'502781' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 20 ;
	}

#paramId: 502782
#Ice fraction of total condensate
'502782' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 21 ;
	}

#paramId: 502783
#Cloud ice mixing ratio
'502783' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 23 ;
	}

#paramId: 502785
#K index
'502785' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	}

#paramId: 502786
#Total totals index
'502786' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 4 ;
	}

#paramId: 502787
#Sweat index
'502787' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 5 ;
	}

#paramId: 502788
#Energy helicity index
'502788' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 9 ;
	}

#paramId: 502789
#Surface lifted index
'502789' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 10 ;
	}

#paramId: 502790
#Best (4-layer) lifted index
'502790' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 11 ;
	}

#paramId: 502791
#Aerosol type
'502791' = {
	 discipline = 0 ;
	 parameterCategory = 13 ;
	 parameterNumber = 0 ;
	}

#paramId: 502792
#Base spectrum width
'502792' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 0 ;
	}

#paramId: 502793
#Base radial velocity
'502793' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 2 ;
	}

#paramId: 502794
#Vertically-integrated liquid
'502794' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 3 ;
	}

#paramId: 502795
#Layer-maximum base reflectivity
'502795' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 4 ;
	}

#paramId: 502796
#Precipitation
'502796' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 502797
#Air concentration of Caesium 137
'502797' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 0 ;
	}

#paramId: 502798
#Air concentration of Iodine 131
'502798' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 1 ;
	}

#paramId: 502799
#Air concentration of radioactive pollutant
'502799' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 2 ;
	}

#paramId: 502800
#Ground deposition of Caesium 137
'502800' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 3 ;
	}

#paramId: 502801
#Ground deposition of Iodine 131
'502801' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 4 ;
	}

#paramId: 502802
#Ground deposition of radioactive pollutant
'502802' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 5 ;
	}

#paramId: 502843
#Time-integrated air concentration of caesium pollutant
'502843' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 6 ;
	}

#paramId: 502844
#Time-integrated air concentration of iodine pollutant
'502844' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 7 ;
	}

#paramId: 502845
#Time-integrated air concentration of radioactive pollutant
'502845' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 8 ;
	}

#paramId: 502846
#Volcanic ash
'502846' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 4 ;
	}

#paramId: 502847
#Icing top
'502847' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 5 ;
	}

#paramId: 502848
#Icing base
'502848' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 6 ;
	}

#paramId: 502849
#Turbulence top
'502849' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 8 ;
	}

#paramId: 502850
#Turbulence base
'502850' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 9 ;
	}

#paramId: 502851
#Turbulence
'502851' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 10 ;
	}

#paramId: 502852
#Planetary boundary layer regime
'502852' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 12 ;
	}

#paramId: 502853
#Contrail intensity
'502853' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 13 ;
	}

#paramId: 502854
#Contrail engine type
'502854' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 14 ;
	}

#paramId: 502855
#Contrail top
'502855' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 15 ;
	}

#paramId: 502856
#Contrail base
'502856' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 16 ;
	}

#paramId: 502857
#Maximum snow albedo
'502857' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 17 ;
	}

#paramId: 502858
#Icing
'502858' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 20 ;
	}

#paramId: 502859
#Horizontal extent of cumulonimbus (CB)
'502859' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 25 ;
	}

#paramId: 502860
#In-cloud turbulence
'502860' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 21 ;
	}

#paramId: 502861
#Clear air turbulence (CAT)
'502861' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 22 ;
	}

#paramId: 502862
#Supercooled large droplet probability (see Note 4)
'502862' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 23 ;
	}

#paramId: 502864
#Seconds prior to initial reference time (defined in Section 1)
'502864' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}

#paramId: 502865
#Flash flood guidance (Encoded as an accumulation over a floating subinterval of time between the ref
'502865' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	}

#paramId: 502866
#Flash flood runoff (Encoded as an accumulation over a floating subinterval of time)
'502866' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 1 ;
	}

#paramId: 502867
#Remotely sensed snow cover
'502867' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 502868
#Elevation of snow covered terrain
'502868' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 502869
#Snow water equivalent percent of normal
'502869' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 502870
#Baseflow-groundwater runoff
'502870' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}

#paramId: 502871
#Storm surface runoff
'502871' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 502872
#Conditional percent precipitation amount fractile for an overall period (Encoded as an accumulation)
'502872' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 502873
#Percent precipitation in a sub-period of an overall period (Encoded as per cent accumulation over th
'502873' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 502874
#Probability of 0.01 inch of precipitation (POP)
'502874' = {
	 discipline = 1 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 502875
#Evapotranspiration
'502875' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 502876
#Land use
'502876' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 8 ;
	}

#paramId: 502877
#Volumetric soil moisture content
'502877' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}

#paramId: 502878
#Ground heat flux
'502878' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}

#paramId: 502879
#Moisture availability
'502879' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}

#paramId: 502880
#Exchange coefficient
'502880' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}

#paramId: 502881
#Blackadar mixing length scale
'502881' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 14 ;
	}

#paramId: 502882
#Canopy conductance
'502882' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	}

#paramId: 502883
#Solar parameter in canopy conductance
'502883' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 18 ;
	}

#paramId: 502885
#Soil moisture parameter in canopy conductance
'502885' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}

#paramId: 502886
#Humidity parameter in canopy conductance
'502886' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}

#paramId: 502887
#Column-integrated soil water
'502887' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}

#paramId: 502888
#Heat flux
'502888' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}

#paramId: 502889
#Volumetric soil moisture
'502889' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 25 ;
	}

#paramId: 502890
#Volumetric wilting point
'502890' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}

#paramId: 502891
#Upper layer soil temperature
'502891' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}

#paramId: 502892
#Upper layer soil moisture
'502892' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 2 ;
	}

#paramId: 502893
#Lower layer soil moisture
'502893' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 3 ;
	}

#paramId: 502894
#Bottom layer soil temperature
'502894' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 4 ;
	}

#paramId: 502895
#Liquid volumetric soil moisture (non-frozen)
'502895' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 5 ;
	}

#paramId: 502896
#Number of soil layers in root zone
'502896' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	}

#paramId: 502897
#Transpiration stress-onset (soil moisture)
'502897' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}

#paramId: 502898
#Direct evaporation cease (soil moisture)
'502898' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}

#paramId: 502899
#Soil porosity
'502899' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}

#paramId: 502900
#Liquid volumetric soil moisture (non-frozen)
'502900' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 10 ;
	}

#paramId: 502919
#Volumetric transpiration stress-onset (soil moisture)
'502919' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 11 ;
	}

#paramId: 502920
#Transpiration stress-onset (soil moisture)
'502920' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 12 ;
	}

#paramId: 502921
#Volumetric direct evaporation cease (soil moisture)
'502921' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 13 ;
	}

#paramId: 502922
#Direct evaporation cease (soil moisture)
'502922' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 14 ;
	}

#paramId: 502923
#Soil porosity
'502923' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 15 ;
	}

#paramId: 502924
#Volumetric saturation of soil moisture
'502924' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	}

#paramId: 502926
#Estimated precipitation
'502926' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 0 ;
	}

#paramId: 502927
#Instantaneous rain rate
'502927' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	}

#paramId: 502928
#Cloud top height quality indicator
'502928' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}

#paramId: 502929
#Estimated u component of wind
'502929' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}

#paramId: 502930
#Estimated v component of wind
'502930' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}

#paramId: 502931
#Number of pixels used
'502931' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 6 ;
	}

#paramId: 502932
#Solar zenith angle
'502932' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}

#paramId: 502933
#Reflectance in 0.6 micron channel
'502933' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 9 ;
	}

#paramId: 502934
#Reflectance in 0.8 micron channel
'502934' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}

#paramId: 502935
#Reflectance in 1.6 micron channel
'502935' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	}

#paramId: 502936
#Reflectance in 3.9 micron channel
'502936' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 12 ;
	}

#paramId: 502937
#Atmospheric divergence
'502937' = {
	 discipline = 3 ;
	 parameterCategory = 1 ;
	 parameterNumber = 13 ;
	}

#paramId: 502938
#Primary wave direction
'502938' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 10 ;
	}

#paramId: 502939
#Primary wave mean period
'502939' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 11 ;
	}

#paramId: 502940
#Secondary wave mean period
'502940' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	}

#paramId: 502941
#Deviation of sea level from mea
'502941' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 1 ;
	}

#paramId: 502942
#Seconds prior to initial reference time (defined in Section 1)
'502942' = {
	 discipline = 10 ;
	 parameterCategory = 191 ;
	 parameterNumber = 0 ;
	}

#paramId: 502943
#Standard deviation of height
'502943' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 7 ;
	}

#paramId: 502944
#Maximum temperature
'502944' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	}

#paramId: 502945
#Minimum temperature
'502945' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 5 ;
	}

#paramId: 502946
#Visibility
'502946' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	}

#paramId: 502947
#Radar spectra (2)
'502947' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 7 ;
	}

#paramId: 502948
#Radar spectra (3)
'502948' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 8 ;
	}

#paramId: 502949
#Parcel lifted index (to 500 hPa)
'502949' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	}

#paramId: 502950
#Temperature anomaly
'502950' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 9 ;
	}

#paramId: 502951
#Pressure anomaly
'502951' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 8 ;
	}

#paramId: 502952
#Geopotential height anomaly
'502952' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 9 ;
	}

#paramId: 502953
#Montgomery stream Function
'502953' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}

#paramId: 502954
#Sigma coordinate vertical velocity
'502954' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}

#paramId: 502955
#Absolute divergence
'502955' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	}

#paramId: 502958
#U-component of current
'502958' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 502959
#V-component of current
'502959' = {
	 discipline = 10 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}

#paramId: 502960
#Precipitable water
'502960' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 3 ;
	}

#paramId: 502961
#Saturation deficit
'502961' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 5 ;
	}

#paramId: 502962
#Precipitation rate
'502962' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 7 ;
	}

#paramId: 502963
#Thunderstorm probability
'502963' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 2 ;
	}

#paramId: 502964
#Convective precipitation (water)
'502964' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 10 ;
	}

#paramId: 502965
#Transient thermocline depth
'502965' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 2 ;
	}

#paramId: 502966
#Main thermocline depth
'502966' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	}

#paramId: 502967
#Main thermocline anomaly
'502967' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 1 ;
	}

#paramId: 502968
#Best lifted index (to 500 hPa)
'502968' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 1 ;
	}

#paramId: 502969
#Soil moisture content
'502969' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	}

#paramId: 503011
#Salinity
'503011' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 3 ;
	}

#paramId: 503012
#Direction of ice drift
'503012' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 503013
#Speed of ice drift
'503013' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}

#paramId: 503014
#U-component of ice drift
'503014' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}

#paramId: 503015
#V-component of ice drift
'503015' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}

#paramId: 503016
#Ice growth rate
'503016' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}

#paramId: 503017
#Ice divergence
'503017' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}

#paramId: 503019
#Secondary wave direction
'503019' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 12 ;
	}

#paramId: 503020
#Net short-wave radiation flux (surface)
'503020' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 0 ;
	}

#paramId: 503021
#Radiance (with respect to wave number)
'503021' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 5 ;
	}

#paramId: 503022
#Radiance (with respect to wave length)
'503022' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 6 ;
	}

#paramId: 503023
#Convective inhibition
'503023' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 7 ;
	}

#paramId: 503024
#Wind mixing energy
'503024' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 19 ;
	}

#paramId: 503025
#Soil Temperature
'503025' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	}

#paramId: 503028
#Wilting point
'503028' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfSecondFixedSurface = 106 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 2 ;
	 typeOfFirstFixedSurface = 106 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 503038
#Snow phase change heat flux
'503038' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}

#paramId: 503039
#Vapor pressure
'503039' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 4 ;
	}

#paramId: 503047
#Land use class fraction
'503047' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 36 ;
	}

#paramId: 503048
#Saturation of soil moisture
'503048' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 17 ;
	}

#paramId: 503049
#Eddy dissipitation rate of TKE
'503049' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 227 ;
	}

#paramId: 503050
#Radar precipitation rate
'503050' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 195 ;
	}

#paramId: 503052
#Radar quality information
'503052' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 196 ;
	}

#paramId: 503053
#Radar blacklist
'503053' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 197 ;
	}

#paramId: 503054
#Height of radar beam above ground
'503054' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 198 ;
	}

#paramId: 503055
#Specific humidity (diagnostic)
'503055' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 211 ;
	}

#paramId: 503056
#Specific cloud water content (diagnostic)
'503056' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 212 ;
	}

#paramId: 503057
#Specific cloud ice content (diagnostic)
'503057' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 213 ;
	}

#paramId: 503058
#Total column integrated water vapour (diagnostic)
'503058' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 214 ;
	}

#paramId: 503059
#Total column integrated cloud water (diagnostic)
'503059' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 215 ;
	}

#paramId: 503060
#Total column integrated cloud ice (diagnostic)
'503060' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 216 ;
	}

#paramId: 503061
#Downward diffusive short wave radiation flux at surface (mean over forecast time)
'503061' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503062
#Upward diffusive short wave radiation flux at surface ( mean over forecast time)
'503062' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503063
#Momentum Flux, U-Component (m)
'503063' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503064
#Momentum Flux, V-Component (m)
'503064' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503065
#u-momentum flux due to SSO-effects
'503065' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 503066
#v-momentum flux due to SSO-effects
'503066' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfGeneratingProcess = 1 ;
	}

#paramId: 503068
#precipitation, qualified,BRD
'503068' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503069
#precipitation,BRD
'503069' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503070
#precipitation phase,BRD
'503070' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 194 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503071
#hail flag,BRD
'503071' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 195 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503072
#snow_rate,BRD
'503072' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 196 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503073
#snow_rate,qualified,BRD
'503073' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 197 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503074
#Area weights for regular lon-lat grid
'503074' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 193 ;
	}

#paramId: 503075
#Geometric height of the earths surface above mean sea level at vertex point (ICON)
'503075' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 numberOfGridInReference = 2 ;
	 typeOfSecondFixedSurface = 101 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503076
#Gravity wave dissipation
'503076' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 23 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503078
#Relative humidity over mixed phase
'503078' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 220 ;
	}

#paramId: 503079
#Soil moisture index (multilayers)
'503079' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503080
#Land use class
'503080' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 35 ;
	}

#paramId: 503081
#Water depth
'503081' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 14 ;
	}

#paramId: 503082
#Friction velocity
'503082' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 17 ;
	}

#paramId: 503083
#Coefficient of drag with waves
'503083' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 16 ;
	}

#paramId: 503084
#Normalized wave stress
'503084' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 19 ;
	}

#paramId: 503085
#Inverse mean frequency of wind waves
'503085' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	}

#paramId: 503086
#Mean zero-crossing period of wind waves
'503086' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 29 ;
	}

#paramId: 503087
#Directional width of wind waves
'503087' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 32 ;
	}

#paramId: 503088
#Inverse mean frequency of total swell
'503088' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}

#paramId: 503089
#Inverse mean zero crossing period of total swell
'503089' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 30 ;
	}

#paramId: 503090
#Directional width of total swell
'503090' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 33 ;
	}

#paramId: 503091
#Goda peakedness parameter
'503091' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 45 ;
	}

#paramId: 503092
#Spectral kurtosis
'503092' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 43 ;
	}

#paramId: 503093
#Benjamin-Feir index
'503093' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 44 ;
	}

#paramId: 503094
#Maximum individual wave height
'503094' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 24 ;
	}

#paramId: 503095
#Maximum wave period
'503095' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 23 ;
	}

#paramId: 503096
#Peak frequency (interpolated)
'503096' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 201 ;
	}

#paramId: 503097
#Meansquare slope
'503097' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 20 ;
	}

#paramId: 503106
#Hail  mixing ratio
'503106' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 71 ;
	}

#paramId: 503107
#Hail
'503107' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 72 ;
	}

#paramId: 503108
#Hail  precipitation rate
'503108' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 73 ;
	}

#paramId: 503109
#Reflectivity of cloud droplets
'503109' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 9 ;
	}

#paramId: 503110
#Reflectivity of  cloud ice
'503110' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 10 ;
	}

#paramId: 503111
#Reflectivity of snow
'503111' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 11 ;
	}

#paramId: 503112
#Reflectivity of rain
'503112' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 12 ;
	}

#paramId: 503113
#Reflectivity of graupel
'503113' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 13 ;
	}

#paramId: 503114
#Reflectivity of hail
'503114' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 14 ;
	}

#paramId: 503115
#Specific number concentration of rain
'503115' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 228 ;
	}

#paramId: 503116
#Number density of rain
'503116' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 229 ;
	}

#paramId: 503117
#Specific number concentration of snow
'503117' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 217 ;
	}

#paramId: 503118
#Specific number concentration of graupel
'503118' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 218 ;
	}

#paramId: 503119
#Specific number concentration of hail
'503119' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 219 ;
	}

#paramId: 503120
#Number density of snow
'503120' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 221 ;
	}

#paramId: 503121
#Number density of graupel
'503121' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 222 ;
	}

#paramId: 503122
#Number density of hail
'503122' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 223 ;
	}

#paramId: 503123
#Mass density of rain
'503123' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 224 ;
	}

#paramId: 503124
#Mass density of snow
'503124' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 225 ;
	}

#paramId: 503125
#Mass density of graupel
'503125' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 226 ;
	}

#paramId: 503126
#Mass density of cloud droplets
'503126' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 203 ;
	}

#paramId: 503127
#Mass density of cloud ice
'503127' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 204 ;
	}

#paramId: 503128
#Mass density of hail
'503128' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 227 ;
	}

#paramId: 503130
#Hail  precipitation rate, accumulation
'503130' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 73 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503132
#Number density of cloud droplets
'503132' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 30 ;
	}

#paramId: 503133
#Number density of cloud ice particles
'503133' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 31 ;
	}

#paramId: 503134
#Downward long-wave radiation flux
'503134' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503135
#Downward long-wave radiation flux avg
'503135' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503136
#Downward long-wave radiation flux accum
'503136' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503137
#Eddy Dissipation Rate Total Col-Max. Lower FIR
'503137' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 228 ;
	}

#paramId: 503142
#Lightning Potential Index
'503142' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 192 ;
	}

#paramId: 503143
#Rain drain from snowpack - accumulation
'503143' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 230 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503145
#2m absolute humidity
'503145' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 18 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503146
#Height of -10 degree Celsius isotherm
'503146' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 196 ;
	}

#paramId: 503147
# probability density function of EDP for turbulence  greater well defined threshold and model grid box
'503147' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 229 ;
	}

#paramId: 503148
#Adedokun 2 Index
'503148' = {
	 discipline = 215 ;
	 parameterCategory = 7 ;
	 parameterNumber = 0 ;
	}

#paramId: 503149
#Downward direct short wave radiation flux at surface on horizontal plane (time average)
'503149' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 201 ;
	}

#paramId: 503150
#Gauss Boaga Coordinates West to East,East Sector
'503150' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 194 ;
	}

#paramId: 503151
#Gauss Boaga Coordinates South to North,East Sector
'503151' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 195 ;
	}

#paramId: 503152
#Gauss Boaga Coordinates West to East, West Sector
'503152' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 196 ;
	}

#paramId: 503153
#Gauss Boaga Coordinates South to North, West Sector
'503153' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 197 ;
	}

#paramId: 503154
#Bulk Richardson number
'503154' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 16 ;
	}

#paramId: 503155
#Cape of mixed (mean) layer parcel, ascent up to 3 km
'503155' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 192 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 3000 ;
	}

#paramId: 503156
#Ellrod and Knapp turbulence index1
'503156' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 230 ;
	}

#paramId: 503157
#Ellrod and Knapp turbulence index2
'503157' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 231 ;
	}

#paramId: 503158
#Deformation of horizontal wind field
'503158' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 29 ;
	}

#paramId: 503159
#Divergence trend (scaled divergence tendency needed for CAT_DVI)
'503159' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 232 ;
	}

#paramId: 503160
#Divergence modified turbulence index (Ellrod and Knox)
'503160' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 233 ;
	}

#paramId: 503161
#Cloud ice ratio qi/(qc+qi)
'503161' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 231 ;
	}

#paramId: 503162
#Percentage of convective precipitation (from total prec)
'503162' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 232 ;
	}

#paramId: 503163
#Deep convection index
'503163' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503164
#Wind direction in azimuth class
'503164' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	}

#paramId: 503165
#Wind direction in azimuth class
'503165' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503166
#Geostrophic wind direction
'503166' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 43 ;
	}

#paramId: 503167
#Possible astronomical maximum of sunshine
'503167' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503168
#Relative duration of sunshine (DURSUN * 100 / DURSUN_M)
'503168' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 206 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503169
#Dewpoint depression
'503169' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	}

#paramId: 503170
#2m dewpoint depression
'503170' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503171
#Enthalpy
'503171' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 195 ;
	}

#paramId: 503172
#2m Enthalpy
'503172' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503173
#Geostrophic wind speed
'503173' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 44 ;
	}

#paramId: 503174
#Downward short wave radiation flux at surface (time average)
'503174' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503175
#Downward short wave radiation flux at surface on horizontal plane (time average)
'503175' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 201 ;
	}

#paramId: 503176
#Downward short wave radiation flux at surface on vertical surface facing east (time average)
'503176' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 202 ;
	}

#paramId: 503177
#Downward short wave radiation flux at surface on vertical surface facing north (time average)
'503177' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 203 ;
	}

#paramId: 503178
#Downward short wave radiation flux at surface on vertical surface facing south (time average)
'503178' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 204 ;
	}

#paramId: 503179
#Downward short wave radiation flux at surface on vertical surface facing west (time average)
'503179' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 205 ;
	}

#paramId: 503180
#Along-wind Lagrangian time scale (Hanna)
'503180' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	}

#paramId: 503181
#Cross-wind Lagrangian time scale (Hanna)
'503181' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	}

#paramId: 503182
#Vertical Lagrangian time scale (Hanna)
'503182' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	}

#paramId: 503183
#Zonal Lagrangian time scale (direct) (Hanna)
'503183' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 4 ;
	}

#paramId: 503184
#Meridional Lagrangian time scale (direct) (Hanna)
'503184' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 5 ;
	}

#paramId: 503185
#Vertical Lagrangian time scale (direct) (Hanna)
'503185' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 6 ;
	}

#paramId: 503186
#Height of lifting condensation level of mixed (mean) layer parcel
'503186' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 192 ;
	 typeOfFirstFixedSurface = 5 ;
	}

#paramId: 503187
#Height of level of free convection of mixed (mean) layer parcel
'503187' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 192 ;
	 typeOfFirstFixedSurface = 194 ;
	}

#paramId: 503188
#Luminosity
'503188' = {
	 discipline = 215 ;
	 parameterCategory = 19 ;
	 parameterNumber = 0 ;
	}

#paramId: 503189
#Downward long-wave radiation flux at surface based on T_2M (time average)
'503189' = {
	 discipline = 215 ;
	 parameterCategory = 5 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503190
#Downward long-wave radiation flux at surface based on T_G (time average)
'503190' = {
	 discipline = 215 ;
	 parameterCategory = 5 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503191
#Downward long-wave radiation flux at surface based on T_SO(0) (time average)
'503191' = {
	 discipline = 215 ;
	 parameterCategory = 5 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503192
#Humidity mixing ratio
'503192' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	}

#paramId: 503193
#2m Humidity mixing ratio
'503193' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503194
#Pressure difference between cloud base and cloud top
'503194' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 197 ;
	 typeOfSecondFixedSurface = 2 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 503195
#relative humidity over ice
'503195' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 94 ;
	}

#paramId: 503196
#Gradient Richardson number
'503196' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 17 ;
	}

#paramId: 503197
#Showalter index
'503197' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 13 ;
	}

#paramId: 503198
#Along-wind velocity fluctuation (Hanna)
'503198' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 7 ;
	}

#paramId: 503199
#Cross-wind velocity fluctuation (Hanna)
'503199' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 8 ;
	}

#paramId: 503200
#Vertical velocity fluctuation (Hanna)
'503200' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 9 ;
	}

#paramId: 503201
#Zonal velocity fluctuation (Hanna)
'503201' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 10 ;
	}

#paramId: 503202
#Meridional velocity fluctuation (Hanna)
'503202' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 11 ;
	}

#paramId: 503203
#Vertical velocity fluctuation (Hanna)
'503203' = {
	 discipline = 215 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 503204
#Surface lifted index
'503204' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503205
#Percentage of precipitation in snow (from total prec.)
'503205' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 233 ;
	}

#paramId: 503206
#Thunderstorm index for Switzerland (night time)
'503206' = {
	 discipline = 215 ;
	 parameterCategory = 7 ;
	 parameterNumber = 1 ;
	}

#paramId: 503207
#Thunderstorm index for Switzerland (day time)
'503207' = {
	 discipline = 215 ;
	 parameterCategory = 7 ;
	 parameterNumber = 2 ;
	}

#paramId: 503208
#Swiss coordinate (south-north)
'503208' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 198 ;
	}

#paramId: 503209
#Swiss coordinate (west-east)
'503209' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 199 ;
	}

#paramId: 503210
#2m potential temperature
'503210' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503211
#Dew point temperature
'503211' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	}

#paramId: 503212
#2m equivalentTemperature
'503212' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 3 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503213
#2m virtual potential temperature
'503213' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 15 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503214
#Temperature at cloud top
'503214' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 3 ;
	}

#paramId: 503215
#Wet bulb temperature
'503215' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	}

#paramId: 503216
#2m wet bulb temperature
'503216' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 27 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503217
#2m temperature, corrected in presence of snow
'503217' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503218
#Universal thermal climate index without direct incident short wave radiation
'503218' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	}

#paramId: 503219
#Universal thermal climate index with direct incident short wave radiation
'503219' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}

#paramId: 503220
#u-component of geostrophic wind
'503220' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 41 ;
	}

#paramId: 503221
#v-component of geostrophic wind
'503221' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 42 ;
	}

#paramId: 503222
#Relative geostrophic vorticity
'503222' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 26 ;
	}

#paramId: 503223
#Relative geostrophic vorticity advection
'503223' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 27 ;
	}

#paramId: 503226
#Wind divergence (3D)
'503226' = {
	 discipline = 0 ;
	 parameterCategory = 193 ;
	 parameterNumber = 28 ;
	}

#paramId: 503227
#Mean vertical wind shear for specified layer or layer-mean vertical wind shear
'503227' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 201 ;
	}

#paramId: 503228
#Norm of (vertical) wind shear vector between two levels
'503228' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 202 ;
	}

#paramId: 503229
#Prognostic mass mixing ratio of volcanic ash particles for bin number 1
'503229' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503230
#Prognostic mass mixing ratio of volcanic ash particles for bin number 2
'503230' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503231
#Prognostic mass mixing ratio of volcanic ash particles for bin number 3
'503231' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503232
#Prognostic mass mixing ratio of volcanic ash particles for bin number 4
'503232' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 4 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503233
#Prognostic mass mixing ratio of volcanic ash particles for bin number 5
'503233' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 5 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503234
#Prognostic mass mixing ratio of volcanic ash particles for bin number 6
'503234' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 6 ;
	 typeOfDistributionFunction = 1 ;
	}

#paramId: 503235
#Modal prognostic mass mixing ratio of volcanic ash particles (fine mode)
'503235' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503236
#Modal prognostic mass mixing ratio of volcanic ash particles (medium mode)
'503236' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503237
#Modal prognostic mass mixing ratio of volcanic ash particles (coarse mode)
'503237' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503238
#Modal prognostic specific number concentration of volcanic ash particles (fine mode)
'503238' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62025 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503239
#Modal prognostic specific number concentration of volcanic ash particles (medium mode)
'503239' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62025 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503240
#Modal prognostic specific number concentration of volcanic ash particles (coarse mode)
'503240' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62025 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503241
#Modal prognostic mass mixing ratio of mineral dust particles (fine mode)
'503241' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503242
#Modal prognostic mass mixing ratio of mineral dust particles (medium mode)
'503242' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503243
#Modal prognostic mass mixing ratio of mineral dust particles (coarse mode)
'503243' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503244
#Modal prognostic specific number concentration  of mineral dust particles (fine mode)
'503244' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503245
#Modal prognostic specific number concentration  of mineral dust particles (medium mode)
'503245' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503246
#Modal prognostic specific number concentration  of mineral dust particles (coarsemode)
'503246' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503247
#Modal prognostic mass mixing ratio of sea salt particles (fine mode)
'503247' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503248
#Modal prognostic mass mixing ratio of sea salt particles (medium mode)
'503248' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503249
#Modal prognostic mass mixing ratio of sea salt particles (coarse mode)
'503249' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503250
#Modal prognostic specific number concentration of sea salt particles (fine mode)
'503250' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62008 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503251
#Modal prognostic specific number concentration of sea salt particles (medium mode)
'503251' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62008 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503252
#Modal prognostic specific number concentration of sea salt particles (coarse mode)
'503252' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62008 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503253
#Cs137 - wet deposition
'503253' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30172 ;
	}

#paramId: 503254
#Prognostic specific activity concentration of Iodine 131 aerosol
'503254' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30141 ;
	}

#paramId: 503255
#Te132 - total (wet + dry) deposition
'503255' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30129 ;
	}

#paramId: 503256
#Prognostic specific activity concentration of Zirconium 95
'503256' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30079 ;
	}

#paramId: 503257
#Prognostic specific activity concentration of Xenon 133
'503257' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30161 ;
	}

#paramId: 503258
#Prognostic specific activity concentration of Iodine 131 elementary gaseous
'503258' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30138 ;
	}

#paramId: 503259
#Prognostic specific activity concentration of Iodine 131 organic bounded
'503259' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30139 ;
	}

#paramId: 503260
#Prognostic specific activity concentration of Barium 140
'503260' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30175 ;
	}

#paramId: 503261
#Prognostic specific activity concentration of Ruthenium 103
'503261' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30102 ;
	}

#paramId: 503262
#Diagnostic total mass concentration of volcanic ash
'503262' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62025 ;
	}

#paramId: 503263
#Diagnostic maximum total mass concentration of volcanic ash in layer SFC-FL200
'503263' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 101325 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 46500 ;
	 constituentType = 62025 ;
	}

#paramId: 503265
#Diagnostic total column of mass concentration of volcanic ash
'503265' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 10 ;
	 constituentType = 62025 ;
	}

#paramId: 503266
#Diagnostic height of model layer with maximal total mass concentration of volcanic ash
'503266' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 62 ;
	 constituentType = 62025 ;
	}

#paramId: 503267
#Diagnostic volcanic ash optical depth
'503267' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62025 ;
	}

#paramId: 503268
#Diagnostic mineral dust optical depth
'503268' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62001 ;
	}

#paramId: 503269
#Diagnostic sea salt optical depth
'503269' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62008 ;
	}

#paramId: 503270
#Diagnostic vmaximum activity concentration of radionuclides in a layer
'503270' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 15 ;
	}

#paramId: 503273
#Diagnostic maximum total mass concentration of volcanic ash in layer FL200-FL350
'503273' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 46500 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 24000 ;
	 constituentType = 62025 ;
	}

#paramId: 503274
#Diagnostic maximum total mass concentration of volcanic ash in layer SFC-FL100
'503274' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 101325 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 70000 ;
	 constituentType = 62025 ;
	}

#paramId: 503275
#Diagnostic maximum total mass concentration of volcanic ash in layer FL350-FL550
'503275' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 24000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 9100 ;
	 constituentType = 62025 ;
	}

#paramId: 503276
#Diagnostic maximum total mass concentration of volcanic ash in layer FL100-FL245
'503276' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 70000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 38500 ;
	 constituentType = 62025 ;
	}

#paramId: 503277
#Diagnostic maximum total mass concentration of volcanic ash in layer FL245-FL390
'503277' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 38500 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 20000 ;
	 constituentType = 62025 ;
	}

#paramId: 503278
#Diagnostic maximum total mass concentration of volcanic ash in layer FL390-FL530
'503278' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 typeOfSecondFixedSurface = 100 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 20000 ;
	 typeOfFirstFixedSurface = 100 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10000 ;
	 constituentType = 62025 ;
	}

#paramId: 503279
#Diagnostic maximum total mass concentration of volcanic ash in a layer
'503279' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 constituentType = 62025 ;
	}

#paramId: 503280
#Aerosol optical depth
'503280' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	}

#paramId: 503282
#Diagnostic total column of activity concentration of radionuclides
'503282' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 192 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503283
#Liquid water potential temperature variance
'503283' = {
	 discipline = 0 ;
	 parameterCategory = 198 ;
	 parameterNumber = 0 ;
	}

#paramId: 503284
#Total water specific humidity variance
'503284' = {
	 discipline = 0 ;
	 parameterCategory = 198 ;
	 parameterNumber = 1 ;
	}

#paramId: 503285
#Liquid water potential temperature - total water specific humidity covariance
'503285' = {
	 discipline = 0 ;
	 parameterCategory = 198 ;
	 parameterNumber = 2 ;
	}

#paramId: 503286
#Impervious (paved or sealed) surface fraction
'503286' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 196 ;
	}

#paramId: 503287
#Antropogenic heat flux (e.g. urban heating, traffic)
'503287' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 197 ;
	}

#paramId: 503292
#Sea ice albedo - diffusive solar (0.3 - 5.0 m-6)
'503292' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 234 ;
	}

#paramId: 503293
#Large Scale Rain Difference
'503293' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 77 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503294
#Large Scale Snowfall water Equivalent Difference
'503294' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 56 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503295
#Convective Rain Difference
'503295' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 76 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503296
#Convective Snowfall Water Equivalent Difference
'503296' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 55 ;
	 typeOfStatisticalProcessing = 4 ;
	}

#paramId: 503299
#Sky-view-factor
'503299' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 0 ;
	}

#paramId: 503300
#Horizon angle - topography
'503300' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 1 ;
	}

#paramId: 503301
#Slope aspect - topography
'503301' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 3 ;
	}

#paramId: 503302
#Slope angle - topography
'503302' = {
	 discipline = 0 ;
	 parameterCategory = 199 ;
	 parameterNumber = 2 ;
	}

#paramId: 503303
#Total precipitation rate
'503303' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	}

#paramId: 503304
#Horizontal moisture convergence
'503304' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 26 ;
	}

#paramId: 503305
#TOA downward solar radiation
'503305' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503306
#Surface upward thermal radiation
'503306' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503307
#Surface upward thermal radiation
'503307' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503308
#Specific mass of liquid water coating on hail
'503308' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 110 ;
	}

#paramId: 503309
#Specific mass of liquid water coating on graupel
'503309' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 113 ;
	}

#paramId: 503310
#Specific mass of liquid water coating on snow
'503310' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 116 ;
	}

#paramId: 503311
#Specific number concentration of rain
'503311' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 100 ;
	}

#paramId: 503312
#Number density of rain
'503312' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 104 ;
	}

#paramId: 503313
#Specific number concentration of snow
'503313' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 101 ;
	}

#paramId: 503314
#Specific number concentration of graupel
'503314' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 102 ;
	}

#paramId: 503315
#Specific number concentration of hail
'503315' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 103 ;
	}

#paramId: 503316
#Number density of snow
'503316' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 105 ;
	}

#paramId: 503317
#Number density of graupel
'503317' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 106 ;
	}

#paramId: 503318
#Number density of hail
'503318' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 107 ;
	}

#paramId: 503319
#Mass density of rain
'503319' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 96 ;
	}

#paramId: 503320
#Mass density of snow
'503320' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 97 ;
	}

#paramId: 503321
#Mass density of graupel
'503321' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 98 ;
	}

#paramId: 503322
#Mass density of cloud droplets
'503322' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 38 ;
	}

#paramId: 503323
#Mass density of cloud ice
'503323' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 39 ;
	}

#paramId: 503324
#Mass density of hail
'503324' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 99 ;
	}

#paramId: 503325
#Lightning Potential Index
'503325' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 1 ;
	}

#paramId: 503326
#Diagnostic total column of activity concentration of radionuclides
'503326' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 17 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503327
#Base for given threshold of mass density for volcanic ash cloud
'503327' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 21 ;
	 constituentType = 62025 ;
	}

#paramId: 503328
#Base for given threshold of mass density for mineral dust cloud
'503328' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 21 ;
	 constituentType = 62001 ;
	}

#paramId: 503330
#Top for given threshold of mass density for volcanic ash cloud
'503330' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 22 ;
	 constituentType = 62025 ;
	}

#paramId: 503331
#Top for given threshold of mass density for mineral dust cloud
'503331' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 22 ;
	 constituentType = 62001 ;
	}

#paramId: 503332
#Top for given threshold of air concentration of radionuclides
'503332' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 24 ;
	}

#paramId: 503333
#Emission rate of dust for mode 2
'503333' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503334
#Emission rate of dust for mode 3
'503334' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503335
#Emission rate of dust for mode 1
'503335' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503336
#Accumulated dust Emission for mode 2
'503336' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503337
#Accumulated dust Emission for mode 1
'503337' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503338
#Accumulated dust Emission for mode 3
'503338' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503339
#Threshold friction velocity
'503339' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 203 ;
	}

#paramId: 503340
#Base for given threshold of air concentration of radionuclides
'503340' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 23 ;
	}

#paramId: 503341
#Maximum amplitude (positive or negative) of updraft helicity  (over given time interval)
'503341' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503342
#Maximum rotation amplitude (positive or negative) (over given time interval and column)
'503342' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503343
#Maximum updraft track (over given time interval and column)
'503343' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503344
#Maximum total-column integrated condensed water above -10 C isotherm (over given time interval)
'503344' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 20 ;
	 scaleFactorOfFirstFixedSurface = 2 ;
	 scaledValueOfFirstFixedSurface = 26315 ;
	}

#paramId: 503345
#Maximum total-column integrated condensed  water (over given time interval)
'503345' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 81 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503346
#Composite reflectivity - observation
'503346' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 5 ;
	 typeOfGeneratingProcess = 8 ;
	}

#paramId: 503347
#Composite reflectivity - forecast (simulation)
'503347' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 5 ;
	}

#paramId: 503348
#Maximum of Lightning Potential Index (over given time interval)
'503348' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 192 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503349
#Maximum reflectivity track (over given time interval and entire atmosphere)
'503349' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503350
#relative vorticity
'503350' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 12 ;
	}

#paramId: 503351
#mean radiation temperature of an environment assumed black body related to standing human
'503351' = {
	 discipline = 0 ;
	 parameterCategory = 192 ;
	 parameterNumber = 4 ;
	}

#paramId: 503352
#2m Temperature, restricted to land
'503352' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 181 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503353
#2m Dew Point Temperature, restricted to land
'503353' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 6 ;
	 typeOfSecondFixedSurface = 181 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503354
#2m Relative Humidity, restricted to land
'503354' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 181 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503355
#Maximum 10m dynamical gust
'503355' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503356
#Maximum 10m convective gust
'503356' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503357
#Maximum 10m wind speed without  gust
'503357' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503358
#Standard deviation of saturation deficit
'503358' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 234 ;
	}

#paramId: 503359
#Evaporation of plants (integrated since "nightly reset")
'503359' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 198 ;
	}

#paramId: 503360
#Birch (betula) pollen concentration
'503360' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62101 ;
	}

#paramId: 503362
#Fraction of land occupied by birch (betula)
'503362' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503363
#Number of birch (betula) pollen in the reservoir (previous timestep)
'503363' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62101 ;
	}

#paramId: 503364
#Number of birch (betula) pollen released into the reservoir (new)
'503364' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62101 ;
	}

#paramId: 503365
#Sum of released birch (betula) pollen into the reservoir (daily sum)
'503365' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62101 ;
	}

#paramId: 503366
#State of the birch (betula) season (eq.zero before and after season, the higher, the more plants are flowering)
'503366' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62101 ;
	}

#paramId: 503367
#Height correction for emission (decreasing emission with height) for birch (betula)
'503367' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503368
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of birch (betula)
'503368' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62101 ;
	}

#paramId: 503369
#Cumulated weighted 2m temperature sum of daily values for birch (betula) pollen
'503369' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62101 ;
	}

#paramId: 503370
#Cumulated 2m temperature sum threshold for the start of birch (betula) pollen season (climatological)
'503370' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503371
#Cumulated 2m temperature sum threshold for the end of birch (betula) pollen season (climatological)
'503371' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62101 ;
	}

#paramId: 503372
#Number of days since the start of birch (betula) pollen season (if present day is outside the season: length of current season)
'503372' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62101 ;
	}

#paramId: 503373
#Length of birch (betula) pollen season
'503373' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62101 ;
	}

#paramId: 503374
#Pollen number emission flux for birch (betula)
'503374' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62101 ;
	}

#paramId: 503375
#Alder (alnus) pollen concentration
'503375' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62100 ;
	}

#paramId: 503376
#Fraction of land occupied by alder (alnus)
'503376' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503377
#Number of alder (alnus) pollen in the reservoir (previous timestep)
'503377' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62100 ;
	}

#paramId: 503378
#Number of alder (alnus) pollen released into the reservoir (new)
'503378' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62100 ;
	}

#paramId: 503379
#Sum of released alder (alnus) pollen into the reservoir (daily sum)
'503379' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62100 ;
	}

#paramId: 503380
#State of the alder (alnus) season (eq.zero before and after season, the higher, the more plants are flowering)
'503380' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62100 ;
	}

#paramId: 503381
#Height correction for emission (decreasing emission with height) for alder (alnus)
'503381' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503382
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of alder (alnus)
'503382' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62100 ;
	}

#paramId: 503383
#Cumulated weighted 2m temperature sum of daily values for alder (alnus) pollen
'503383' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62100 ;
	}

#paramId: 503384
#Cumulated 2m temperature sum threshold for the start of  alder (alnus) pollen season (climatological)
'503384' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503385
#Cumulated 2m temperature sum threshold for the end of  alder (alnus) pollen season (climatological)
'503385' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62100 ;
	}

#paramId: 503386
#Number of days since the start of alder (alnus) pollen season (if present day is in the season: zero outside season)
'503386' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62100 ;
	}

#paramId: 503387
#Number of days since the start of alder (alnus) pollen season (if present day is outside the season: length of current season)
'503387' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62100 ;
	}

#paramId: 503388
#Length of alder (alnus) pollen season
'503388' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62100 ;
	}

#paramId: 503389
#Pollen number emission flux for alder (alnus)
'503389' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62100 ;
	}

#paramId: 503390
#Grasses (poaceae) pollen concentration
'503390' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62300 ;
	}

#paramId: 503391
#Fraction of land occupied by grasses (poaceae)
'503391' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503392
#Number of grasses (poaceae) pollen in the reservoir (previous timestep)
'503392' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62300 ;
	}

#paramId: 503393
#Number of grasses (poaceae) pollen released into the reservoir (new)
'503393' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62300 ;
	}

#paramId: 503394
#Sum of released grasses (poaceae) pollen into the reservoir (daily sum)
'503394' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62300 ;
	}

#paramId: 503395
#State of the grasses (poaceae) season (eq.zero before and after season, the higher, the more plants are flowering)
'503395' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62300 ;
	}

#paramId: 503396
#Height correction for emission (decreasing emission with height) for grasses (poaceae)
'503396' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503397
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of grasses (poaceae)
'503397' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62300 ;
	}

#paramId: 503398
#Cumulated weighted 2m temperature sum of daily values for grasses (poaceae) pollen
'503398' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62300 ;
	}

#paramId: 503399
#Cumulated 2m temperature sum threshold for the start of  grasses (poaceae) pollen season (climatological)
'503399' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503400
#Cumulated 2m temperature sum threshold for the end of  grasses (poaceae) pollen season (climatological)
'503400' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62300 ;
	}

#paramId: 503401
#Number of days since the start of grasses (poaceae) pollen season (if present day is in the season: zero outside season)
'503401' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62300 ;
	}

#paramId: 503402
#Number of days since the start of grasses (poaceae) pollen season (if present day is outside the season: length of current season)
'503402' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62300 ;
	}

#paramId: 503403
#Length of grasses (poaceae) pollen season
'503403' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62300 ;
	}

#paramId: 503404
#Pollen number emission flux for grasses (poaceae)
'503404' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62300 ;
	}

#paramId: 503405
#ragweed  (ambrosia) pollen concentration
'503405' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62200 ;
	}

#paramId: 503406
#Fraction of land occupied by ragweed  (ambrosia)
'503406' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503407
#Number of ragweed  (ambrosia) pollen in the reservoir (previous timestep)
'503407' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62200 ;
	}

#paramId: 503408
#Number of ragweed  (ambrosia) pollen released into the reservoir (new)
'503408' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62200 ;
	}

#paramId: 503409
#Sum of released ragweed  (ambrosia) pollen into the reservoir (daily sum)
'503409' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62200 ;
	}

#paramId: 503410
#State of the ragweed  (ambrosia) season (eq.zero before and after season, the higher, the more plants are flowering)
'503410' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62200 ;
	}

#paramId: 503411
#Height correction for emission (decreasing emission with height) for ragweed  (ambrosia)
'503411' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503412
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of ragweed  (ambrosia)
'503412' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62200 ;
	}

#paramId: 503413
#Cumulated weighted 2m temperature sum of daily values for ragweed  (ambrosia) pollen
'503413' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62200 ;
	}

#paramId: 503414
#Cumulated 2m temperature sum threshold for the start of  ragweed  (ambrosia) pollen season (climatological)
'503414' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503415
#Cumulated 2m temperature sum threshold for the end of  ragweed  (ambrosia) pollen season (climatological)
'503415' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62200 ;
	}

#paramId: 503416
#Number of days since the start of ragweed  (ambrosia) pollen season (if present day is in the season: zero outside season)
'503416' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62200 ;
	}

#paramId: 503417
#Number of days since the start of ragweed  (ambrosia) pollen season (if present day is outside the season: length of current season)
'503417' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62200 ;
	}

#paramId: 503418
#Length of ragweed  (ambrosia) pollen season
'503418' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62200 ;
	}

#paramId: 503419
#Pollen number emission flux for ragweed  (ambrosia)
'503419' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62200 ;
	}

#paramId: 503420
#Number of days since the start of birch (betula) pollen season (if present day is in the season: zero outside season)
'503420' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62101 ;
	}

#paramId: 503421
#Echotop-pressure: smallest pressure where radar reflectivity above a threshold is present
'503421' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 25 ;
	}

#paramId: 503422
#Echotop-height: largest height where radar reflectivity above a threshold is present
'503422' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 25 ;
	}

#paramId: 503423
#Maximum horizontal moisture convergence track (over given time interval and column)
'503423' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 26 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503424
#Random pattern for  the stochastically perturbed parametrization tendencies (SPPT) scheme at levels without tapering. If multi-scale random patterns are used, RAPA_SPPT is the sum of those.
'503424' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 235 ;
	}

#paramId: 503425
#Skin conductivity (ratio ground heat flux to temperature difference soil-skin layer)
'503425' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 199 ;
	}

#paramId: 503426
#Maximum snow height during contiguous accumulating snow period (coupled with snow age)
'503426' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 235 ;
	}

#paramId: 503427
#U-component of (vertical) wind shear vector between two levels
'503427' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 208 ;
	}

#paramId: 503428
#V-component of (vertical) wind shear vector between two levels
'503428' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 209 ;
	}

#paramId: 503431
#Accumulated dry deposition (surface) of dust for mode 1
'503431' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503432
#Accumulated dry deposition (surface) of dust for mode 2
'503432' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503433
#Accumulated dry deposition (surface) of dust for mode 3
'503433' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503434
#Accumulated wet deposition by grid scale precipitation of dust for mode 1
'503434' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503435
#Accumulated wet deposition by grid scale precipitation of dust for mode 2
'503435' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503436
#Accumulated wet deposition by grid scale precipitation of dust for mode 3
'503436' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503437
#Accumulated wet deposition by convective precipitation of dust for mode 1
'503437' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503438
#Accumulated wet deposition by convective precipitation of dust for mode 2
'503438' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503439
#Accumulated wet deposition by convective precipitation of dust for mode 3
'503439' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503440
#Accumulated wet deposition of dust if rain reaches the surface for mode 1
'503440' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 203 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503441
#Accumulated wet deposition of dust if rain reaches the surface for mode 2
'503441' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 203 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503442
#Accumulated wet deposition of dust if rain reaches the surface for mode 3
'503442' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 203 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503443
#Accumulated sedimentation of dust for mode 1
'503443' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503444
#Accumulated sedimentation of dust for mode 2
'503444' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503445
#Accumulated sedimentation of dust for mode 3
'503445' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503446
#Accumulated dry deposition of dust number concentration for mode 1
'503446' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503447
#Accumulated dry deposition of dust number concentration for mode 2
'503447' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503448
#Accumulated dry deposition of dust number concentration for mode 3
'503448' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 204 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503449
#Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 1
'503449' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503450
#Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 2
'503450' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503451
#Accumulated wet deposition by grid scale precipitation of dust number concentration for mode 3
'503451' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 205 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503452
#Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 1
'503452' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503453
#Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 2
'503453' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503454
#Accumulated wet deposition of dust number concentration  if rain reaches the surface for mode 3
'503454' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 207 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503455
#Accumulated sedimentation of dust number concentration for mode 1
'503455' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 208 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503456
#Accumulated sedimentation of dust number concentration for mode 2
'503456' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 208 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503457
#Accumulated sedimentation of dust number concentration for mode 3
'503457' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 208 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503458
#Attenuated backscatter from satellite for dust (for given wave length)
'503458' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	 aerosolType = 62001 ;
	}

#paramId: 503459
#Attenuated backscatter from ground (ceilometer) for dust (for given wave length)
'503459' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	 aerosolType = 62001 ;
	}

#paramId: 503460
#Mineral dust backscatter (not attenuated, for given wave length)
'503460' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 209 ;
	 aerosolType = 62001 ;
	}

#paramId: 503461
#Attenuated backscatter from satellite for volcanic ash (for given wave length)
'503461' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 107 ;
	 aerosolType = 62025 ;
	}

#paramId: 503462
#Attenuated backscatter from ground (ceilometer) for volcanic ash (for given wave length)
'503462' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 108 ;
	 aerosolType = 62025 ;
	}

#paramId: 503463
#Volcanic ash backscatter (not attenuated, for given wave length)
'503463' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 209 ;
	 aerosolType = 62025 ;
	}

#paramId: 503464
#Accumulated wet deposition by convective precipitation of dust number concentration for mode 3
'503464' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503465
#Accumulated wet deposition by convective precipitation of dust number concentration for mode 2
'503465' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503466
#Accumulated wet deposition by convective precipitation of dust number concentration for mode 1
'503466' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 206 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503467
#2m Temperature analysis increment, filtered in time
'503467' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	 typeOfGeneratingProcess = 206 ;
	}

#paramId: 503468
#Cs137 - total (wet + dry) deposition
'503468' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30172 ;
	}

#paramId: 503469
#Prognostic specific activity concentration of Caesium 137
'503469' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30172 ;
	}

#paramId: 503470
#Averaged air concentration of Caesium 137
'503470' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30172 ;
	}

#paramId: 503471
#Accumulated air concentration of Caesium 137
'503471' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30172 ;
	}

#paramId: 503480
#Prognostic specific activity concentration of Krypton 85
'503480' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30059 ;
	}

#paramId: 503481
#Kr85 - total (wet + dry) deposition
'503481' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30059 ;
	}

#paramId: 503482
#Averaged air concentration of Krypton 85
'503482' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30059 ;
	}

#paramId: 503483
#Accumulated air concentration of Krypton 85
'503483' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30059 ;
	}

#paramId: 503484
#Prognostic specific activity concentration of Strontium 90
'503484' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30067 ;
	}

#paramId: 503485
#Averaged air concentration of Strontium 90
'503485' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30067 ;
	}

#paramId: 503486
#Accumulated air concentration of Strontium 90
'503486' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30067 ;
	}

#paramId: 503487
#Sr90 - total (wet + dry) deposition
'503487' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30067 ;
	}

#paramId: 503489
#I131a - total (wet + dry) deposition
'503489' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30141 ;
	}

#paramId: 503490
#Averaged air concentration of Iodine 131 aerosol
'503490' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30141 ;
	}

#paramId: 503491
#Accumulated air concentration of Iodine 131 aerosol
'503491' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30141 ;
	}

#paramId: 503492
#Averaged air concentration of Cobalt 60
'503492' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30042 ;
	}

#paramId: 503493
#Accumulated air concentration of Cobalt 60
'503493' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30042 ;
	}

#paramId: 503494
#Prognostic specific activity concentration of Cobalt 60
'503494' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30042 ;
	}

#paramId: 503495
#Co-60 - wet deposition
'503495' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30042 ;
	}

#paramId: 503496
#Co60 - total (wet + dry) deposition
'503496' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30042 ;
	}

#paramId: 503497
#Ru103 - total (wet + dry) deposition
'503497' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30102 ;
	}

#paramId: 503499
#Averaged air concentration of Ruthenium 103
'503499' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30102 ;
	}

#paramId: 503500
#Accumulated air concentration of Ruthenium 103
'503500' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30102 ;
	}

#paramId: 503501
#Prognostic specific activity concentration of Tellurium 132
'503501' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30129 ;
	}

#paramId: 503502
#Averaged air concentration of Tellurium 132
'503502' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30129 ;
	}

#paramId: 503503
#Accumulated air concentration of Tellurium 132
'503503' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30129 ;
	}

#paramId: 503504
#Zr95 - total (wet + dry) deposition
'503504' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30079 ;
	}

#paramId: 503505
#Averaged air concentration of Zirconium 95
'503505' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30079 ;
	}

#paramId: 503506
#Accumulated air concentration of Zirconium 95
'503506' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30079 ;
	}

#paramId: 503507
#TRACER - total (wet + dry) deposition
'503507' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30000 ;
	}

#paramId: 503508
#Prognostic specific activity concentration of TRACER
'503508' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30000 ;
	}

#paramId: 503509
#Averaged air concentration of TRACER
'503509' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30000 ;
	}

#paramId: 503510
#Accumulated air concentration of TRACER
'503510' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30000 ;
	}

#paramId: 503511
#Averaged air concentration of Xenon 133
'503511' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30161 ;
	}

#paramId: 503512
#Accumulated air concentration of Xenon 133
'503512' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30161 ;
	}

#paramId: 503513
#Xe133 - total (wet + dry) deposition
'503513' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30161 ;
	}

#paramId: 503514
#Air concentration of Iodine 131
'503514' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30137 ;
	}

#paramId: 503515
#I131 - dry deposition
'503515' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30137 ;
	}

#paramId: 503516
#Averaged air concentration of Iodine 131
'503516' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30137 ;
	}

#paramId: 503517
#Accumulated air concentration of Iodine 131
'503517' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30137 ;
	}

#paramId: 503518
#Prognostic specific activity concentration of Iodine 131
'503518' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30137 ;
	}

#paramId: 503519
#I131 - wet deposition
'503519' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30137 ;
	}

#paramId: 503520
#I131 - total (wet + dry) deposition
'503520' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30137 ;
	}

#paramId: 503522
#Averaged air concentration of Iodine 131 elementary gaseous
'503522' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30138 ;
	}

#paramId: 503523
#Accumulated air concentration of Iodine 131 elementary gaseous
'503523' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30138 ;
	}

#paramId: 503524
#I131g - total (wet + dry) deposition
'503524' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30138 ;
	}

#paramId: 503525
#Averaged air concentration of Iodine 131 organic bounded
'503525' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30139 ;
	}

#paramId: 503526
#Accumulated air concentration of Iodine 131 organic bounded
'503526' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30139 ;
	}

#paramId: 503527
#I131o - total (wet + dry) deposition
'503527' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30139 ;
	}

#paramId: 503528
#Ba140 - total (wet + dry) deposition
'503528' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30175 ;
	}

#paramId: 503529
#Averaged air concentration of Barium 140
'503529' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30175 ;
	}

#paramId: 503530
#Accumulated air concentration of Barium 140
'503530' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30175 ;
	}

#paramId: 503531
#Air concentration of Ruthenium 106
'503531' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30104 ;
	}

#paramId: 503532
#Ru106 - total (wet + dry) deposition
'503532' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30104 ;
	}

#paramId: 503533
#Prognostic specific activity concentration of Ruthenium 106
'503533' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30104 ;
	}

#paramId: 503534
#Ru106 - dry deposition
'503534' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30104 ;
	}

#paramId: 503535
#Ru106 - wet deposition
'503535' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30104 ;
	}

#paramId: 503536
#Averaged air concentration of Ruthenium 106
'503536' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30104 ;
	}

#paramId: 503537
#Accumulated air concentration of Ruthenium 106
'503537' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30104 ;
	}

#paramId: 503538
#Co-60 - dry deposition
'503538' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30042 ;
	}

#paramId: 503539
#Air concentration of Cobalt 60
'503539' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30042 ;
	}

#paramId: 503542
#Kr85m - wet deposition
'503542' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 11 ;
	 constituentType = 30060 ;
	}

#paramId: 503543
#Kr85m - total (wet + dry) deposition
'503543' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 13 ;
	 constituentType = 30060 ;
	}

#paramId: 503544
#Prognostic specific activity concentration of Krypton 85m
'503544' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 14 ;
	 constituentType = 30060 ;
	}

#paramId: 503545
#Kr85m - dry deposition
'503545' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 12 ;
	 constituentType = 30060 ;
	}

#paramId: 503546
#Averaged air concentration of Krypton 85m
'503546' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 constituentType = 30060 ;
	}

#paramId: 503547
#Accumulated air concentration of Krypton 85m
'503547' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 30060 ;
	}

#paramId: 503548
#Air concentration of Krypton 85m
'503548' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 constituentType = 30060 ;
	}

#paramId: 503549
#Swiss coordinate LV 95 (south-north)
'503549' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 200 ;
	}

#paramId: 503550
#Swiss coordinate LV 95 (west-east)
'503550' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 201 ;
	}

#paramId: 503551
#Birch (betula) pollen specific number concentration
'503551' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62101 ;
	}

#paramId: 503552
#Alder (alnus) pollen specific number concentration
'503552' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62100 ;
	}

#paramId: 503553
#Grasses (poaceae) pollen specific number concentration
'503553' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62300 ;
	}

#paramId: 503554
#Ragweed (ambrosia) pollen specific number concentration
'503554' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62200 ;
	}

#paramId: 503555
#Average hail diameter
'503555' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 238 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503556
#Standard deviation of hail diameter
'503556' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 238 ;
	 typeOfStatisticalProcessing = 6 ;
	}

#paramId: 503557
#Maximum hail diameter
'503557' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 238 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503558
#Duration of updraft
'503558' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 210 ;
	}

#paramId: 503559
#Updraft mask
'503559' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 211 ;
	}

#paramId: 503560
#Total lightning flash density - instantaneous
'503560' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503561
#Total lightning flash density - time average
'503561' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503563
#Temperature tendency perturbation due to stochastic model of model error
'503563' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 26 ;
	 typeOfGeneratingProcess = 221 ;
	}

#paramId: 503564
#Zonal wind tendency perturbation due to stochastic model of model error
'503564' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 39 ;
	 typeOfGeneratingProcess = 221 ;
	}

#paramId: 503565
#Meridional wind tendency perturbation due to stochastic model of model error
'503565' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 40 ;
	 typeOfGeneratingProcess = 221 ;
	}

#paramId: 503566
#Effective radius of cloud water
'503566' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 129 ;
	}

#paramId: 503567
#Effective radius of rain
'503567' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 130 ;
	}

#paramId: 503568
#Effective radius of cloud ice
'503568' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 131 ;
	}

#paramId: 503569
#Effective radius of snow
'503569' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 132 ;
	}

#paramId: 503570
#Effective radius of graupel
'503570' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 133 ;
	}

#paramId: 503571
#Effective radius of hail
'503571' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 134 ;
	}

#paramId: 503572
#Effective radius of subgrid liquid clouds
'503572' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 135 ;
	}

#paramId: 503573
#Effective radius of subgrid ice clouds
'503573' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 136 ;
	}

#paramId: 503574
#Effective aspect ratio of rain
'503574' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 137 ;
	}

#paramId: 503575
#Effective aspect ratio of cloud ice
'503575' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 138 ;
	}

#paramId: 503576
#Effective aspect ratio of snow
'503576' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 139 ;
	}

#paramId: 503577
#Effective aspect ratio of graupel
'503577' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 140 ;
	}

#paramId: 503578
#Effective aspect ratio of hail
'503578' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 141 ;
	}

#paramId: 503579
#Effective aspect ratio of subgrid ice clouds
'503579' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 142 ;
	}

#paramId: 503580
#Relative Humidity in lowest model layer - time-filtered assimilation increment
'503580' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503581
#Temperature in lowest model layer - time-filtered assimilation increment
'503581' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503582
#Frequency of winds in defined wind sector for defined time interval
'503582' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 0 ;
	 typeOfStatisticalProcessing = 11 ;
	 typeOfSecondFixedSurface = 233 ;
	 typeOfFirstFixedSurface = 233 ;
	}

#paramId: 503583
#Wind speed (time average)
'503583' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503584
#10m wind speed (time average)
'503584' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503585
#10m wind speed in wind sector (time average)
'503585' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfSecondFixedSurface = 233 ;
	 typeOfFirstFixedSurface = 233 ;
	}

#paramId: 503586
#10m wind speed in wind sector (time maximum)
'503586' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 233 ;
	 typeOfFirstFixedSurface = 233 ;
	}

#paramId: 503587
#Total cloud cover (time average)
'503587' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 1 ;
	 typeOfStatisticalProcessing = 0 ;
	}

#paramId: 503588
#Downward direct short-wave radiation flux at surface on a plane normal to the sun (time average)
'503588' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 206 ;
	}

#paramId: 503589
#Downward direct short-wave radiation flux at surface on a plane normal to the sun without orographic shading (time average)
'503589' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 207 ;
	}

#paramId: 503590
#Solar elevation angle
'503590' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 202 ;
	}

#paramId: 503591
#Solar azimuth angle
'503591' = {
	 discipline = 0 ;
	 parameterCategory = 191 ;
	 parameterNumber = 203 ;
	}

#paramId: 503592
#Turbulence intensity (time maximum)
'503592' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 236 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503593
#Clear-sky net solar radiation flux (at the surface)
'503593' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503594
#Clear-sky net thermal radiation flux (at the surface)
'503594' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503595
#Clear-sky net solar radiation flux (on model top)
'503595' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503596
#Clear-sky net thermal radiation flux (on model top)
'503596' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503597
#Clear-sky net solar radiation flux (at the surface) - time average
'503597' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503598
#Clear-sky net thermal radiation flux (at the surface) - time average
'503598' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503599
#Clear-sky net solar radiation flux (on model top) - time average
'503599' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503600
#Clear-sky net thermal radiation flux (on model top) - time average
'503600' = {
	 discipline = 0 ;
	 parameterCategory = 5 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503601
#TOA downward solar radiation (time average)
'503601' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 8 ;
	}

#paramId: 503602
#Volumetric saturation of soil moisture
'503602' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 16 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503603
#Soil water mass flux at layer interfaces (sum of conductive and diffusive fluxes)
'503603' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 201 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503604
#Ground water runoff rate, aquifer
'503604' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 195 ;
	 typeOfSecondFixedSurface = 106 ;
	 typeOfFirstFixedSurface = 106 ;
	}

#paramId: 503605
#Water table depth
'503605' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 177 ;
	}

#paramId: 503606
#Soil moisture saturation level
'503606' = {
	 discipline = 1 ;
	 parameterCategory = 0 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 177 ;
	}

#paramId: 503607
#Slope of orography (using average of maximum gradient in different directions)
'503607' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 198 ;
	}

#paramId: 503608
#Total column zonal water flux
'503608' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 236 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503609
#Total column meridional water flux
'503609' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 237 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503610
#Total column zonal water flux - time average
'503610' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 236 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503611
#Total column meridional water flux - time average
'503611' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 237 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 10 ;
	}

#paramId: 503612
#Number of active clouds per horizontal unit area
'503612' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 210 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503613
#Number of passive clouds per horizontal unit area
'503613' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 211 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503614
#Cloud base mass flux associated with active clouds
'503614' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 200 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503615
#Cloud base mass flux associated with passive clouds
'503615' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 199 ;
	 typeOfFirstFixedSurface = 2 ;
	}

#paramId: 503616
#Pressure in lowest model layer - time-filtered assimilation increment
'503616' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503617
#Maximum amplitude of updraft helicity in tropospheric column of low height
'503617' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 102 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 3000 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 503618
#Maximum amplitude of updraft helicity in tropospheric column of medium height
'503618' = {
	 discipline = 0 ;
	 parameterCategory = 7 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 102 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 5000 ;
	 typeOfFirstFixedSurface = 102 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2000 ;
	}

#paramId: 503619
#Single scan reflectivity - observation
'503619' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 200 ;
	 typeOfGeneratingProcess = 8 ;
	}

#paramId: 503620
#Single scan reflectivity - simulation
'503620' = {
	 discipline = 0 ;
	 parameterCategory = 16 ;
	 parameterNumber = 4 ;
	 typeOfFirstFixedSurface = 198 ;
	}

#paramId: 503621
#Large-scale precipitation rate
'503621' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 54 ;
	}

#paramId: 503622
#Lightning Potential Index from convection scheme, modified by convection index
'503622' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 193 ;
	}

#paramId: 503623
#Maximum Lightning Potential Index from convection scheme, modified by convection index
'503623' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503624
#Total lightning flash density - maximum
'503624' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 4 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfSecondFixedSurface = 8 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503625
#Mass median diameter of dust for mode 1
'503625' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 220 ;
	 constituentType = 62001 ;
	 modeNumber = 1 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503626
#Mass median diameter of dust for mode 2
'503626' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 220 ;
	 constituentType = 62001 ;
	 modeNumber = 2 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503627
#Mass median diameter of dust for mode 3
'503627' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 220 ;
	 constituentType = 62001 ;
	 modeNumber = 3 ;
	 typeOfDistributionFunction = 8 ;
	}

#paramId: 503628
#Smoke - high absorption (mass mixing ratio)
'503628' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62020 ;
	}

#paramId: 503629
#Smoke - high absorption (mass density)
'503629' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62020 ;
	}

#paramId: 503630
#Smoke - high absorption (specific number concentration)
'503630' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62020 ;
	}

#paramId: 503631
#Smoke - low absorption (mass mixing ratio)
'503631' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62021 ;
	}

#paramId: 503632
#Smoke - low absorption (mass density)
'503632' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62021 ;
	}

#paramId: 503633
#Smoke - low absorption (specific number concentration)
'503633' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62021 ;
	}

#paramId: 503634
#Sulphur dioxide (SO2) - volume mixing ratio
'503634' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 52 ;
	 constituentType = 8 ;
	}

#paramId: 503635
#Sulphur dioxide (SO2) - mass density
'503635' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 8 ;
	}

#paramId: 503636
#Hazel (corylus) pollen concentration
'503636' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 59 ;
	 constituentType = 62104 ;
	}

#paramId: 503637
#Fraction of land occupied by hazel (corylus)
'503637' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 4 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503638
#Number of hazel (corylus) pollen in the reservoir (previous timestep)
'503638' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 192 ;
	 constituentType = 62104 ;
	}

#paramId: 503639
#Number of hazel (corylus) pollen released into the reservoir (new)
'503639' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 constituentType = 62104 ;
	}

#paramId: 503640
#State of the hazel (corylus) season (eq.zero before and after season, the higher, the more plants are flowering)
'503640' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 194 ;
	 constituentType = 62104 ;
	}

#paramId: 503641
#Height correction for emission (decreasing emission with height) for hazel (corylus)
'503641' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 195 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503642
#Sum of released hazel (corylus) pollen into the reservoir (daily sum)
'503642' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 193 ;
	 typeOfStatisticalProcessing = 11 ;
	 constituentType = 62104 ;
	}

#paramId: 503643
#Precipitation reservoir (liquid water on the flowers, preventing them from flowering) of hazel (corylus)
'503643' = {
	 discipline = 2 ;
	 parameterCategory = 0 ;
	 parameterNumber = 13 ;
	 constituentType = 62104 ;
	}

#paramId: 503644
#Cumulated weighted 2m temperature sum of daily values for hazel (corylus) pollen
'503644' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 196 ;
	 constituentType = 62104 ;
	}

#paramId: 503645
#Cumulated 2m temperature sum threshold for the start of hazel (corylus) pollen season (climatological)
'503645' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 197 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503646
#Cumulated 2m temperature sum threshold for the end of hazel (corylus) pollen season (climatological)
'503646' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 198 ;
	 typeOfGeneratingProcess = 9 ;
	 constituentType = 62104 ;
	}

#paramId: 503647
#Number of days since the start of hazel (corylus) pollen season (if present day is in the season: zero outside season)
'503647' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 199 ;
	 constituentType = 62104 ;
	}

#paramId: 503648
#Length of hazel (corylus) pollen season
'503648' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 201 ;
	 constituentType = 62104 ;
	}

#paramId: 503649
#Pollen number emission flux for hazel (corylus)
'503649' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 202 ;
	 constituentType = 62104 ;
	}

#paramId: 503650
#Number of days since the start of hazel (corylus) pollen season (if present day is outside the season: length of current season)
'503650' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 200 ;
	 constituentType = 62104 ;
	}

#paramId: 503651
#Hazel (corylus) pollen specific number concentration
'503651' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62104 ;
	}

#paramId: 503652
#Emission tuning factor for birch (betula) pollen
'503652' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62101 ;
	}

#paramId: 503653
#Emission tuning factor for alder (alnus) pollen
'503653' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62100 ;
	}

#paramId: 503654
#Emission tuning factor for grasses (poaceae) pollen
'503654' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62300 ;
	}

#paramId: 503655
#Emission tuning factor for ragweed (ambrosia) pollen
'503655' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62200 ;
	}

#paramId: 503656
#Emission tuning factor for hazel (corylus) pollen
'503656' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 211 ;
	 constituentType = 62104 ;
	}

#paramId: 503657
#Temperature in lowest model layer - time-filtered assimilation increment, weighted with cos(2pi loc.time/day)
'503657' = {
	 discipline = 0 ;
	 parameterCategory = 0 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 208 ;
	}

#paramId: 503658
#Height of new snow (without settling)
'503658' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 207 ;
	}

#paramId: 503659
#Volumetric ice content of snow layer - multi level
'503659' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	 constituentType = 63000 ;
	}

#paramId: 503660
#Volumetric water content of snow layer - multi level
'503660' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	 constituentType = 62002 ;
	}

#paramId: 503661
#Volumetric air content of snow layer - multi level
'503661' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	 constituentType = 63001 ;
	}

#paramId: 503662
#Thickness of snow layer - multi level
'503662' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 11 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503663
#Number of snow layer - multi level
'503663' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 206 ;
	}

#paramId: 503664
#Snow temperature of layer (defined at layer top) - multi level
'503664' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 28 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503665
#Building area fraction (proportion: 0=no building, 1=whole urban area)
'503665' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 0 ;
	}

#paramId: 503666
#Street canyon aspect (height - width) ratio
'503666' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 1 ;
	}

#paramId: 503667
#Height of building
'503667' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 2 ;
	}

#paramId: 503668
#Urban material thermal albedo
'503668' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 3 ;
	}

#paramId: 503669
#Urban material shortwave (solar) albedo
'503669' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 4 ;
	}

#paramId: 503670
#Volumetric heat capacity of urban material (capacity x density)
'503670' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 5 ;
	}

#paramId: 503671
#Heat conductivity of urban material
'503671' = {
	 discipline = 2 ;
	 parameterCategory = 192 ;
	 parameterNumber = 6 ;
	}

#paramId: 503672
#Lightning Potential Index from convection scheme
'503672' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 5 ;
	}

#paramId: 503673
#Maximum Lightning Potential Index from convection scheme
'503673' = {
	 discipline = 0 ;
	 parameterCategory = 17 ;
	 parameterNumber = 5 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503674
#Wind speed in lowest model layer - time-filtered assimilation increment
'503674' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503675
#Eddy Dissipation Parameter
'503675' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 30 ;
	}

#paramId: 503676
#Icing Severity (0=None, 1=Trace, 2=Light, 3=Moderate, 4=Severe)
'503676' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 37 ;
	}

#paramId: 503677
#U-component surface Stokes drift
'503677' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 21 ;
	}

#paramId: 503678
#V-component surface Stokes drift
'503678' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 22 ;
	}

#paramId: 503679
#Peak wave direction
'503679' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 46 ;
	}

#paramId: 503680
#Significant wave height of first swell partition
'503680' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 47 ;
	}

#paramId: 503681
#Significant wave height of second swell partition
'503681' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 48 ;
	}

#paramId: 503682
#Significant wave height of third swell partition
'503682' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 49 ;
	}

#paramId: 503683
#Mean wave period of first swell partition
'503683' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 50 ;
	}

#paramId: 503684
#Mean wave period of second swell partition
'503684' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 51 ;
	}

#paramId: 503685
#Mean wave period of third swell partition
'503685' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 52 ;
	}

#paramId: 503686
#Mean wave direction of first swell partition
'503686' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 53 ;
	}

#paramId: 503687
#Mean wave direction of second swell partition
'503687' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 54 ;
	}

#paramId: 503688
#Mean wave direction of third swell partition
'503688' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 55 ;
	}

#paramId: 503689
#Diagnostic total mass concentration of mineral dust aerosol
'503689' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62001 ;
	}

#paramId: 503690
#Diagnostic total mass concentration of sea salt aerosol
'503690' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62008 ;
	}

#paramId: 503691
#Diagnostic total mass concentration of black carbon aerosol (soot)
'503691' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 0 ;
	 constituentType = 62009 ;
	}

#paramId: 503692
#Diagnostic black carbon aerosol (soot) optical depth
'503692' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 aerosolType = 62009 ;
	}

#paramId: 503693
#Total atmosphere optical depth due to mineral dust aerosol
'503693' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62001 ;
	}

#paramId: 503694
#Total atmosphere optical depth due to sea salt aerosol
'503694' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62008 ;
	}

#paramId: 503695
#Total atmosphere optical depth due to volcanic ash aerosol
'503695' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62025 ;
	}

#paramId: 503696
#Total atmosphere optical depth due to black carbon aerosol (soot)
'503696' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 102 ;
	 typeOfFirstFixedSurface = 10 ;
	 aerosolType = 62009 ;
	}

#paramId: 503697
#Modal prognostic mass mixing ratio of mineral dust aerosol (all modes)
'503697' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62001 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503698
#Modal prognostic mass mixing ratio of sea salt aerosol (all modes)
'503698' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62008 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503699
#Modal prognostic mass mixing ratio of black carbon aerosol (soot) (all modes)
'503699' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62009 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503700
#Modal prognostic specific number concentration of black carbon aerosol (soot) (all modes)
'503700' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62009 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503701
#Modal prognostic mass mixing ratio of volcanic ash aerosol (all modes)
'503701' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 2 ;
	 constituentType = 62025 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503702
#Modal prognostic specific number concentration of total aerosol (all modes)
'503702' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 60 ;
	 constituentType = 62000 ;
	 typeOfDistributionFunction = 7 ;
	}

#paramId: 503703
#Base reflectivity - low layer maximum
'503703' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 4 ;
	 typeOfSecondFixedSurface = 103 ;
	 scaleFactorOfSecondFixedSurface = 0 ;
	 scaledValueOfSecondFixedSurface = 500 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2500 ;
	}

#paramId: 503704
#Potential flight distance PFD (gliding)
'503704' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 240 ;
	}

#paramId: 503705
#Lifting ratio VST (gliding)
'503705' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 241 ;
	}

#paramId: 503706
#Sea water density
'503706' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 16 ;
	}

#paramId: 503707
#Sea water potential temperature
'503707' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 18 ;
	}

#paramId: 503708
#Sea water potential density
'503708' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 19 ;
	}

#paramId: 503709
#Sea water practical salinity
'503709' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 21 ;
	}

#paramId: 503710
#U-component of mean wind (vertical mean over specified layer)
'503710' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 212 ;
	}

#paramId: 503711
#V-component of mean wind (vertical mean over specified layer)
'503711' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 213 ;
	}

#paramId: 503712
#Extreme weather index of snow amount, grid-scale plus convective
'503712' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 240 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503713
#Extreme weather index of maximum Wind 10m
'503713' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 214 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503714
#Extreme weather index of total precipitation (Accumulation)
'503714' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 239 ;
	 typeOfStatisticalProcessing = 1 ;
	}

#paramId: 503715
#Cloud cover for use in radiative transfer (modified where large hydrometeors are present)
'503715' = {
	 discipline = 0 ;
	 parameterCategory = 6 ;
	 parameterNumber = 215 ;
	}

#paramId: 503716
#Snow temperature at node (i.e. at snow layer interface or boundary) - multi level
'503716' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 208 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503717
#Volumetric ice content of snow layer (for use in tile approach) - multi level
'503717' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 209 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503718
#Volumetric water content of snow layer (for use in tile approach) - multi level
'503718' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 210 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503719
#Volumetric air content of snow layer (for use in tile approach) - multi level
'503719' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 211 ;
	 typeOfSecondFixedSurface = 114 ;
	 typeOfFirstFixedSurface = 114 ;
	}

#paramId: 503720
#Probability for freezing precipitation/wet snow
'503720' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 242 ;
	}

#paramId: 503721
#Probability for freezing precipitation with wind
'503721' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 243 ;
	}

#paramId: 503722
#Diagnostic total column of mass concentration of mineral dust aerosol
'503722' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 1 ;
	 typeOfFirstFixedSurface = 10 ;
	 constituentType = 62001 ;
	}

#paramId: 503723
#Diagnostic vertical maximum total mass concentration of mineral dust aerosol in a layer
'503723' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 61 ;
	 constituentType = 62001 ;
	}

#paramId: 503724
#Diagnostic temporal maximum activity concentration of Caesium 137 in a time range
'503724' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30172 ;
	}

#paramId: 503725
#Diagnostic temporal maximum activity concentration of Iodine 131 in a time range
'503725' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30137 ;
	}

#paramId: 503726
#Diagnostic temporal maximum activity concentration of Caesium 137 in a time range and vertical maximum in a layer
'503726' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30172 ;
	}

#paramId: 503727
#Diagnostic temporal maximum activity concentration of Iodine 131 in a time range and vertical maximum in a layer
'503727' = {
	 discipline = 0 ;
	 parameterCategory = 18 ;
	 parameterNumber = 15 ;
	 typeOfStatisticalProcessing = 2 ;
	 constituentType = 30137 ;
	}

#paramId: 503728
#Total accumulated dry deposition (surface) of dust (sum of all modes)
'503728' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 6 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503729
#Total accumulated dust emission (sum of all modes)
'503729' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503730
#Total accumulated sedimentation of dust (sum of all modes)
'503730' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 11 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503731
#Total accumulated wet deposition of dust (sum of all modes)
'503731' = {
	 discipline = 0 ;
	 parameterCategory = 20 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 1 ;
	 constituentType = 62001 ;
	}

#paramId: 503732
#NowCastMIX-AutoWARN (Warnpolygone: Gewitter, Starkregen, Schnee, gefrierender Regen)
'503732' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 220 ;
	}

#paramId: 503733
#NowCastMIX-AutoWARN (Schneepolygon-Attribute)
'503733' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 221 ;
	}

#paramId: 503734
#NowCastMIX-Aviation (Konvektiver Status, Radolan-Gebiet)
'503734' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 222 ;
	}

#paramId: 503735
#NowCastMIX-Aviation (Konvektiver Status, EuCOM-Gebiet)
'503735' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 223 ;
	}

#paramId: 503736
#NowCastMIX-Winterwetter (Schnee, gefrierender Regen, Radolan-Gebiet)
'503736' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 224 ;
	}

#paramId: 503737
#Maximum total precipitation rate
'503737' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 2 ;
	}

#paramId: 503738
#Top of persistent contrails
'503738' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 48 ;
	}

#paramId: 503739
#Base of persistent contrails
'503739' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 49 ;
	}

#paramId: 503740
#NowCastMIX-AutoWARN (Gewitter-Warnkeulen mit variablen L??ngen)
'503740' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 225 ;
	}

#paramId: 503741
#NowCastMIX-Aviation (Starkregen, Radolan-Gebiet)
'503741' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 226 ;
	}

#paramId: 503742
#NowCastMIX-AutoWARN (Schneefallgrenze)
'503742' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 227 ;
	}

#paramId: 503743
#U-component of 10m wind - time average
'503743' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 2 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503744
#V-component of 10m wind - time average
'503744' = {
	 discipline = 0 ;
	 parameterCategory = 2 ;
	 parameterNumber = 3 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 10 ;
	}

#paramId: 503745
#Net short wave radiation flux at surface on horizontal plane including orographic shading
'503745' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503746
#Net short wave radiation flux at surface on tangent plane to terrain including orographic shading
'503746' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503747
#Upward diffusive short wave radiation flux at surface on horizontal plane including orographic shading
'503747' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503748
#Upward diffusive short wave radiation flux at surface on tangent plane to terrain including orographic shading
'503748' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503749
#Photosynthetically active radiation at surface on tangent plane to terrain including orographic shading
'503749' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503750
#Net short wave radiation flux at surface on horizontal plane including orographic shading - time average
'503750' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503751
#Net short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'503751' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 9 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503752
#Downward direct short wave radiation flux at surface on horizontal plane including orographic shading - time average
'503752' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503753
#Downward direct short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'503753' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 198 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503754
#Downward short wave radiation flux at surface on horizontal plane including orographic shading - time average
'503754' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503755
#Downward short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'503755' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 7 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503756
#Upward diffusive short wave radiation flux at surface on horizontal plane including orographic shading - time average
'503756' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 208 ;
	}

#paramId: 503757
#Upward diffusive short wave radiation flux at surface on tangent plane to terrain including orographic shading - time average
'503757' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 8 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503758
#Photosynthetically active radiation at surface on tangent plane to terrain including orographic shading - time average
'503758' = {
	 discipline = 0 ;
	 parameterCategory = 4 ;
	 parameterNumber = 10 ;
	 typeOfStatisticalProcessing = 0 ;
	 typeOfFirstFixedSurface = 209 ;
	}

#paramId: 503759
#Zonal component of sea water velocity (west-east direction counted positive)
'503759' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 23 ;
	}

#paramId: 503760
#Meridional component of sea water velocity (south-north direction counted positive)
'503760' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 24 ;
	}

#paramId: 503761
#Snow depth over sea ice (total depth)
'503761' = {
	 discipline = 10 ;
	 parameterCategory = 2 ;
	 parameterNumber = 192 ;
	}

#paramId: 503762
#Stretching factor of rescaled height coordinate zstar - ocean modelling
'503762' = {
	 discipline = 10 ;
	 parameterCategory = 192 ;
	 parameterNumber = 20 ;
	}

#paramId: 503763
#Mixed layer depth in ocean
'503763' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 52 ;
	}

#paramId: 503764
#Normal component of sea water velocity (normal in relation to local grid cell edge)
'503764' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 53 ;
	}

#paramId: 503765
#Temperature in lowest model layer - time-filtered assimilation increment, daytime weighting
'503765' = {
	 discipline = 0 ;
	 parameterCategory = 210 ;
	 parameterNumber = 0 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503766
#Relative Humidity in lowest model layer - time-filtered assimilation increment, daytime weighting
'503766' = {
	 discipline = 0 ;
	 parameterCategory = 210 ;
	 parameterNumber = 1 ;
	 typeOfSecondFixedSurface = 1 ;
	 typeOfFirstFixedSurface = 103 ;
	 typeOfGeneratingProcess = 207 ;
	}

#paramId: 503767
#NowCastMIX-Aviation-XL (Konvektiver Status, EuCOM-XL-Gebiet)
'503767' = {
	 discipline = 0 ;
	 parameterCategory = 15 ;
	 parameterNumber = 228 ;
	}

#paramId: 503768
#Mean mass diameter of cloud droplets (mean mass with respect to particle size distribution)
'503768' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 241 ;
	}

#paramId: 503769
#Mean mass diameter of rain (mean mass with respect to particle size distribution)
'503769' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 242 ;
	}

#paramId: 503770
#Mean mass diameter of cloud ice (mean mass with respect to particle size distribution)
'503770' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 243 ;
	}

#paramId: 503771
#Mean mass diameter of snow (mean mass with respect to particle size distribution)
'503771' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 244 ;
	}

#paramId: 503772
#Mean mass diameter of graupel (mean mass with respect to particle size distribution)
'503772' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 245 ;
	}

#paramId: 503773
#Cold-skin temperature deviation from analyzed sea-surface temperature (SST) at sea surface
'503773' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 193 ;
	 typeOfFirstFixedSurface = 160 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 503774
#Warm-layer temperature deviation from analyzed sea-surface temperature (SST) at sea surface
'503774' = {
	 discipline = 10 ;
	 parameterCategory = 3 ;
	 parameterNumber = 194 ;
	 typeOfFirstFixedSurface = 160 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 0 ;
	}

#paramId: 503775
#2m Temperature - time-filtered such that the diurnal cycle is partly smoothed out
'503775' = {
	 discipline = 0 ;
	 parameterCategory = 210 ;
	 parameterNumber = 2 ;
	 typeOfFirstFixedSurface = 103 ;
	 scaleFactorOfFirstFixedSurface = 0 ;
	 scaledValueOfFirstFixedSurface = 2 ;
	}

#paramId: 503776
#Saturated hydraulic conductivity of soil
'503776' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 212 ;
	}

#paramId: 503777
#Water retention curve of soil - inverse air entry suction (Mualem-Van-Genuchten alpha parameter)
'503777' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 213 ;
	}

#paramId: 503778
#Water retention curve of soil - pore-size distribution (Mualem-Van-Genuchten n parameter)
'503778' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 214 ;
	}

#paramId: 503779
#Volumetric air dryness point of soil
'503779' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 215 ;
	}

#paramId: 503780
#Volumetric field capacity of soil
'503780' = {
	 discipline = 2 ;
	 parameterCategory = 3 ;
	 parameterNumber = 216 ;
	}

#paramId: 503781
#Model level - height above mean sea level
'503781' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 33 ;
	 typeOfFirstFixedSurface = 150 ;
	}

#paramId: 503782
#Model level - height above ground level
'503782' = {
	 discipline = 0 ;
	 parameterCategory = 3 ;
	 parameterNumber = 34 ;
	 typeOfFirstFixedSurface = 150 ;
	}

#paramId: 503783
#Sea water turbulent kinetic energy
'503783' = {
	 discipline = 10 ;
	 parameterCategory = 4 ;
	 parameterNumber = 192 ;
	}

#paramId: 503784
#Mean mass diameter of hail (mean mass with respect to particle size distribution)
'503784' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 170 ;
	}

#paramId: 503785
#Time maximum of mean mass diameter of hail at surface
'503785' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 170 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503786
#Estimated maximum diameter of hail at surface (maximum estimated with respect to particle size distribution)
'503786' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 171 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503787
#Time maximum of estimated maximum diameter of hail at surface
'503787' = {
	 discipline = 0 ;
	 parameterCategory = 1 ;
	 parameterNumber = 171 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503788
#Hail kinetic energy flux at surface
'503788' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 52 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503789
#Time maximum of hail kinetic energy flux at surface
'503789' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 2 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503790
#Hail kinetic energy at surface (flux accumulated over time)
'503790' = {
	 discipline = 0 ;
	 parameterCategory = 19 ;
	 parameterNumber = 52 ;
	 typeOfStatisticalProcessing = 1 ;
	 typeOfFirstFixedSurface = 1 ;
	}

#paramId: 503791
#Wave energy spectral density of ocean surface gravity waves
'503791' = {
	 discipline = 10 ;
	 parameterCategory = 0 ;
	 parameterNumber = 42 ;
	}

